<?php
require_once('framework/ItemController.php');
require_once('plugins/banking/model/BankingServices.php');
require_once('plugins/banking/model/BankingPreferences.php');
require_once('plugins/banking/model/CancellistController.php');

require_class('RequestCast',
	'framework/util/request/RequestCast.class.php'); // added by Michael
/**
 * The Banking Controller
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Thomas Sterren - October 2004
 * @package org.brim-project.plugins.banking
 * @filesource
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class BankingController extends ItemController
{
	var $cancellistController;

	/**
	 * Constructor.
	 * Makes sure that the appropriate operations are instantiated.
	 * @param string renderEngineName the render engine that is used
	 * (either Smarty or phpSavant)
	 */
	function BankingController()
	{
		parent::ItemController();

		$this->operations = new BankingServices();
		$this->preferences = new BankingPreferences();
		$this->itemFactory = new BankingFactory();

		$this->pluginName = 'banking';
		$this->title = 'Brim - E-Banking';
		$this->itemName = 'Banking';
		$this->expandName = 'bankingExpand';

		$this->cancellistController = new CancellistController($this);
	}

	/**
 	 * Returns the actions defined for this item only
 	 *
 	 * @return array an array of item specific actions
	 * (like search, import etc.)
 	 */
	function getActions()
	{
		$actions=array();

		// Actions
		$actions[0]['name']='actions';
		$actions[0]['contents'][]=
					array('href' => 'BankingController.php?action=add',
						  'name' => 'add');
		$actions[0]['contents'][]=
					array('href' => 'BankingController.php?action=search',
						  'name' => 'search');

		// Sort
		$actions[1]['name']='sort';
		$actions[1]['contents'][]=
					array('href'=>'BankingController.php?action=sort&order=ASC&field=name',
						'name'=> 'name');
		$actions[1]['contents'][]=
					array('href'=>'BankingController.php?action=sort&order=ASC&field=url',
						'name'=> 'url');
		$actions[1]['contents'][]=
					array('href'=>'BankingController.php?action=sort&order=ASC&field=login',
						'name'=> 'login');

		// Preferences
		$actions[2]['name'] = 'preferences';
		$actions[2]['contents'][] =
			array ('href' => 'BankingController.php?action=modifyPreferencesPre',
				   'name' => 'modify');

		// help
		$actions[3]['name'] = 'help';
		$actions[3]['contents'][] =
				array ('href' => 'BankingController.php?action=help',
					   'name' => 'help');

		return $actions;
	}

	/**
	 * Activate. Basically this means that the appropriate actions
	 * are executed and an optional result is returned
	 * to be processed/displayed
	 */
	function activate()
	{
		switch ($this->getAction())
		{
			case "add":
				$this->addAction();
				break;
			case "modify":
				$this->modifyAction();
				break;
			case "deleteItemPost":
				$this->deleteItemAction();
				$this->getShowItemsParameters();
				break;
			case "addItemPost":
				$this->addItemAction();
				break;
			case "search":
				$this->renderer = $this->getAction().'Banking';
				break;
			case "searchInEBanking":
				$this->searchItemAction();
				break;
			case "modifyItemPost":
				$this->modifyItemAction();
				$this->getShowItemsParameters();
				break;
			case "help":
				$this->helpAction();
				break;
			case "sort":
				$field = $_GET['field'];
				$order = $_GET['order'];
				$this->sortAllAction ($field, $order);
				break;
			case "modifyPreferencesPre":
				$this->renderObjects =
					$this->preferences->getAllPreferences($this->getUserName());
				$this->renderer = 'modifyPreferences';
				break;
			case "modifyPreferencesPost":
				$this->preferences->setPreference($this->getUserName(),
												  $_POST['name'],
												  $_POST['value']);
				$_SESSION['bankingOverlib'] =
						$this->preferences->getOverlib($this->getUserName(),
													   'bankingOverlib');
				$_SESSION['bankingOpenURLinNewWindow'] =
						$this->preferences->getOpenURLinNewWindow($this->getUserName(),
																  'bankingOpenURLinNewWindow');
				$this->renderer = 'modifyPreferences';
				$this->renderObjects = $_SESSION;
				break;
			case "modifyAcceptDisclaimerPost":
				if (isset($_POST['value']) &&
					$_POST['value'] = 'accepted')
				{
					$this->preferences->setPreference($this->getUserName(),
													  $this->preferences->DISCLAIMER,
												 	  $_POST['value']);
					$this->getShowItemsParameters();
				}
				break;
			case "showItem":	// Is the same like showCancellists
				// This action is only called from the Dashboard.
				// Give the itemId to the cancellistController and
				// call its activate function
				$this->cancellistController->bankId = $this->itemId;
			case "showCancellists":
			case "addCancellist":
			case "addCancellistPost":
			case "modifyCancellist":
			case "modifyCancellistPost":
			case "showCancellist":
			case "deleteCancellistPost":
			case "sortCancellists":
            case "cancelCancellist":

			case "showSecrets":
			case "addSecret":
			case "addSecretPost":
			case "setSecretUsed":
			case "modifySecret":
			case "modifySecretPost":
			case "showSecret":
			case "deleteSecretPost":
			case "sortSecrets":
            case "cancelSecret":
				$this->cancellistController->activate();
				break;
			default:
				$this->getShowItemsParameters();
				break;
		}
	}

	function display()
	{
		switch ($this->getAction())
		{
		case "showItem":
		case "showCancellists":
		case "addCancellist":
		case "addCancellistPost":
		case "modifyCancellist":
		case "modifyCancellistPost":
		case "showCancellist":
		case "deleteCancellistPost":
		case "sortCancellists":
        case "cancelCancellist":

		case "showSecrets":
		case "addSecret":
		case "addSecretPost":
		case "setSecretUsed":
		case "modifySecret":
		case "modifySecretPost":
		case "showSecret":
		case "deleteSecretPost":
		case "sortSecrets":
        case "cancelSecret":
			$this->cancellistController->display();
			break;
		default:
			$this->addParameter('openURLinNewWindow',
					$this->preferences->getOpenURLinNewWindow());
			parent::display();
		}
	}

	function getShowPrivateItemsParameters()
	{
		$this->renderer = 'show'.$this->getItemName().'s';
		$rootItems = $this->operations->getChildren
			($this->getUserName(), $this->getParentId());

		$this->renderObjects = $rootItems;
	}

	/**
	 * Search for items
	 */
	function searchItemAction ()
	{
		$fields[0] = $_POST['field1'];
		$fields[1] = $_POST['field2'];
		$fields[2] = $_POST['field3'];
		$fields[3] = $_POST['field4'];
		$fields[4] = $_POST['field5'];
		$fields[5] = $_POST['field6'];

		$items = $this->operations->searchExpressionInMultibleFielsItems($this->getUserName(),
																		 $fields,
																		 $_POST['value']);

		$this->renderObjects = $items;
		$this->renderer = 'show'.$this->getItemName ().'s';
	}
}
?>
