<?php

require_once 'framework/Installer.php';

/**
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Thomas Sterren - January 2006
 * @package org.brim-project.plugins.banking
 * @subpackage model
 * @filesource
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class BankInstaller extends Installer
{
	function BankInstaller($engine, $db)
	{
		$this->tableName = 'brim_bk_banks';
		parent::Installer($engine, $db);
	}

	function install()
	{
		if (!$this->findTable ())
		{
			$dbFile = 'plugins/banking/sql/create.';
			$dbFile .= $this->engine;
			$dbFile .= '.brim_bk_banks.sql';
			$this->createTable($dbFile);
			$this->createStandardIndex();
		}
		else
		{
			if (!$this->isTableUpToDate ())
			{
				die ('Table '.$this->tableName.' found but does not appear to be up-to-date and no upgrade procedure is found!');
			}
		}
	}

	function isTableUpToDate()
	{
		if (!$this->findTable ())
		{
			return false;
		}
		$columnNames =
			$this->db->MetaColumnNames($this->tableName, true);

		$this->tableUpToDate =
			(count($columnNames) == 16 &&
			$columnNames[ 0] == 'item_id' &&
			$columnNames[ 1] == 'owner' &&
			$columnNames[ 2] == 'parent_id' &&
			$columnNames[ 3] == 'is_parent' &&
			$columnNames[ 4] == 'name' &&
			$columnNames[ 5] == 'description' &&
			$columnNames[ 6] == 'visibility' &&
			$columnNames[ 7] == 'category' &&
			$columnNames[ 8] == 'is_deleted' &&
			$columnNames[ 9] == 'when_created' &&
			$columnNames[10] == 'when_modified' &&

			$columnNames[11] == 'guid' &&
			$columnNames[12] == 'login' &&
			$columnNames[13] == 'url' &&
			$columnNames[14] == 'contact_person' &&
			$columnNames[15] == 'contact_phone');

		return $this->tableUpToDate;
	}

	function getColumnsCount($tableName)
	{
		$columnNames =
			$this->db->MetaColumnNames($this->tableName, true);

		return count($columnNames);
	}

	function createStandardIndex()
	{
		$indexName = $this->tableName . '_index';

		$primaryKeys = $this->db->MetaIndexes($this->tableName);

		if (!array_key_exists($indexName, $primaryKeys))
		{
			$query = 'CREATE INDEX '.$this->tableName.'_index ';
			$query .= 'ON '.$this->tableName.' ';
			$query .= '(owner, name(32), login)';

			if (!$this->db->Execute ($query))
			{
				echo ('Error creating index. The database reported the following problem: ');
				echo ('<code>'.$this->db->ErrorMsg().'</code><br />');
				echo ('Indexes are not required so I will just continue....<br />');
			}
		}
	}
}
?>