<?php

require_once('framework/model/ItemFactory.php');
require_once('plugins/banking/model/Banking.php');

require_class('BankingRequestCast', 'plugins/banking/util/request/BankingRequestCast.php');
require_class('ClassHelper', 'framework/util/ClassHelper.class.php');

/**
 * BankingFactory
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Thomas Sterren - October 2004
 * @package org.brim-project.plugins.banking
 * @subpackage model
 * @filesource
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class BankingFactory extends ItemFactory
{
	/**
	 * Default constructor
	 */
	function BankingFactory()
	{
		parent::ItemFactory();
		$this->requestCast = new BankingRequestCast("Banking");
	}


	/**
	 * Returns the type of this specific item
	 * @return string the type of this specific item:
	 * <code>Banking</code>
	 */
	function getType()
	{
		return "Banking";
	}

	function requestToItem()
	{
		$itemId = $this->getFromPost('itemId', 0);
		$owner = $_SESSION['brimUsername'];
		$parentId = $this->getFromPost('parentId', 0);
		$isParent = $this->getFromPost('isParent', 0);
		$name =
			$this->stringUtils->gpcStripSlashes($_POST['name']);
		$description = $this->getFromPost('description', null);
		$visibility = $this->getFromPost('visibility', 'private');
		$category = $this->getFromPost('category', null);
		$isDeleted = $this->getFromPost('isDeleted', 0);
		$when_created = $this->getFromPost('when_created', null);
		$when_modified = $this->getFromPost('when_modified', null);
		$when_visisted = $this->getFromPost('when_visited', null);
		$guid = $this->createGUID();
		$login = $this->getFromPost('login', '');
		$url = $this->getFromPost('url', '');
		$contact_person = $this->getFromPost('contact_person', '');
		$contact_phone = $this->getFromPost('contact_phone', '');

		$item = new Banking($itemId,
							$owner,
							$parentId,
							$isParent,
							$name,
							$description,
							$visibility,
							$category,
							$isDeleted,
							$when_created,
							$when_modified,
							$guid,
							$login,
							$url,
							$contact_person,
							$contact_phone);
		return $item;
	}

	/**
	 * Factory method: Returns a database result into an item
	 *
	 * @param object result the result retrieved from the database
	 * @return array the items constructed from the database resultset
	 */
	function resultsetToItems($result)
	{
		$items = array();

		while (!$result->EOF)
		{
			$item = new Banking(
				$result->fields['item_id'],
				trim ($result->fields['owner']),
				$result->fields['parent_id'],
				$result->fields['is_parent'],
				trim($this->stringUtils->gpcStripSlashes
					($result->fields['name'])),
				$this->stringUtils->gpcStripSlashes
					($result->fields['description']),
				trim ($result->fields['visibility']),
				trim ($result->fields['category']),
				$result->fields['is_deleted'],
				$result->fields['when_created'],
				$result->fields['when_modified'],
				trim($result->fields['guid']),
				trim($result->fields['login']),
				trim($result->fields['url']),
				trim($result->fields['contact_person']),
				trim($result->fields['contact_phone']));

			$items[] = $item;

			$result->MoveNext();
		}
		return $items;
	}

	/**
	 * Returns an empty item
	 * @return object an empty item, all values
	 * set to -null-
	 */
	function getEmptyItem()
	{
		$item = new Bookmark(null, null, null, null,
			 				 null, null, null, null,
			 				 null, null, null, null,
			 				 null, null, null, null);
		return $item;
	}


	/**
	 * Generates a GUID (Global Unique Identifier). Used to identify an
	 * record in a table.
	 */
	function createGUID()
	{
		return md5(uniqid(rand()));
	}
}
?>