<?php
require_once('framework/ItemController.php');
require_once('plugins/banking/model/CancellistServices.php');
require_once('plugins/banking/model/BankingPreferences.php');
require_once('plugins/banking/model/SecretController.php');

/**
 * The Cancellist Controller
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Thomas Sterren - October 2004
 * @package org.brim-project.plugins.banking
 * @subpackage model
 * @filesource
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class CancellistController extends ItemController
{
	var $bankId;
	var $secretController;
	var $bankController;

	/**
	 * Constructor.
	 * Makes sure that the appropriate operations are instantiated.
	 * @param string renderEngineName the render engine that is used
	 * (either Smarty or phpSavant)
	 */
	function CancellistController(&$theBankController)
	{
		parent::ItemController();

		$this->bankController = &$theBankController;
		$this->secretController = new SecretController($theBankController);

		$this->operations = &$theBankController->operations->cancellistServices;
		$this->preferences = new BankingPreferences();
		$this->itemFactory = new CancellistFactory();

		$this->pluginName = 'banking';
		$this->title = 'Brim - E-Banking';
		$this->itemName = 'Cancellist';
		$this->expandName = 'cancellistExpand';

		//
		// Fetch the bankId parameter
		//
		if (isset ($_GET['bankId']))
		{
			$this->bankId = $_GET['bankId'];
		}
		else if (isset ($_POST['bankId']))
		{
			$this->bankId = $_POST['bankId'];
		}
	}

	/**
 	 * Returns the actions defined for this item only
 	 *
 	 * @return array an array of item specific actions
	 * (like search, import etc.)
 	 */
	function getActions()
	{
		//
		// Actions
		//
		$actions[0]['name']='actions';
		$actions[0]['contents'][]=
					array('href' => 'BankingController.php?action=addCancellist&bankId='.$this->getBankId(),
						'name' => 'addCancellist');
		//
		// Sort
		//
		$actions[1]['name']='sort';
		$actions[1]['contents'][]=
					array('href'=>'BankingController.php?action=sortCancellists&order=ASC&field=name&bankId='.$this->getBankId(),
						'name'=> 'cancellistName');

		// Preferences
		$actions[2]['name'] = 'preferences';
		$actions[2]['contents'][] =
			array('href' => 'BankingController.php?action=modifyPreferencesPre',
				  'name' => 'modify');

		// help
		$actions[3]['name'] = 'help';
		$actions[3]['contents'][] =
			array('href' => 'BankingController.php?action=help',
				  'name' => 'help');

		return $actions;
	}

	/**
	 * Activate. Basically this means that the appropriate actions
	 * are executed and an optional result is returned
	 * to be processed/displayed
	 */
	function activate()
	{
		switch ($this->getAction())
		{
			case "showSecrets":
			case "addSecret":
			case "addSecretPost":
			case "setSecretUsed":
			case "modifySecret":
			case "modifySecretPost":
			case "showSecret":
			case "deleteSecretPost":
			case "sortSecrets":
            case "cancelSecret":
				$this->secretController->activate();
				break;
			case "addCancellist":
				$this->addAction();
				break;
			case "showCancellist":
				$this->showAction();
				break;
			case "modifyCancellist":
				$this->modifyAction();
				break;
			case "modifyCancellistPost":
				$this->modifyItemAction();
				$this->getShowItemsParameters();
				break;
			case "deleteCancellistPost":
				$this->deleteItemAction();
				$this->getShowItemsParameters();
				break;
			case "addCancellistPost":
				$this->addItemAction();
				break;
			case "sortCancellists":
				$bankId = $_GET['bankId'];
				$field = $_GET['field'];
				$order = $_GET['order'];
				$this->sortAction($bankId, $field, $order);
				break;
			case "showCancellists":
			default:
				$this->getShowItemsParameters();
				break;
		}
	}

	function display()
	{
		switch ($this->getAction())
		{
		case "showSecrets":
		case "addSecret":
		case "addSecretPost":
		case "setSecretUsed":
		case "modifySecret":
		case "modifySecretPost":
		case "showSecret":
		case "deleteSecretPost":
		case "sortSecrets":
        case "cancelSecret":
			$this->secretController->display();
			break;
		default:
			$this->renderEngine->assign('bank',
					$this->bankController->getItem($this->getUserName(),
												   $this->getBankId()));
			$this->addParameter('openURLinNewWindow',
					$this->preferences->getOpenURLinNewWindow());
			parent::display();
		}
	}

	function addAction()
	{
		$this->addParameterAncestors();

		parent::addAction();

	}

	function modifyAction()
	{
		$this->addParameterAncestors();

		parent::modifyAction();

	}

	function showAction()
	{
		$this->addParameterAncestors();
		parent::showAction();

	}

	function getShowItemsParameters()
	{
		$this->addParameterAncestors();

		if($this->navigationMode == 'public')
		{
			return $this->getShowPublicItemsParameters();
		}
		else
		{
			return $this->getShowPrivateItemsParameters();
		}
	}

	/**
	 * Sorts the items based on specified criteria
	 *
	 * @param integer parentId the id of the parent of which we
	 * 		would like to sort items
	 * @param string field the field on which we would like to sort
	 * @param string sortOrder either <code>ASC</code> or
	 * 		<code>DESC</code>
	 */
	function sortAction($parentId, $field, $sortOrder)
	{
		$this->addParameterAncestors();

		parent::sortAction($parentId, $field, $sortOrder);
	}

	function getShowPrivateItemsParameters()
	{
		$this->renderer = 'show'.$this->getItemName().'s';
		$rootItems = $this->operations->
						getChildren($this->getUserName(),
									$this->getBankId());

		$this->renderObjects = $rootItems;
	}

	function getBankId()
	{
		return $this->bankId;
	}

	function addParameterAncestors()
	{
		// These 3 lines are used to provide the complete path of
		// items, from current up to root
		$currentBank = $this->bankController->operations->
							getItem($this->getUserName(),
									$this->getBankId());
		$ancestors[] = $currentBank;
		$this->addParameter("ancestors", array_reverse($ancestors));
	}
}
?>