<?php

require_once('plugins/banking/model/Cancellist.php');
require_once('plugins/banking/model/CancellistFactory.php');
require_once('framework/model/Services.php');
require_once('plugins/banking/model/SecretServices.php');

/**
 * Services for Cancellist
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Thomas Sterren - December 2004
 * @package org.brim-project.plugins.banking
 * @subpackage model
 * @filesource
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class CancellistServices extends Services
{
	var $secretServices;

	/**
	 * Default constructor
	 */
	function CancellistServices()
	{
		parent::Services();
		$this->itemFactory = new CancellistFactory();

		$this->secretServices = new SecretServices();

		include ('plugins/banking/sql/cancellistQueries.php');
		$this->queries = $queries;
	}

	/**
	 * Adds a cancellist
	 *
	 * @param integer userId the identifier for the user
	 * @param object item cancellist to be added
	 *
     * @return integer last know id. This is the id of the cancellist
	 * that was newly inserted and for which an id has automatically
	 * been assigned.
	 */
	function addItem($userId, $item)
	{
		if ($item->bankId == 0 ||
			!$item->isValid())
		{
			return;
		}

		$now = date("Y-m-d H:i:s");

		if (!isset($item->guid))
		{
			$item->guid = $this->itemFactory->createGUID();
		}

		// execute the query
		$query = sprintf($this->queries['addItem'],
						 $userId,
						 addslashes($item->parenId),
						 addslashes($item->isParent),
						 addslashes(trim($item->name)),
						 addslashes(trim($item->description)),
						 addslashes($item->visibility),
						 addslashes($item->category),
						 addslashes($now),
						 addslashes($item->bankId),
						 $item->guid);

		$this->db->Execute($query) or
				die ("Could not add cancellist.".
				$this->db->ErrorMsg () . " " . $query . '<br />');

		// fetch the last known id
		// todo this is generic code and is candidate to move to the base Services class
		$query = $this->queries['lastItemInsertId'];
		$result = $this->db->Execute($query) or
			die ("Could not retrieve last insert id for cancellist. ".
			$this->db->ErrorMsg () . " " . $query . '<br />');

        return $result->fields[0];
	}

	/**
	 * Modifies a cancellist
	 *
 	 * @param integer userId the identifier for the user who modifies a cancellist
	 * @param object item the modified cancellist
	 */
	function modifyItem($userId, $item)
	{
		//die ("CancellistService::modifyItem ".bprint_r($item));
		$now = date ("Y-m-d H:i:s");

		$query = sprintf ($this->queries['modifyItem'],
			$now,							// when_modified
			addslashes($item->name),
			addslashes(trim($item->description)),
			$item->isDeleted,
			$item->itemId);

		$this->db->Execute($query)
			or die ("Error modifying item cancellist: " .
	 		$this->db->ErrorMsg() . " " . $query . '<br />');
	}

	function deleteItem($userId, $itemId)
	{
		$item = $this->getItem($userId, $itemId);

		if (isset($item))
		{
			// if the cancellist has secrets attached, delete
			// the secret as well
			$this->secretServices->deleteItems($userId, $itemId);

			// now delete the specific item
			$query = sprintf($this->queries['deleteItem'], $itemId);

			$result = $this->db->Execute($query) or
				die("CancellistServices::DeleteItem: " .
				$this->db->ErrorMsg() . " " . $query. '<br />');
		}
	}

	function deleteItems($userId, $bankId)
	{
		// Get the cancellists for the bank
		$items = $this->getChildren($userId, $bankId);

		for ($i = 0; $i < count($items); $i++)
		{
			// Delete the cancellist with its secrets.
			$this->deleteItem($userId, $items[$i]->itemId);
		}
	}

	function getParent($item)
	{
		if (!isset($item) && $item->bankId != 0)
		{
			$query = sprintf($this->queries['getBank'],
							 $item->owner);
			$result = $this->db->Execute($query)
				or die ("getParent failed ".
					$this->db->ErrorMsg () . " " . $query . '<br />');

			$items = $this->bankingController->operations->
						itemFactory->resultsetToItems($result);

			if (count($items) == 0)
			{
				return null;
			}
			else
			{
				return $items[0];
			}
		}
		else
		{
			return null;
		}
	}

	function getChildren($userId, $bankId)
	{
		// sterry temp
		if ($bankId == 0)
		{
			return null;
		}
		else
		{
			$query = sprintf ($this->queries ['getItemChildren'], $bankId, $userId);
		}
		$result = $this->db->Execute ($query) or die
			("Operations. GetChildren " . $this->db->ErrorMsg () .
				" Error getting children: " . $query);
		$items = $this->itemFactory->resultsetToItems($result);

		$this->addSecretCountToItems($userId, $items);

		if ($items == null)
		{
			return null;
		}
		else if ($items[0]->owner == $userId)
		{
			return $items;
		}
		else
		{
			die ("Not owner?");
		}
	}

	/**
	 * Retrieves all items for a user, sorted by the indicated value
	 * @param integer userId the identifier for the user
	 * @param integer parentId the identifier of the parent folder in
	 * 		which we would like to sort
	 * @param string field the field on which we would like to sort
	 * @return array an array of the sorted items
	 */
	function getSortedItems ($userId, $parentId, $field, $sortOrder)
	{
		$query = sprintf
			($this->queries['getSortedItems'], $userId, $parentId,
				$field, $sortOrder);
		$result = $this->db->Execute($query) or
			die("GetSortedItems: " . $this->db->ErrorMsg());

		$items =  $this->itemFactory->resultsetToItems($result);

		$this->addSecretCountToItems($userId, $items);

		return $items;
	}

	function addSecretCountToItems($userId, &$items)
	{
		if (isset($items))
		{
			if (is_array($items))
			{
				for ($i = 0; $i < count($items); $i++)
				{
					$items[$i]->secretCount = $this->secretServices->
							getSecretCount($userId, $items[$i]->itemId, false);
					$items[$i]->secretNotUsedCount = $this->secretServices->
							getSecretCount($userId, $items[$i]->itemId, true);
				}
			}
			else if (is_object($items))
			{
				$items->secretCount = $this->secretServices->
						getSecretCount($userId, $items->itemId, false);
				$items->secretNotUsedCount = $this->secretServices->
						getSecretCount($userId, $items->itemId, true);
			}
		}
	}
}
?>
