<?php
require_once('framework/ItemController.php');
require_once('plugins/banking/model/SecretServices.php');
require_once('plugins/banking/model/BankingPreferences.php');

/**
 * The Secret Controller
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Thomas Sterren - October 2004
 * @package org.brim-project.plugins.banking
 * @subpackage model
 * @filesource
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class SecretController extends ItemController
{
	var $cancellistId;
	var $bankController;

	/**
	 * Constructor.
	 * Makes sure that the appropriate operations are instantiated.
	 * @param string renderEngineName the render engine that is used
	 * (either Smarty or phpSavant)
	 */
	function SecretController(&$theBankController)
	{
		parent::ItemController();

		$this->bankController = &$theBankController;

		$this->operations = &$theBankController->operations->cancellistServices->secretServices;
		$this->preferences = new BankingPreferences();
		$this->itemFactory = new SecretFactory();

		$this->pluginName = 'banking';
		$this->title = 'Brim - E-Banking';
		$this->itemName = 'Secret';
		$this->expandName = 'secretExpand';

		//
		// Fetch the cancellistId parameter
		//
		if (isset($_GET['cancellistId']))
		{
			$this->cancellistId = $_GET['cancellistId'];
		}
		else if (isset($_POST['cancellistId']))
		{
			$this->cancellistId = $_POST['cancellistId'];
		}
	}

	/**
 	 * Returns the actions defined for this item only
 	 *
 	 * @return array an array of item specific actions
	 * (like search, import etc.)
 	 */
	function getActions()
	{
		//
		// Actions
		//
		$actions[0]['name']='actions';
		$actions[0]['contents'][]=
					array('href' => 'BankingController.php?action=addSecret&cancellistId='.$this->getCancellistId(),
						'name' => 'addSecret');
		//
		// Sort
		//
		$actions[1]['name']='sort';
		$actions[1]['contents'][]=
					array('href'=>'BankingController.php?action=sortSecrets&cancellistId='.$this->getCancellistId().'&order=ASC&field=number',
						'name'=> 'number');
		$actions[1]['contents'][]=
					array('href'=>'BankingController.php?action=sortSecrets&cancellistId='.$this->getCancellistId().'&order=ASC&field=secret',
						'name'=> 'secret');
		$actions[1]['contents'][]=
					array('href'=>'BankingController.php?action=sortSecrets&cancellistId='.$this->getCancellistId().'&order=ASC&field=when_used',
						'name'=> 'when_used');

		// Preferences
		$actions[2]['name'] = 'preferences';
		$actions[2]['contents'][] =
			array('href' => 'BankingController.php?action=modifyPreferencesPre',
				  'name' => 'modify');

		// help
		$actions[3]['name'] = 'help';
		$actions[3]['contents'][] =
			array('href' => 'BankingController.php?action=help',
				  'name' => 'help');

		return $actions;
	}

	/**
	 * Activate. Basically this means that the appropriate actions
	 * are executed and an optional result is returned
	 * to be processed/displayed
	 */
	function activate()
	{
		switch ($this->getAction())
		{
			case "addSecret":
				$this->addAction();
				break;
			case "showSecret":
				$this->showAction();
				break;
			case "modifySecret":
				$this->modifyAction();
				break;
			case "modifySecretPost":
				$this->modifyItemAction();
				$this->getShowItemsParameters();
				break;
			case "deleteSecretPost":
				$this->deleteItemAction();
				$this->getShowItemsParameters();
				break;
			case "setSecretUsed":
				$this->setSecretUsed();
				$this->getShowItemsParameters();
				break;
			case "addSecretPost":
				$this->addItemAction();
				break;
			case "sortSecrets":
				$cancellistId = $_GET['cancellistId'];
				$field = $_GET['field'];
				$order = $_GET['order'];
				$this->sortAction($cancellistId, $field, $order);
				break;
			case "showSecrets":
			default:
				$this->getShowItemsParameters();
				break;
		}
	}

	function display()
	{
		switch ($this->getAction())
		{
		case "showSecrets":
		case "modifySecretPost":
		case "addSecretPost":
		case "setSecretUsed":
		case "deleteSecretPost":
		case "sortSecrets":
        case "cancelSecret":
			$cancellistItem = $this->bankController->cancellistController->
								getItem($this->getUserName(),
										$this->getCancellistId());
			$bankItem = $this->bankController->
								getItem($this->getUserName(),
										$cancellistItem->bankId);
			$this->renderEngine->assign('bankItem',
										$bankItem);
			$this->renderEngine->assign('cancellistItem',
										$cancellistItem);
		default:
			$this->addParameter('openURLinNewWindow',
						$this->preferences->getOpenURLinNewWindow());
			parent::display();
		}
	}

	function addAction()
	{
		$this->addParameterAncestors();

		parent::addAction();

	}

	function modifyAction()
	{
		$this->addParameterAncestors();

		parent::modifyAction();

	}

	function showAction()
	{
		$this->addParameterAncestors();

		parent::showAction();

	}

	function getShowItemsParameters()
	{
		$this->addParameterAncestors();

		if($this->navigationMode == 'public')
		{
			return $this->getShowPublicItemsParameters();
		}
		else
		{
			return $this->getShowPrivateItemsParameters();
		}
	}

	/**
	 * Sorts the items based on specified criteria
	 *
	 * @param integer parentId the id of the parent of which we
	 * 		would like to sort items
	 * @param string field the field on which we would like to sort
	 * @param string sortOrder either <code>ASC</code> or
	 * 		<code>DESC</code>
	 */
	function sortAction($parentId, $field, $sortOrder)
	{
		$this->addParameterAncestors();

		parent::sortAction($parentId, $field, $sortOrder);
	}

	function getShowPrivateItemsParameters()
	{
		$this->renderer = 'show'.$this->getItemName().'s';
		$rootItems = $this->operations->
						getChildren($this->getUserName(),
									$this->getCancellistId());

		$this->renderObjects = $rootItems;
	}

	function setSecretUsed()
	{
		$this->operations->setSecretUsed($this->itemId);
	}

	function getCancellistId()
	{
		return $this->cancellistId;
	}

	function addParameterAncestors()
	{
		// These 3 lines are used to provide the complete path of
		// items, from current up to root
		$currentCancellist = $this->bankController->cancellistController->operations->
							getItem($this->getUserName(),
									$this->getCancellistId());
		$ancestors[] = $currentCancellist;
		$ancestors[] = $this->bankController->operations->
							getItem($this->getUserName(),
									$currentCancellist->bankId);
		$this->addParameter("ancestors", array_reverse($ancestors));
	}
}
?>