<?php

require_once('plugins/banking/model/Secret.php');
require_once('plugins/banking/model/SecretFactory.php');
require_once('framework/model/Services.php');

/**
 * Services for Secret
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Thomas Sterren - December 2004
 * @package org.brim-project.plugins.banking
 * @subpackage model
 * @filesource
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class SecretServices extends Services
{

	/**
	 * Default constructor
	 */
	function SecretServices()
	{
		parent::Services();
		$this->itemFactory = new SecretFactory();

		include ('plugins/banking/sql/secretQueries.php');
		$this->queries = $queries;
	}

	/**
	 * Adds a secret
	 *
	 * @param integer userId the identifier for the user
	 * @param object item the secret to be added
	 *
     * @return integer last know id. This is the id of the secret
	 * that was newly inserted and for which an id has automatically
	 * been assigned.
	 */
	function addItem($userId, $item)
	{
		if ($item->cancellistId == 0 ||
			!$item->isValid())
		{
			return;
		}

		$now = date("Y-m-d H:i:s");

		if (!isset($item->guid))
		{
			$item->guid = $this->itemFactory->createGUID();
		}

		// execute the query
		$query = sprintf($this->queries['addItem'],
			$userId,
			addslashes(trim($item->parentId)),
			addslashes(trim($item->isParent)),
			addslashes(trim($item->name)),
			addslashes(trim($item->description)),
			addslashes(trim($item->visibility)),
			addslashes(trim($item->category)),
			$now,
			$item->cancellistId,
			$item->guid,
			addslashes(trim($item->number)),
			addslashes(trim($item->secret)));

		$this->db->Execute($query) or
				die ("Could not add secret.".
				$this->db->ErrorMsg () . " " . $query . '<br />');

		// fetch the last known id
		// todo this is generic code and is candidate to move to the base Services class
		$query = $this->queries['lastItemInsertId'];
		$result = $this->db->Execute($query) or
			die ("Could not retrieve last insert id for secret. ".
			$this->db->ErrorMsg () . " " . $query . '<br />');

        return $result->fields[0];
	}

	/**
	 * Modifies a secret
	 *
 	 * @param integer userId the identifier for the user who modifies a secret
	 * @param object item the modified secret
	 */
	function modifyItem($userId, $item)
	{
		//die ("SecretService::modifyItem ".bprint_r($item));
		$now = date ("Y-m-d H:i:s");

		$query = sprintf ($this->queries['modifyItem'],
			$now,							// when_modified
			$item->isDeleted,
			addslashes($item->number),
			addslashes($item->secret),
			$item->itemId);

		$this->db->Execute($query)
			or die ("Error modifying item: " .
	 		$this->db->ErrorMsg() . " " . $query . '<br />');
	}

	function getParent($item)
	{
		return null;
	}

	function getChildren($userId, $cancellistId)
	{
		// sterry temp
		if ($cancellistId == 0)
		{
			return null;
		}
		else
		{
			$query = sprintf($this->queries['getItemChildren'],
							 $userId,
							 $cancellistId);
		}

		$result = $this->db->Execute ($query) or die
			("SecretServices::getChildren " . $this->db->ErrorMsg () .
				" Error getting children: " . $query);
		$items = $this->itemFactory->resultsetToItems($result);

		if ($items == null)
		{
			return null;
		}
		else if ($items[0]->owner == $userId)
		{
			return $items;
		}
		else
		{
			die ("Not owner?");
		}
	}

	function setSecretUsed($itemId)
	{
		$now = date ("Y-m-d H:i:s");

		$query = sprintf ($this->queries['setSecretUsed'],
			$now,			// when_modified
			$now,			// when_used
			$itemId);

		$this->db->Execute($query)
			or die ("Error setting secret to used: " .
	 		$this->db->ErrorMsg() . " " . $query . '<br />');

	}

	function deleteItems($userId, $cancellistId)
	{
		// now delete the specific item
		$query = sprintf($this->queries['deleteItems'], $userId, $cancellistId);

		$result = $this->db->Execute($query) or
			die("SecretServices::DeleteItems: " .
		$this->db->ErrorMsg() . " " . $query. '<br />');
	}

	function getSecretCount($userId, $cancellistId, $onlyNotUsed=false)
	{
		$query = sprintf($this->queries['getSecrets'],
						 $userId,
						 $cancellistId);
		$result = $this->db->Execute($query) or
			die("SecretServices::getSecretCount: " .
				$this->db->ErrorMsg() . " " . $query. '<br />');

		if (!$onlyNotUsed)
		{
			return $result->RecordCount();
		}
		else
		{
			// Unfortunately I was not able to get the right
			// results when I put something like
			// "WHERE when_used = 'NULL'" in the SQL string.
			// As a wonder "WHERE when_used != 'NULL'" works!
			$query = sprintf($this->queries['getSecretsUsed'],
							 $userId,
							 $cancellistId);
			$result2 = $this->db->Execute($query) or
						die("SecretServices::getSecretCount2: " .
							$this->db->ErrorMsg() . " " . $query. '<br />');
			return $result->RecordCount() - $result2->RecordCount();
		}
	}
}
?>
