<?php
/*
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Thomas Sterren - March 2006
 * @package org.brim-project.plugins.banking
 * @subpackage util.request
 * @filesource
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */

require_once('framework/util/request/RequestCastConfiguration.class.php');

/**
 * The Request cast configuration class knows about the inner details
 * of a class that needs to be casted.
 */
class BankingRequestCastConfiguration extends RequestCastConfiguration
{
	/**
  	 * Default constructor.
 	 */
	function BankingRequestCastConfiguration()
	{

	}

	/**
	 * Returns the configuration mapping between a POST and an Object.
	 * (may be refactored as to use an XML config file).
	 *
	 *
	 * @return array
	 * This array is composed like this :
	 * - key : numeric
	 * - values :
	 * - name of the field
	 * - minimal required (1 means mandatory, more than 1 is for arrays)
	 * - maximal required (more than 1 is for arrays)
	 * - type, can be string (everything), alpha, digit, mail.
	 * - error message if no match on min/max/type
	 * - default value
	 */
	function getFieldMapping($className)
	{
		switch(strtolower($className))
		{
		// Banking
			case strtolower("Banking"):
				$config[] = array(
					"name" => "itemId",
					"field" => "itemId",
					"min" => 0,
					"max" => 1,
					"type" => "digit",
					"message" => "",
					"default" => 0);

				$config[] = array(
					"name" => "parentId",
					"field" => "parentId",
					"min" => 0,
					"max" => 1,
					"type" => "digit",
					"message" => "",
					"default" => 0);

				$config[] = array(
					"name" => "isParent",
					"field" => "isParent",
					"min" => 0,
					"max" => 1,
					"type" => "digit",
					"message" => "",
					"default" => 0);

				$config[] = array(
					"name" => "visibility",
					"field" => "visibility",
					"min" => 0,
					"max" => 1,
					"type" => "alpha",
					"message" => "",
					"default" => "private");

				$config[] = array(
					"name" => "when_created",
					"field" => "when_created",
					"min" => 0,
					"max" => 1,
					"type" => "string",
					"message" => "",
					"default" => null);

				$config[] = array(
					"name" => "when_modified",
					"field" => "when_modified",
					"min" => 0,
					"max" => 1,
					"type" => "string",
					"message" => "",
					"default" => null);

				$config[] = array(
					"name" => "name",
					"field" => "name",
					"min" => 1,
					"max" => 1,
					"type" => "string",
					"message" => 'bankMissing',
					"default" => null);

				$config[] = array(
					"name" => "description",
					"field" => "description",
					"min" => 0,
					"max" => 1,
					"type" => "string",
					"message" => "",
					"default" => null);

				$config[] = array(
					"name" => "type",
					"field" => "type",
					"min" => 0,
					"max" => 1,
					"type" => "string",
					"message" => "",
					"default" => 'Banking');

				$config[] = array(
					"name" => "guid",
					"field" => "guid",
					"min" => 0,
					"max" => 1,
					"type" => "string",
					"message" => "",
					"default" => null);

				$config[] = array(
					"name" => "login",
					"field" => "login",
					"min" => 1,
					"max" => 1,
					"type" => "string",
					"message" => "loginMissing",
					"default" => null);

				$config[] = array(
					"name" => "url",
					"field" => "url",
					"min" => 0,
					"max" => 1,
					"type" => "string",
					"message" => "",
					"default" => null);

				$config[] = array(
					"name" => "contact_person",
					"field" => "contact_person",
					"min" => 0,
					"max" => 1,
					"type" => "string",
					"message" => "",
					"default" => null);

				$config[] = array(
					"name" => "contact_phone",
					"field" => "contact_phone",
					"min" => 0,
					"max" => 1,
					"type" => "string",
					"message" => "",
					"default" => null);

				return $config;
				break;
		// Cancellist
			case strtolower("Cancellist"):
				$config[] = array(
					"name" => "itemId",
					"field" => "itemId",
					"min" => 0,
					"max" => 1,
					"type" => "digit",
					"message" => "",
					"default" => 0);

				$config[] = array(
					"name" => "parentId",
					"field" => "parentId",
					"min" => 0,
					"max" => 1,
					"type" => "digit",
					"message" => "",
					"default" => 0);

				$config[] = array(
					"name" => "isParent",
					"field" => "isParent",
					"min" => 0,
					"max" => 1,
					"type" => "digit",
					"message" => "",
					"default" => 0);

				$config[] = array(
					"name" => "visibility",
					"field" => "visibility",
					"min" => 0,
					"max" => 1,
					"type" => "alpha",
					"message" => "",
					"default" => "private");

				$config[] = array(
					"name" => "when_created",
					"field" => "when_created",
					"min" => 0,
					"max" => 1,
					"type" => "string",
					"message" => "",
					"default" => null);

				$config[] = array(
					"name" => "when_modified",
					"field" => "when_modified",
					"min" => 0,
					"max" => 1,
					"type" => "string",
					"message" => "",
					"default" => null);

				$config[] = array(
					"name" => "name",
					"field" => "name",
					"min" => 1,
					"max" => 1,
					"type" => "string",
					"message" => 'cancellistNameMissing',
					"default" => null);

				$config[] = array(
					"name" => "description",
					"field" => "description",
					"min" => 0,
					"max" => 1,
					"type" => "string",
					"message" => "",
					"default" => null);

				$config[] = array(
					"name" => "type",
					"field" => "type",
					"min" => 0,
					"max" => 1,
					"type" => "string",
					"message" => "",
					"default" => 'Cancellist');

				$config[] = array(
					"name" => "bankId",
					"field" => "bankId",
					"min" => 1,
					"max" => 1,
					"type" => "string",
					"message" => "bankIdMissing",
					"default" => null);

				$config[] = array(
					"name" => "guid",
					"field" => "guid",
					"min" => 0,
					"max" => 1,
					"type" => "string",
					"message" => "",
					"default" => null);

				return $config;
				break;
		// Secret
			case strtolower("Secret"):
				$config[] = array(
					"name" => "itemId",
					"field" => "itemId",
					"min" => 0,
					"max" => 1,
					"type" => "digit",
					"message" => "",
					"default" => 0);

				$config[] = array(
					"name" => "parentId",
					"field" => "parentId",
					"min" => 0,
					"max" => 1,
					"type" => "digit",
					"message" => "",
					"default" => 0);

				$config[] = array(
					"name" => "isParent",
					"field" => "isParent",
					"min" => 0,
					"max" => 1,
					"type" => "digit",
					"message" => "",
					"default" => 0);

				$config[] = array(
					"name" => "visibility",
					"field" => "visibility",
					"min" => 0,
					"max" => 1,
					"type" => "alpha",
					"message" => "",
					"default" => "private");

				$config[] = array(
					"name" => "when_created",
					"field" => "when_created",
					"min" => 0,
					"max" => 1,
					"type" => "string",
					"message" => "",
					"default" => null);

				$config[] = array(
					"name" => "when_modified",
					"field" => "when_modified",
					"min" => 0,
					"max" => 1,
					"type" => "string",
					"message" => "",
					"default" => null);

				$config[] = array(
					"name" => "name",
					"field" => "name",
					"min" => 0,
					"max" => 1,
					"type" => "string",
					"message" => 'secretMissing',
					"default" => null);

				$config[] = array(
					"name" => "description",
					"field" => "description",
					"min" => 0,
					"max" => 1,
					"type" => "string",
					"message" => "",
					"default" => null);

				$config[] = array(
					"name" => "type",
					"field" => "type",
					"min" => 0,
					"max" => 1,
					"type" => "string",
					"message" => "",
					"default" => 'Secret');

				$config[] = array(
					"name" => "cancellistId",
					"field" => "cancellistId",
					"min" => 1,
					"max" => 1,
					"type" => "string",
					"message" => "cancellistIdMissing",
					"default" => null);

				$config[] = array(
					"name" => "guid",
					"field" => "guid",
					"min" => 0,
					"max" => 1,
					"type" => "string",
					"message" => "",
					"default" => null);

				$config[] = array(
					"name" => "number",
					"field" => "number",
					"min" => 1,
					"max" => 1,
					"type" => "string",
					"message" => "numberMissing",
					"default" => null);

				$config[] = array(
					"name" => "secret",
					"field" => "secret",
					"min" => 1,
					"max" => 1,
					"type" => "string",
					"message" => "secretMissing",
					"default" => null);

				$config[] = array(
					"name" => "when_used",
					"field" => "when_used",
					"min" => 0,
					"max" => 1,
					"type" => "string",
					"message" => "",
					"default" => null);

				return $config;
				break;
		}
	}
}
?>