<?php

require_once('framework/util/StringUtils.php');
require_once('framework/view/TreeDelegate.php');

/**
 * Used in combination with the Tree class
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Thomas Sterren - October 2004
 * @package org.brim-project.plugins.banking
 * @subpackage view
 * @filesource
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class BankingLineBasedTreeDelegate extends TreeDelegate
{
	/**
	 * Have we already drawn a header?
	 */
	var $headersDrawn;

	function BankingLineBasedTreeDelegate ($theConfiguration)
	{
		parent::TreeDelegate ($theConfiguration);
		$this->headersDrawn = false;
	}

	/**
	 * Builds up html code to display the root of the tree
	 * @private
	 *
	 * @param object item the item that is the root of the tree
	 */
	function showRoot($item, $tree)
	{

		if (isset($item) && $item->itemId != 0)
		{
			$resultString = '<h2>'.$item->name.'</h2>';
			$resultString .= '<a href="'.$this->configuration['callback'];
			$resultString .= '?action=show&parentId='.$item->parentId.'">';
			$resultString .= $this->configuration['icons']['up'];
			$resultString .= '</a><br />';
		}
		else
		{
			$resultString = '';
		}
		return $resultString;
	}

	/**
	 * If the specified item is a folder, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean isExpanded whether this folder is expanded (i.e. do the
	 * children of this folder need to be displayed as well?)
	 * @param object tree the tree that uses this class as delegate
	 * @return string the string for this folder
	 */
	function drawFolder($item, $isExpanded, $tree, $indentLevel)
	{
		$resultString = '';
		$resultString .= '<a href="';
		$resultString .= $this->configuration['callback'];
        $resultString .= '?action=modify&itemId='.$item->itemId;
        $resultString .= '&parentId='.$tree->root->itemId.'">';
		$resultString .= $this->configuration['icons']['folder_closed'];
		$resultString .= '</a>';

		$resultString .= '<a href="';
		$resultString .= $this->configuration['callback'];
		$resultString .= '?action=show&parentId=';
		$resultString .= $item->itemId . '">';
		$resultString .= $item->name;
		$resultString .= '</a>';

		$resultString .= '<br />';
		return $resultString;
	}

	function drawLinesHeader($parentId)
	{
		$resultString = '<td colspan="8"></td></tr><tr>';
		$resultString .= '<td>&nbsp;</td>';
		$resultString .= '<td>&nbsp;</td>';

		$resultString .= '<td><b>'.$this->configuration['dictionary']['name'];
		$resultString .= $this->sortArrows ('name', $parentId);
		$resultString .= '</b></td>';

		$resultString .= '<td><b>'.$this->configuration['dictionary']['url'];
		$resultString .= $this->sortArrows ('url', $parentId);
		$resultString .= '</b></td>';

		$resultString .= '<td><b>'.$this->configuration['dictionary']['login'];
		$resultString .= $this->sortArrows ('login', $parentId);
		$resultString .= '</b></td>';

		$resultString .= '</tr><tr class="odd">';
		return $resultString;
	}
	/**
	 * If the specified item is a node, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean lastNode whether this node is the last one
	 * @return string the string for this node
	 */
	function drawNode($item, $lastNode, $tree, $indentLevel)
	{
		if ($this->headersDrawn)
		{
			$resultString = '';
		}
		else
		{
			$resultString = $this->drawLinesHeader ($item->parentId);
			$this->headersDrawn = true;
		}
		// header with two icons and overlib popup
		$resultString .= '<td width="20" align="right">';
		$resultString .= '<a href="'.$this->configuration['callback'];
        $resultString .= '?action=modify&itemId='.$item->itemId;
        $resultString .= '&parentId='.$item->parentId.'">';
		$resultString .= $this->configuration['icons']['edit'].'</a>';
		$resultString .= '</td>';

		$resultString .= '<td width="20" align="right">';
		$resultString .= '<a href="'.$this->configuration['callback'];
		$resultString .= '?itemId='.$item->itemId;
		$resultString .= '&action=deleteItemPost" ';
		// delete confirmation
		$resultString .= 'onclick="javascript:return confirm (\'';
		$resultString .= $this->configuration['dictionary']['confirm_delete'];
		$resultString .= '\');" ';
		$resultString .= '>'.$this->configuration['icons']['delete'].'</a>';
		$resultString .= '</td>';

		$resultString .= '<td>';
		$resultString .= '<a href="'.$this->configuration['callback'].'?';
		$resultString .= 'bankId='.$item->itemId.'&action=showCancellists" ';
		if ($this->configuration['overlib'])
		{
			$popUp = $this->overlibPopup ($item);
			$resultString .= $this->overLib ($item->name, $popUp);
		}
		$resultString .= '>';
		$resultString .= '<b>' . $item->name . '</b></a>';
		$resultString .= '</td>';

		$resultString .= '<td>';
		if ($item->url != null)
		{
			$resultString .= '<a href="' . $item->url . '" ';
			if ($this->configuration['openURLinNewWindow'])
			{
				$resultString .= 'onClick="newWindow(\''.$item->url.'\');return false"';
			}
			$resultString .= '>';
			$resultString .= $item->url;
			$resultString .= '</a>';
		}
		else
		{
			$resultString .= '&nbsp;';
		}
		$resultString .= '</td>';

		$resultString .= '<td>';
		if ($item->login != null)
		{
			$resultString .= $item->login;
		}
		else
		{
			$resultString .= '&nbsp;';
		}
		$resultString .= '</td>';

		return $resultString;
	}

	function overlibPopup ($item)
	{
		if ($this->configuration['overlib'])
		{
			$popUp  = '<table cellspacing=2>';
			if ($item->url != null)
			{
				$popUp .= "<tr>";
				$popUp .= "<td><b>".$this->configuration['dictionary']['url'].":</b></td>";
				$popUp .= "<td>".$item->url."</td>";
				$popUp .= "</tr>";
			}
			if ($item->login != null)
			{
				$popUp .= "<tr>";
				$popUp .= "<td><b>".$this->configuration['dictionary']['login'].":</b></td>";
				$popUp .= "<td>".$item->login."</td>";
				$popUp .= "</tr>";
			}
			if ($item->contact_person != null)
			{
				$popUp .= "<tr>";
				$popUp .= "<td><b>".$this->configuration['dictionary']['contact_person'].":</b></td>";
				$popUp .= "<td>".$item->contact_person."</td>";
				$popUp .= "</tr>";
			}
			if ($item->contact_phone != null)
			{
				$popUp .= "<tr>";
				$popUp .= "<td><b>".$this->configuration['dictionary']['contact_phone'].":</b></td>";
				$popUp .= "<td>".$item->contact_phone."</td>";
				$popUp .= "</tr>";
			}
			if ($item->description != null)
			{
				$popUp .= "<tr>";
				$popUp .= '<td colspan="2">'.$item->description."</td>";
				$popUp .= "</tr>";
			}
			$popUp .= "</table>";
		}
		return $popUp;
	}

	/**
	 * Returns the overlib javascript
	 * @param string title the title of the popup
	 * @param string text the text of the popup
	 */
	function overLib ($title, $text)
	{
		$string = addslashes ($text);
		$string = $this->stringUtils->urlEncodeQuotes ($string);
		$string = $this->stringUtils->newlinesToHtml ($string);

		$resultString  = 'onmouseover="return overlib(\'';
		$resultString .= $string;
		$resultString .= "', WIDTH, '";
		$resultString .= $this->stringUtils->urlEncodeQuotes(addslashes (300));
		$resultString .= "', CAPTION, '";
		$resultString .= $this->stringUtils->urlEncodeQuotes(addslashes ($title)) . '\');" ';
		$resultString .= 'onmouseout="return nd();" ';
		return $resultString;
	}

	/**
	 * Renders the sort arrows
	 *
	 * @param string sortField the field on which we would like
	 * to sort
	 * @param integer parentId the current parentId
	 */
	function sortArrows ($sortField, $parentId)
	{
		$resultString = '&nbsp;';
		$resultString .= '<a href="'.$this->configuration['callback'];
		$resultString .= '?action=sort&order=ASC&field='.$sortField;
		if (isset ($_GET['order']) && $_GET['order'] == 'ASC' && $_GET['field'] == $sortField)
		{
			$resultString .= '">'.$this->configuration['icons']['up_arrow_shaded'].'</a>';
		}
		else
		{
			$resultString .= '">'.$this->configuration['icons']['up_arrow'].'</a>';
		}
		$resultString .= '<a href="'.$this->configuration['callback'];
		$resultString .= '?action=sort&order=DESC&field='.$sortField;
		if (isset ($_GET['order']) && $_GET['order'] == 'DESC' && $_GET['field'] == $sortField)
		{
			$resultString .= '">'.$this->configuration['icons']['down_arrow_shaded'].'</a>';
		}
		else
		{
			$resultString .= '">'.$this->configuration['icons']['down_arrow'].'</a>';
		}
		return $resultString;
	}
}
?>