<?php

require_once ("framework/util/StringUtils.php");
require_once ("framework/view/TreeDelegate.php");
require_once ("plugins/banking/view/globalFunctions.php");

/**
 * Used in combination with the Tree class
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Thomas Sterren - October 2004
 * @package org.brim-project.plugins.banking
 * @subpackage view
 * @filesource
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class CancellistLineBasedTreeDelegate extends TreeDelegate
{
	/**
	 * Have we already drawn a header?
	 */
	var $headersDrawn;

	function CancellistLineBasedTreeDelegate ($theConfiguration)
	{
		parent::TreeDelegate($theConfiguration);
		$this->headersDrawn = false;
	}

	/**
	 * Builds up html code to display the root of the tree
	 * @private
	 *
	 * @param object item the item that is the root of the tree
	 */
	function showRoot($item, $tree)
	{
		// item is of type banking
		if (isset($item))
		{
			$resultString = '<h2>'.$item->name.'</h2>';
			$resultString .= '<table border="0" cellspacing="0" cellpadding="2">';
			$resultString .=  standardTableRowUrlExt('url',
													 $this->configuration['dictionary'],
													 $item,
													 $this->configuration['openURLinNewWindow']);
			$resultString .=  standardTableRowInputExt('login',
													   $this->configuration['dictionary'],
													   'show',
													   $item);

			$resultString .= '<tr><td colspan="2">&nbsp;</td></tr>';

			$resultString .=  standardTableRowInputExt('contact_person',
													   $this->configuration['dictionary'],
													   'show',
													   $item);

			$resultString .=  standardTableRowInputExt('contact_phone',
													   $this->configuration['dictionary'],
													   'show',
													   $item);

			$resultString .= '</table>';
			$resultString .= '<br />';
			$resultString .= '<a href="'.$this->configuration['callback'];
			$resultString .= '">';
			$resultString .= $this->configuration['icons']['up'];
			$resultString .= '</a><br />';

			$resultString .= '<h2>'.$this->configuration['dictionary']['cancellists'].'</h2>';
		}
		else
		{
			$resultString = '';
		}

		return $resultString;
	}

	/**
	 * If the specified item is a folder, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean isExpanded whether this folder is expanded (i.e. do the
	 * children of this folder need to be displayed as well?)
	 * @param object tree the tree that uses this class as delegate
	 * @return string the string for this folder
	 */
	function drawFolder($item, $isExpanded, $tree, $indentLevel)
	{
		$resultString = '';
		$resultString .= '<a href="';
		$resultString .= $this->configuration['callback'];
		$resultString .= '?action=modify&itemId=';
		$resultString .= $item->itemId . '">';
		$resultString .= $this->configuration['icons']['folder_closed'];
		$resultString .= '</a>';

		$resultString .= '<a href="';
		$resultString .= $this->configuration['callback'];
		$resultString .= '?action=show&parentId=';
		$resultString .= $item->itemId . '">';
		$resultString .= $item->name;
		$resultString .= '</a>';

		$resultString .= '<br />';
		return $resultString;
	}

	function drawLinesHeader($parentId)
	{
		$resultString = '<td colspan="8"></td></tr><tr>';
		$resultString .= '<td>&nbsp;</td>';
		$resultString .= '<td>&nbsp;</td>';

		$resultString .= '<td><b>'.$this->configuration['dictionary']['cancellistName'];
		$resultString .= $this->sortArrows('name', $parentId);
		$resultString .= '</b></td>';

		$resultString .= '<td><b>'.$this->configuration['dictionary']['totalSecrets'];
		$resultString .= '</b></td>';

		$resultString .= '<td><b>'.$this->configuration['dictionary']['secretsNotUsed'];
		$resultString .= '</b></td>';

		$resultString .= '</tr><tr class="odd">';
		return $resultString;
	}
	/**
	 * If the specified item is a node, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean lastNode whether this node is the last one
	 * @return string the string for this node
	 */
	function drawNode($item, $lastNode, $tree, $indentLevel)
	{
		if ($this->headersDrawn)
		{
			$resultString = '';
		}
		else
		{
			$resultString = $this->drawLinesHeader($item->bankId);
			$this->headersDrawn = true;
		}
		// header with two icons and overlib popup
		$resultString .= '<td width="20" align="right">';
		$resultString .= '<a href="'.$this->configuration['callback'];
		$resultString .= '?action=modifyCancellist';
		$resultString .= '&itemId=' . $item->itemId;
		$resultString .= '&bankId=' . $item->bankId . '" ';
		$resultString .= '>'.$this->configuration['icons']['edit'].'</a>';
		$resultString .= '</td>';

		$resultString .= '<td width="20" align="right">';
		$resultString .= '<a href="'.$this->configuration['callback'];
		$resultString .= '?action=deleteCancellistPost';
		$resultString .= '&itemId=' .$item->itemId;
		$resultString .= '&bankId=' .$item->bankId . '" ';
		// delete confirmation
		$resultString .= 'onclick="javascript:return confirm (\'';
		$resultString .= $this->configuration['dictionary']['confirm_delete'];
		$resultString .= '\');" ';
		$resultString .= '>'.$this->configuration['icons']['delete'].'</a>';
		$resultString .= '</td>';

		$resultString .= '<td>';
		$resultString .= '<a href="'.$this->configuration['callback'].'?';
		$resultString .= 'action=showSecrets';
	//	$resultString .= '&bankId='.$item->bankId;
		$resultString .= '&cancellistId='.$item->itemId . '" ';
		if ($this->configuration['overlib'])
		{
			$popUp = $this->overlibPopup ($item);
			$resultString .= $this->overLib($item->name, $popUp);
		}
		$resultString .= '>';
		$resultString .= '<b>' . $item->name . '</b></a>';
		$resultString .= '</td>';

		$resultString .= '<td>';
		if (isset($item->secretCount))
		{
			$resultString .= $item->secretCount;
		}
		else
		{
			$resultString .= '&nbsp;';
		}
		$resultString .= '</td>';

		$resultString .= '<td>';
		if (isset($item->secretNotUsedCount))
		{
			$resultString .= $item->secretNotUsedCount;
		}
		else
		{
			$resultString .= '&nbsp;';
		}
		$resultString .= '</td>';

		return $resultString;
	}

	function overlibPopup ($item)
	{
		if ($this->configuration['overlib'])
		{
			$popUp  = '<table cellspacing=2>';
			if ($item->name != null)
			{
				$popUp .= "<tr>";
				$popUp .= "<td><b>".$this->configuration['dictionary']['cancellistName'].":</b></td>";
				$popUp .= "<td>".$item->name."</td>";
				$popUp .= "</tr>";
			}
			if ($item->description != null)
			{
				$popUp .= "<tr>";
				$popUp .= '<td colspan="2">'.$item->description."</td>";
				$popUp .= "</tr>";
			}
			$popUp .= "</table>";
		}
		return $popUp;
	}

	/**
	 * Returns the overlib javascript
	 *
	 * @param string title the title of the popup
	 * @param string text the text of the popup
	 */
	function overLib($title, $text)
	{
		$string = addslashes ($text);
		$string = $this->stringUtils->urlEncodeQuotes ($string);
		$string = $this->stringUtils->newlinesToHtml ($string);

		$resultString  = 'onmouseover="return overlib(\'';
		$resultString .= $string;
		$resultString .= "', WIDTH, '";
		$resultString .= $this->stringUtils->urlEncodeQuotes(addslashes (300));
		$resultString .= "', CAPTION, '";
		$resultString .= $this->stringUtils->urlEncodeQuotes(addslashes ($title)) . '\');" ';
		$resultString .= 'onmouseout="return nd();" ';
		return $resultString;
	}

	/**
	 * Renders the sort arrows
	 *
	 * @param string sortField the field on which we would like
	 * to sort
	 * @param integer parentId the current parentId
	 */
	function sortArrows($sortField, $parentId)
	{
		$resultString = '&nbsp;';
		$resultString .= '<a href="'.$this->configuration['callback'];
		$resultString .= '?action=sortCancellists&order=ASC&field='.$sortField.'&bankId='.$parentId;
		if (isset ($_GET['order']) && $_GET['order'] == 'ASC' && $_GET['field'] == $sortField)
		{
			$resultString .= '">'.$this->configuration['icons']['up_arrow_shaded'].'</a>';
		}
		else
		{
			$resultString .= '">'.$this->configuration['icons']['up_arrow'].'</a>';
		}
		$resultString .= '<a href="'.$this->configuration['callback'];
		$resultString .= '?action=sortCancellists&order=DESC&field='.$sortField.'&bankId='.$parentId;
		if (isset ($_GET['order']) && $_GET['order'] == 'DESC' && $_GET['field'] == $sortField)
		{
			$resultString .= '">'.$this->configuration['icons']['down_arrow_shaded'].'</a>';
		}
		else
		{
			$resultString .= '">'.$this->configuration['icons']['down_arrow'].'</a>';
		}
		return $resultString;
	}
}
?>