<?php

require_once ('framework/util/StringUtils.php');
require_once ('framework/view/TreeDelegate.php');
require_once ('plugins/banking/view/globalFunctions.php');

/**
 * Used in combination with the Tree class
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Thomas Sterren - October 2004
 * @package org.brim-project.plugins.banking
 * @subpackage view
 * @filesource
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class SecretLineBasedTreeDelegate extends TreeDelegate
{
	/**
	 * Have we already drawn a header?
	 */
	var $headersDrawn;

	function SecretLineBasedTreeDelegate ($theConfiguration)
	{
		parent::TreeDelegate($theConfiguration);
		$this->headersDrawn = false;
	}

	/**
	 * Builds up html code to display the root of the tree
	 * @private
	 *
	 * @param object item the item that is the root of the tree
	 */
	function showRoot($item, $tree)
	{
		// item is of type cancellist
		if (isset($item))
		{
			$bankItem = $this->configuration['bankItem'];

			$resultString = '<h2>'.$bankItem->name.'</h2>';
			$resultString .= '<table border="0" cellspacing="0" cellpadding="2">';
			$resultString .=  standardTableRowUrlExt('url',
													 $this->configuration['dictionary'],
													 $bankItem,
													 $this->configuration['openURLinNewWindow']);
			$resultString .=  standardTableRowInputExt('login',
													   $this->configuration['dictionary'],
													   'show',
													   $bankItem);

			$resultString .= '<tr><td colspan="2">&nbsp;</td></tr>';

			$resultString .=  standardTableRowInputExt('contact_person',
													   $this->configuration['dictionary'],
													   'show',
													   $bankItem);

			$resultString .=  standardTableRowInputExt('contact_phone',
													   $this->configuration['dictionary'],
													   'show',
													   $bankItem);

			$resultString .= '</table>';
			$resultString .= '<br />';

			$resultString .= '<a href="?bankId='.$bankItem->itemId.'&action=' . $this->configuration['showCancellistAction'] . '" class="ancestor">';
			$resultString .= $this->configuration['icons']['up'];
			$resultString .= '</a>';
			$resultString .= '<br />';

			$resultString .= '<h2>'.$item->name.'</h2>';	// cancellist name
		}
		else
		{
			$resultString = '';
		}

		return $resultString;
	}

	/**
	 * If the specified item is a folder, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean isExpanded whether this folder is expanded (i.e. do the
	 * children of this folder need to be displayed as well?)
	 * @param object tree the tree that uses this class as delegate
	 * @return string the string for this folder
	 */
	function drawFolder($item, $isExpanded, $tree, $indentLevel)
	{
		$resultString = '';
		$resultString .= '<a href="';
		$resultString .= $this->configuration['callback'];
		$resultString .= '?action=modify&itemId=';
		$resultString .= $item->itemId . '">';
		$resultString .= $this->configuration['icons']['folder_closed'];
		$resultString .= '</a>';

		$resultString .= '<a href="';
		$resultString .= $this->configuration['callback'];
		$resultString .= '?action=show&parentId=';
		$resultString .= $item->itemId . '">';
		$resultString .= $item->name;
		$resultString .= '</a>';

		$resultString .= '<br />';
		return $resultString;
	}

	function drawLinesHeader($parentId)
	{
		$resultString = '<td colspan="8"></td></tr><tr>';
		$resultString .= '<td>&nbsp;</td>';
		$resultString .= '<td>&nbsp;</td>';

		$resultString .= '<td><b>'.$this->configuration['dictionary']['number'];
		$resultString .= $this->sortArrows ('number', $parentId);
		$resultString .= '</b></td>';

		$resultString .= '<td><b>'.$this->configuration['dictionary']['secret'];
		$resultString .= $this->sortArrows ('secret', $parentId);
		$resultString .= '</b></td>';

		$resultString .= '<td><b>'.$this->configuration['dictionary']['when_used'];
		$resultString .= $this->sortArrows ('dateUsed', $parentId);
		$resultString .= '</b></td>';

		$resultString .= '<td><b>'.$this->configuration['dictionary']['state'];
		$resultString .= '</b></td>';

		$resultString .= '</tr><tr class="odd">';
		return $resultString;
	}
	/**
	 * If the specified item is a node, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean lastNode whether this node is the last one
	 * @return string the string for this node
	 */
	function drawNode($item, $lastNode, $tree, $indentLevel)
	{
		if ($this->headersDrawn)
		{
			$resultString = '';
		}
		else
		{
			$resultString = $this->drawLinesHeader($item->cancellistId);
			$this->headersDrawn = true;
		}
		// header with two icons and overlib popup
		$resultString .= '<td width="20" align="right">';
		$resultString .= '<a href="'.$this->configuration['callback'];
		$resultString .= '?action=modifySecret';
		$resultString .= '&itemId=' . $item->itemId;
		$resultString .= '&cancellistId=' . $item->cancellistId . '" ';
		$resultString .= '>'.$this->configuration['icons']['edit'].'</a>';
		$resultString .= '</td>';

		$resultString .= '<td width="20" align="right">';
		$resultString .= '<a href="'.$this->configuration['callback'];
		$resultString .= '?action=deleteSecretPost';
		$resultString .= '&itemId=' . $item->itemId;
		$resultString .= '&cancellistId=' . $item->cancellistId . '" ';
		// delete confirmation
		$resultString .= 'onclick="javascript:return confirm (\'';
		$resultString .= $this->configuration['dictionary']['confirm_delete'];
		$resultString .= '\');" ';
		$resultString .= '>'.$this->configuration['icons']['delete'].'</a>';
		$resultString .= '</td>';

		$resultString .= '<td>';
		if ($item->number != null)
		{
			$resultString .= $item->number;
		}
		else
		{
			$resultString .= '&nbsp;';
		}
		$resultString .= '</td>';

		$resultString .= '<td>';
		$resultString .= '<a href="'.$this->configuration['callback'].'?';
		$resultString .= 'action=showSecret';
		$resultString .= '&cancellistId='.$item->cancellistId;
		$resultString .= '&itemId='.$item->itemId . '" ';
		if ($this->configuration['overlib'])
		{
			$popUp = $this->overlibPopup ($item);
			$resultString .= $this->overLib ($item->secret, $popUp);
		}
		$resultString .= '>';
		$resultString .= '<b>' . $item->secret . '</b></a>';
		$resultString .= '</td>';

		$resultString .= '<td>';
		if (isset($item->when_used))
		{
			$resultString .= $item->when_used;
		}
		else
		{
			$resultString .= '&nbsp;';
		}
		$resultString .= '</td>';

		$resultString .= '<td>';
		if (isset($item->when_used))
		{
			$resultString .= $this->configuration['dictionary']['secret_used'];
		}
		else
		{
			$resultString .= '<form method="POST" action="BankingController.php?cancellistId='. $item->cancellistId .'">';
			$resultString .= '<input type="hidden" name="action" value="setSecretUsed" />';
			$resultString .= '<input type="hidden"
								name="itemId"
								value="' . $item->itemId . '" />';
			$resultString .= '<input type="submit"
								class="button"
								name="submit"
								value="'. $this->configuration['dictionary']['set_secret_used'] .'" />';
			$resultString .= '</form>';
		}
		$resultString .= '</td>';

		return $resultString;
	}

	function overlibPopup($item)
	{
		if ($this->configuration['overlib'])
		{
			$popUp  = '<table cellspacing=2>';
			if ($item->secret != null)
			{
				$popUp .= "<tr>";
				$popUp .= "<td><b>".$this->configuration['dictionary']['number'].":</b></td>";
				$popUp .= "<td>".$item->number."</td>";
				$popUp .= "</tr>";

				$popUp .= "<tr>";
				$popUp .= "<td><b>".$this->configuration['dictionary']['secret'].":</b></td>";
				$popUp .= "<td>".$item->secret."</td>";
				$popUp .= "</tr>";

				if (isset($item->when_used))
				{
					$popUp .= "<tr>";
					$popUp .= "<td><b>".$this->configuration['dictionary']['when_used'].":</b></td>";
					$popUp .= "<td>".$item->when_used."</td>";
					$popUp .= "</tr>";
				}
			}
			$popUp .= "</table>";
		}
		return $popUp;
	}

	/**
	 * Renders the sort arrows
	 *
	 * @param string sortField the field on which we would like
	 * to sort
	 * @param integer parentId the current parentId
	 */
	function sortArrows($sortField, $parentId)
	{
		$resultString = '&nbsp;';
		$resultString .= '<a href="'.$this->configuration['callback'];
		$resultString .= '?action=sortSecrets&order=ASC&field='.$sortField.'&cancellistId='.$parentId;
		if (isset ($_GET['order']) && $_GET['order'] == 'ASC' && $_GET['field'] == $sortField)
		{
			$resultString .= '">'.$this->configuration['icons']['up_arrow_shaded'].'</a>';
		}
		else
		{
			$resultString .= '">'.$this->configuration['icons']['up_arrow'].'</a>';
		}
		$resultString .= '<a href="'.$this->configuration['callback'];
		$resultString .= '?action=sortSecrets&order=DESC&field='.$sortField.'&cancellistId='.$parentId;
		if (isset ($_GET['order']) && $_GET['order'] == 'DESC' && $_GET['field'] == $sortField)
		{
			$resultString .= '">'.$this->configuration['icons']['down_arrow_shaded'].'</a>';
		}
		else
		{
			$resultString .= '">'.$this->configuration['icons']['down_arrow'].'</a>';
		}
		return $resultString;
	}
}
?>