<?php
/**
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Barry Nauta
 *		   Extented by Thomas Sterren - October 2004
 * @package org.brim-project.plugins.banking
 * @subpackage view
 * @filesource
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */

require_once ('framework/util/DateUtils.php');
require_once ('framework/util/StringUtils.php');

/**
 * Returns a row with two data fields.
 * The first field will contain the mapping of the name in the
 * dictionary, the second field will contain the value of the field
 * in an input field.
 *
 * If the action is 'show' then editable will be set to false
 * and if modify or show is action, the fieldValue will be
 * filled in, which is not the case for adding and item
 * (we do not have a fieldValue at this moment)
 *
 * @param name the name of the field, this name will be used to
 * retrieve the appropriate dictionary title and also to retrieve
 * the appropriate object member
 * @param array dictionary the dictionary
 * @param sting action either add, modify or show
 * @param fieldValue the value to be filled in
 *		(expect for the add action)
 * @param string inputText optional text to be put in the input field
 * @return string the string with the additional parameters
 */
function standardTableRowInputExt($name,
							      $dictionary,
								  $action,
								  $object,
								  $inputText="")
{
	$stringUtils = new StringUtils();
	$result = '<tr>';

	//
	// First field contains the name
	//
	$result .= '<td class="inputParamName" bgcolor="#EEEEEE" bordercolor="#EEEEEE">'.$dictionary[$name].':</td>';

	//
	// Second field contains the value
	//
	$result .= '<td bgcolor="#EEEEEE" bordercolor="#EEEEEE">';
	if ($action == 'add' || $action == 'modify')
	{
		$result .= '<input type="text" class="text" ';
		$result .= 'name="'.$stringUtils->urlEncodeQuotes ($name).'" ';
		//
		// Fill in the value if we are modifying the item.
		// This has no use for adding...
		//
		if ($action == 'modify' || isset ($object))
		{
			if (isset ($object->$name) && $object->$name != '')
			{
				$result .= 'value="'.$stringUtils->urlEncodeQuotes ($object->$name).'" ';
			}
		}
		$result .= ' />';
	}
	//
	// Show-action: no input but plain text
	//
	if ($action == 'show')
	{
		$result .= $object->$name;
	}
	$result .= '</td>';
	$result .= '</tr>';

	return $result;
}

function standardTableRowUrlExt($name,
							 $dictionary,
							 $object,
							 $openURLinNewWindow = false)
{
	$result = '<tr>';

	//
	// First field contains the name
	//
	$result .= '<td class="inputParamName" bgcolor="#EEEEEE" bordercolor="#EEEEEE">'.$dictionary[$name].':</td>';

	//
	// Second field contains the value
	//
	$result .= '<td bgcolor="#EEEEEE" bordercolor="#EEEEEE">';

	$result .= '<a href="' . $object->$name . '" ';
	if ($openURLinNewWindow)
	{
		$result .= 'onClick="newWindow(\''.$object->$name.'\');return false"';
	}
	$result .= '>';
	$result .= $object->$name;
	$result .= '</a>';

	$result .= '</td>';
	$result .= '</tr>';

	return $result;
}

function deleteButtonAndTextExt($dictionary,
								$item,
								$action=null,
								$parentIdName=null)
{
	$defaultAction = (isset($action)) ? $action : 'deleteItemPost';
	$defaultParentIdName = (isset($parentIdName)) ? $parentIdName : 'parentId';

	//$result = '<h3>'.$dictionary['delete'].'</h3>';
	$result  = '<input type="hidden"
					name="itemId"
					value="'.$item->itemId.'" />';
	$result .= '<input type="hidden"
					name="'. $defaultParentIdName .'"
					value="'. $item->$defaultParentIdName .'" />';
	$result .= '<input type="hidden"
	    			name="action"
		    		value="'. $defaultAction .'" />';
	$result .= '<input type="submit"
					class="button"
					name="submit"
					value="'.$dictionary['delete'].'" />';
	return $result;
}

/**
 * The modify button. WARNING!!! This putton must be placed
 * inside the first form!!!
 */
function modifyButtonAndTextExt($dictionary,
								$item,
								$action=null,
								$parentIdName=null)
{
	$defaultAction = (isset($action)) ? $action : 'modifyItemPost';
	$defaultParentIdName = (isset($parentIdName)) ? $parentIdName : 'parentId';

	//$result = '<h3>'.$dictionary['modify'].'</h3>';
	$result  = '<input type="hidden"
						name="itemId"
						value="'.$item->itemId.'" />';
	$result .= '<input type="hidden"
						name="'. $defaultParentIdName .'"
						value="'. $item->$defaultParentIdName .'" />';
	$result .= '<input type="hidden"
	    				name="action"
		    			value="'. $defaultAction .'" />';
	$result .= '<input type="submit"
						class="button"
						name="submit"
						value="'.$dictionary['modify'].'" />';
	return $result;
}

function addButtonAndTextExt($dictionary,
						  	 $parentId,
						  	 $action=null,
						  	 $parentIdName=null)
{
	$defaultAction = (isset($action)) ? $action : 'addItemPost';
	$defaultParentIdName = (isset($parentIdName)) ? $parentIdName : 'parentId';

	//$result = '<h3>'.$dictionary['add'].'</h3>';
	$result  = '<input type="hidden"
					name="' . $defaultParentIdName . '"
					value="'.$parentId.'" />';
	$result .= '<input type="hidden"
	    			name="action"
		    		value="' . $defaultAction . '" />';
	$result .= '<input type="submit"
					class="button"
					name="submit"
					value="'.$dictionary['add'].'" />';
	return $result;
}

function cancelButtonAndTextExt($dictionary,
                                $parentId,
								$action=null,
								$parentIdName=null)
{
    $defaultAction = (isset($action)) ? $action : 'cancel';
	$defaultParentIdName = (isset($parentIdName)) ? $parentIdName : 'parentId';

    $result  = '<input type="hidden"
    						name="' .$defaultParentIdName. '"
    						value="'. $parentId .'" />';
	$result .= '<input type="hidden"
	    				name="action"
		    			value="'.$defaultAction.'" />';
	$result .= '<input type="submit"
						class="button"
						name="submit"
						value="'.$dictionary['cancel'].'" />';
	return $result;
}

function ancestorsToHtmlInBankings($ancestors,
								   $configuration,
								   $inSubView=false)
{
	$resultString = "";

	if(isset($ancestors))
	{
		$resultString .= '<!-- Ancestors -->';
		$resultString .= '<table><tr>';

		$resultString .= '<td>';
		$resultString .= '<a href="' . $configuration['callback'] . '" class="ancestor">';
		$resultString .= 'Root';
		$resultString .= '</a>';
		$resultString .= '</td>';

		// all ancestors other than root
		foreach($ancestors as $ancestor)
		{
			$resultString .= '<td>';
			switch ($ancestor->itemName)
			{
			case "Banking":
				$resultString .= '&nbsp;/&nbsp;';
				if ($inSubView == true)
				{
					$resultString .= '<a href="?bankId='.$ancestor->itemId.'&action=' . $configuration['showCancellistAction'] . '" class="ancestor">';
				}
				$resultString .= $ancestor->name;
				if ($inSubView == true)
				{
					$resultString .= '</a>';
				}
				break;
			}
			$resultString .= '</td>';
		}
		$resultString .= '</tr></table>';
	}
	return $resultString;
}

function ancestorsToHtmlInCultists($ancestors,
								   $configuration,
								   $inSubView=false)
{
	$resultString = "";

	if(isset($ancestors))
	{
		$resultString .= '<!-- Ancestors -->';
		$resultString .= '<table><tr>';

		$resultString .= '<td>';
		$resultString .= '<a href="' . $configuration['callback'] . '" class="ancestor">';
		$resultString .= 'Root';
		$resultString .= '</a>';
		$resultString .= '</td>';

		// all ancestors other than root
		foreach($ancestors as $ancestor)
		{
			$resultString .= '<td>';
			switch ($ancestor->itemName)
			{
			case "Banking":
				$resultString .= '&nbsp;/&nbsp;';
				$resultString .= '<a href="?bankId='.$ancestor->itemId.'&action=' . $configuration['showCancellistAction'] . '" class="ancestor">';
				$resultString .= $ancestor->name;
				$resultString .= '</a>';
				break;
			case "Cancellist":
				$resultString .= '&nbsp;/&nbsp;';
				if ($inSubView)
				{
					$resultString .= '<a href="?cancellistId='.$ancestor->itemId;
					$resultString .= '&action=' . $configuration['showSecretsAction'] . '" class="ancestor">';
				}
				$resultString .= $ancestor->name;	// cancellist name
				if ($inSubView)
				{
					$resultString .= '</a>';
				}
				break;
			}

			$resultString .= '</td>';
		}
		$resultString .= '</tr></table>';
	}

	return $resultString;
}
?>