<?php

require_once ('framework/ItemController.php');
require_once ('plugins/checkbook/model/CheckbookServices.php');
require_once ('plugins/checkbook/model/CheckbookPreferences.php');

/**
 * The Checkbook Controller
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Barry Nauta - April 2006
 * @package org.brim-project.plugins.checkbook
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class CheckbookController extends ItemController
{
	/**
	 * Constructor.
	 * Makes sure that the appropriate operations are instantiated.
	 */
	function CheckbookController ()
	{
		parent::ItemController ();
		$this->operations = new CheckbookServices ();
		$this->preferences = new CheckbookPreferences ();
		$this->itemFactory = new CheckbookFactory ();

		$this->pluginName = 'checkbook';
		$this->title = 'Brim - Checkbook';
		$this->itemName = 'Checkbook';

		$this->expandName = 'checkbookExpand';
	}

	/**
 	 * Returns the actions defined for this item only
 	 *
 	 * @return array an array of item specific actions (like search, import etc.)
 	 */
	function getActions ()
	{
		$actions=array();

		// Actions
		$actions[0]['name']= 'actions';
		$actions[0]['contents'][]=
			array('href' => 'index.php?plugin=checkbook&action=add&parentId='.$this->getParentId (),
			'name' => 'add');
		$actions[0]['contents'][]=
			array('href' => 'index.php?plugin=checkbook&action=transferPrepare&parentId='.
				$this->getParentId (),
			'name' => 'transfer');
		$actions[0]['contents'][]=
			array('href' => 'index.php?plugin=checkbook&action=search',
			'name' => 'search');

		//
		// If we are simply 'viewing' an item, add 'modify' as action
		// to the action list
		//
		if ($this->renderEngine->getTokens ('viewAction') == 'show')
		{
			$actions[0]['contents'][]= array (
			'href'=>'index.php?plugin=checkbook&action=modify&itemId='.$this->itemId,
			'name'=>'modify');
		}

		// View
		$actions[1]['name']= 'view';
		$actions[1]['contents'][] =
			array('href' => 'index.php?plugin=checkbook&action=setModePublic&parentId='.$this->getParentId (),
				'name' => 'setModePublic');
		$actions[1]['contents'][] =
			array('href' => 'index.php?plugin=checkbook&action=setModePrivate&parentId='.$this->getParentId (),
				'name' => 'setModePrivate');

		// Preferences
		$actions[2]['name']= 'preferences';
		$actions[2]['contents'][]=
			array ('href'=>'index.php?plugin=checkbook&action=modifyPreferencesPre',
				'name'=>'modify');

		$actions[3]['name']='help';
		$actions[3]['contents'][]=
			array ('href'=>'index.php?plugin=checkbook&action=help',
				'name'=>'help');
		return $actions;
	}

	/**
	 * Activate. Basically this means that the appropriate actions
	 * are executed and an optional result is returned
	 * to be processed/displayed
	 */
	function activate ()
	{
		switch ($this->getAction ())
		{
			case "help":
				$this->helpAction ();
				break;
			case "add":
				$this->addAction ();
				break;
			case "modify":
				$this->modifyAction ();
				break;
			case "showItem":
				$this->showAction ();
				break;
			case "deleteItemPost":
				$this->deleteItemAction ();
				$this->getShowItemsParameters ();
				break;
			case "transferPrepare":
				$this->renderer = 'transferPrepare'.$this->getItemName ();
				$this->renderEngine->assign ('pageTitle', 'Transfer');
				$this->renderEngine->assign ('viewAction', 'add');
				break;
			case "transfer":
				$this->prepareMoveAction ();
				$this->renderer = 'transfer'.$this->getItemName ();
				$item = $this->itemFactory->requestToItem ();
				$this->renderEngine->assign ('itemToTransfer',
					$item);
				$this->renderEngine->assign ('pageTitle', 'Transfer');
				break;
			case "transferItem":
				$item = $this->itemFactory->getToItem();
				//die (print_r ($_GET['oldParentId']));
				$item->parentId = $_GET['oldParentId'];
				$this->operations->transferItem ($this->getUserName (),
					$item, $this->parentId);
				$this->getShowItemsParameters ();
				break;
			case "move":
				$this->moveAction ();
				break;
			case "moveItem":
				$this->moveItemAction ();
				$this->getShowItemsParameters ();
				break;
			// Added by Michael. Default navigation mode.
			case "setModePublic":
				$_SESSION['navigationMode']='public';
				$this->navigationMode ='public';
				$this->getShowItemsParameters ();
				break;
			case "setModePrivate":
				$_SESSION['navigationMode']='private';
				$this->navigationMode ='private';
				$this->getShowItemsParameters ();
				break;
			case "searchCheckbook":
				$this->searchItemAction();
				break;
			case "search":
				$this->renderer = $this->getAction().'Checkbook';
				break;
                        case "addAndAddAnother":
                                $this->addItemAction ();
                                unset ($this->renderObjects);
                                $this->addAction ();
                                break;
			case "addItemPost":
				$this->addItemAction();
				break;
			case "modifyItemPost":
				$this->modifyItemAction();
				$this->getShowItemsParameters ();
				break;
			case "setLineBasedTree":
				$_SESSION['checkbookTree']='LineBased';
				$this->getShowItemsParameters ();
				break;
			case "setExplorerTree":
				$_SESSION['checkbookTree']='Explorer';
				$this->getShowItemsParameters ();
				break;
			case "modifyPreferencesPre":
				$this->renderObjects =
					$this->preferences->getAllPreferences ($this->getUserName ());
				$this->renderer = 'modifyPreferences';
				break;
			case "modifyPreferencesPost":
				$this->preferences->setPreference
					($this->getUserName (), $_POST['name'], $_POST['value']);
				$_SESSION['checkbookTree']=
					$this->preferences->getPreferenceValue
						($this->getUserName (), 'checkbookTree');
				$_SESSION['checkbookOverlib']=
					$this->preferences->getPreferenceValue
						($this->getUserName (), 'checkbookOverlib');
				$_SESSION['checkbookTreeColumnCount']=
					$this->preferences->getPreferenceValue
						($this->getUserName (), 'checkbookTreeColumnCount');
				$this->renderer = 'modifyPreferences';
				$this->renderObjects=$_SESSION;
				break;
			case 'sort':
				$parentId = $_GET['parentId'];
				$field = $_GET['field'];
				$order = $_GET['order'];
				$this->sortAction ($parentId, $field, $order);
				break;
			default:
				if (!isset ($_SESSION['checkbookOverlib']))
				{
					$_SESSION['checkbookOverlib']=
						$this->preferences->getPreferenceValue
							($this->getUserName (), 'checkbookOverlib');
				}
				$this->getShowItemsParameters ();
				break;
			}
	}
}
?>
