<?php

require_once ('framework/model/ItemFactory.php');
require_once ('plugins/checkbook/model/Checkbook.php');

/**
 * CheckbookFactory
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Barry Nauta - April 2006
 * @package org.brim-project.plugins.checkbook
 * @subpackage model
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class CheckbookFactory  extends ItemFactory
{
	/**
	 * Default constructor
	 */
	function CheckbookFactory ()
	{
		parent::ItemFactory ();
	}

	/**
	 * Returns the type of this specific item
	 * @return string the type of this specific
	 * item: <code>Checkbook</code>
	 */
	function getType ()
	{
		return "Checkbook";
	}


	/**
	 * Factory method: Returns a database result into an item
	 *
	 * @param object result the result retrieved from the database
	 * @return array the items constructed from the database resultset
	 */
	function resultsetToItems ($result)
	{
		$items = array ();
		while (!$result->EOF)
		{
			$item = new Checkbook (
				$result->fields['item_id'],
				trim ($result->fields['owner']),
				$result->fields['parent_id'],
				$result->fields['is_parent'],
				trim ($this->stringUtils->gpcStripSlashes
					($result->fields['name'])),
				trim ($this->stringUtils->gpcStripSlashes
					($result->fields['description'])),
				trim ($result->fields['visibility']),
				trim ($result->fields['category']),
				$result->fields['is_deleted'],
				$result->fields['when_created'],
				$result->fields['when_modified'],
				$result->fields['transfer_id'],
				$result->fields['amount'],
				/*$result->fields['is_expense'],*/
				trim ($result->fields['participator']),
				$result->fields['payment_date'],
				trim ($result->fields['medium']),
				trim ($result->fields['payment_type']),
				trim ($result->fields['reference'])
			);
			$items [] = $item;
			$result->MoveNext();
		}
		return $items;
	}

	/**
	 * Returns an empty item
	 * @return object an empty item, all values
	 * set to -null-
	 */
	function getEmptyItem ()
	{
		$item = new Checkbook
			(null, null, null, null,
			null, null, null, null,
			null, null, null, null,
			null, null, null,
			null, null, null
		);
		return $item;
	}

	function requestToItemErrors ()
	{
		$errors = array ();
		if (!isset ($_POST['name']) || $_POST['name']== '')
		{
			$errors[] = 'nameMissing';
		}
		if (!isset ($_POST['amount']) || $_POST['amount']== '')
		{
			if ($_POST['isParent'] == 0)
			{
				$errors[] = 'amountMissing';
			}
		}
		else if (isset ($_POST['amount']))
		{
			if (!$this->checkForValidAmount ())
			{
				$errors[] = 'invalidAmount';
			}
		}
		return $errors;
	}

	function checkForValidAmount ()
	{
		$amount = str_replace ('+', '', $_POST['amount']);
		$amount = str_replace ('-', '', $amount);
		return is_numeric ('0'.str_replace (',','.',$amount));
	}

	function requestToItem ()
	{
		$itemId = $this->getFromPost ('itemId', 0);
		$owner = $_SESSION['brimUsername'];
		$parentId = $this->getFromPost ('parentId', 0);
		$isParent = $this->getFromPost ('isParent', 0);
		$transferId = $this->getFromPost ('transferId', 0);
		$name =
			$this->stringUtils->gpcStripSlashes ($_POST['name']);
		$description = $this->getFromPost ('description', null);
		$visibility = $this->getFromPost ('visibility', 'private');
		$category = $this->getFromPost ('category', null);
		$isDeleted = $this->getFromPost ('isDeleted', 0);
		$when_created = $this->getFromPost ('when_created', null);
		$when_modified = $this->getFromPost ('when_modified', null);
		$amount = str_replace (',','.',$this->getFromPost ('amount', 0));
		$participator = $this->getFromPost ('participator', null);
		$year = $_POST['paymentDateYear'];
		$month = $_POST['paymentDateMonth'];
		$day = $_POST['paymentDateDay'];
		$paymentDate = $year.'-'.$month.'-'.$day;
		$medium = $this->getFromPost ('medium', null);
		$paymentType = $this->getFromPost ('paymentType', null);
		$reference = $this->getFromPost ('reference', null);
		$item = new Checkbook
			(
				$itemId,
				$owner,
				$parentId,
				$isParent,
				$name,
				$description,
				$visibility,
				$category,
				$isDeleted,
				$when_created,
				$when_modified,
				$transferId,
				$amount,
				$participator,
				$paymentDate,
				$medium,
				$paymentType,
				$reference
			);
		return $item;
	}

	function getToItem ()
	{
		$itemId = $this->getFromGet ('itemId', 0);
		$owner = $_SESSION['brimUsername'];
		$parentId = $this->getFromGet ('parentId', 0);
		$isParent = $this->getFromGet ('isParent', 0);
		$name =
			$this->stringUtils->gpcStripSlashes ($_GET['name']);
		$description = $this->getFromGet ('description', null);
		$visibility = $this->getFromGet ('visibility', 'private');
		$category = $this->getFromGet ('category', null);
		$isDeleted = $this->getFromGet ('isDeleted', 0);
		$when_created = $this->getFromGet ('when_created', null);
		$when_modified = $this->getFromGet ('when_modified', null);
		$amount = str_replace (',','.',$this->getFromGet ('amount', 0));
		$isExpense = $this->getFromGet ('isExpense', true);
		$participator = $this->getFromGet ('participator', null);
		$year = $_POST['paymentDateYear'];
		$month = $_POST['paymentDateMonth'];
		$day = $_POST['paymentDateDay'];
		$paymentDate = $year.'-'.$month.'-'.$day;
		$medium = $this->getFromGet ('medium', null);
		$paymentType = $this->getFromGet ('paymentType', null);
		$reference = $this->getFromGet ('reference', null);
		if ($isExpense)
		{
			$amount = $amount * -1;
		}
		// hmm.. what to do about this one at this point?
		$transferId = 0;
		$item = new Checkbook
			(
				$itemId,
				$owner,
				$parentId,
				$isParent,
				$name,
				$description,
				$visibility,
				$category,
				$isDeleted,
				$when_created,
				$when_modified,
				$transferId,
				$amount,
				$participator,
				$paymentDate,
				$medium,
				$paymentType,
				$reference
			);
		return $item;
	}

	function getFromGet ($value, $default)
	{
		if (isset ($_GET[$value]))
		{
			return $_GET[$value];
		}
		return $default;
	}
}
?>