<?php

require_once ('plugins/checkbook/model/Checkbook.php');
require_once ('plugins/checkbook/model/CheckbookFactory.php');
require_once ('framework/model/Services.php');

/**
 * Operations on checkbook items
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Barry Nauta - April 2006
 * @package org.brim-project.plugins.checkbook
 * @subpackage model
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class CheckbookServices extends Services
{
	/**
 	 * Default constructor
	 */
	function CheckbookServices ()
	{
		parent::Services();
		$this->itemFactory = new CheckbookFactory ();

		$queries = array ();
		include ('plugins/checkbook/sql/checkbookQueries.php');
		$this->queries = $queries;
	}

	/**
	 * Adds a checkbook entry for a user
	 *
	 * @param integer userId the identifier for the user
	 * @param object item the item to be added
	 *
	 * @return integer last know id. This is the id of the item
	 * that was newly inserted and for which an id has automatically
	 * been assigned.
	 */
	function addItem ($userId, $item)
	{
		$now = date ("Y-m-d H:i:s");
		$query  = sprintf ($this->queries['addItem'],
			$userId,
			addslashes ($item->parentId),
			addslashes ($item->isParent),
			addslashes ($item->name),
			addslashes ($item->description),
			addslashes ($item->visibility),
			addslashes ($item->category),
			$now,
			$item->transferId,
			$item->amount,
			/*$item->isExpense,*/
			addslashes ($item->participator),
			$item->paymentDate,
			addslashes ($item->medium),
			addslashes ($item->paymentType),
			addslashes ($item->reference)
		);
		$result = $this->db->Execute($query)
			or die("AddCheckbookEntry: " . $this->db->ErrorMsg() . " " . $query);
	}

	/**
	 * Modifies a checkbook entry.
	 *
 	 * @param integer userId the identifier for the user who modifies a
	 i* checkbook entry
	 * @param object item the modified checkbook entry
	 */
	function modifyItem ($userId, $item)
	{
		$this->modifyAnItem ($userId, $item);
		if ($item->transferId > 0)
		{
			$other = $this->getItem ($userId, $item->transferId);
			$other->name = $item->name;
			$other->visibility = $item->visibility;
			$other->description = $item->descirption;
			$other->medium = $item->medium;
			$other->amount = $item->amount*-1;
			$other->participator = $item->participator;
			$other->paymentDate = $item->paymentDate;
			$other->paymentType = $item->paymentType;
			$other->reference = $item->reference;
			$this->modifyAnItem ($userId, $other);
		}
	}

	function modifyAnItem ($userId, $item)
	{
		$now = date ("Y-m-d H:i:s");

		//
		// If we are transferring, this will be a 'negative' amount
		// which will be added as positive amount for the participator
		//
		if ($item->transferId > 0)
		{
			$item->amount = $item->amount * -1;
		}
		$query  = sprintf ($this->queries['modifyItem'],
			$now,
			$item->transferId,
			addslashes ($item->name),
			addslashes ($item->visibility),
			addslashes ($item->description),
			addslashes ($item->parentId),
			$item->isDeleted,
			$item->amount,
			addslashes ($item->participator),
			$item->paymentDate,
			addslashes ($item->medium),
			addslashes ($item->paymentType),
			addslashes ($item->reference),
			$item->itemId) ;

		$result = $this->db->Execute($query)
			or die("ModifyItem: " . $this->db->ErrorMsg() . " " . $query);
	}

	function transferItem ($userId, $item, $parentId)
	{
		//
		// Transferdate is now
		//
		$item->paymentDate = date ('Y-m-d');
		//
		// Retrieve origin and destination folder
		//
		$originalFolder = $this->getItem ($userId, $item->parentId);
		$destinationFolder = $this->getItem ($userId, $parentId);
		//
		// Set amount and paymenttype
		//
		$item->amount = $item->amount * -1;
		$item->paymentType = 'Transfer';
		//
		// Set the participator based on folder name
		//
		if ($parentId == 0)
		{
			$item->participator = 'Brim::Root';
		}
		else
		{
			$item->participator =
				'Brim::'.$destinationFolder->name;
		}
		$item->transferId = $parentId;
		$this->addItem ($userId, $item);
		//
		// Retrieve the id receive upon insertion of the item
		//
		$query = $this->queries['lastItemInsertId'];
		$result=$this->db->Execute($query)
			or die ("transferItem: " .$this->db->ErrorMsg () . " " . $query);
		$originId =  $result->fields[0];
		//
		// Now handle the destination
		//
		$item->transferId = $item->parentId;
		$item->parentId = $parentId;
		$item->participator = 'Brim::'.$originalFolder->name;
		$item->amount = $item->amount * -1;
		$this->addItem ($userId, $item);
		//
		// Retrieve the id receive upon insertion of the item
		//
		$query = $this->queries['lastItemInsertId'];
		$result=$this->db->Execute($query)
			or die ("transferItem: " .$this->db->ErrorMsg () . " " . $query);
		$destinId =  $result->fields[0];
		//
		// Retrieve the two items and toggle their transferId
		//
		$origin = $this->getItem ($userId, $originId);
		$destin = $this->getItem ($userId, $destinId);
		$origin->transferId = $destin->itemId;
		$destin->transferId = $origin->itemId;
		$this->modifyItem ($userId, $origin);
		$this->modifyItem ($userId, $destin);
	}


	function deleteItem ($userId, $itemId)
	{
		$item = $this->getItem ($userId, $itemId);
		if ($item->transferId != 0)
		{
				parent::deleteItem ($userId, $item->transferId);
		}
		parent::deleteItem ($userId, $itemId);
	}
}
?>