<?php

require_once ("framework/util/StringUtils.php");
require_once ("framework/view/TreeDelegate.php");

/**
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Barry Nauta - April 2006
 * @package org.brim-project.plugins.checkbook
 * @subpackage view
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class CheckbookLineBasedTreeDelegate extends TreeDelegate
{
	/**
	 * Have we already drawn a header?
	 */
	var $headersDrawn;

	/**
	 * The total amount
	 */
	var $totalAmount;

	function CheckbookLineBasedTreeDelegate ($theConfiguration)
	{
		parent::TreeDelegate ($theConfiguration);
		$this->headersDrawn = false;
		$this->totalAmount = 0;
	}

	/**
	 * Builds up html code to display the root of the tree
	 * @private
	 *
	 * @param object item the item that is the root of the tree
	 */
	function showRoot ($item, $tree)
	{

		if (isset($item) && $item->itemId != 0)
		{
			$resultString = '<h2>'.$item->name.'</h2>';
			$resultString .= '<a href="'.$this->configuration['callback'];
			$resultString .= '&action=show&parentId='.$item->parentId.'">';
			$resultString .= $this->configuration['icons']['up'];
			$resultString .= '</a><br />';
		}
		else
		{
			$resultString = '';
		}
		return $resultString;
	}

	/**
	 * If the specified item is a folder, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean isExpanded whether this folder is expanded (i.e. do the
	 * children of this folder need to be displayed as well?)
	 * @param object tree the tree that uses this class as delegate
	 * @return string the string for this folder
	 */
	function drawFolder ($item, $isExpanded, $tree, $indentLevel)
	{
		$resultString = '';
		if ($item->owner == $_SESSION['brimUsername'])
		{
			$resultString .= '<a href="';
			$resultString .= $this->configuration['callback'];
			$resultString .= '&action=modify&itemId='.$item->itemId;
			$resultString .= '&parentId='.$item->parentId.'">';
			$resultString .= $this->configuration['icons']['folder_closed'];
			$resultString .= '</a>';
		}
		else 
		{
			$resultString .= $this->configuration['icons']['folder_closed'];
		}
		$resultString .= '<a href="';
		$resultString .= $this->configuration['callback'];
		$resultString .= '&action=show&parentId=';
		$resultString .= $item->itemId . '">';
		$resultString .= $item->name;
		$resultString .= '</a>';

		$resultString .= '<br />';
		return $resultString;
	}

	function drawLinesHeader ($parentId)
	{
		$resultString = '<td colspan="10"></td></tr><tr>';
		$resultString .= '<td>&nbsp;</td>';
		$resultString .= '<td>&nbsp;</td>';

		$resultString .= '<td><b>'.$this->configuration['dictionary']['name'];
		$resultString .= $this->sortArrows ('name', $parentId);
		$resultString .= '</b></td>';

		//$resultString .= '<td><b>'.$this->configuration['dictionary']['medium'];
		//$resultString .= $this->sortArrows ('medium', $parentId);
		//$resultString .= '</b></td>';

		$resultString .= '<td><b>'.$this->configuration['dictionary']['reference'];
		$resultString .= $this->sortArrows ('reference', $parentId);
		$resultString .= '</b></td>';

		$resultString .= '<td><b>'.$this->configuration['dictionary']['type'];
		$resultString .= $this->sortArrows ('payment_type', $parentId);
		$resultString .= '</b></td>';

		$resultString .= '<td><b>'.$this->configuration['dictionary']['participator'];
		$resultString .= $this->sortArrows ('participator', $parentId);
		$resultString .= '</b></td>';

		$resultString .= '<td><b>'.$this->configuration['dictionary']['date'];
		$resultString .= $this->sortArrows ('payment_date', $parentId);
		$resultString .= '</b></td>';

		$resultString .= '<td><b>'.$this->configuration['dictionary']['income'];
		$resultString .= $this->sortArrows ('amount', $parentId);
		$resultString .= '</b></td>';

		$resultString .= '<td><b>'.$this->configuration['dictionary']['expense'];
		$resultString .= $this->sortArrows ('amount', $parentId);
		$resultString .= '</b></td>';

		$resultString .= '<td><b>'.$this->configuration['dictionary']['total'];
		$resultString .= '</b></td>';

		$resultString .= '</tr><tr class="odd">';
		return $resultString;
	}

	/**
	 * If the specified item is a node, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean lastNode whether this node is the last one
	 * @return string the string for this node
	 */
	function drawNode ($item, $lastNode, $tree, $indentLevel)
	{
		if ($this->headersDrawn)
		{
			$resultString = '';
		}
		else
		{
			$resultString = $this->drawLinesHeader ($item->parentId);
			$this->headersDrawn = true;
		}
		if ($item->owner == $_SESSION['brimUsername'])
		{
			// header with two icons and overlib popup
			$resultString .= '<td width="20" align="right">';
			$resultString .= '<a href="'.$this->configuration['callback'];
			$resultString .= '&action=modify&itemId='.$item->itemId;
			$resultString .= '&parentId='.$item->parentId.'">';
			$resultString .= $this->configuration['icons']['edit'].'</a>';
			$resultString .= '</td>';
	
			$resultString .= '<td width="20" align="right">';
			$resultString .= '<a href="'.$this->configuration['callback'];
			$resultString .= '&itemId='.$item->itemId;
			$resultString .= '&parentId='.$item->parentId;
			$resultString .= '&action=deleteItemPost" ';
			// delete confirmation
			$resultString .= 'onclick="javascript:return confirm (\'';
			if ($item->transferId > 0)
			{
				$resultString .=
					$this->configuration['dictionary']['confirmDeleteTransfer'];
			}
			else
			{
				$resultString .=
					$this->configuration['dictionary']['confirm_delete'];
			}
			$resultString .= '\');" ';
			$resultString .= '>'.$this->configuration['icons']['delete'].'</a>';
			$resultString .= '</td>';
		}
		else 
		{
			$resultString .= '<td width="20" align="right">';
			$resultString .= $this->configuration['icons']['edit'].'</a>';
			$resultString .= '</td>';
	
			$resultString .= '<td width="20" align="right">';
			$resultString .= $this->configuration['icons']['delete'];
			$resultString .= '</td>';
		}
		$resultString .= '<td>';
		$resultString .= '<a href="'.$this->configuration['callback'];
		$resultString .= '&action=showItem&itemId='.$item->itemId;
		$resultString .= '&parentId='.$item->parentId.'" ';
		if ($this->configuration['overlib'])
		{
			$popUp = $this->overlibPopup ($item);
			$resultString .= $this->overLib ($item->name, $popUp);
		}
		$resultString .= '>';
		$resultString .= '<b>'.$this->stringUtils->truncate ($item->name, 30). '</b></a>';
		$resultString .= '</td>';

		/*
		$resultString .= '<td>';
		if (isset ($item->medium))
		{
			$resultString .= $item->medium;
		}
		else
		{
			$resultString .= '&nbsp;';
		}
		$resultString .= '</td>';
		*/

		$resultString .= '<td>';
		if (isset ($item->reference))
		{
			$resultString .= $item->reference;
		}
		else
		{
			$resultString .= '&nbsp;';
		}
		$resultString .= '</td>';

		$resultString .= '<td>';
		if (isset ($item->paymentType))
		{
			$resultString .= $item->paymentType;
		}
		else
		{
			$resultString .= '&nbsp;';
		}
		$resultString .= '</td>';

		$resultString .= '<td>';
		if (isset ($item->participator))
		{
			$resultString .= $item->participator;
		}
		else
		{
			$resultString .= '&nbsp;';
		}
		$resultString .= '</td>';

		$resultString .= '<td>';
		$resultString .= date ('Y-m-d', strtotime ($item->paymentDate));
		$resultString .= '</td>';

		if (isset ($item->amount))
		{
			if ($item->amount >= 0)
			{
				$resultString .= '<td align="right">';
				$resultString .= $item->amount;
				$resultString .= '</td>';
				$resultString .= '<td>&nbsp;</td>';
			}
			else
			{
				$resultString .= '<td>&nbsp;</td>';
				$resultString .= '<td align="right">';
				$resultString .= $item->amount;
				$resultString .= '</td>';
			}
			$this->totalAmount += $item->amount;
		}
		else
		{
			$resultString .= '<td>&nbsp;</td>';
			$resultString .= '<td>&nbsp;</td>';
		}
		$resultString .= '<td align="right">'.$this->totalAmount.'</td>';

		if ($lastNode)
		{
			$resultString .= '<tr>';
			$resultString .= '<td colspan="9">&nbsp;</td>';
			$resultString .= '<td class="linebaseTotal"
				align="right">'.$this->totalAmount.'</td>';
			$resultString .= '</tr>';
		}
		return $resultString;
	}

	function overlibPopup ($item)
	{
		if ($this->configuration['overlib'])
		{
			$popUp  = '<table cellspacing=2>';
			if (isset ($item->description))
			{
				$popUp .= "<tr>";
				$popUp .= '<td colspan="2">'.$item->description."</td>";
				$popUp .= "</tr>";
			}
			$popUp .= "</table>";
		}
		return $popUp;
	}
}
?>