<?php
require_once('framework/ItemController.php');
require_once('plugins/collections/model/CollectionsServices.php');
require_once('plugins/collections/model/CollectionsPreferences.php');
require_once('plugins/collections/model/CollectionsDetailController.php');
require_once('plugins/collections/model/PlaylistController.php');
require_once('plugins/collections/util/CollectionsID3.php');

/**
 * The Collections Controller
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Moritz Julen - March 2006
 * @package org.brim-project.plugins.collections
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class CollectionsController extends ItemController
{
    var $DetailController;
    var $PlaylistController;

    /**
     * Constructor.
     * Makes sure that the appropriate operations are instantiated.
     * @param string renderEngineName the render engine that is used
     * (either Smarty or phpSavant)
     */
    function CollectionsController()
    {
            parent::ItemController();

            $this->DetailController = new CollectionsDetailController();
            $this->PlaylistController = new PlaylistController($this);

            $this->operations = new CollectionsServices();
            $this->preferences = new CollectionsPreferences();
            $this->itemFactory = new CollectionsFactory();

            $this->pluginName = 'collections';
            $this->title = 'Brim - Collections';
            $this->itemName = 'CollectionItem';
            $this->expandName = 'collectionsExpand';
    }


    /**
      * Returns the actions defined for this item only
      *
      * @return array an array of item specific actions
     * (like search, import etc.)
      */
    function getActions()
    {
        // Actions
        $actions[0]['name']='actions';
        // other actions added in template
        $actions[0]['contents'][]= array(
            'href' => 'CollectionsController.php?action=search',
            'name' => 'search');
        $parent = NULL;
        if (0 != $this->parentId)
        {
            $parent = $this->operations->getItem($this->getUserName(), $this->parentId);
        }
        // echo $this->parentId.":".$parent."->".$parent->entryId." ".$parent->isEntry."<br />";
        // echo $this->action."<br />";
        switch ($this->action)
        {
            case 'showItem':
                if ((0 == $parent->entryId) && (!$parent->isEntry))
                {
                    $actions[0]['contents'][]= array (
						'href' => 'CollectionsController.php?action=modify&parentId='.$this->parentId.'&itemId='.$this->itemId,
                        'name' => 'modify');
                }
                break;
            case 'add':
            case 'modify':
                break;
            case 'searchCollections':
                break;
            case 'multipleSelectPre':
                    $actions[0]['contents'][]= array (
                    	'href'=>'javascript:selectAll();',
						'name'=>'selectAll');
					$actions[0]['contents'][]= array (
						'href'=>'javascript:inverseAll();',
						'name'=>'inverseAll');
            	break;
            default:
                if ((NULL == $parent) || ((0 == $parent->entryId) & !$parent->isEntry))
                {
                    // can only add an entry or folder, when the parent folder is not an entry
                    $actions[0]['contents'][]= array (
        	            'href' => 'CollectionsController.php?action=add&parentId='.$this->parentId,
                        'name' => 'add');
                    $actions[0]['contents'][]= array (
        	            'href' => 'CollectionsController.php?action=createPlaylist&parentId='.$this->parentId,
                        'name' => 'createPlaylist');
                    $actions[0]['contents'][]=
        			    array ('href'=>'CollectionsController.php?action=multipleSelectPre&parentId='.$this->parentId,
        			    'name'=>'multipleSelect');
                }
        }
        // View
        $actions[1]['name']='view';
        $actions[1]['contents'][]=
			array('href' => 'CollectionsController.php?expand=*',
			'name' => 'expand');
		$actions[1]['contents'][]=
			array('href' => 'CollectionsController.php?expand=0',
			'name' => 'collapse');
		$actions[1]['contents'][]=
			array('href' => 'CollectionsController.php?action=setYahooTree&parentId='.$this->getParentId (),
			'name' => 'yahooTree');
		$actions[1]['contents'][]=
			array('href' => 'CollectionsController.php?action=setExplorerTree&parentId='.$this->getParentId (),
			'name' => 'explorerTree');
        $actions[1]['contents'][]=
			array('href' => 'CollectionsController.php?action=setLineBasedTree&parentId='.$this->getParentId (),
				'name' => 'lineBasedTree');
        $actions[1]['contents'][]=
			array('href' => 'CollectionsController.php?action=setThumbnailTree&parentId='.$this->getParentId (),
			'name' => 'thumbnailTree');
        $actions[1]['contents'][] =
			array('href' => 'CollectionsController.php?action=setModePublic&parentId='.$this->getParentId (),
			'name' => 'setModePublic');
		$actions[1]['contents'][] =
			array('href' => 'CollectionsController.php?action=setModePrivate&parentId='.$this->getParentId (),
			'name' => 'setModePrivate');


        // Preferences
        $actions[2]['name'] = 'preferences';
        $actions[2]['contents'][] =
                array ('href' => 'CollectionsController.php?action=modifyPreferencesPre&parentId='.$this->getParentId (),
                           'name' => 'modify');

        // help
        $actions[3]['name'] = 'help';
        $actions[3]['contents'][] =
                        array ('href' => 'CollectionsController.php?action=help&parentId='.$this->getParentId (),
                                   'name' => 'help');

        return $actions;
    }

    /**
     * Activate. Basically this means that the appropriate actions
     * are executed and an optional result is returned
     * to be processed/displayed
     */
    function activate()
    {
        $dictionary = $this->getDictionary();
//        echo $_SESSION['collectionsExpand']."<br />";
        switch ($this->getAction())
        {
            case "createPlaylist":
            	$_SESSION['Playlist'] = 'add';
         	case "add":
                $this->addAction();
                break;
            case "modify":
                $this->modifyAction();
                break;
            case "showItem":
                $this->showAction();
                break;
            case "deleteItemPost":
                $this->deleteItemAction();
                $this->getShowItemsParameters();
                break;
            case "addItemPost":
                $this->addItemAction();
                break;
            case "modifyItemPost":
                $this->modifyItemAction();
                $this->getShowItemsParameters();
                break;
   			case "move":
				$this->moveAction ();
				break;
  			case "moveItem":
				$this->moveItemAction ();
				$this->getShowItemsParameters ();
				break;
            case "help":
                $this->helpAction();
                break;
			case "setYahooTree":
				$_SESSION['collectionsTree']='Yahoo';
				$this->getShowItemsParameters ();
				break;
			case "setExplorerTree":
				$_SESSION['collectionsTree']='Explorer';
				$this->getShowItemsParameters ();
				break;
            case "setLineBasedTree":
				$_SESSION['collectionsTree']='LineBased';
				$this->getShowItemsParameters ();
	            break;
	        case "setThumbnailTree":
                $_SESSION['collectionsTree']='Thumbnail';
				$this->getShowItemsParameters ();
	            break;
            case "sort":
				$this->sortAction($_GET['parentId'], $_GET['field'], $_GET['order']);
				$this->AddItemsDetails($this->renderObjects);
				break;
			case "modifyPreferencesPre":
				$this->renderObjects =
					$this->preferences->getAllPreferences ($this->getUserName ());
				$this->renderer = 'modifyPreferences';
				break;
			case "modifyPreferencesPost":
				$this->preferences->setPreference ($this->getUserName (), $_POST['name'], $_POST['value']);
				$_SESSION['collectionsTree']=
					$this->preferences->getPreferenceValue ($this->getUserName (), 'collectionsTree');
				$_SESSION['collectionsOverlib']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'collectionsOverlib');
				$_SESSION['collectionsYahooTreeColumnCount']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'collectionsYahooTreeColumnCount');
                $_SESSION['collectionsTruncateSize']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'collectionsTruncateSize');
                $_SESSION['collectionsNewWindowTarget']=
                 		$this->preferences->getPreferenceValue ($this->getUserName (), 'collectionsNewWindowTarget');
				$this->renderer = 'modifyPreferences';
				$this->renderObjects=$_SESSION;
				break;
   			case "multipleSelectPre":
				$_SESSION['collectionsExpand']='*';
                $this->operations->getAllChildren = false;
                $this->multipleSelectAction();
                $this->operations->getAllChildren = true;
				break;
			case "multipleSelectPost":
				$_SESSION['collectionsExpand']='0';
				$itemIds = array_keys ($_POST, "itemId");
				if (isset ($_POST['move']))
				{
					$this->moveMultipleAction($itemIds);
				}
				else if (isset ($_POST['delete']))
				{
					foreach ($itemIds as $itemId)
					{
						$this->operations->deleteItem($this->getUserName (), $itemId);
					}
					$this->getShowItemsParameters ();
				}
				break;
			case "moveMultipleItemsPost":
				$_SESSION['collectionsExpand']='0';
				$itemIds = explode (",", $_GET['itemIds']);
				$parentId = $_GET['parentId'];
				foreach ($itemIds as $itemId)
				{
				    $this->operations->moveItem($this->getUserName (), $itemId, $parentId);
				}
				$this->getShowItemsParameters ();
				break;

            case "searchCollections":
				$this->searchItemAction();
				break;
			case "search":
				$this->renderer = $this->getAction().'Collections';
				break;
            case "help":
				$this->helpAction ();
				break;
            // Added by Michael. Default navigation mode. If used, change in other plugins.
			case "setModePublic":
				$_SESSION['navigationMode']='public';
				$this->navigationMode ='public';
				$this->getShowItemsParameters ();
				break;
			case "setModePrivate":
				$_SESSION['navigationMode']='private';
				$this->navigationMode ='private';
				$this->getShowItemsParameters ();
				break;
			case "execute":
			case "playTrack":
                $item = $this->operations->getItem($this->getUserName(), $this->itemId);
                if( isset($item->path) && ("" != $item->path) )
                {
	                // start with empty output buffer
	                ob_clean();

                    // Date in the past
					header("Expires: Mon, 26 Jul 1997 05:00:00 GMT");
					// always modified
					header("Last-Modified: " . gmdate("D, d M Y H:i:s") . " GMT");
					// HTTP/1.1
					header("Cache-Control: no-store, no-cache, must-revalidate");
					header("Cache-Control: post-check=0, pre-check=0", false);
					// HTTP/1.0
					header("Pragma: no-cache");
                    // to download the file
					header('content-type: binary/octet-stream');
                    header('content-disposition: attachment; filename='.$item->name);
					@readfile($item->path);
	                exit;
				}
			case "showThumbnail":
                // get item
				$item = $this->operations->getItem($this->getUserName(), $this->itemId);
				$id3 = new CollectionsID3();
                // get id3v
				$info = $id3->getInfo($item->path);
                if (isset($info['fileformat']))
		        {
                    // start with empty output buffer
	                ob_clean();

	                /*
                    // Date in the past
					header("Expires: Mon, 26 Jul 1997 05:00:00 GMT");
					// always modified
					header("Last-Modified: " . gmdate("D, d M Y H:i:s") . " GMT");
					// HTTP/1.1
					header("Cache-Control: no-store, no-cache, must-revalidate");
					header("Cache-Control: post-check=0, pre-check=0", false);
					// HTTP/1.0
					header("Pragma: no-cache");
					*/
                    // to download the file
					header('content-type: '.$info['mime_type']);
                    $this->readThumbnail($item->path, $info['fileformat']);
				}
				exit;

            case "addPlaylistItems":
            case "cancelPlaylist":
            case "deletePlaylistItemPost":
            case "moveDownInPlaylist":
            case "moveUpInPlaylist":
            case "multipleAddPlaylistPost":
            case "playPlaylist":
            case "playTrack":
            case "showPlaylist":
                $this->PlaylistController->activate();
                break;

            case "showTree":
            default:
   				if (!isset ($_SESSION['collectionsTree']))
				{
					$_SESSION['collectionsTree']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'collectionsTree');
				}
				if (!isset ($_SESSION['collectionsOverlib']))
				{
					$_SESSION['collectionsOverlib']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'collectionsOverlib');
				}
				if (!isset ($_SESSION['collectionsYahooTreeColumnCount']))
				{
					$_SESSION['collectionsYahooTreeColumnCount']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'collectionsYahooTreeColumnCount');
				}
                if (!isset ($_SESSION['collectionsTruncateSize']))
				{
					$_SESSION['collectionsTruncateSize']=
						$this->preferences->getPreferenceValue($this->getUserName (), 'collectionsTruncateSize');
					if ("" == $_SESSION['collectionsTruncateSize'])
					{
					 	$_SESSION['collectionsTruncateSize'] = "25";
					}
				}
                if (!isset($_SESSION['collectionsNewWindowTarget']))
				{
                 	$_SESSION['collectionsNewWindowTarget']=
                 		$this->preferences->getPreferenceValue ($this->getUserName (), 'collectionsNewWindowTarget');
				}
				$this->getShowItemsParameters ();
                break;
        }
    }

    function display()
	{
        switch ($this->getAction())
		{
            case "addPlaylistItems":
            case "cancelPlaylist":
            case "deletePlaylistItemPost":
            case "moveDownInPlaylist":
            case "moveUpInPlaylist":
            case "multipleAddPlaylistPost":
            case "playPlaylist":
            case "showPlaylist":
            	$this->PlaylistController->display();
            	break;
    		default:
    			parent::display();
		}
    }

    function getShowItemsParameters()
    {
//    	echo "getShowItemsParameters: ".date("Y-m-d H:i:s")."<br />";
        parent::getShowItemsParameters();
//        echo "parent::getShowItemsParameters: ".date("Y-m-d H:i:s")."<br />";
        $showdetails = $this->AddItemsDetails($this->renderObjects);
//        echo "AddItemsDetails: ".date("Y-m-d H:i:s")."<br />";
    }

    /**
	 * show Action
     * extended Moritz Julen
	 */
	function showAction ()
	{
        parent::showAction();
        $this->renderObjects->entryName = $this->operations->getEntryName($this->renderObjects->itemId, $this->renderObjects->entryId);
        if (NULL != $this->renderObjects->entryType)
        {
            $this->renderObjects->AddDetail($this->DetailController->operations->getChildren($this->getUserName(), $this->renderObjects->itemId));
        }
	}

    function modifyAction ()
	{
		parent::modifyAction();
        if (NULL != $this->renderObjects->entryType)
        {
            $this->renderObjects->AddDetail($this->DetailController->operations->getChildren($this->getUserName(), $this->renderObjects->itemId));
        }
	}


    /**
	 * Search for items
	 *
	 * @protected
	 * @modifed Michael Haussmann
     * extended Moritz Julen
	 */
	function searchItemAction ()
	{
       $items = array();
       if($this->navigationMode == 'public')
	 {
	  	$items = $this->operations->searchPublicItems
   			($this->getUserName(), $_POST['field1'], $_POST['value']);
		$items2 = $this->operations->searchPublicItems
   			($this->getUserName(), $_POST['field2'], $_POST['value']);
	 }
	 else
	 {
		$items = $this->operations->searchItems
   			($this->getUserName(), $_POST['field1'], $_POST['value']);
		$items2 = $this->operations->searchItems
   			($this->getUserName(), $_POST['field2'], $_POST['value']);
	 }
	//array_push($items, $items2);
	foreach ($items2 as $item)
	{
		$items[] = $item;
	}

       // mark list view for search result
       $_SESSION['collectionsSearch']= true;
       $this->renderObjects = $items;
	   $this->renderer = 'show'.$this->getItemName ().'s';
	}


    /**
     * Items parameters has been provided, now really add it
	 *
	 * @protected
	 * @modified Michael Haussmann
     * extended Moritz Julen
	 */
	function addItemAction ()
	{
	 	$errors = array ();
	 	$dictionary = $this->getDictionary();
		$item = $this->itemFactory->requestToItem ();
		$errors = $this->itemFactory->requestToItemErrors ();
		if (empty($errors))
		{
            if (isset($item->entryType) && ('m3u'==$item->entryType))
            {
                $this->operations->addItem($this->getUserName(), $item, true);
	            if (!empty($this->operations->errors))
	            {
	             	// send error message
	            	$this->addParameter("errors", $this->operations->errors);
					$this->addAction ();
					return;
				}
				$this->getShowItemsParameters();
			}
			else
			{
	         	$item->path = $this->FormatPathName($item->path);
			 	$manentry = ((isset($_POST['detailname']) && ("" != $_POST['detailname'])) ||
			 				 (isset($_POST['detaildescription']) && ("" != $_POST['detaildescription'])) );
			 	if ($manentry)
			 	{
	            	$item->path .= $item->name;
				}
				$itemid = $this->operations->addItem(
					$this->getUserName(), $item, $manentry);
	            if (!empty($this->operations->errors))
	            {
	             	// send error message
	            	$this->addParameter("errors", $this->operations->errors);
					$this->addAction ();
					return;
				}
	            if (0 != $itemid)
	            {
	                // detail entry
	                $item->itemId = $itemid;
	                $_POST['parentId'] = $itemid;
	                $this->DetailController->addItemAction();
	            }
				$this->getShowItemsParameters ();
			}
		}
		else
		{
			$this->addParameter("errors", $errors);
			$this->addAction ();
		}
	}

    function modifyItemAction()
    {
        if (parent::modifyItemAction())
        {
            $item = $this->getItem($this->getUserName(), $this->itemId);
              if (NULL != $item->entryType)
              {
                  	// detail entry
                    $_POST['parentId'] = $itemid;
                    $_POST['itemId'] = $itemid;
                	$this->DetailController->modifyItemAction();
              }
        }
    }


    function AddItemsDetails(&$items)
    {
        $showdetail = false;
        $i = 0;
        while (isset($items[$i]))
        {
            if ($items[$i]->isParent)
            {
                $showdetail |= $this->AddItemsDetails($items[$i]->children);

            }
            if (NULL != $items[$i]->entryType)
            {
                $items[$i]->AddDetail($this->DetailController->operations->getChildren($this->getUserName(),
                                                    $items[$i]->itemId));
                $showdetail = true;
                $_SESSION['collectionsShowDetails']='true';
            }
            $i++;
        }
        return $showdetail;
    }

    function FormatPathName($path)
    {
     	$path = trim($path);
        $path = str_replace(DIRECTORY_SEPARATOR.DIRECTORY_SEPARATOR, '/', $path);
        $path = str_replace(DIRECTORY_SEPARATOR, '/', $path);
        if (("" != $path) && ('/' != substr($path, strlen($path)-1, 1)))
        {
         	$path .= '/';
		}
		return $path;
	}

	// read file, create thumbnail and put it to the output-buffer
	function readThumbnail($path, $typ)
	{
	 	$src = NULL;
	 	// get the image from the file
    	switch($typ)
    	{
    	 	case 'gif':
    	 		$src = imagecreatefromgif($path);
    	 		break;
         	case 'jpg':
         		$src = imagecreatefromjpeg($path);
         		break;
         	case 'png':
         		$src = imagecreatefrompng($path);
         		break;
		}
		if ($src)
		{
            $x = imagesx($src);
            $y = imagesy($src);
            // create the thumbnail destination image
			// true color for better result
            if ($x==$y)
            {
            	$img = imagecreatetruecolor(90, 90);
			}
            elseif ($x > $y)
            {
			 	$img = imagecreatetruecolor(120, 90);
			}
			else
			{
			 	$img = imagecreatetruecolor(90, 120);
			}
			/*
            imageinterlace($src, false);
            imageinterlace($img, false);
            imageantialias($src, false);
            imageantialias($img, false);
             */
		 	// generate thumbnail
            imagecopyresampled($img, $src,
		 						0, 0, 0, 0,
		 						imagesx($img), imagesy($img), $x, $y);
            imagejpeg($img);
		}
	}
}
?>
