<?php

require_once 'framework/Installer.php';
require_once('plugins/collections/model/CollectionItemInstaller.php');
require_once('plugins/collections/model/CollectionDetailItemInstaller.php');

/**
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Moritz Julen - April 2006
 * @package org.brim-project.plugins.collections
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class CollectionsInstaller extends Installer
{
	var $collectionInstaller;
	var $detailInstaller;

	function CollectionsInstaller($engine, $db)
	{
		$this->collectionInstaller = new CollectionItemInstaller($engine, $db);
		$this->detailInstaller = new CollectionDetailItemInstaller($engine, $db);
	}

	function getMessage()
	{
        if (!$this->CheckUtils())
    	{
		}
		$message = $this->collectionInstaller->getMessage();
		if (isset($message) && $message != "")
		{
			return $message;
		}

		$message = $this->detailInstaller->getMessage();
		if (isset($message) && $message != "")
		{
			return $message;
		}

        $this->tableUpToDate = $this->collectionInstaller->isTableUpToDate () &&
        $this->detailInstaller->isTableUpToDate ();
	}

	function install ()
	{
        if ($this->checkUtils())
        {
         	// only install when all utils are installed
			$this->collectionInstaller->install();
			$this->detailInstaller->install();
		}
		else
		{
         	echo 'please install the GD library first
         			(available at <a href="http://www.boutell.com/gd/">
         			http://www.boutell.com/gd/</a>)<br />
         			activate extension=php_gd*.dll in your php.ini';
		}
	}

	function findTable()
	{
		if ($this->collectionInstaller->findTable())
		{
			return $this->detailInstaller->findTable();
		}
		return false;
	}

	function isTableUpToDate()
	{
        if ($this->checkUtils())
        {
         	// only install when all utils are installed
         	if ($this->collectionInstaller->isTableUpToDate())
			{
				$this->detailInstaller->isTableUpToDate();
			}
		}
		return false;
	}

	function createStandardIndex()
	{
		$this->collectionInstaller->createStandardIndex();
		$this->detailInstaller->createStandardIndex();
	}

    function checkUtils()
	{
     	return function_exists('imagecreatetruecolor') && function_exists('imagecopyresampled') &&
     			function_exists('imagejpeg');
	}
}

?>
