<?php
require_once ('plugins/collections/model/CollectionsServices.php');
require_once ('plugins/collections/model/CollectionItem.php');
require_once('plugins/collections/util/getid3/getid3/getid3.php');
require_once('plugins/collections/util/CollectionsID3.php');

/**
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Moritz Julen
 * @package org.brim-project.plugins.collections
 * @subpackage model
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class CDArchiver
// search all the information and files of a path
// and store them into a data base
{
    var $dbServices;
    var $Path = "";
    var $userID;
    var $cditem;
    var $cdrootid;
    var $getID3;
    var $errors = array();

    function CDArchiver($services)
    {
        $this->dbServices = $services;
        $this->getID3 = new CollectionsID3;
    }

    // create the cd info entry in the database
    function GetCDSize()
    {
        if ("" != $this->Path)
        {
            // echo "total: ". disk_total_space($this->Path)."<br />";
            // echo "free: ". disk_free_space($this->Path)."<br />";
            // echo "used: ". (disk_total_space($this->Path) - disk_free_space($this->Path))."<br />";
            return (disk_total_space($this->Path) - disk_free_space($this->Path));
        }
        else
        {
            return 0;
        }
    }

    // convert the time stamp to store into the database
    function ConvStateTimestamp($state)
    {
        for ($i=8; $i<=10; $i++)
        {
            $state[$i] = date("Y-m-d H:i:s", $state[$i]);
        }
        return $state;
    }

    /**
     * Map the directory tree given by the directory parameter and store the tree in the db
     *
     * @param string $directory contains the directory path that you want to map.
     * @param integer $parentid used to rebuild the tree
     *
     * @return array a multidimensional array containing all subdirectories
     * and their files
     *
     */
    function &StoreTree($directory, $parentid)
    {

        $retval = array();

        // is last character a /
        if (strrchr($directory, DIRECTORY_SEPARATOR) != strlen($directory))
        {
            // add / at the end
            $directory .= DIRECTORY_SEPARATOR;
        }
        $dh=opendir($directory);
        while ($entry = readdir($dh)) {
            if ($entry != "." && $entry != "..") {
                 array_push($retval, $entry);
            }
        }
        closedir($dh);

        while (list($key, $val) = each($retval))
        {
            $path = $directory . $val;
            $path = str_replace(DIRECTORY_SEPARATOR.DIRECTORY_SEPARATOR,
                                DIRECTORY_SEPARATOR, $path);

            if (!(is_array($val)))
            {
                if (is_dir($path))
                {
                    // add a folder
                    $nextparentid = $this->StoreEntry($path, $val, $parentid, 1);
                    unset($retval[$key]);
                    $retval[$val] = $this->StoreTree($path,
                                    $nextparentid);
                }
                else
                {
                    // add a file
                    $this->AddEntryDetails($path, $val, $parentid);
                }
            }
        }
        return($retval);
    }


    /**
	 * store the information of a folder or file in the db
	 * @param path of the file/folder
     * @param name of the file/folder
     * @param parentid used for the tree structure
     * @param isparent used to identify if it is a folder
	 * @return itemId return from the db
	 */
    function AddEntryDetails($path, $name, $parentid)
    {
        $fileinfo = $this->getID3->getInfo($path);
         // detect filetype
        if (isset($fileinfo['fileformat']))
        {
            switch($fileinfo['fileformat'])
            {
                case 'mp3':
                    $detail = new CollectionDetailItem(0,
                                                    $this->userID,                              // $theOwner
                                                    0,                                          // $theParentId
                                                    0,                                          // $parent
                                                    $fileinfo['id3v1']['title'],                // $theName
                                                    $fileinfo['id3v1']['album'],                // $theDescription
                                                    $this->cditem->visibility,                  // $theVisibility
                                                    $this->cditem->category,                    // $theCategory
                                                    0,                                          // $deleted
                                                    NULL,                                       // $theCreation
                                                    NULL,                                       // $theModified
                                                    $fileinfo['id3v1']['artist'],               // field1
                                                    $fileinfo['id3v1']['genre'],                // field2
                                                    $fileinfo['id3v1']['year'],                 // field3
                                                    $fileinfo['id3v1']['track'],                // field4
                                                    $fileinfo['playtime_seconds'],              // field5
                                                    $fileinfo['id3v1']['comment']            ); // field6
                    $this->StoreEntry($path, $name, $parentid, 0, $fileinfo['fileformat'], $detail);
                    break;
                case 'iso':
                	$detail = new CollectionDetailItem(0,
                                                    $this->userID,                              // $theOwner
                                                    0,                                          // $theParentId
                                                    0,                                          // $parent
                                                    $fileinfo['iso']['primary_volume_descriptor']['application_identifier'],
                                                    											// $theName
                                                    $fileinfo['iso']['primary_volume_descriptor']['volume_set_identifier'],
                                                    											// $theDescription
                                                    $this->cditem->visibility,                  // $theVisibility
                                                    $this->cditem->category,                    // $theCategory
                                                    0,                                          // $deleted
                                                    $fileinfo['iso']['primary_volume_descriptor']['volume_creation_date_time'],
                                                    											// $theCreation
                                                    $fileinfo['iso']['primary_volume_descriptor']['volume_modification_date_time'],
                                                    											// $theModified
                                                    $fileinfo['iso']['primary_volume_descriptor']['publisher_identifier'],
                                                    											// field1
                                                    $fileinfo['iso']['primary_volume_descriptor']['system_identifier'],
                                                    											// field2
                                                    NULL,                 						// field3
                                                    NULL,                						// field4
                                                    NULL,              							// field5
                                                    NULL            ); 							// field6
                    $parentId = $this->StoreEntry($path, $name, $parentid, 1, $fileinfo['fileformat'], $detail);
                    $this->StoreSubStructure($fileinfo['iso']['files'], $parentId);
                	break;
                case 'zip':
                	$detail = new CollectionDetailItem(0,
                                                    $this->userID,                              // $theOwner
                                                    0,                                          // $theParentId
                                                    0,                                          // $parent
                                                    $fileinfo['zip']['uncompressed_size'],		// $theName
                                                    $fileinfo['zip']['entries_count'],			// $theDescription
                                                    $this->cditem->visibility,					// $theVisibility
                                                    $this->cditem->category,					// $theCategory
                                                    0,                                          // $deleted
                                                    NULL,                                       // $theCreation
                                                    NULL,                                       // $theModified
                                                    NULL,										// field1
                                                    NULL,										// field2
                                                    NULL,										// field3
                                                    NULL,										// field4
                                                    NULL,										// field5
                                                    NULL            );							// field6
                    $parentId = $this->StoreEntry($path, $name, $parentid, 1, $fileinfo['fileformat'], $detail);
                    $this->StoreSubStructure($fileinfo['zip']['files'], $parentId);
                    break;
                default:
                    // no additional information available
                    $this->StoreEntry($path, $name, $parentid, 0, $fileinfo['fileformat']);
                    break;
            }
        }
        else
        {
            // no additional information available
            $this->StoreEntry($path, $name, $parentid, 0);
        }
    }


    /**
	 * store the information of a folder or file in the db
	 * @param path of the file/folder
     * @param name of the file/folder
     * @param parentid used for the tree structure
     * @param isparent used to identify if it is a folder
	 * @return itemId return from the db
	 */
    function StoreEntry($path, $name, $parentid, $isparent=0, $filetype=NULL, $detail=NULL)
    {
        $state = $this->ConvStateTimestamp(stat($path));
        // fill information in a collectionitem object
        $item = new CollectionItem(0,                           // $theItemId
                                $this->userID,                  // $theOwner
                                $parentid,                      // $theParentId
                                $isparent,                      // $parent
                                $name,                          // $theName
                                "",                             // $theDescription
                                $this->cditem->visibility,      // $theVisibility
                                $this->cditem->category,        // $theCategory
                                0,                              // $deleted
                                $state[10],                     // $theCreation
                                $state[9],                      // $theModified
                                0,                              // theIsEntry
                                $this->cditem->itemId,          // $theEntryId
                                $filetype,                      // $theEntryType
                                $state[7],                      // $theSize
                                $path);                         // $thePath
        unset($state);
        if (NULL != $detail)
        {
        	$item->AddDetail($detail);
		}
        // store information
        return $this->dbServices->AddEntry($this->userID, $item);
    }


	// store tree from getid3 details in database
    function StoreSubStructure($tree, $parentid)
    {
        while (list($key, $val) = each($tree))
        {
            if (is_array($val))
            {
                // store folder
                $nextparentid = $this->StoreSubStructureEntry($key, 0, $parentid, 1);
                // expand folder recursive
                $this->StoreSubStructure($tree[$key], $nextparentid);
            }
            else
            {
                // store file
            	$this->StoreSubStructureEntry($key, $val, $parentid, 0);
			}
        }
	}

    /**
	 * store the information of a folder or file in the db
	 */
    function StoreSubStructureEntry($name, $size, $parentid, $isparent=0)
    {
         // fill information in a collectionitem object
        $item = new CollectionItem(0,                           // $theItemId
                                $this->userID,                  // $theOwner
                                $parentid,                      // $theParentId
                                $isparent,                      // $parent
                                $name,                          // $theName
                                "",                             // $theDescription
                                $this->cditem->visibility,      // $theVisibility
                                $this->cditem->category,        // $theCategory
        						NULL,                           // $deleted
                                NULL,                     		// $theCreation
                                NULL,							// $theModified
                                0,                              // theIsEntry
                                $this->cditem->itemId,          // $theEntryId
                                NULL,							// $theEntryType
                                $size,							// $theSize
                                "");                            // $thePath
        return $this->dbServices->AddEntry($this->userID, $item);
	}


    // check the path
    function CheckAndAddPath($path)
    {
        // replace \\ -> \ or // -> /
        $this->Path = str_replace(DIRECTORY_SEPARATOR.DIRECTORY_SEPARATOR, DIRECTORY_SEPARATOR, $path);
        if (is_dir($this->Path))
        {
            if ($dirhandle=@opendir($this->Path))
            {
            	closedir($dirhandle);
         		return true;
			}
			else
			{
			 	// directory is empty
                $this->errors[] = 'directoryEmpty';
            	return false;
			}
        }
        else
        {
            // path is not valid
         	$this->errors[] = 'pathNotFound';
            return false;
        }
    }

    function Run($userID, $cditem)
    {
//        echo date("Y-m-d H:i:s")."<br />";
        $this->userID = $userID;
        $ret = $this->CheckAndAddPath($cditem->path);
        if ($ret)
        {
        	// calculate the cd disk size
	        $cditem->size = $this->GetCDSize();
	        // the root entry for the cd must be a folder
	        $cditem->isParent = "1";
	        $cditem->itemId = $this->dbServices->AddEntry($this->userID, $cditem);
	        $this->cditem = $cditem;
	        // now check the tree
	        $tree = $this->StoreTree($this->Path, $cditem->itemId);
		}
//        echo date("Y-m-d H:i:s")."<br />";
		return $this->errors;
    }
}
?>
