<?php

require_once 'framework/Installer.php';

/**
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Moritz Julen - April 2006
 * @package org.brim-project.plugins.collections
 * @subpackage model
 * @filesource
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class CollectionItemInstaller extends Installer
{
	function CollectionItemInstaller($engine, $db)
	{
		$this->tableName = 'brim_collections';
		parent::Installer($engine, $db);
	}

	function getMessage()
	{
		if (!$this->findTable ($this->tableName))
		{
			return '<h2>Create table <code>' . $this->tableName . '</code></h2>
				<form method="POST"
					action="'.$_SERVER['PHP_SELF'].'">
				<input type="submit" value="Create table"
					name="create_brim_collections" />
				</form>';
		}
		else if (!$this->isTableUpToDate())
		{
			echo ('Table not up to date');
			return '<h2>Upgrade <code>' . $this->tableName . '</code></h2>
				<p>
					Some important fields will be added to
					the table
				</p>
				<form method="POST"
						action="'.$_SERVER['PHP_SELF'].'">
					<input type="submit" value="Upgrade table"
						name="upgrade_brim_collections" />
				</form>';
		}
	}

	function install ()
	{
		if (!$this->findTable ())
		{
			$dbFile = 'plugins/collections/sql/create.';
			$dbFile .= $this->engine;
			$dbFile .= '.brim_collections.sql';
			$this->createTable($dbFile);
			$this->createStandardIndex();
		}
		else if (!$this->isTableUpToDate ())
		{
			$this->upgradeTable();
			if (!$this->isTableUpToDate ())
			{
				die ('Table '.$this->tableName.' upgraded but does not appear to be up-to-date!!??');
			}
		}
	}


	function isTableUpToDate()
	{
		if (!$this->findTable ())
		{
			return false;
		}
		$columnNames =
			$this->db->MetaColumnNames($this->tableName, true);
		$this->tableUpToDate =
			(count($columnNames) == 16 &&
			$columnNames[ 0] == 'item_id' &&
			$columnNames[ 1] == 'owner' &&
			$columnNames[ 2] == 'parent_id' &&
			$columnNames[ 3] == 'is_parent' &&
			$columnNames[ 4] == 'name' &&
			$columnNames[ 5] == 'description' &&
			$columnNames[ 6] == 'visibility' &&
			$columnNames[ 7] == 'category' &&
			$columnNames[ 8] == 'is_deleted' &&
			$columnNames[ 9] == 'when_created' &&
			$columnNames[10] == 'when_modified' &&

			$columnNames[11] == 'is_entry' &&
			$columnNames[12] == 'entry_id' &&
			$columnNames[13] == 'entry_type' &&
			$columnNames[14] == 'size' &&
			$columnNames[15] == 'path');
		return $this->tableUpToDate;
	}

	function upgradeTable()
	{
        $columnNames =
			$this->db->MetaColumnNames($this->tableName, true);
		if (15 == $this->getColumnsCount())
		{
           // version without path
           // Add field path
		   $query = "ALTER TABLE `".$this->tableName."` ADD path text DEFAULT NULL AFTER size; ";
		   $this->db->Execute($query) or die($this->db->ErrorMsg());
           $this->isTableUpToDate();
		}
	}

    function createStandardIndex()
	{
		$indexName = $this->tableName . '_index';

		$primaryKeys = $this->db->MetaIndexes($this->tableName);

		if (!array_key_exists($indexName, $primaryKeys))
		{
			$query = 'CREATE INDEX '.$this->tableName.'_index ';
			$query .= 'ON '.$this->tableName.' ';
			$query .= '(item_id, parent_id)';
			if (!$this->db->Execute ($query))
			{
				echo ('Error creating index. The database reported the following problem: ');
				echo ('<code>'.$this->db->ErrorMsg().'</code><br />');
				echo ('Indexes are not required so I will just continue....<br />');
			}
		}
	}

    function getColumnsCount()
	{
		$columnNames =
			$this->db->MetaColumnNames($this->tableName, true);
		return count($columnNames);
	}
}
?>