<?php
require_once ('plugins/collections/model/CollectionDetailItem.php');
require_once ('plugins/collections/model/CollectionsDetailFactory.php');
require_once ('framework/model/Services.php');

/**
 * Operations on collection  detail
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Moritz Julen - April 2006
 * @package org.brim-project.plugins.collections
 * @subpackage model
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class CollectionsDetailServices extends Services
{
        /**
         * Default constructor
         */
        function CollectionsDetailServices()
        {
                parent::Services();
                $this->itemFactory = new CollectionsDetailFactory();

                include ('plugins/collections/sql/collectionsdetailQueries.php');
                $this->queries = $queries;
        }


        /**
         * Search for items for a user
         *
         * @param string userId the identifier for the user for which we
         *  	would like to search for items
         * @param string field the field-array on which we would like to search
         * @param string value the value for which we would like to search
         *
         * @return array all items that match the given search criteria
         */
    	function searchItems ($userId, $field, $value)
    	{
            $query = sprintf
    			($this->queries ['searchItems'], $field, $value,
                    $value, $value, $value, $value, $value, $value, $userId);
    		$result = $this->db->Execute ($query) or die
    				("Operations. Search " . $this->db->ErrorMsg () .
    					" " . $query);
    		$items = $this->itemFactory->resultsetToItems($result);
    		return $items;
    	}


        /**
         * Search for items for a user
         *
         * @param string userId the identifier for the user for which we
         *  	would like to search for items
         * @param string field-array the field on which we would like to search
         * @param string value the value for which we would like to search
         *
         * @return array all items that match the given search criteria
         */
    	function searchPublicItems ($userId, $field, $value)
    	{
            $query = sprintf
    			($this->queries ['searchPublicItems'], $field, $value,
                    $value, $value, $value, $value, $value, $value, $userId);
    		$result = $this->db->Execute ($query) or die
    				("Operations. Search " . $this->db->ErrorMsg () .
    					" " . $query);
    		$items = $this->itemFactory->resultsetToItems($result);
    		return $items;
    	}

        function addItem($userId, $item)
        {
    		$query = sprintf ($this->queries['addItem'],
    			$userId,
    			addslashes ($item->parentId),
    			addslashes ($item->isParent),
    			addslashes ($item->name),
    			addslashes ($item->description),
    			addslashes ($item->visibility),
    			addslashes ($item->category),
    			addslashes ($item->isDeleted),
    			addslashes (date ("Y-m-d H:i:s")),
    			addslashes ($item->field1),
                addslashes ($item->field2),
                addslashes ($item->field3),
                addslashes ($item->field4),
                addslashes ($item->field5),
                addslashes ($item->field6)
                );
    		$this->db->Execute ($query) or die ('AddCollectionsDetail: not able to add
    			collections detail ' . $query . " " . $this->db->ErrorMsg());
            $query = $this->queries['lastItemInsertId'];
		    $result=$this->db->Execute($query)
			    or die ("addBookmark: " .$this->db->ErrorMsg () . " " . $query);
    		return $result->fields[0];
        }


        /*
    	 * Modifies a collections detail information
    	 *
     	 * @param integer userId the identifier for the user who modifies a note
    	 * @param object item the modified note
    	 */
    	function modifyItem ($userId, $item)
    	{
    		$query  = sprintf ($this->queries['modifyItem'],
                date ("Y-m-d H:i:s"),
    			addslashes ($item->name),
    			addslashes ($item->visibility),
    			addslashes ($item->description),
    			addslashes ($item->field1),
                addslashes ($item->field2),
                addslashes ($item->field3),
                addslashes ($item->field4),
                addslashes ($item->field5),
                addslashes ($item->field6),
    			$item->itemId) ;

    		$result = $this->db->Execute($query)
    			or die("ModifyCollectionsDetailEntry: " . $this->db->ErrorMsg() . " " . $query);
    	}

	function deleteEntry ($userId, $itemId)
	{
		$query = sprintf ($this->queries['deleteItemId'], $itemId);
		$result = $this->db->Execute($query) or
			die("DeleteItem: " .
			$this->db->ErrorMsg() . " " . $query);
	}
}
?>