<?php
require_once ('plugins/collections/model/CollectionItem.php');
require_once ('plugins/collections/model/CollectionsFactory.php');
require_once ('plugins/collections/model/CollectionsDetailServices.php');
require_once ('plugins/collections/model/CDArchiver.php');
require_once ('framework/model/Services.php');

/**
 * Operations on collection
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Moritz Julen - March 2006
 * @package org.brim-project.plugins.collections
 * @subpackage model
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class CollectionsServices extends Services
{
    var $detailoperations;
    var $getAllChildren = true;
    var $errors = array();

    /**
     * Default constructor
     */
    function CollectionsServices()
    {
        parent::Services();
        $this->itemFactory = new CollectionsFactory();

        include ('plugins/collections/sql/collectionsQueries.php');
        $this->queries = $queries;

        $this->detailoperations = new CollectionsDetailServices();
    }



    /**
     * Adds information for a collections item or the cd tree
     *
     * @param string userId the identifier for the user
     * @param object item the CDCollection information to be added
     *
    * @return integer last know id. This is the id of the CDCollection information
     * that was newly inserted and for which an id has automatically
     * been assigned.
     */
    function addItem($userId, $item, $manentry=false)
    {
		$now = date("Y-m-d H:i:s");
		$item->when_created = $now;
		if ($item->isParent())
		{
		    $item->entryType = NULL;
		    // add the folder
		    return $this->addEntry($userId, $item);
		}
		else
		{
		    $item->isEntry = 1;
		    if ($manentry)
		    {
		        // manual entry
		        return $this->addEntry($userId, $item);
		    }
		    else
		    {
		        $item->entryType = NULL;
		        // automatic tree entry
		        $archiver = new CDArchiver($this);
		        $this->errors = $archiver->Run($userId, $item);
		        return 0;
		    }
		}
    }


    /**
     * Adds information for a collection item
     *
     * @param integer userId the identifier for the user
     * @param object item the CDCollection information to be added
     *
    * @return integer last know id. This is the id of the collection information
     * that was newly inserted and for which an id has automatically
     * been assigned.
     */
    function addEntry($userId, $item)
    {
        $item->path = str_replace(DIRECTORY_SEPARATOR.DIRECTORY_SEPARATOR, '/', $item->path);
        $item->path = str_replace(DIRECTORY_SEPARATOR, '/', $item->path);
        // execute the query
        $query = sprintf($this->queries['addItem'],
                $userId,
                $item->parentId,
                $item->isParent,
                addslashes(trim($item->name)),
                addslashes(trim($item->description)),
                addslashes(trim($item->visibility)),
                addslashes(trim($item->category)),
                $item->isDeleted,
                $item->when_created,
                $item->when_modified,
                $item->isEntry,
                $item->entryId,
                addslashes(trim($item->entryType)),
                $item->size,
                addslashes(trim($item->path))
                );
        $this->db->Execute($query) or
                        die ("Could not add collection information.".
                        $this->db->ErrorMsg () . " " . $query . '<br />');
        $query = $this->queries['lastItemInsertId'];
		$result=$this->db->Execute($query)
			or die ("addBookmark: " .$this->db->ErrorMsg () . " " . $query);
        $itemId = $result->fields[0];
        if (NULL != $item->detailData)
        {
            // add detail data too
            $item->detailData->parentId = $itemId;
            $this->detailoperations->addItem($userId, $item->detailData);
        }
        return $itemId;
    }

	/**
	 * Modifies a collections information
	 *
 	 * @param integer userId the identifier for the user who modifies a note
	 * @param object item the modified note
	 */
	function modifyItem ($userId, $item)
	{
		$now = date ("Y-m-d H:i:s");

		$query  = sprintf ($this->queries['modifyItem'],
            $now,
			addslashes ($item->name),
			addslashes ($item->visibility),
			addslashes ($item->description),
			addslashes ($item->parentId),
			$item->itemId) ;

		$result = $this->db->Execute($query)
			or die("ModifyCollectionEntry: " . $this->db->ErrorMsg() . " " . $query);
	}


    /**
	 * Retrieves the children of a specified item
	 *
	 * @param string userId the identifier of the user that issues the
	 * request
	 * @param integer itemId the identifier of the item for which we would
	 * like to have its children
	 * @return array all children for specified user and itemId
	 */
	function getChildren ($userId, $itemId)
	{
        if (!$this->getAllChildren)
        {
         	$item = $this->getItem($userId, $itemId);
        }
        if ($this->getAllChildren || (isset($item) && !$item->isEntry) || (0 == $itemId))
        {
            // don't show auto children from generated folder if in multiselect mode
    		$query = sprintf ($this->queries ['getItemChildren'], $itemId, $userId);
    		$result = $this->db->Execute ($query) or die
    			("Operations. GetChildren " . $this->db->ErrorMsg () .
    				" Error getting children: " . $query);
    		$items = $this->itemFactory->resultsetToItems($result);
    		if ($items == null)
    		{
    			return null;
    		}
    		else if ($items[0]->owner == $userId)
    		{
    			return $items;
    		}
    		else
    		{
    			die ("Not owner?");
    		}
        }
        return null;
	}


    /**
	 * Retrieves the children of a specified item. It starts with the
	 * root and retrieves ALL items for this user (including the
	 * private ones) AND ALL PUBLIC items for other users
	 *
	 * @param string userId the identifier of the user that issues the
	 * request
	 * @param integer itemId the identifier of the item for which we would
	 * like to have its children
	 * @return array all children for specified user and itemId
	 */
	function getPublicChildren ($userId, $itemId)
	{
        if (!$this->getAllChildren)
        {
            $item = $this->getItem($userId, $itemId);
        }
        if ($this->getAllChildren || (isset($item) && !$item->isEntry) || (0 == $itemId))
        {
    		$query = sprintf
    			($this->queries ['getPublicItemChildren'], $itemId, $userId);
    		$result = $this->db->Execute ($query) or die
    			("Operations. GetPublicChildren " . $this->db->ErrorMsg () .
    				" Error getting children: " . $query);
    		$items = $this->itemFactory->resultsetToItems($result);
    		return $items;
        }
        return null;
	}


    /**
	 * Retrieves the name of the entryId
	 *
 	 * @param integer entryId the identifier for the entry root
     * return name of the entryId
	 */
	function getEntryName ($userId, $entryId)
	{
        $item = $this->getItem($userId, $entryId);

        if ( NULL != $item)
        {
            return $item->name;
        }
        else
        {
            return "";
        }
	}


    function getEntriesName()
    {
        $query = sprintf
			($this->queries ['searchEntriesName']);
		$result = $this->db->Execute ($query) or die
				("Operations. Search " . $this->db->ErrorMsg () .
					" " . $query);

        $items = array ();
		while ($object = $result->FetchNextObj())
		{
            $items [$object->item_id] = $object->name;
		}
		return $items;
    }

	/**
	* executes the query and assigns the entry names
	*
	* @param string userId the identifier for the user for which we
	*  	would like to search for items
	* @param string query the sql query for the database search
	* @param array with the result of the search of the details
	*
	* @return array all items that match the given search criteria
	*/
	function searchOperation($userId, $query, $details)
	{
		$items = array();
		$orderitem = array();
		$result = $this->db->Execute ($query) or die
			("Operations. Search " . $this->db->ErrorMsg () .
				" " . $query);
		$items = $this->itemFactory->resultsetToItems($result);
		// search entry names in the database
		$entriesName = $this->getEntriesName();
		for ($i=0; $i<count($items); $i++)
		{
			// set the entry name for each item
			if (0 != $items[$i]->entryId)
			{
				$items[$i]->entryName = $entriesName[$items[$i]->entryId];
			}
			else
			{
				$items[$i]->entryName = '';
			}
			if (NULL != $items[$i]->entryType)
			{
				// add detail data
				$items[$i]->AddDetail($this->detailoperations->getChildren($userId, $items[$i]->itemId));
			}
			// make it easier to search details
			$orderitem[$items[$i]->itemId] = $items[$i];
		}
		// check if detail allready added to main item
		foreach ($details as $detail)
		{
			if (!array_key_exists($detail->parentId, $orderitem))
			{
				// item not in the list -> add it
				$newitem = $this->getItem($userId, $detail->parentId);
				if (NULL != $newitem)
				{
					// must be the entryId of the parent
					if (0 != $newitem->entryId)
					{
						$newitem->entryName = $entriesName[$newitem->entryId];
					}
					else
					{
						$newitem->entryName = '';
					}
					// add detail data
					$newitem->AddDetail($detail);
					// add to output items
					$items[] = $newitem;
				}
			}
		}
		return $items;
	}

    /**
     * Search for items for a user
     *
     * @param string userId the identifier for the user for which we
     *  	would like to search for items
     * @param string field the field-array on which we would like to search
     * @param string value the value for which we would like to search
     *
     * @return array all items that match the given search criteria
     */
	function searchItems ($userId, $field, $value)
	{
		$query = sprintf
			($this->queries ['searchItems'], $field, $value, $userId);
		$details = $this->detailoperations->searchItems
   					($userId, $field, $value);
		return $this->searchOperation($userId, $query, $details);
	}


    /**
     * Search for items for a user
     *
     * @param string userId the identifier for the user for which we
     *  	would like to search for items
     * @param string field-array the field on which we would like to search
     * @param string value the value for which we would like to search
     *
     * @return array all items that match the given search criteria
     */
	function searchPublicItems ($userId, $field, $value)
	{
		$query = sprintf
			($this->queries ['searchPublicItems'], $field, $value, $userId);
		$details = $this->detailoperations->searchPublicItems
   					($userId, $field, $value);
		return $this->serachOperation($userId, $query, $details);
	}


    	/**
	 * Delete a item (with a specified ID) for a specific
	 * user. This function will recurively delete all children
	 * of this item if this item is a parent/folder!
	 *
	 * @param string userId the identifier for the user
	 * @param string itemId the identifier for the item that will
	 *        be deleted
	 */
	function deleteItem ($userId, $itemId)
	{
		$item = $this->getItem ($userId, $itemId);
		//
		// if we are a parent, delete the children as well....
		//
		if ($item->isParent==1)
		{
			$children = $this->getChildren ($userId, $itemId);
			for ($i=0; $i<count($children); $i++)
			{
				$this->deleteItem ($userId, $children[$i]->itemId);
			}
		}
        if (NULL != $item->entryType)
        {
            // delete detail data
            $this->detailoperations->deleteItem($userId, $item->itemId);
        }
		//
		// now delete the specific item (children are already
		// deleted if this is a parent item)
		//
		$query = sprintf ($this->queries['deleteItem'], $itemId);
		$result = $this->db->Execute($query) or
			die("DeleteItem: " .
			$this->db->ErrorMsg() . " " . $query);
	}
}
?>
