<?php
require_once('framework/ItemController.php');
require_once('plugins/collections/model/CollectionsDetailServices.php');
require_once('plugins/collections/model/CollectionsDetailFactory.php');


/**
 * The Collections Playlist Controller
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Moritz Julen - June 2006
 * @package org.brim-project.plugins.collections
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class PlaylistController extends ItemController
{
        var $collectionsController;

 		/**
         * Constructor.
         * Makes sure that the appropriate operations are instantiated.
         * @param string renderEngineName the render engine that is used
         * (either Smarty or phpSavant)
         */
        function PlaylistController(&$parentcontroller)
        {
                parent::ItemController();

                $this->collectionsController = $parentcontroller;

                $this->operations = new CollectionsDetailServices();
                $this->itemFactory = new CollectionsDetailFactory();


                $this->pluginName = 'collections';
                $this->title = 'Brim - Collections';
                $this->itemName = 'PlaylistItem';
        }

        /**
      * Returns the actions defined for this item only
      *
      * @return array an array of item specific actions
     * (like search, import etc.)
      */
    function getActions()
    {
        // Actions
        $actions[0]['name']='actions';
        // other actions added in template
        $actions[0]['contents'][]= array(
            'href' => 'CollectionsController.php?action=addPlaylistItems&parentId='.$this->getParentId(),
            'name' => 'add');
        $actions[0]['contents'][]= array(
            'href' => 'CollectionsController.php?action=playPlaylist&parentId='.$this->getParentId(),
            'name' => 'play');

        // help
        $actions[3]['name'] = 'help';
        $actions[3]['contents'][] =
                        array ('href' => 'CollectionsController.php?action=help&parentId='.$this->getParentId(),
                                   'name' => 'help');

        return $actions;
    }

    /**
     * Activate. Basically this means that the appropriate actions
     * are executed and an optional result is returned
     * to be processed/displayed
     */
    function activate()
    {
        $dictionary = $this->getDictionary();
        echo $this->getAction().' parent:'.$this->parentId.' item:'.$this->itemId."<br />";
        switch ($this->getAction())
        {
            case "addPlaylistItems":
				$_SESSION['collectionsExpand']='*';
                $this->multipleSelectAction();
            	break;
            case "deletePlaylistItemPost":
            	$this->deletePlaylistEntry($this->itemId);
            	$this->getShowItemsParameters();
            	break;
            case "moveDownInPlaylist":
            	$this->changeOrder($this->itemId, +1);
            	$this->getShowItemsParameters ();
            	break;
            case "moveUpInPlaylist":
            	$this->changeOrder($this->itemId, -1);
            	$this->getShowItemsParameters ();
            	break;
            case "multipleAddPlaylistPost":
                $_SESSION['collectionsExpand']='0';
                // add items to playlist
				$this->addPlaylistItems(array_keys ($_POST, "itemId"));
            	$this->getShowItemsParameters ();
            	break;
            case "playPlaylist":
            	$this->streamPlaylist();
            	break;
         	default:
				$this->getShowItemsParameters ();
                break;
        }
    }

    function getShowItemsParameters()
    {
        parent::getShowItemsParameters();
        // get infos for playlist entries
        for ($i=0; $i<count($this->renderObjects); $i++)
        {
         	$item = $this->operations->getItem(
         		$this->getUserName(),
         		$this->renderObjects[$i]->description);
            $this->renderObjects[$i]->field1 = $item->name;
            $this->renderObjects[$i]->field2 = $item->description;
            $this->renderObjects[$i]->field3 = $item->field1;
            $this->renderObjects[$i]->field4 = $item->field4;
            $this->renderObjects[$i]->field5 = $item->field5;
		}
        // add playlist item
    	$item = $this->collectionsController->operations->getItem($this->getUserName(), $this->parentId);
		$this->renderEngine->assign('collectionsItem', $item);
	}

    function multipleSelectAction ()
	{
	 	// show all items in collections
    	$this->collectionsController->parentId = 0;
		$this->collectionsController->getShowItemsParameters();
		$this->renderer = 'multipleSelect'.$this->getItemName();
		$this->renderObjects = $this->collectionsController->renderObjects;
	}

	function addPlaylistItems($itemIds)
	{
     	$parent = $this->collectionsController->operations->getItem(
                $this->getUserName(), $this->getParentId() );
        // didn't work with getChildrenCount
        $items = $this->operations->getChildren(
        		$this->getUserName(), $this->getParentId() );
		$count = count($items);
        // $count = $this->operations->getChildrenCount($parent);
     	for ($i=0; $i<count($itemIds); $i++)
        {
     		$item = new CollectionDetailItem(
     			0,
                $this->getUserName(),       // $theOwner
                $this->getParentId(),       // $theParentId
                0,                          // $parent
                sprintf("%04d", $i+$count),	// $theName
                $itemIds[$i],				// $theDescription
                $parent->visibility,        // $theVisibility
                $parent->category,          // $theCategory
                0,                          // $deleted
                NULL,                       // $theCreation
                NULL,                       // $theModified
                NULL,               		// field1
                NULL,                		// field2
                NULL,                 		// field3
                NULL,                		// field4
                NULL,         				// field5
                NULL            		);  // field6
            $this->operations->addItem($this->getUserName(), $item);
		}
	}

	function streamPlaylist()
	{
        $parent = $this->collectionsController->operations->getItem(
                $this->getUserName(), $this->getParentId());
     	$items = $this->operations->getChildren($this->getUserName(), $this->getParentId());
        // start with empty output buffer
        ob_clean();
        // Date in the past
		header("Expires: Mon, 26 Jul 1997 05:00:00 GMT");
		// always modified
		header("Last-Modified: " . gmdate("D, d M Y H:i:s") . " GMT");
		// HTTP/1.1
		header("Cache-Control: no-store, no-cache, must-revalidate");
		header("Cache-Control: post-check=0, pre-check=0", false);
		// HTTP/1.0
		header("Pragma: no-cache");
        // to download the file
		header('content-type: audio/x-mpegurl');
        header('content-disposition: attachment; filename='.$parent->name.'.'.$parent->entryType);
        echo '#EXTM3U'.chr(13).chr(10);
        for ($i=0; $i<count($items); $i++)
        {
         	// get track infos
            $track = $this->collectionsController->operations->getItem(
            	$this->getUserName(), $items[$i]->description);
            $track->AddDetail($this->collectionsController->DetailController->operations->getChildren(
            	$this->getUserName(), $track->itemId));
         	echo '#EXTINF:'.intval($track->detailData->field5).', '.
         		$track->detailData->field1.' - '.$track->detailData->name.chr(13).chr(10);
            echo 'http://'.$_SERVER['HTTP_HOST'].'/plugins/collections'.
				'/CollectionsStreamer.php?path='.str_replace('//', '/', $track->path).chr(13).chr(10);
		}
        exit;
	}

	function changeOrder($number, $offset)
	{
     	$items = $this->operations->getChildren($this->getUserName(), $this->parentId);
        // change sorting number
        $temp = $items[$number]->name;
     	$items[$number]->name = $items[$number + $offset]->name;
     	$items[$number + $offset]->name = $temp;
     	// modify items
     	$this->operations->modifyItem($this->getUserName(), $items[$number]);
     	$this->operations->modifyItem($this->getUserName(), $items[$number + $offset]);
    }

    function deletePlaylistEntry($number)
    {
     	// get all children
        $items = $this->operations->getChildren($this->getUserName(), $this->parentId);
        // delete the specified entry
     	$this->operations->deleteEntry($this->getUserName(), $items[$number]->itemId);
     	// renumber the items for correct order
     	for($i=$number+1; $i<count($items); $i++)
     	{
     	 	$items[$i]->name = sprintf("%04d", $i-1);
     	 	$this->operations->modifyItem($this->getUserName(), $items[$i]);
		}
	}
}
?>
