<?php

require_once ("framework/util/StringUtils.php");
require_once "plugins/collections/view/overlibPopup.php";

/**
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Mortiz Julen - March 2006
 * @package org.brim-project.plugins.collections
 * @subpackage view
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */

class CollectionsExplorerTreeDelegate extends CollectionsTreeDelegate
{
	/**
	 * Default constructor
	 */
	function CollectionsExplorerTreeDelegate ($theConfiguration)
	{
		parent::TreeDelegate ($theConfiguration);
	}
	
	/**
	 * Builds up html code to display the root of the tree
	 * @private
	 *
	 * @param object item the item that is the root of the tree
	 */
	function showRoot ($item, $tree)
	{
        if (!isset($item) || $item->itemId == 0)
		{
			$resultString = $this->configuration['icons']['root'];
		}
		else
		{
			$resultString = '<h2>'.$item->name.'</h2>';
			$resultString .= '<a href="'.$this->configuration['callback'];
			$resultString .= '?action=show&parentId='.$item->parentId.'">';
			$resultString .= $this->configuration['icons']['up'];
			$resultString .= '</a>';
		}
		return $resultString;
	}

	/**
	 * If the specified item is a folder, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean isExpanded whether this folder is expanded (i.e. do the
	 * children of this folder need to be displayed as well?)
	 * @param object tree the tree that uses this class as delegate
	 * @return string the string for this folder
	 */
	function drawFolder ($item, $isExpanded, $tree, $indentLevel)
	{
		$resultString = '
								<tr><td>';

		for ($i=0; $i<$indentLevel; $i++)
		{
			$resultString .= $this->configuration['icons']['bar'];
		}

		if ($item->isParent)
		{
			//die ("Is parent. Expanded?" . $isExpanded);
		}

		if ($isExpanded)
		{

			$res = $tree->createExpandedListWithout ($item->itemId);

			$resultString .= '<a href="';
			$resultString .= $this->configuration['callback'];
			$resultString .= '?expand=' . implode (',', $res);
            if (isset($tree->root))
            {
				$resultString .= '&parentId='.$tree->root->itemId;
			}
			$resultString .= '">';
			$resultString .= $this->configuration['icons']['minus'];
			$resultString.= '</a>';

            if (isset($item) && $item->isEntry != 0)
            {
                // collection information root folder
				if ($item->owner == $_SESSION['brimUsername'])
				{
	    			$resultString.= '<a href="'.$this->configuration['callback'];
	    			$resultString .= '?action=modify&itemId='.$item->itemId;
	                if (isset($tree->root))
			        {
						$resultString .= '&parentId='.$tree->root->itemId;
					}
					$resultString .= '">';
	    			$resultString .= $this->configuration['icons']['folder_open_entry'];
	    			$resultString .= '</a>';
				}
				else 
				{
	    			$resultString .= $this->configuration['icons']['folder_open_entry'];
				}
            }
            else
            {
                if ($item->entryId == 0)
                {
					if ($item->owner == $_SESSION['brimUsername'])
					{
	                    // manual created folder can be modified
	        			$resultString.= '<a href="'.$this->configuration['callback'];
	        			$resultString .= '?action=modify&itemId='.$item->itemId;
	                    if (isset($tree->root))
			            {
							$resultString .= '&parentId='.$tree->root->itemId;
						}
						$resultString .= '">';
					}
                }
                switch ($item->entryType)
                {
                	case "zip":
                		$resultString .= $this->configuration['icons']['folder_open_zip'];
                		break;
                	case "iso":
                        $resultString .= $this->configuration['icons']['folder_open_iso'];
                		break;
                	default:
                 		$resultString .= $this->configuration['icons']['folder_open'];
                 		break;
				}
                if ($item->entryId == 0)
                {
					if ($item->owner == $_SESSION['brimUsername'])
					{
	        			$resultString .= '</a>';
					}
                }
            }
		}
		else
		{
            // ???
			$linkExpand = "";
			// ???
			if (!$tree->isExpanded ($item->itemId) && $tree->expanded != null)
			{
				$linkExpand .= implode(",", $tree->expanded).",".$item->itemId;
			}
			else
			{
				$linkExpand = $item->itemId;
			}
			$resultString .= '<a href="';
			$resultString .= $this->configuration['callback'];
			$resultString .= '?expand=' . $linkExpand;
            if (isset($tree->root))
		    {
				$resultString .= '&parentId='.$tree->root->itemId;
			}
			$resultString .= '">';
			$resultString .= $this->configuration['icons']['plus'];
            $resultString .= '</a>';
            if (isset($item) && $item->isEntry != 0)
            {
                // collection information root folder
				if ($item->owner == $_SESSION['brimUsername'])
				{
	    			$resultString .= '<a href="';
	    			$resultString .= $this->configuration['callback'];
	    			$resultString .= '?action=modify&itemId='.$item->itemId;
	                if (isset($tree->root))
		            {
						$resultString .= '&parentId='.$tree->root->itemId;
					}
					$resultString .= '">';
	    			$resultString .= $this->configuration['icons']['folder_closed_entry'];
	    			$resultString .= '</a>';
				}
				else 
				{
	    			$resultString .= $this->configuration['icons']['folder_closed_entry'];
				}
            }
            else
            {
                if ($item->entryId == 0)
                {
                    // manual created folder can be modified
					if ($item->owner == $_SESSION['brimUsername'])
					{
        				$resultString.= '<a href="'.$this->configuration['callback'];
        				$resultString .= '?action=modify&itemId='.$item->itemId;
                	    if (isset($tree->root))
		            	{
							$resultString .= '&parentId='.$tree->root->itemId;
						}
						$resultString .= '">';
					}
				}
                switch ($item->entryType)
                {
                	case "zip":
                		$resultString .= $this->configuration['icons']['folder_closed_zip'];
                		break;
                	case "iso":
                        $resultString .= $this->configuration['icons']['folder_closed_iso'];
                		break;
                	default:
                 		$resultString .= $this->configuration['icons']['folder_closed'];
                 		break;
				}
                if ($item->entryId == 0)
                {
					if ($item->owner == $_SESSION['brimUsername'])
					{
	        			$resultString .= '</a>';
					}
                }
            }
		}
		$resultString .= '&nbsp;<a href="';
		$resultString .= $this->configuration['callback'];
		$resultString .= '?action=show&parentId=';
		$resultString .= $item->itemId.'" ';
        if ($this->configuration['overlib'])
		{
            $popup = $this->overlibPopup($item);
			$resultString .= $this->overLib ($item->name, $popup);
		}
		$resultString .= '>' . $item->name;
		$resultString .= '</a>';

		$resultString .= '</td></tr>';

		return $resultString;
	}


	/**
	 * If the specified item is a node, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean lastNode whether this node is the last one
	 * @return string the string for this node
	 */
	function drawNode ($item, $lastNode, $tree, $indentLevel)
	{
		$resultString = '
								<tr><td>';
		for ($i=0; $i<$indentLevel; $i++)
		{
			$resultString .= $this->configuration['icons']['bar'];
		}
		if ($lastNode)
		{
			$resultString .= $this->configuration['icons']['corner'];
		}
		else
		{
			$resultString .= $this->configuration['icons']['tee'];
		}
        if ($item->isEntry)
        {
			if ($item->owner == $_SESSION['brimUsername'])
			{
	            $resultString .= '<a href="CollectionsController.php?itemId='.$item->itemId;
    	        $resultString .= '&action=modify';
        	    if (isset($tree->root))
            	{
				$resultString .= '&parentId='.$tree->root->itemId;
				}
				$resultString .= '">';
    			$resultString .= $this->configuration['icons']['node_entry'].'</a>';
			}
			else 
			{
    			$resultString .= $this->configuration['icons']['node_entry'];
			}
        }
        else
        {
           	$resultString .= $this->configuration['icons']['node'];
        }
        if ((NULL != $item->path) && file_exists($item->path))
        {
            $resultString .= '&nbsp;<a href="'.$this->configuration['callback'];
            $resultString .= '?itemId='.$item->itemId;
            $resultString .= '&action=execute"';
            if (isset($this->configuration['collectionsNewWindowTarget']) &&
            	('_blank' ==  $this->configuration['collectionsNewWindowTarget']))
            {
            	$resultString .= 'target="_blank"';
            }
            $resultString .= '>'.$this->configuration['icons']['execute'].'</a>';
		}
        // icon and link to play the playlist
		else if ('m3u' == $item->entryType)
		{
            $resultString .= '&nbsp;<a href="'.$this->configuration['callback'];
            $resultString .= '?parentId='.$item->itemId;
            $resultString .= '&action=playPlaylist"';
            if (isset($this->configuration['collectionsNewWindowTarget']) &&
            	('_blank' ==  $this->configuration['collectionsNewWindowTarget']))
            {
            	$resultString .= 'target="_blank"';
            }
            $resultString .= '>'.$this->configuration['icons']['execute'].'</a>';
		}
		$resultString .= '&nbsp;<a href="';
		$resultString .= $this->configuration['callback'];
        if ('m3u' == $item->entryType)
		{
        	$resultString .= '?parentId='.$item->itemId.'&action=showPlaylist" ';
		}
		else
		{
		 	$resultString .= '?itemId='.$item->itemId.'&parentId='.$item->parentId.'&action=showItem" ';
		}
		if (isset($tree->root))
        {
			$resultString .= '&parentId='.$tree->root->itemId;
		}
		$resultString .= "' ";
		if ($this->configuration['overlib'])
		{
            $popup = $this->overlibPopup($item);
			$resultString .= $this->overLib ($item->name, $popup);
		}
		$resultString .= 'alt="'. $this->stringUtils->urlEncodeQuotes ($this->stringUtils->gpcAddSlashes ($item->name)) . '">';
		$resultString .= $item->name;
		$resultString .= '</a>';

		$resultString .= '</td></tr>';
		return $resultString;
	}
}
?>