<?php

require_once ("framework/util/StringUtils.php");
require_once ("plugins/collections/view/overlibPopup.php");

/**
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Mortiz Julen - March 2006
 * @package org.brim-project.plugins.collections
 * @subpackage view
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */

class CollectionsLineBasedTreeDelegate extends CollectionsTreeDelegate
{
	/**
	 * Have we already drawn a header?
	 */
	var $headersDrawn;
	var $isParentEntry;

	function CollectionsLineBasedTreeDelegate ($theConfiguration)
	{
		parent::TreeDelegate ($theConfiguration);
		$this->headersDrawn = false;
		$this->isParentEntry = false;
	}
	
	/**
	 * Builds up html code to display the root of the tree
	 * @private
	 *
	 * @param object item the item that is the root of the tree
	 */
	function showRoot ($item, $tree)
	{
		if (isset($item) && $item->itemId != 0)
		{
            if ((0 != $item->entryId) || $item->isEntry)
            {
                 $this->isParentEntry = true;
			}
			$resultString = '<h2>'.$item->name.'</h2>';
			$resultString .= '<a href="'.$this->configuration['callback'];
			$resultString .= '?action=show&parentId='.$item->parentId.'">';
			$resultString .= $this->configuration['icons']['up'];
			$resultString .= '</a><br />';
		}
		else
		{
			$resultString = '';
		}
		return $resultString;
	}

	/**
	 * If the specified item is a folder, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean isExpanded whether this folder is expanded (i.e. do the
	 * children of this folder need to be displayed as well?)
	 * @param object tree the tree that uses this class as delegate
	 * @return string the string for this folder
	 */
	function drawFolder ($item, $isExpanded, $tree, $indentLevel)
	{
        if (isset($item))
        {
             if (0 != $item->entryId)
             {
                switch ($item->entryType)
                {
                	case "zip":
                		$resultString = $this->configuration['icons']['folder_closed_zip'];
                		break;
                	case "iso":
                        $resultString = $this->configuration['icons']['folder_closed_iso'];
                		break;
                	default:
                 		$resultString = $this->configuration['icons']['folder_closed'];
                 		break;
				}
             }
             else
             {
             	$resultString = '';
             
				if ($item->owner == $_SESSION['brimUsername'])
				{
	                $resultString .= '<a href="';
	        		$resultString .= $this->configuration['callback'];
	        		$resultString .= '?action=modify&itemId='.$item->itemId;
	        		$resultString .= '&parentId='.$item->parentId.'">';
	                if ($item->isEntry)
	                {
	                    $resultString .= $this->configuration['icons']['folder_closed_entry'];
	                }
	                else
	                {
	                    $resultString .= $this->configuration['icons']['folder_closed'];
	                }
	                $resultString .= '</a>';
				}
				else 
				{
	                if ($item->isEntry)
	                {
	                    $resultString .= $this->configuration['icons']['folder_closed_entry'];
	                }
	                else
	                {
	                    $resultString .= $this->configuration['icons']['folder_closed'];
	                }
				}
             }
             $resultString .= '<a href="';
    		 $resultString .= $this->configuration['callback'];
    		 $resultString .= '?action=show&parentId=';
    	 	 $resultString .= $item->itemId.'" ';
             if ($this->configuration['overlib'])
     		 {
     			$popUp = $this->overlibPopup($item);
     			$resultString .= $this->overLib ($item->name, $popUp);
    		 }
             $resultString .= '>';
    		 $resultString .= $item->name;
    		 $resultString .= '</a>';

    		 $resultString .= '<br />';
    		 return $resultString;
        }
        return "";
	}



	function drawLinesHeader ($parentId)
	{
        if ($this->configuration['search'])
        {
            $resultString = '<td colspan="9"></td></tr><tr>';
        }
        else
        {
            if ($this->configuration['showDetails'])
            {
            	$resultString = '<td colspan="7"></td></tr><tr>';
			}
			else
			{
                 $resultString = '<td colspan="6"></td></tr><tr>';
			}
        }
        $resultString .= '<td class="collections_treeicon">&nbsp;</td>';

		$resultString .= '<td><b>'.$this->configuration['dictionary']['name'];
		$resultString .= $this->sortArrows ('name', $parentId);
		$resultString .= '</b></td>';

		$resultString .= '<td  class="collections_treesize"><b>'.$this->configuration['dictionary']['size'];
		$resultString .= $this->sortArrows ('size', $parentId);
		$resultString .= '</b></td>';

        // empty column
        $resultString .= '<td class="collections_treeemptycolumn"></td>';

        if ($this->configuration['search'])
        {
            $resultString .= '<td><b>'.$this->configuration['dictionary']['entryName'];
    		$resultString .= $this->sortArrows ('entryId', $parentId);
    		$resultString .= '</b></td>';
        }

		$resultString .= '<td class="collections_treedate"><b>'.$this->configuration['dictionary']['modify'];
		$resultString .= $this->sortArrows ('when_modified', $parentId);
		$resultString .= '</b></td>';

		if ($this->configuration['showDetails'] || $this->configuration['search'])
		{
	        $resultString .= '<td>&nbsp;</td>';
	        $resultString .= '<td>&nbsp;</td>';
		}

		$resultString .= '</tr><tr class="odd">';
		return $resultString;
	}
	/**
	 * If the specified item is a node, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean lastNode whether this node is the last one
	 * @return string the string for this node
	 */
	function drawNode ($item, $lastNode, $tree, $indentLevel)
	{
		if ($this->headersDrawn)
		{
			$resultString = '';
		}
		else
		{
			$resultString = $this->drawLinesHeader ($item->parentId);
			$this->headersDrawn = true;
		}
        if ($item->isEntry)
        {
            $resultString .= '<td align="left">';
			if ($item->owner == $_SESSION['brimUsername'])
			{
	    		$resultString .= '<a href="'.$this->configuration['callback'];
	    		$resultString .= '?itemId='.$item->itemId;
	    		$resultString .= '&parentId='.$item->parentId.'&action=modify" ';
	    		$resultString .= '>'.$this->configuration['icons']['node_entry'].'</a>';
	
	            $resultString .= '&nbsp;<a href="'.$this->configuration['callback'];
	    		$resultString .= '?itemId='.$item->itemId;
	    		$resultString .= '&parentId='.$item->parentId;
	    		$resultString .= '&action=deleteItemPost" ';
	    		// delete confirmation
	    		$resultString .= 'onclick="javascript:return confirm (\'';
	    		$resultString .= $this->configuration['dictionary']['confirm_delete'];
	    		$resultString .= '\');" ';
	    		$resultString .= '>'.$this->configuration['icons']['delete'].'</a>';
			}
			else 
			{
	    		$resultString .= $this->configuration['icons']['node_entry'];
	    		$resultString .= $this->configuration['icons']['delete'];
			}
            if ((NULL != $item->path) && file_exists($item->path))
            {
                $resultString .= '&nbsp;<a href="'.$this->configuration['callback'];
                $resultString .= '?itemId='.$item->itemId;
                $resultString .= '&action=execute"';
                if (isset($this->configuration['collectionsNewWindowTarget']) &&
                	('_blank' ==  $this->configuration['collectionsNewWindowTarget']))
                {
                	$resultString .= 'target="_blank"';
                }
                $resultString .= '>'.$this->configuration['icons']['execute'].'</a>';
			}
			// icon and link to play the playlist
			else if ('m3u' == $item->entryType)
			{
                $resultString .= '&nbsp;<a href="'.$this->configuration['callback'];
                $resultString .= '?parentId='.$item->itemId;
                $resultString .= '&action=playPlaylist"';
                if (isset($this->configuration['collectionsNewWindowTarget']) &&
                	('_blank' ==  $this->configuration['collectionsNewWindowTarget']))
                {
                	$resultString .= 'target="_blank"';
                }
                $resultString .= '>'.$this->configuration['icons']['execute'].'</a>';
			}
    		$resultString .= '</td>';
        }
        else
        {
           	$resultString .= '<td align="left">';
           	$resultString .= $this->configuration['icons']['node'];
            if ((NULL != $item->path) && file_exists($item->path))
            {
                $resultString .= '&nbsp;<a href="'.$this->configuration['callback'];
                $resultString .= '?itemId='.$item->itemId;
                $resultString .= '&action=execute"';
                if (isset($this->configuration['collectionsNewWindowTarget']) &&
                	('_blank' ==  $this->configuration['collectionsNewWindowTarget']))
                {
                	$resultString .= 'target="_blank"';
                }
                $resultString .= '>'.$this->configuration['icons']['execute'].'</a>';
			}
			// icon and link to play the playlist
			else if ('m3u' == $item->entryType)
			{
                $resultString .= '&nbsp;<a href="'.$this->configuration['callback'];
                $resultString .= '?parentId='.$item->itemId;
                $resultString .= '&action=playPlaylist"';
                if (isset($this->configuration['collectionsNewWindowTarget']) &&
                	('_blank' ==  $this->configuration['collectionsNewWindowTarget']))
                {
                	$resultString .= 'target="_blank"';
                }
                $resultString .= '>'.$this->configuration['icons']['execute'].'</a>';
			}
           	$resultString .= '</td>';
           	        }

		$resultString .= '<td>';
		$resultString .= '<a href="'.$this->configuration['callback'];
		if ('m3u' == $item->entryType)
		{
        	$resultString .= '?parentId='.$item->itemId.'&action=showPlaylist" ';
		}
		else
		{
		 	$resultString .= '?itemId='.$item->itemId.'&parentId='.$item->parentId.'&action=showItem" ';
		}
		if ($this->configuration['overlib'])
		{
			$popUp = $this->overlibPopup ($item);
			$resultString .= $this->overLib ($item->name, $popUp);
		}
		$resultString .= '>';
		$resultString .= '<b>'.$this->stringUtils->truncate ($item->name, $_SESSION['collectionsTruncateSize']). '</b></a>';
		$resultString .= '</td>';

        if ($item->isEntry && (0 == $item->size))
        {
            $resultString .= '<td>&nbsp;</td>';
		}
		else
		{
		 	$resultString .= '<td align="right">'.$item->ConvSizeText().'</td>';
		}

        // empty column
        $resultString .= '<td></td>';

        if ($this->configuration['search'])
        {
            $resultString .= '<td>'.$this->stringUtils->truncate($item->entryName,$_SESSION['collectionsTruncateSize']).'</td>';
        }
		$resultString .= '<td>';

		if (($item->when_modified != null) && ("0" != substr($item->when_modified,0,1)))
		{
			$resultString .= $item->when_modified;
		}
		else
		{
			$resultString .= '&nbsp;';
		}
		$resultString .= '</td>';

        if ($this->configuration['showDetails'] || $this->configuration['search'])
		{
	        if (NULL != $item->detailData)
	        {
	            switch ($item->entryType)
	            {
	            	case "zip":
	                    // only used if tree in zip not scanned
	                    // uncompressed size
	                    $resultString .= '<td>'.$item->detailData->ConvSizeText($item->detailData->name).'</td>';
	                    // entries count
	                    $resultString .= '<td>'.$item->detailData->description.'</td>';
	                    break;
	                case "iso":
	                	// only used if tree in iso not scanned
	                case "mp3":
	                case "basic":
	                    $resultString .= '<td>'.$this->stringUtils->truncate($item->detailData->name,$_SESSION['collectionsTruncateSize']).'</td>';
	                    $resultString .= '<td>'.$this->stringUtils->truncate($item->detailData->description,$_SESSION['collectionsTruncateSize']).'</td>';
	                    break;
	                default:
	                	$resultString .= '<td>&nbsp;</td>';
	                	$resultString .= '<td>&nbsp;</td>';
	            }
	        }
	        else
	        {
                 $resultString .= '<td>&nbsp;</td>';
	             $resultString .= '<td>&nbsp;</td>';
			}
		}
		return $resultString;
	}
}
?>