<?php

require_once ("framework/util/StringUtils.php");
require_once ('framework/view/TreeDelegate.php');

/**
 * extends MultipleSelectExplorerTreeDelegate
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Moritz Julen - April 2006
 * @package org.brim-project.plugins.collections
 * @subpackage view
 *
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class CollectionsMultipleSelectExplorerTreeDelegate extends MultipleSelectExplorerTreeDelegate
{
	/**
	 * Default constructor
	 */
	function CollectionsMultipleSelectExplorerTreeDelegate ($theConfiguration)
	{
		parent::MultipleSelectExplorerTreeDelegate ($theConfiguration);
	}

    /**
	 * Builds up html code to display the root of the tree
	 * @private
	 *
	 * @param object item the item that is the root of the tree
	 */
	function showRoot ($item, $tree)
	{
		if (isset($item) && $item->itemId != 0)
		{
            if ((0 != $item->entryId) || $item->isEntry)
            {
                 $this->isParentEntry = true;
			}
			$resultString = '<h2>'.$item->name.'</h2>';
		}
		else
		{
			$resultString = '';
		}
		return $resultString;
	}


	/**
	 * If the specified item is a folder, draw it
	 *
	 * @private
	 * @param object item the item to draw
	 * @param boolean isExpanded whether this folder is expanded (i.e. do the
	 * children of this folder need to be displayed as well?)
	 * @param object tree the tree that uses this class as delegate
	 * @return string the string for this folder
	 */
	function drawFolder ($item, $isExpanded, $tree, $indentLevel)
	{
		$resultString = '
								<tr>';
		$resultString .= '<td>&nbsp;</td><td>';
		for ($i=0; $i<$indentLevel; $i++)
		{
			$resultString .= $this->configuration['icons']['bar'];
		}

		$resultString .= $this->configuration['icons']['minus'];
        if ($item->isEntry)
        {
            $resultString .= $this->configuration['icons']['folder_open_entry'];
        }
        else
        {
            switch ($item->entryType)
            {
            	case "zip":
            		$resultString .= $this->configuration['icons']['folder_open_zip'];
            		break;
            	case "iso":
                    $resultString .= $this->configuration['icons']['folder_open_iso'];
            		break;
            	default:
             		$resultString .= $this->configuration['icons']['folder_open'];
             		break;
			}
        }
		$resultString .= $item->name;
		$resultString .= '</td></tr>';

		return $resultString;
	}


	/**
	 * If the specified item is a node, draw it
	 *
	 * @private
	 * @param object item the item to draw
	 * @param boolean lastNode whether this node is the last one
	 * @return string the string for this node
	 */
	function drawNode ($item, $lastNode, $tree, $indentLevel)
	{
		$resultString  = '<tr>';
        if (0 == $item->entryId)
        {
		    $resultString .= '<td><input type="checkbox" name="'.$item->itemId.'" value="itemId"></td>';
        }
        else
        {
            $resultString .= '<td>&nbsp;</td>';
        }
		$resultString .= '<td>';
		for ($i=0; $i<$indentLevel; $i++)
		{
			$resultString .= $this->configuration['icons']['bar'];
		}
		if ($lastNode)
		{
			$resultString .= $this->configuration['icons']['corner'];
		}
		else
		{
			$resultString .= $this->configuration['icons']['tee'];
		}
        if (0 == $item->entryId)
        {
            $resultString .= $this->configuration['icons']['node_entry'];
        }
        else
        {
            $resultString .= $this->configuration['icons']['node'];
        }

		$resultString .= $this->stringUtils->gpcAddSlashes ($item->name);
		$resultString .= '</td></tr>';
		return $resultString;
	}
}
?>