<?php

require_once ("framework/util/StringUtils.php");
require_once ("plugins/collections/view/overlibPopup.php");

/**
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Mortiz Julen - June 2006
 * @package org.brim-project.plugins.collections
 * @subpackage view
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class CollectionsThumbnailTreeDelegate extends CollectionsTreeDelegate
{
    /**
	 * Default constructor
	 */
	function CollectionsYahooTreeDelegate ($theConfiguration)
	{
		parent::TreeDelegate ($theConfiguration);
	}

	/**
	 * Builds up html code to display the root of the tree
	 * @private
	 *
	 * @param object item the item that is the root of the tree
	 */
	function showRoot ($item, $tree)
	{
		if (isset($item) && $item->itemId != 0)
		{
			$resultString = '<h2>'.$item->name.'</h2>';
			$resultString .= '<a href="'.$this->configuration['callback'];
			$resultString .= '?action=show&parentId='.$item->parentId.'">';
			$resultString .= $this->configuration['icons']['up'];
			$resultString .= '</a><br />';
		}
		else
		{
			$resultString = '';
		}
		return $resultString;
	}

	/**
	 * If the specified item is a folder, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean isExpanded whether this folder is expanded (i.e. do the
	 * children of this folder need to be displayed as well?)
	 * @param object tree the tree that uses this class as delegate
	 * @return string the string for this folder
	 */
	function drawFolder ($item, $isExpanded, $tree, $indentLevel)
	{
        if (isset($item))
        {
             if (0 != $item->entryId)
             {
             	switch ($item->entryType)
                {
                	case "zip":
                		$resultString = $this->configuration['icons']['folder_closed_zip'];
                		break;
                	case "iso":
                        $resultString = $this->configuration['icons']['folder_closed_iso'];
                		break;
                	default:
                 		$resultString = $this->configuration['icons']['folder_closed'];
                 		break;
				}
             }
             else
             {
   				if ($item->owner == $_SESSION['brimUsername'])
				{
	                $resultString = '<a href="';
	        		$resultString .= $this->configuration['callback'];
	        		$resultString .= '?action=modify&itemId='.$item->itemId;
	        		$resultString .= '&parentId='.$item->parentId.'">';
	                if ($item->isEntry)
	                {
	                    $resultString .= $this->configuration['icons']['folder_closed_entry'];
	                }
	                else
	                {
	                    $resultString .= $this->configuration['icons']['folder_closed'];
	                }
	                $resultString .= '</a>';
				}
				else 
				{
	                if ($item->isEntry)
	                {
	                    $resultString .= $this->configuration['icons']['folder_closed_entry'];
	                }
	                else
	                {
	                    $resultString .= $this->configuration['icons']['folder_closed'];
	                }
				}
             }
             $resultString .= '<a href="';
    		 $resultString .= $this->configuration['callback'];
    		 $resultString .= '?action=show&parentId=';
    	 	 $resultString .= $item->itemId.'" ';
             if ($this->configuration['overlib'])
     		 {
     			$popUp = $this->overlibPopup ($item);
     			$resultString .= $this->overLib ($item->name, $popUp);
    		 }
             $resultString .= '>';
    		 $resultString .= $this->stringUtils->truncate ($item->name, $_SESSION['collectionsTruncateSize']);
    		 $resultString .= '</a>';

    		 $resultString .= '<br />';
    		 return $resultString;
        }
        return "";
	}


	/**
	 * If the specified item is a node, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean lastNode whether this node is the last one
	 * @return string the string for this node
	 */
	function drawNode ($item, $lastNode, $tree, $indentLevel)
	{
        $resultString  = '
						 <table border="1" valign="top" width="98%" ';
		$resultString .= 'bgcolor="#ffffff"	cellpadding="1" cellspacing="2">';

		//
		//	Note header: title with link, icons (delete+modify)
		//	and note popup
		//
		$resultString .= '<tr><td class="collections_menu" colspan="2">';
		$resultString .= '<table width="100%" cellpadding="0" cellspacing="" border="0">';
		$resultString .= '<tr><td width="120px">';
        switch ($item->entryType)
        {
            case 'gif':
         	case 'jpg':
         	case 'png':
                if ((NULL != $item->path) && file_exists($item->path))
	            {
	             	$resultString .= '<a href="'.$this->configuration['callback'];
	                $resultString .= '?itemId='.$item->itemId;
	                $resultString .= '&action=execute"';
	                if (isset($this->configuration['collectionsNewWindowTarget']) &&
	                	('_blank' ==  $this->configuration['collectionsNewWindowTarget']))
	                {
	                	$resultString .= 'target="_blank"';
	                }
	                $resultString .= '>';
                    $resultString .= '<img src="'.$this->configuration['callback'];
		        	$resultString .= '?itemId='.$item->itemId.'&action=showThumbnail" border="0">';
		        	$resultString .= '</a>';
				}
		        break;
		}
		$resultString .= '</td><td width="5px">&nbsp;</td><td valign="top">';
        if (0 == $item->entryId)
        {
			if ($item->owner == $_SESSION['brimUsername'])
			{
	    		$resultString .= '<a href="CollectionsController.php?itemId='.$item->itemId;
	            $resultString .= '&parentId='.$item->parentId.'&action=modify"';
	    		$resultString .= '>'.$this->configuration['icons']['node_entry'].'</a>';
			}
			else 
			{
	    		$resultString .= $this->configuration['icons']['node_entry'];
			}
			$resultString .= '&nbsp;';
            if ((NULL != $item->path) && file_exists($item->path))
            {
                $resultString .= '<a href="'.$this->configuration['callback'];
                $resultString .= '?itemId='.$item->itemId;
                $resultString .= '&action=execute"';
                if (isset($this->configuration['collectionsNewWindowTarget']) &&
                	('_blank' ==  $this->configuration['collectionsNewWindowTarget']))
                {
                	$resultString .= 'target="_blank"';
                }
                $resultString .= '>'.$this->configuration['icons']['execute'].'</a>&nbsp;';
			}
			if ($item->owner == $_SESSION['brimUsername'])
			{
	            $resultString .= '<a href="CollectionsController.php';
	    		$resultString .= '?itemId='.$item->itemId;
	    		$resultString .= '&parentId='.$item->parentId;
	    		$resultString .= '&action=deleteItemPost"';
	    		// delete confirmation
	    		$resultString .= 'onclick="javascript:return confirm (\'';
	    		$resultString .= $this->configuration['dictionary']['confirm_delete'];
	    		$resultString .= '\');" ';
	    		$resultString .= '>'.$this->configuration['icons']['delete'].'</a>';
			}
			else 
			{
	    		$resultString .= $this->configuration['icons']['delete'];
			}
    		$resultString .= '<br />';
        }
        else
        {
           	$resultString .= $this->configuration['icons']['node'];
            if ((NULL != $item->path) && file_exists($item->path))
            {
                $resultString .= '&nbsp;<a href="'.$this->configuration['callback'];
                $resultString .= '?itemId='.$item->itemId;
                $resultString .= '&action=execute"';
                if (isset($this->configuration['collectionsNewWindowTarget']) &&
                	('_blank' ==  $this->configuration['collectionsNewWindowTarget']))
                {
                	$resultString .= 'target="_blank"';
                }
                $resultString .= '>'.$this->configuration['icons']['execute'].'</a>';
			}
           	$resultString .= '<br />';
        }


//        $resultString .= '<td class="collections_yahooname">';
		$resultString .= '<a href="'.$this->configuration['callback'].'?itemId='.$item->itemId;
		$resultString .='&parentId='.$item->parentId;
		$resultString .= '&action=showItem" ';
        if ($this->configuration['overlib'])
		{
            $popup = $this->overlibPopup($item);
			$resultString .= $this->overLib ($item->name, $popup);
		}
		$resultString .= '<b>'.$this->stringUtils->truncate ($item->name, $_SESSION['collectionsTruncateSize']). '</b></a>';
        if ($item->entryName != "")
        {
            $resultString .= '<br />'.$this->stringUtils->truncate($item->entryName, $_SESSION['collectionsTruncateSize']);
        }
       	$resultString .= '<br />'.$item->ConvSizeText();

        if (NULL != $item->description)
        {
            $resultString .= '<br />';
    		$resultString .= $this->stringUtils->newlinesToHtml ($this->stringUtils->truncate($item->description, $_SESSION['collectionsTruncateSize']));
        }
        $resultString .= '</td></tr></table>';

        $resultString .= '</tr></td>';
        $resultString .= '</td></tr></table>';
		return $resultString;
	}
}
?>