<?php

require_once ("framework/util/StringUtils.php");
require_once ("plugins/collections/view/overlibPopup.php");

/**
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Mortiz Julen - March 2006
 * @package org.brim-project.plugins.collections
 * @subpackage view
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class CollectionsYahooTreeDelegate extends CollectionsTreeDelegate
{
    /**
	 * Default constructor
	 */
	function CollectionsYahooTreeDelegate ($theConfiguration)
	{
		parent::TreeDelegate ($theConfiguration);
	}

	/**
	 * Builds up html code to display the root of the tree
	 * @private
	 *
	 * @param object item the item that is the root of the tree
	 */
	function showRoot ($item, $tree)
	{
		if (isset($item) && $item->itemId != 0)
		{
			$resultString = '<h2>'.$item->name.'</h2>';
			$resultString .= '<a href="'.$this->configuration['callback'];
			$resultString .= '?action=show&parentId='.$item->parentId.'">';
			$resultString .= $this->configuration['icons']['up'];
			$resultString .= '</a><br />';
		}
		else
		{
			$resultString = '';
		}
		return $resultString;
	}

	/**
	 * If the specified item is a folder, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean isExpanded whether this folder is expanded (i.e. do the
	 * children of this folder need to be displayed as well?)
	 * @param object tree the tree that uses this class as delegate
	 * @return string the string for this folder
	 */
	function drawFolder ($item, $isExpanded, $tree, $indentLevel)
	{
        if (isset($item))
        {
             if (0 != $item->entryId)
             {
             	switch ($item->entryType)
                {
                	case "zip":
                		$resultString = $this->configuration['icons']['folder_closed_zip'];
                		break;
                	case "iso":
                        $resultString = $this->configuration['icons']['folder_closed_iso'];
                		break;
                	default:
                 		$resultString = $this->configuration['icons']['folder_closed'];
                 		break;
				}
             }
             else
             {
             	
             	$resultString = '';
				if ($item->owner == $_SESSION['brimUsername'])
				{
	                $resultString .= '<a href="';
	        		$resultString .= $this->configuration['callback'];
	        		$resultString .= '?action=modify&itemId='.$item->itemId;
	        		$resultString .= '&parentId='.$item->parentId.'">';
	                if ($item->isEntry)
	                {
	                    $resultString .= $this->configuration['icons']['folder_closed_entry'];
	                }
	                else
	                {
	                    $resultString .= $this->configuration['icons']['folder_closed'];
	                }
	                $resultString .= '</a>';
				}
				else 
				{
	                if ($item->isEntry)
	                {
	                    $resultString .= $this->configuration['icons']['folder_closed_entry'];
	                }
	                else
	                {
	                    $resultString .= $this->configuration['icons']['folder_closed'];
	                }
				}
             }
             $resultString .= '<a href="';
    		 $resultString .= $this->configuration['callback'];
    		 $resultString .= '?action=show&parentId=';
    	 	 $resultString .= $item->itemId.'" ';
             if ($this->configuration['overlib'])
     		 {
     			$popUp = $this->overlibPopup ($item);
     			$resultString .= $this->overLib ($item->name, $popUp);
    		 }
             $resultString .= '>';
    		 $resultString .= $this->stringUtils->truncate ($item->name, $_SESSION['collectionsTruncateSize']);
    		 $resultString .= '</a>';

    		 $resultString .= '<br />';
    		 return $resultString;
        }
        return "";
	}


	/**
	 * If the specified item is a node, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean lastNode whether this node is the last one
	 * @return string the string for this node
	 */
	function drawNode ($item, $lastNode, $tree, $indentLevel)
	{
        $resultString  = '
						 <table border="1" valign="top" width="98%" ';
		$resultString .= 'bgcolor="#ffffff"	cellpadding="1" cellspacing="2">';

		//
		//	Note header: title with link, icons (delete+modify)
		//	and note popup
		//
		$resultString .= '<tr><td class="collections_menu" colspan="2">';
		$resultString .= '<table width="100%" cellpadding="0" cellspacing="0" border="0">';
		$resultString .= '<tr>';
        if (0 == $item->entryId)
        {
            $resultString .= '<td class="collections_yahooicons">';
			if ($item->owner == $_SESSION['brimUsername'])
			{
	    		$resultString .= '<a href="CollectionsController.php?itemId='.$item->itemId;
	            $resultString .= '&parentId='.$item->parentId.'&action=modify"';
	    		$resultString .= '>'.$this->configuration['icons']['node_entry'].'</a>';
			}
			else 
			{
	    		$resultString .= $this->configuration['icons']['node_entry'];
			}
			$resultString .= '&nbsp;';
            if ((NULL != $item->path) && file_exists($item->path))
            {
                $resultString .= '<a href="'.$this->configuration['callback'];
                $resultString .= '?itemId='.$item->itemId;
                $resultString .= '&action=execute"';
                if (isset($this->configuration['collectionsNewWindowTarget']) &&
                	('_blank' ==  $this->configuration['collectionsNewWindowTarget']))
                {
                	$resultString .= 'target="_blank"';
                }
                $resultString .= '>'.$this->configuration['icons']['execute'].'</a>&nbsp;';
			}
            // icon and link to play the playlist
			else if ('m3u' == $item->entryType)
			{
                $resultString .= '&nbsp;<a href="'.$this->configuration['callback'];
                $resultString .= '?parentId='.$item->itemId;
                $resultString .= '&action=playPlaylist"';
                if (isset($this->configuration['collectionsNewWindowTarget']) &&
                	('_blank' ==  $this->configuration['collectionsNewWindowTarget']))
                {
                	$resultString .= 'target="_blank"';
                }
                $resultString .= '>'.$this->configuration['icons']['execute'].'</a>';
			}
			if ($item->owner == $_SESSION['brimUsername'])
			{
	            $resultString .= '<a href="CollectionsController.php';
	    		$resultString .= '?itemId='.$item->itemId;
	    		$resultString .= '&parentId='.$item->parentId;
	    		$resultString .= '&action=deleteItemPost"';
	    		// delete confirmation
	    		$resultString .= 'onclick="javascript:return confirm (\'';
	    		$resultString .= $this->configuration['dictionary']['confirm_delete'];
	    		$resultString .= '\');" ';
	    		$resultString .= '>'.$this->configuration['icons']['delete'].'</a>';
			}
			else 
			{
	    		$resultString .= $this->configuration['icons']['delete'];
			}
    		$resultString .= '</td>';
        }
        else
        {
           	$resultString .= '<td class="collections_yahooicons">';
           	$resultString .= $this->configuration['icons']['node'];
            if ((NULL != $item->path) && file_exists($item->path))
            {
                $resultString .= '&nbsp;<a href="'.$this->configuration['callback'];
                $resultString .= '?itemId='.$item->itemId;
                $resultString .= '&action=execute"';
                if (isset($this->configuration['collectionsNewWindowTarget']) &&
                	('_blank' ==  $this->configuration['collectionsNewWindowTarget']))
                {
                	$resultString .= 'target="_blank"';
                }
                $resultString .= '>'.$this->configuration['icons']['execute'].'</a>';
			}
            // icon and link to play the playlist
			else if ('m3u' == $item->entryType)
			{
                $resultString .= '&nbsp;<a href="'.$this->configuration['callback'];
                $resultString .= '?parentId='.$item->itemId;
                $resultString .= '&action=playPlaylist"';
                if (isset($this->configuration['collectionsNewWindowTarget']) &&
                	('_blank' ==  $this->configuration['collectionsNewWindowTarget']))
                {
                	$resultString .= 'target="_blank"';
                }
                $resultString .= '>'.$this->configuration['icons']['execute'].'</a>';
			}
           	$resultString .= '</td>';
        }


        $resultString .= '<td class="collections_yahooname">';
		$resultString .= '<a href="'.$this->configuration['callback'];
        if ('m3u' == $item->entryType)
		{
        	$resultString .= '?parentId='.$item->itemId.'&action=showPlaylist" ';
		}
		else
		{
		 	$resultString .= '?itemId='.$item->itemId.'&parentId='.$item->parentId.'&action=showItem" ';
		}
        if ($this->configuration['overlib'])
		{
            $popup = $this->overlibPopup($item);
			$resultString .= $this->overLib ($item->name, $popup);
		}
		$resultString .= '<b>'.$this->stringUtils->truncate ($item->name, $_SESSION['collectionsTruncateSize']). '</b></a></td>';
        if ($item->entryName != "")
        {
            $resultString .= '<td align="left">'.$this->stringUtils->truncate($item->entryName, $_SESSION['collectionsTruncateSize']).'</td>';
        }
        if($item->isEntry && (0 == $item->size))
        {
         	$resultString .= '<td class="collections_yahoosize">&nbsp;</td></tr>';
		}
		else
		{
        	$resultString .= '<td class="collections_yahoosize">'.$item->ConvSizeText().'</td></tr>';
		}

        if (NULL != $item->description)
        {
            $resultString .= '<tr><td>&nbsp;</td><td>';
    		$resultString .= $this->stringUtils->newlinesToHtml ($this->stringUtils->truncate($item->description, $_SESSION['collectionsTruncateSize']));
    		$resultString .= '</td><td>&nbsp;</td></tr>';
        }
        $resultString .= '</table>';
        if (NULL != $item->detailData)
        {
            //$resultString .= '<tr><td class="menu" colspan="2"><table class="collections_yahooextrainfo" cellspacing="0">';
            switch ($item->entryType)
            {
                case "iso":
                    // only used if tree in zip not scanned
                    // uncompressed size
                    $resultString .= '<tr><td>'.$this->configuration['dictionary']['volume'].'</td><td>';
                    $resultString .= $this->stringUtils->truncate($item->detailData->name,$_SESSION['collectionsTruncateSize']).'</td>></tr>';
                    // entries count
                    $resultString .= '<tr><td>'.$this->configuration['dictionary']['volume_set'].'</td><td>';
                    $resultString .= $this->stringUtils->truncate($item->detailData->description,$_SESSION['collectionsTruncateSize']).'</td></tr>';
                    break;
                case "zip":
                    // only used if tree in zip not scanned
                    // uncompressed size
                    $resultString .= '<tr><td>'.$this->configuration['dictionary']['uncompressed_size'].'</td><td>';
                    $resultString .= $item->detailData->ConvSizeText($item->detailData->name).'</td></tr>';
                    // entries count
                    $resultString .= '<tr><td>'.$this->configuration['dictionary']['zipfiles_count'].'</td><td>';
                    $resultString .= $item->detailData->description.'</td></tr>';
                    break;
                case "mp3":
                    $resultString .= '<tr><td>'.$this->configuration['dictionary']['title'].'</td><td>';
                    $resultString .= $this->stringUtils->truncate($item->detailData->name,$_SESSION['collectionsTruncateSize']).'</td></tr>';
                    $resultString .= '<tr><td>'.$this->configuration['dictionary']['album'].'</td><td>';
                    $resultString .= $this->stringUtils->truncate($item->detailData->description,$_SESSION['collectionsTruncateSize']).'</td></tr>';
                    $resultString .= '<tr><td>'.$this->configuration['dictionary']['artist'].'</td><td>';
                    $resultString .= $this->stringUtils->truncate($item->detailData->field1,$_SESSION['collectionsTruncateSize']).'</td></tr>';
                    $resultString .= '<tr><td>'.$this->configuration['dictionary']['genre'].'</td><td>';
                    $resultString .= $this->stringUtils->truncate($item->detailData->field2,$_SESSION['collectionsTruncateSize']).'</td></tr>';
                    break;
                case "basic":
                    $resultString .= '<tr><td>'.$this->configuration['dictionary']['genre'].'</td><td>';
                    $resultString .= $this->stringUtils->truncate($item->detailData->name,$_SESSION['collectionsTruncateSize']).'</td></tr>';
                    $resultString .= '<tr><td>'.$this->configuration['dictionary']['artist'].'</td><td>';
                    $resultString .= $this->stringUtils->truncate($item->detailData->description,$_SESSION['collectionsTruncateSize']).'</td></tr>';
                    break;
                default:
                	break;
            }
            //$resultString .= '</table></td></tr>';
        }
        $resultString .= '</td></tr></table>';
		return $resultString;
	}
}
?>