<?php

require_once ("framework/util/StringUtils.php");
require_once ("plugins/collections/view/overlibPopup.php");

/**
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Mortiz Julen - June 2006
 * @package org.brim-project.plugins.collections
 * @subpackage view
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */

class PlaylistLineBasedTreeDelegate extends CollectionsTreeDelegate
{
	/**
	 * Have we already drawn a header?
	 */
	var $headersDrawn;
	var $firstNode = true;

	function PlaylistLineBasedTreeDelegate ($theConfiguration)
	{
		parent::TreeDelegate ($theConfiguration);
		$this->headersDrawn = false;
		$this->isParentEntry = false;
	}
	
	/**
	 * Builds up html code to display the root of the tree
	 * @private
	 *
	 * @param object item the item that is the root of the tree
	 */
	function showRoot ($item, $tree)
	{
		if (isset($item) && $item->itemId != 0)
		{
            $resultString =  '<h2><a href="'.$this->configuration['callback'];
			$resultString .= '?action=showItem&itemId='.$item->parentId.'">';
            $resultString .= $this->configuration['icons']['node'].'</a>';
			$resultString = '<h2>'.$item->name.'</h2>';
            if (isset($item->description))
            {
             	$resultString .= $item->description.'<br /><br />';
			}
			$resultString .= '<a href="'.$this->configuration['callback'];
			$resultString .= '?action=show&parentId='.$item->parentId.'">';
			$resultString .= $this->configuration['icons']['up'];
			$resultString .= '</a><br />';

		}
		else
		{
			$resultString = '';
		}
		return $resultString;
	}

	/**
	 * If the specified item is a folder, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean isExpanded whether this folder is expanded (i.e. do the
	 * children of this folder need to be displayed as well?)
	 * @param object tree the tree that uses this class as delegate
	 * @return string the string for this folder
	 */
	function drawFolder ($item, $isExpanded, $tree, $indentLevel)
	{
        if (isset($item))
        {
             if (0 != $item->entryId)
             {
                switch ($item->entryType)
                {
                	case "zip":
                		$resultString = $this->configuration['icons']['folder_closed_zip'];
                		break;
                	case "iso":
                        $resultString = $this->configuration['icons']['folder_closed_iso'];
                		break;
                	default:
                 		$resultString = $this->configuration['icons']['folder_closed'];
                 		break;
				}
             }
             else
             {
       			$resultString = '';
             	if ($item->owner == $_SESSION['brimUsername'])
				{
					$resultString = '<a href="';
	        		$resultString .= $this->configuration['callback'];
	        		$resultString .= '?action=modify&itemId='.$item->itemId;
	        		$resultString .= '&parentId='.$item->parentId.'">';
	                if ($item->isEntry)
	                {
	                    $resultString .= $this->configuration['icons']['folder_closed_entry'];
	                }
	                else
	                {
	                    $resultString .= $this->configuration['icons']['folder_closed'];
	                }
	                $resultString .= '</a>';
				}
				else 
				{
	                if ($item->isEntry)
	                {
	                    $resultString .= $this->configuration['icons']['folder_closed_entry'];
	                }
	                else
	                {
	                    $resultString .= $this->configuration['icons']['folder_closed'];
	                }
				}
             }
             $resultString .= '<a href="';
    		 $resultString .= $this->configuration['callback'];
    		 $resultString .= '?action=show&parentId=';
    	 	 $resultString .= $item->itemId.'" ';
             if ($this->configuration['overlib'])
     		 {
     			$popUp = $this->overlibPopup($item);
     			$resultString .= $this->overLib ($item->name, $popUp);
    		 }
             $resultString .= '>';
    		 $resultString .= $item->name;
    		 $resultString .= '</a>';

    		 $resultString .= '<br />';
    		 return $resultString;
        }
        return "";
	}



	function drawLinesHeader ($parentId)
	{
    	$resultString = '<td colspan="7"></td></tr><tr>';
        $resultString .= '<td class="collections_treeicon">&nbsp;</td>';
        $resultString .= '<td class="collections_treeicon">&nbsp;</td>';
        $resultString .= '<td class="collections_treeicon">&nbsp;</td>';

		$resultString .= '<td><b>'.$this->configuration['dictionary']['song'];
		$resultString .= '</b></td>';
		$resultString .= '<td"><b>'.$this->configuration['dictionary']['album'];
		$resultString .= '</b></td>';
        $resultString .= '<td"><b>'.$this->configuration['dictionary']['artist'];
		$resultString .= '</b></td>';
        $resultString .= '<td"><b>'.$this->configuration['dictionary']['track'];
		$resultString .= '</b></td>';
        $resultString .= '<td"><b>'.$this->configuration['dictionary']['playtime'];
		$resultString .= '</b></td>';

		$resultString .= '</tr><tr class="odd">';
		return $resultString;
	}
	/**
	 * If the specified item is a node, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean lastNode whether this node is the last one
	 * @return string the string for this node
	 */
	function drawNode ($item, $lastNode, $tree, $indentLevel)
	{
		if ($this->headersDrawn)
		{
			$resultString = '';
		}
		else
		{
			$resultString = $this->drawLinesHeader ($item->parentId);
			$this->headersDrawn = true;
		}

		$resultString .= '<td align="left">';
		if (!$lastNode)
		{
	       	if ($item->owner == $_SESSION['brimUsername'])
			{
	            $resultString .= '<a href="'.$this->configuration['callback'];
	            $resultString .= '?parentId='.$item->parentId;
	            $resultString .= '&itemId='.intval($item->name);
	            $resultString .= '&action=moveDownInPlaylist"';
	        	$resultString .= $this->configuration['icons']['down_arrow'].'</a>';
			}
			else 
			{
	        	$resultString .= $this->configuration['icons']['down_arrow'];
			}
		}
		$resultString .= '</td>';
        $resultString .= '<td align="left">';
		if (!$this->firstNode)
		{
	       	if ($item->owner == $_SESSION['brimUsername'])
			{
	        	$resultString .= '<a href="'.$this->configuration['callback'];
	            $resultString .= '?parentId='.$item->parentId;
	            $resultString .= '&itemId='.intval($item->name);
	            $resultString .= '&action=moveUpInPlaylist"';
	        	$resultString .= $this->configuration['icons']['up_arrow'].'</a>';
			}
			else 
			{
	        	$resultString .= $this->configuration['icons']['up_arrow'];
			}
		}
		$this->firstNode = false;
		$resultString .= '</td>';

        $resultString .= '<td align="left">';
       	if ($item->owner == $_SESSION['brimUsername'])
		{
	        $resultString .= '<a href="'.$this->configuration['callback'];
			$resultString .= '?itemId='.intval($item->name);
			$resultString .= '&parentId='.$item->parentId;
			$resultString .= '&action=deletePlaylistItemPost" ';
			// delete confirmation
			$resultString .= 'onclick="javascript:return confirm (\'';
			$resultString .= $this->configuration['dictionary']['confirm_delete'];
			$resultString .= '\');" ';
			$resultString .= '>'.$this->configuration['icons']['delete'].'</a>';
		}
		else 
		{
			$resultString .= $this->configuration['icons']['delete'];
		}
		$resultString .= '</td>';

		$resultString .= '<td>';
		$resultString .= '<b>'.$this->stringUtils->truncate ($item->field1, $_SESSION['collectionsTruncateSize']). '</b>';
		$resultString .= '</td>';

        $resultString .= '<td>';
		$resultString .= $this->stringUtils->truncate ($item->field2, $_SESSION['collectionsTruncateSize']);
		$resultString .= '</td>';

        $resultString .= '<td>';
		$resultString .= $this->stringUtils->truncate ($item->field3, $_SESSION['collectionsTruncateSize']);
		$resultString .= '</td>';

        $resultString .= '<td>';
		$resultString .= $this->stringUtils->truncate ($item->field4, $_SESSION['collectionsTruncateSize']);
		$resultString .= '</td>';

        $resultString .= '<td>';
		$resultString .= strftime('%M:%S', $item->field5);
		$resultString .= '</td>';

		return $resultString;
	}
}
?>
