<?php
require_once('framework/ItemController.php');
require_once('plugins/depot/model/DepotServices.php');
require_once('plugins/depot/model/DepotPreferences.php');

require_once('plugins/depot/model/TransactionController.php');
require_once('plugins/depot/model/DepotDataController.php');
require_once('plugins/depot/model/CurrencyController.php');

/**
 * The Depot Controller
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Moritz Julen - April 2006
 * @package org.brim-project.plugins.depot
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class DepotController extends ItemController
{
    var $TransactionController;
    var $DepotDataController;
    var $CurrencyController;

	/**
	 * Constructor.
	 * Makes sure that the appropriate operations are instantiated.
	 * @param string renderEngineName the render engine that is used
	 * (either Smarty or phpSavant)
	 */
	function DepotController()
	{
		parent::ItemController();

		$this->operations = new DepotServices();
		$this->preferences = new DepotPreferences();
		$this->itemFactory = new DepotFactory();


		$this->pluginName = 'depot';
		$this->title = 'Brim - DepotTracker';
		$this->itemName = 'Depot';
		$this->expandName = 'depotExpand';

		$this->TransactionController = new TransactionController($this);
		$this->CurrencyController = new CurrencyController($this);
		$this->DepotDataController = new DepotDataController($this);
	}

	/**
	 * Returns the name of the item that is controller by this
	 * controller
	 *
	 * @return string the name of the item that is controlled by this
	 * controller
	 */
	function getItemName ()
	{
		return "DepotItem";
	}

	/**
 	 * Returns the actions defined for this item only
 	 *
 	 * @return array an array of item specific actions
	 * (like search, import etc.)
 	 */
	function getActions()
	{
		$dictionary = $this->getDictionary ();

		// Actions
		$actions[0]['name']='actions';
		$actions[0]['contents'][]=
				array('href' => 'DepotController.php?action=add&parentId='.$this->getParentId (),
					'name' => 'add');
        $actions[0]['contents'][]=
				array('href' => 'DepotController.php?action=trackDepot&parentId='.$this->getParentId(),
					'name' => 'track');
        $actions[0]['contents'][]=
				array ('href' => 'DepotController.php?action=showCurrencies',
					'name' => 'Currency');

		// Sort
		$actions[1]['name']='sort';
		$actions[1]['contents'][]=
				array('href'=>'DepotController.php?action=sort&order=ASC&field=name&parentId='.$this->parentId,
					'name'=> 'name');
        $actions[1]['contents'][]=
				array('href'=>'DepotController.php?action=sort&order=ASC&field=symbol&parentId='.$this->parentId,
					'name'=> 'Symbol');
        $actions[1]['contents'][]=
				array('href'=>'DepotController.php?action=sort&order=ASC&field=valor&parentId='.$this->parentId,
					'name'=> 'Valor');

		// Preferences
		$actions[2]['name'] = 'preferences';
		$actions[2]['contents'][] =
				array ('href' => 'DepotController.php?action=modifyPreferencesPre&parentId='.$this->parentId,
				   'name' => 'modify');

		// help
		$actions[3]['name'] = 'help';
		$actions[3]['contents'][] =
				array ('href' => 'DepotController.php?action=help&parentId='.$this->parentId,
					   'name' => 'help');
        $actions[3]['contents'][]=
				array ('href' => 'http://finance.yahoo.com/',
				   'name' => 'yahooFinance');

		return $actions;
	}

	/**
	 * Activate. Basically this means that the appropriate actions
	 * are executed and an optional result is returned
	 * to be processed/displayed
	 */
	function activate()
	{
		$dictionary = $this->getDictionary();
// echo "Depot: ".$this->getAction()." with item: ".$this->itemId." with parent : ".$this->parentId."<br />";
        switch ($this->getAction())
		{
			case "add":
				$this->addAction ();
				break;
            case "addItemPost":
				$this->addItemAction();
				$this->getShowItemsParameters ();
				break;
			case "modify":
                $this->modifyAction ();
				break;
            case "modifyItemPost":
				$this->modifyItemAction();
				$this->getShowItemsParameters ();
				break;
			case "deleteItemPost":
				if ($this->operations->getItemOwner ($this->itemId) == $_SESSION['brimUsername'])
				{
					// delete depot data items
					$this->DepotDataController->operations->deleteChildren
						($this->getUserName(), $this->itemId);
					// delete transactions
					$this->TransactionController->operations->deleteChildren
						($this->getUserName(), $this->itemId);
					// delete depot item
					$this->operations->deleteItem
						($this->getUserName(), $this->itemId);
				}
				$this->getShowItemsParameters ();
				break;
			case "move":
				$this->moveAction ();
				break;
			case "moveItem":
				$this->moveItemAction ();
				$this->getShowItemsParameters ();
				break;
			case "help":
				$this->helpAction();
				break;
			case "sort":
				$this->sortAllAction ($_GET['field'], $_GET['order']);
				$this->addDisplayData();
				break;
			case "modifyPreferencesPre":
				$this->renderObjects =
					$this->preferences->getAllPreferences($this->getUserName());
				$this->renderObjects['depotCurrencies']=
					$this->CurrencyController->getCurrenciesOptions();
				$this->renderer = 'modifyPreferences';
				break;
			case "modifyPreferencesPost":
				$this->preferences->setPreference($this->getUserName(),
												  $_POST['name'],
												  $_POST['value']);
				$_SESSION['depotOverlib'] =
						$this->preferences->getPreferenceValue($this->getUserName(),
															   'depotOverlib');
				$_SESSION['depotCurrency'] =
                		$this->preferences->getPreferenceValue($this->getUserName(),
															   'depotCurrency');
				$_SESSION['depotCurrencyName'] =
						$this->CurrencyController->getCurrencyName($_SESSION['depotCurrency']);
                $_SESSION['depotConversionCurrencyNames'] =
						$this->CurrencyController->getCurrenciesOptions($_SESSION['depotCurrency']);

				$this->renderer = 'modifyPreferences';
				$this->renderObjects = $_SESSION;
                $this->renderObjects['depotCurrencies']=
					$this->CurrencyController->getCurrenciesOptions();
				break;
			case "trackDepot":
				$this->trackChildren();
				// diplay new data
				$this->getShowItemsParameters();
				break;

			case "showTransactions":
            case "buy":
            case "sell":
            case "addTransactionPost":
            case "cancelTransactions":
            case "deleteTransactionPost":
            case "helpTransaction":
            case "modifyTransaction":
            case "modifyTransactionPost":
            case "sortTransaction":
                $this->TransactionController->activate();
                break;
            case "addDepotData":
            case "addDepotDataPost":
            case "deleteDepotDataPost":
            case "drawChart":
            case "helpDepotData":
            case "modifyDepotData":
            case "modifyDepotDataPost":
            case "showDepotData":
            case "sortDepotData":
            case "trackDepotData":
            case "trackHistoricalDepotData":
            case "trackAllHistoricalDepotData":
            	$this->DepotDataController->activate();
            	break;

            case "addCurrency":
            case "addCurrencyPost":
            case "cancelCurrency":
            case "deleteCurrencyPost":
            case "helpCurrency":
            case "modifyCurrency":
            case "modifyCurrencyPost":
            case "showCurrencies":
            case "showCurrency":
			case "sortCurrencies":
			case "trackCurrency":
            	$this->CurrencyController->activate();
            	break;

			default:
                if (!isset ($_SESSION['depotOverlib']))
				{
                    $_SESSION['depotOverlib']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'depotOverlib');
				}
                if (!isset ($_SESSION['depotCurrency']))
				{
                    $_SESSION['depotCurrency']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'depotCurrency');
				}
                if (!isset ($_SESSION['depotLastTrackDate']))
				{
                    $_SESSION['depotLastTrackDate']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'depotLastTrackDate');
				}
				if (date('Y-m-d') != $_SESSION['depotLastTrackDate'])
				{
                 	// today not tracked
                    $this->TrackAll();
                    // store it
                    $_SESSION['depotLastTrackDate'] = date('Y-m-d');
                    $this->preferences->setPreference($this->getUserName(),
												  'depotLastTrackDate',
												  $_SESSION['depotLastTrackDate']);
				}
				// set currency conversion names
				// set allways to be sure when coming from curreny controller or so
                $_SESSION['depotConversionCurrencyNames'] =
						$this->CurrencyController->getCurrenciesOptions($_SESSION['depotCurrency']);
				$this->getShowItemsParameters();
	            break;
		}
	}

    function display()
	{
        switch ($this->getAction())
		{
        	case "showTransactions":
    		case "buy":
    		case "sell":
            case "addTransactionPost":
            case "cancelTransactions":
            case "deleteTransactionPost":
            case "helpTransaction":
            case "modifyTransaction":
            case "modifyTransactionPost":
            case "sortTransaction":
    			$this->TransactionController->display();
    			break;
            case "addDepotData":
            case "addDepotDataPost":
            case "deleteDepotDataPost":
            case "helpDepotData":
            case "modifyDepotData":
            case "modifyDepotDataPost":
            case "showDepotData":
            case "sortDepotData":
            case "trackDepotData":
            case "trackHistoricalDepotData":
            case "trackAllHistoricalDepotData":
    			$this->DepotDataController->display();
    			break;
            case "addCurrency":
            case "addCurrencyPost":
            case "cancelCurrency":
            case "deleteCurrencyPost":
            case "helpCurrency":
            case "modifyCurrency":
            case "modifyCurrencyPost":
            case "showCurrencies":
            case "showCurrency":
            case "sortCurrencies":
            case "trackCurrency":
            	$this->CurrencyController->display();
            	break;
    		default:
    			parent::display();
		}
    }


    function getShowItemsParameters()
    {
        parent::getShowItemsParameters();
        $this->addDisplayData();
    }

    function showAction()
    {
        parent::showAction();
        if (NULL != $this->renderObjects)
        {
         	$this->renderObjects->addTransactions(
                        $this->TransactionController->operations->getChildren($this->getUserName(), $this->renderObjects->itemId));
            $this->renderObjects->addLastTrack(
                        $this->DepotDataController->operations->getChildren($this->getUserName(), $this->renderObjects->itemId, 1));
        }
    }

    function addDisplayData()
    {
        $i = 0;
        while (isset($this->renderObjects[$i]))
        {
            if (!$this->renderObjects[$i]->isParent())
            {
	         	$this->renderObjects[$i]->addTransactions(
	                        $this->TransactionController->operations->getChildren($this->getUserName(), $this->renderObjects[$i]->itemId));
	            $this->renderObjects[$i]->addLastTrack(
	                        $this->DepotDataController->operations->getChildren($this->getUserName(), $this->renderObjects[$i]->itemId, 1));
	            // add last factor of the currency conversion data
                if (isset($this->renderObjects[$i]->Transaction[0]))
                {
		            $this->renderObjects[$i]->lastConversionFactor(
		            			$this->DepotDataController->operations->getChildren(
		            				$this->getUserName(),
		            				$this->renderObjects[$i]->Transaction[0]->purchaseCurrency, 1));
				}
			}
            $i++;
        }
	}

	function trackChildren()
	{
        // get all children
        $items = $this->operations->getChildren($this->getUserName(), $this->parentId);
        if (NULL != $items)
        {
	        foreach ($items as $item)
	        {
	            // track all children
	         	$this->DepotDataController->QueryAndSave($item);
			}
		}
	}

	function trackAll()
	{
        // track all items
        // get all depot items
        $items = $this->operations->getItems($this->getUserName());
        if (NULL != $items)
        {
	        foreach ($items as $item)
	        {
	            // track all children
	         	$this->DepotDataController->QueryAndSave($item);
			}
		}
		// get all currencies
		$items = $this->CurrencyController->operations->getItems($this->getUserName());
        if (NULL != $items)
        {
        foreach ($items as $item)
	        {
	            // track all children
	         	$this->DepotDataController->QueryAndSave($item);
			}
		}
	}
}
?>
