<?php
require_once('framework/ItemController.php');
require_once('plugins/depot/model/CurrencyServices.php');

/**
 * The Currency Controller
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Moritz Julen - April 2006
 * @package org.brim-project.plugins.depot
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class CurrencyController extends ItemController
{
	var $depotController;

 	/**
	 * Constructor.
	 * Makes sure that the appropriate operations are instantiated.
	 * @param string renderEngineName the render engine that is used
	 * (either Smarty or phpSavant)
	 */
	function CurrencyController(&$depotcontroller)
	{
		parent::ItemController();

		$this->operations = new CurrencyServices();
		$this->itemFactory = new DepotFactory();


		$this->pluginName = 'depot';
		$this->title = 'Brim - DepotTracker';
		$this->itemName = 'DepotItem';

		$this->depotController = $depotcontroller;
	}

    /**
	 * Returns the name of the item that is controller by this
	 * controller
	 *
	 * @return string the name of the item that is controlled by this
	 * controller
	 */
	function getItemName ()
	{
		return "CurrencyItem";
	}

	/**
 	 * Returns the actions defined for this item only
 	 *
 	 * @return array an array of item specific actions
	 * (like search, import etc.)
 	 */
	function getActions()
	{
		$dictionary = $this->getDictionary ();

		// Actions
		$actions[0]['name']='actions';
		$actions[0]['contents'][]=
					array('href' => 'DepotController.php?action=addCurrency&parentId='.$this->getParentId (),
						'name' => 'add');
        $actions[0]['contents'][]=
					array('href' => 'DepotController.php?action=trackCurrency&parentId='.$this->getParentId(),
						'name' => 'track');
        $actions[0]['contents'][]=
			array ('href' => 'DepotController.php',
				   'name' => 'depot');

		// help
		$actions[1]['name'] = 'help';
		$actions[1]['contents'][] =
				array ('href' => 'DepotController.php?action=helpCurrency&parentId='.$this->getParentId(),
					   'name' => 'help');
        $actions[1]['contents'][]=
			array ('href' => 'http://finance.yahoo.com/',
				   'name' => 'yahooFinance');

		return $actions;
	}

	/**
	 * Activate. Basically this means that the appropriate actions
	 * are executed and an optional result is returned
	 * to be processed/displayed
	 */
	function activate()
	{
		$dictionary = $this->getDictionary();
// echo "Currency Controller: ".$this->getAction()." with item: ".$this->itemId." with parent : ".$this->parentId."<br />";
		switch ($this->getAction())
		{
		 	case "addCurrency":
		 		$this->addAction();
		 		break;
		 	case "addCurrencyPost":
                $this->addItemAction();
				break;
			case "deleteCurrencyPost":
                $this->deleteItemAction ();
				$this->getShowItemsParameters ();
				break;
				break;
			case "helpCurrency":
				$this->helpAction();
				break;
			case "modifyCurrency":
                $this->modifyAction();
		 		break;
		 	case "modifyCurrencyPost":
                $this->modifyItemAction();
				$this->getShowItemsParameters ();
				break;
			case "sortCurrencies":
                $this->sortAllAction ($_GET['field'], $_GET['order']);
				break;
			case "trackCurrency":
                $this->trackChildren();
				// diplay new data
				$this->getShowItemsParameters();
				break;
			default:
				$this->getShowItemsParameters();
				break;
		}
    }

    function trackChildren()
	{
		// get all children
		$items = $this->operations->getChildren($this->getUserName(), $this->parentId);

		if (isset($items))
		{
			foreach ($items as $item)
			{
				// track all children
				$this->depotController->DepotDataController->QueryAndSave($item);
			}
		}
	}

	function getCurrenciesOptions($parentId = 0)
	{
       // get all parents
       $options = array();
       $items = $this->operations->getChildren($this->getUserName(), $parentId);
       if (NULL != $items)
       {
	       foreach($items as $item)
	       {
	            $options[$item->itemId] = $item->name;
		   }
		   return $options;
	   }
       return NULL;
	}

	function getCurrencyName($itemId)
	{
     	$item = $this->operations->getItem($this->getUserName(), $itemId);
     	return $item->name;
	}

    /**
	 * Items parameters has been provided, now really add it
	 *
	 * @protected
	 * @modified Michael Haussmann
	 */
	function addItemAction ()
	{
		$item = $this->itemFactory->requestToItem ();
		$errors = $this->itemFactory->requestToItemErrors ();
		if (empty($errors))
		{
            $itemId = $this->operations->addItem($this->getUserName(), $item);
	    	if ($item->isParent)
	    	{
	         	// base currency added
	         	// add himself to currency list
	         	$item->isParent = 0;
	         	$item->parentId = $itemId;
	         	$item->description = "auto entry";
	            $dataId = $this->operations->addItem($this->getUserName(), $item);
	            // add price = 1
	            $data = new DepotDataItem
				(
						0,
						$this->getUserName(),
						$dataId,
						0,
						null,
						null,
						$item->visibility,
	                    $item->category,
						0,
						null,
						null,

						date('Y-m-d'),
		                1,
		                0,
		                0,
		                0
				);
            	$this->depotController->DepotDataController->operations->addItem($this->getUserName(), $data);
			}
			$this->getShowItemsParameters ();
		}
		else
		{
				//die ('x');
			$this->addParameter("errors", $errors);
			$this->addAction ();
			$this->renderObjects = $item;
		}
	}

	function getDictionary()
	{
     	$dictionary = parent::getDictionary();
        $dictionary['item_quick_help'] = $dictionary['item_quick_help_currency'];
        return $dictionary;
	}

    /**
	 * The help function is requested. Load the plugins help version
	 * in english, check for the language specific help file afterwards
	 * and load this one afterwards if it exists
	 */
	function helpAction ()
	{
		$this->renderer = 'help';
		$dictionary = $this->getDictionary();
        /*
		include ('plugins/'.$this->pluginName.'/i18n/dictionary_en.php');
		if (file_exists('plugins/'.$this->pluginName.'/i18n/dictionary_'.
			$_SESSION['brimLanguage'].'.php'))
		{
			include ('plugins/'.$this->pluginName.'/i18n/dictionary_'.
				$_SESSION['brimLanguage'].'.php');
		}
		*/
		$this->renderEngine->assign ('pluginHelp', $dictionary['item_help_currency']);
		$this->renderEngine->assign ('helpaction', 'showCurrencies');
	}
}
?>
