<?php
require_once('framework/ItemController.php');
require_once('plugins/depot/model/DepotDataServices.php');
require_once('plugins/depot/util/phplot/phplot.php');

/**
 * The Depot Data Controller
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Moritz Julen - April 2006
 * @package org.brim-project.plugins.depot
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class DepotDataController extends ItemController
{
	var $depotController;
	var $chartData;

 	/**
	 * Constructor.
	 * Makes sure that the appropriate operations are instantiated.
	 * @param string renderEngineName the render engine that is used
	 * (either Smarty or phpSavant)
	 */
	function DepotDataController(&$depotcontroller)
	{
		parent::ItemController();

		$this->operations = new DepotDataServices();
		$this->itemFactory = new DepotDataFactory();


		$this->pluginName = 'depot';
		$this->title = 'Brim - DepotTracker';
		$this->itemName = 'DepotData';
		$this->expandName = 'depotdataExpand';

		$this->depotController = $depotcontroller;
	}

    /**
	 * Returns the name of the item that is controller by this
	 * controller
	 *
	 * @return string the name of the item that is controlled by this
	 * controller
	 */
	function getItemName ()
	{
		return "DepotDataItem";
	}

	/**
 	 * Returns the actions defined for this item only
 	 *
 	 * @return array an array of item specific actions
	 * (like search, import etc.)
 	 */
	function getActions()
	{
		$dictionary = $this->getDictionary ();

		// Actions
		$actions[0]['name']='actions';
		$actions[0]['contents'][]=
					array('href' => 'DepotController.php?action=addDepotData&parentId='.$this->getParentId (),
						'name' => 'add');
        $actions[0]['contents'][]=
					array('href' => 'DepotController.php?action=trackDepotData&parentId='.$this->getParentId(),
						'name' => 'track');
        $actions[0]['contents'][]=
					array('href' => 'DepotController.php?action=trackHistoricalDepotData&parentId='.$this->getParentId(),
						'name' => 'trackHistorical');
        $actions[0]['contents'][]=
					array('href' => 'DepotController.php?action=trackAllHistoricalDepotData&parentId='.$this->getParentId(),
						'name' => 'trackHistoricalAll');
		// Sort
		$actions[1]['name']='sort';
		$actions[1]['contents'][]=
					array('href'=>'DepotController.php?action=sort&order=ASC&field=name',
						'name'=> 'name');

		// help
		$actions[2]['name'] = 'help';
		$actions[2]['contents'][] =
				array ('href' => 'DepotController.php?action=helpDepotData&parentId='.$this->getParentId(),
					   'name' => 'help');

		return $actions;
	}

	/**
	 * Activate. Basically this means that the appropriate actions
	 * are executed and an optional result is returned
	 * to be processed/displayed
	 */
	function activate()
	{
		$dictionary = $this->getDictionary();
// echo "DepotData: ".$this->getAction()." with item: ".$this->itemId." with parent : ".$this->parentId."<br />";
		switch ($this->getAction())
		{
			case "addDepotData":
				$this->addAction ();
				break;
            case "addDepotDataPost":
				$this->addItemAction();
				$this->getShowItemsParameters ();
				break;
			case "drawChart":
                if (isset($_SESSION['chartData']))
				{
                    $this->drawGraph($_SESSION['chartData']);
					// free memory
					unset($_SESSION['chartData']);
				}
				exit;
				break;
			case "modifyDepotData":
				$this->modifyAction ();
				break;
            case "modifyDepotDataPost":
				$this->modifyItemAction();
				$this->getShowItemsParameters ();
				break;
			case "deleteDepotDataPost":
				$this->operations->deleteItem
					($this->getUserName(), $this->itemId);
				$this->getShowItemsParameters ();
				break;
			case "sortDepotData":
				$this->sortAllAction ($_GET['field'], $_GET['order']);
				break;
			case "trackDepotData":
                $depotitem = $this->depotController->operations->getItem(
            														$this->getUserName(),
													   				$this->parentId);
                $this->QueryAndSave($depotitem);
                $this->getShowItemsParameters();
				break;
			case "trackHistoricalDepotData":
                $depotitem = $this->depotController->operations->getItem(
            														$this->getUserName(),
													   				$this->parentId);
				$this->QueryAndSaveHistorical($depotitem);
				$this->getShowItemsParameters();
				break;
			case "trackAllHistoricalDepotData":
            	$depotitem = $this->depotController->operations->getItem(
            														$this->getUserName(),
													   				$this->parentId);
				$this->QueryAndSaveHistorical($depotitem, "1980-01-01", date('Y-m-d'));
				$this->getShowItemsParameters();
				break;
			case "helpDepotData":
				$this->helpAction();
				break;
			default:
				$this->getShowItemsParameters();
				break;
		}
	}

    function getShowItemsParameters()
    {
        parent::getShowItemsParameters();
		if (isset($this->renderObjects) && (0 < count($this->renderObjects)))
        {
            // save the data into session to draw the chart
	        $data = array();
	        foreach ($this->renderObjects as $item)
	        {
	            // [timestamp, price]
	         	$data[] = array(strtotime($item->trackDate), strtotime($item->trackDate), $item->Price);
			}
            // allways the same order for the graph
			array_multisort($data, SORT_ASC);
			$_SESSION['chartData'] = $data;
			// must be executed -> update of session data
			// else it is possible that the chart contains old data
			session_write_close();
			// no changes to session vars are possible
		}
        $item = $this->depotController->operations->getItem($this->getUserName(), $this->parentId);
		$this->renderEngine->assign('depotItem', $item);
	}

    /**
	 * Gets the ancestors for a specific item
	 * and adds them to the controller as parameter
	 */
	function getCurrentAncestors ()
	{
		$currentDepot = $this->depotController->operations->getItem
			($this->getUserName(), $this->parentId);
		$ancestors = $this->depotController->operations->getAncestors($currentDepot);
		$this->addParameter ("ancestors", array_reverse($ancestors));
	}


	function QueryAndSave($depotitem)
	{
         $data = $this->queryYahoo($depotitem);
         if (NULL != $data)
         {
          	$this->operations->addItem($this->getUserName(), $data);
		 }
	}

    function QueryAndSaveHistorical($depotitem, $from=NULL, $to=NULL)
	{
     	$items = $this->queryhistoricalYahoo($depotitem, $from, $to);
		if (NULL != $items)
		{
			$this->operations->addItem($this->getUserName(), $items);
		}
	}

    // Copyright (C) 2006 Joshua Eldridge (joshuae74@hotmail.com)
    // modified by Moritz Julen May 2006
    function queryYahoo($item)
    {
        $depotdata = NULL;
     	if ($item->Tracking & ("" != $item->Symbol))
        {
            // download comma seperate file with data for the symbol from yahoo
            if ($fp = @fopen("http://quote.yahoo.com/d/quotes.csv?s=" . $item->Symbol . "&f=sl1d1t1c1ohgv&e=.csv", "r"))
            {
	            // read it in a buffer
	            $data = fread($fp, 10000);
	            // close the file
	            fclose($fp);
	            // use the comma to split the string into an array
	            $data = explode(",", $data);
	            if ((NULL != $data) & (0 != $data[1]))
	            {
	             	$depotdata = new DepotDataItem(NULL,
	             									$this->getUserName(),
	             									$item->itemId,
	             									0,
	             									NULL,
	             									NULL,
	             									$item->visibility,
	             									NULL,
	             									0,
	             									date('Y-m-d'),
	             									NULL,
	             									date("Y-m-d", strtotime(str_replace("\"", "", $data[2]))),
	             									$data[1],
	             									$data[8],
	             									0,
	             									0);
	            }
	            else
	            {
	                echo 'Symbol "' . $item->Symbol.'" not found by Yahoo-Finance!!!<br />';
	                echo 'Try to find by <a href="http://finance.yahoo.com/q?s='.$item->Symbol.'" target="_blank">http://finance.yahoo.com/</a><br />';
	            }
			}

        }
        return $depotdata;
	}

	// Copyright (C) 2006 Joshua Eldridge (joshuae74@hotmail.com)
	// modified and extended by Moritz Julen May 2006
    function queryhistoricalYahoo($item, $from=NULL, $to=NULL)
    {
        $dateUtils = new DateUtils ();
        $depotdata = array();
        if (NULL == $to)
        {
	     	$to = date('Y-m-d');
		}
		if (NULL == $from)
		{
            // get one year as default
            $from = date('Y-m-d', strtotime("-1 year", strtotime($to)));
		}
        if( $fp = @fopen("http://ichart.finance.yahoo.com/table.csv?s=".$item->Symbol.
        		"&a=".($dateUtils->getMonthfromDate($from)-1).
        		"&b=".$dateUtils->getDayInMonthFromDate($from).
        		"&c=".$dateUtils->getYearfromDate($from).
        		"&d=".($dateUtils->getMonthfromDate($to)-1).
        		"&e=".$dateUtils->getDayInMonthFromDate($to).
        		"&f=".$dateUtils->getYearfromDate($to).
        		"&g=d&ignore=.csv", "r"))
        {
            // first data is header
         	$i = fgetcsv($fp, 10000, ",");
         	for ($index=0; $index<count($i); $index++)
         	{
             	switch($i[$index])
             	{
                	case "Date":
                		$date_index = $index;
                		break;
                	case "Close":
                		$price_index = $index;
                		break;
                	case "Volume":
                		$volume_index = $index;
                		break;
				}
			}
         	while (($i = fgetcsv($fp, 10000, ",")) != FALSE)
            {
                if(NULL != $i)
                {
                    // not empty rows
	             	// store data in depotdata array
	             	$depotdata[] = new DepotDataItem(NULL,
	             									$this->getUserName(),
	             									$item->itemId,
	             									0,
	             									NULL,
	             									NULL,
	             									$item->visibility,
	             									$item->category,
	             									0,
	             									date('Y-m-d'),
	             									NULL,
	             									date('Y-m-d', strtotime($i[$date_index])),
	             									$i[$price_index],
	             									$i[$volume_index],
	             									0,
	             									0);
				}
            }
            fclose($fp);
        }
        return $depotdata;
    }

    function drawGraph($data)
    {
     	$dictionary = $this->getDictionary();
     	// start with empty output buffer
     	ob_get_clean();
		// create a graph object
		$graph = new PHPlot(600,300);

		$graph->SetIsInline(true);
		// format the X axis to display the date
        $graph->SetXGridLabelType("time");
        $graph->SetXTimeFormat("%Y-%m-%d");
        $graph->SetXDataLabelAngle(90);
        if (15 < count($data))
        {
        	$graph->SetNumHorizTicks(15);
		}
		else
		{
			$graph->SetNumHorizTicks(count($data)-1);
		}
        $graph->SetDrawXDataLabels(false);
		// set axis names
        $graph->SetXLabel("");
		$graph->SetYLabel($dictionary['Price']);
		// must be called before SetDataValues
        $graph->SetDataType("data-data");
		// add the data
        $graph->SetDataValues($data);
        // appearance
        $graph->SetPlotType('linepoints');
        $graph->SetBackgroundColor(array(240, 240 ,210));
        $graph->SetPointSize(5);
        $graph->SetLineWidth(2);
        $graph->SetDataColors('orange', 'black');
		//Draw it
		$graph->DrawGraph();
	}

    function getDictionary()
	{
     	$dictionary = parent::getDictionary();
        $dictionary['item_quick_help'] = $dictionary['item_quick_help_depotData'];
        return $dictionary;
	}

    /**
	 * The help function is requested. Load the plugins help version
	 * in english, check for the language specific help file afterwards
	 * and load this one afterwards if it exists
	 */
	function helpAction ()
	{
		$this->renderer = 'help';
		$dictionary = $this->getDictionary();
        /*
		include ('plugins/'.$this->pluginName.'/i18n/dictionary_en.php');
		if (file_exists('plugins/'.$this->pluginName.'/i18n/dictionary_'.
			$_SESSION['brimLanguage'].'.php'))
		{
			include ('plugins/'.$this->pluginName.'/i18n/dictionary_'.
				$_SESSION['brimLanguage'].'.php');
		}
		*/
		$this->renderEngine->assign ('pluginHelp', $dictionary['item_help_depotData']);
		$this->renderEngine->assign ('helpaction', 'showDepotData');
	}
}
?>
