<?php
require_once('plugins/depot/model/DepotDataItem.php');
require_once('plugins/depot/model/DepotDataFactory.php');
require_once('framework/model/Services.php');
require_once('framework/util/DateUtils.php');

/**
 * Services for Depot Data
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Moritz Julen - April 2006
 * @package org.brim-project.plugins.depot
 * @subpackage model
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class DepotDataServices extends Services
{

	/**
	 * Default constructor
	 */
	function DepotDataServices()
	{
		parent::Services();
		$this->itemFactory = new DepotDataFactory();


		include ('plugins/depot/sql/depotdataQueries.php');
		$this->queries = $queries;
	}

	/**
	 * Adds depot data
	 *
	 * @param integer userId the identifier for the user
	 * @param object items the e-depot information to be added
	 *
     * @return integer last know id. This is the id of the depot information
	 * that was newly inserted and for which an id has automatically
	 * been assigned.
	 */
	function addItem($userId, $items)
	{
		$yearchecked = true;
		$oldyear = NULL;
		$dateUtils = new DateUtils();
        if (!is_array($items))
        {
            // build an array of the item
         	$item = $items;
         	$items = array();
         	$items[] = $item;
		}
		foreach ($items as $item)
		{
	        $query = sprintf($this->queries['getDateItem'],
	        	$item->parentId,
	        	$item->trackDate);
	        $result = $this->db->Execute($query);
	        if (!$result->fields)
	        {
                if (!isset($oldyear) ||
                	($oldyear != $dateUtils->getYearfromDate($item->trackDate)))
                {
                    if (!$yearchecked)
	                {
	                 	$yearchecked = true;
			        	$this->checkYearData($userId, $item->parentId, $oldyear.'-01-01');
					}
                 	$oldyear = $dateUtils->getYearfromDate($item->trackDate);
                    $yearchecked = false;
                    $this->resetYearData($userId, $item->parentId, $item->trackDate);
				}
				// execute the query
				$query = sprintf($this->queries['addItem'],
					$userId,
					$item->parentId,
					$item->isParent,
					addslashes(trim($item->name)),
					addslashes(trim($item->description)),
					addslashes(trim($item->visibility)),
					addslashes(trim($item->category)),
		            date("Y-m-d H:i:s"),

		            $item->trackDate,
		            $item->Price,
		            $item->Volume,
		            $item->isYearHigh,
		            $item->isYearLow);

				$result = $this->db->Execute($query) or
						die ("Could not add a TrackItem.".
						$this->db->ErrorMsg () . " " . $query . '<br />');
                $query = $this->queries['lastItemInsertId'];
				$result=$this->db->Execute($query)
					or die ("addDepotDataItem: " .$this->db->ErrorMsg () . " " . $query);

			}
		}
        if (!$yearchecked)
        {
        	$this->checkYearData($userId, $item->parentId, $item->trackDate);
		}
        return $result->fields[0];
	}

	/**
	 * Modifies information for the depot data
	 *
 	 * @param integer userId the identifier for the user who modifies a e-depot account
	 * @param object item the modified e-depot information
	 */
	function modifyItem($userId, $item)
	{
        $this->resetYearData($userId, $item->parentId, $item->trackDate);
        $this->modifyItemEntry($userId, $item);
        $this->checkYearData($userId, $item->parentId, $item->trackDate);
	}

    /**
	 * Modifies information for the depot data
	 *
 	 * @param integer userId the identifier for the user who modifies a e-depot account
	 * @param object item the modified e-depot information
	 */
	function modifyItemEntry($userId, $item, $dontchangeModifyDate=NULL)
	{
		//die ("DepotService::modifyItem ".bprint_r($item));
        if (!isset($dontchangeModifyDate) || !isset ($item->when_modified))
        {
		 	$now = date ("Y-m-d H:i:s");
		 	$item->when_modified=$now;
		}

		$query = sprintf ($this->queries['modifyItem'],
			$item->when_modified,
            $item->trackDate,
            $item->Price,
            $item->Volume,
            $item->isYearHigh,
            $item->isYearLow,
			$item->itemId);

		$this->db->Execute($query)
			or die ("Error modifying item " .
	 		$this->db->ErrorMsg() . " " . $query . '<br />');
	}

	function deleteItem($userId, $itemId)
	{
		$item = $this->getItem($userId, $itemId);
		if (isset($item))
		{
			// now delete the specific item
			$query = sprintf($this->queries['deleteItem'], $itemId);

			$result = $this->db->Execute($query) or
				die("DepotServices::DeleteItem: " .
				$this->db->ErrorMsg() . " " . $query. '<br />');

            $this->CheckYearData($userId, $item->parentId, $item->trackDate);
		}
	}

	/**
	 * Delete ALL items for the specified user
	 * @param string userId the name for the user of which all
	 * 	items needs to be deleted
	 */
	function deleteAllItemsForUser($userId)
	{
		// Delete first all secrets and cancellists for the user

		// Delete the basic depot information too
		$query = sprintf($this->queries ['deleteAllForUser'], $userId);
		$this->db->Execute ($query);
	}


	function getYearItems($parentId, $date)
	{
        $dateUtils = new DateUtils();
		$query = sprintf ($this->queries['getDateRangeItems'],
			$dateUtils->getYearFromDate($date),
			$dateUtils->getYearFromDate($date),
			$parentId);

		$result = $this->db->Execute($query)
			or die ("Error search track range: " .
	 		$this->db->ErrorMsg() . " " . $query . '<br />');
        return $this->itemFactory->resultsetToItems($result);
	}

	function resetYearData($userId, $parentId, $date)
	{
	 	$items = $this->getYearItems($parentId, $date);
	 	if (NULL != $items)
	 	{
            $last = count($items)-1;
            $items[0]->isYearHigh = 0;
            $items[0]->isYearLow = 0;
            $this->modifyItemEntry($userId, $items[0], true);
            $items[$last]->isYearHigh = 0;
            $items[$last]->isYearLow = 0;
            $this->modifyItemEntry($userId, $items[$last], true);
		}
	}

	function checkYearData($userId, $parentId, $date)
	{
     	$items = $this->getYearItems($parentId, $date);
        if (NULL != $items)
        {
         	$last = count($items)-1;
            $items[0]->isYearHigh = 1;
            $this->modifyItemEntry($userId, $items[0], true);
			$items[$last]->isYearLow = 1;
            $this->modifyItemEntry($userId, $items[$last], true);
		}
	}

	function deleteChildren ($userId, $parentId)
	{
		$children = $this->getChildren ($userId, $parentId);
		for ($i=0; $i<count($children); $i++)
		{
            $query = sprintf ($this->queries['deleteItem'], $children[$i]->itemId);
			$result = $this->db->Execute($query) or
				die("DeleteItem: " .
				$this->db->ErrorMsg() . " " . $query);
		}
	}


    /**
	 * Retrieves the children of a specified item
	 *
	 * @param string userId the identifier of the user that issues the
	 * request
	 * @param integer itemId the identifier of the item for which we would
	 * like to have its children
	 * @return array all children for specified user and itemId
	 */
	function getChildren ($userId, $itemId, $limit=NULL)
	{
		if (NULL == $limit)
		{
		 	$limit = "";
		}
		else
		{
		 	$limit = ' LIMIT '.$limit;
		}
		$query = sprintf ($this->queries ['getItemChildren'], $itemId, $userId, $limit);
		$result = $this->db->Execute ($query) or die
			("Operations. GetChildren " . $this->db->ErrorMsg () .
				" Error getting children: " . $query);
		$items = $this->itemFactory->resultsetToItems($result);
		if ($items == null)
		{
			return null;
		}
		else if ($items[0]->owner == $userId)
		{
			return $items;
		}
		else
		{
			die ("Not owner?");
		}
	}
}
?>
