<?php

require_once('framework/model/ItemFactory.php');
require_once('plugins/depot/model/DepotItem.php');


/**
 * Depot Factory
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Moritz Julen - April 2006
 * @package org.brim-project.plugins.depot
 * @subpackage model
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */

class DepotFactory extends ItemFactory
{
	/**
	 * Default constructor
	 */
	function DepotFactory()
	{
		parent::ItemFactory();
	}


	/**
	 * Returns the type of this specific item
	 * @return string the type of this specific item:
	 * <code>Depot</code>
	 */
	function getType()
	{
		return "Depot";
	}


    /**
	 * Factory method. Return an HTTP request into an item by
	 * fecthing the appropriate parameters from the POST request
	 *
	 * @return object the item constructed from the POST request
	 * @uses the POST request
	 */

	function requestToItem ()
	{
		$item = new DepotItem
		(
				$this->getFromPost ('itemId', 0),
				$_SESSION['brimUsername'],
				$this->getFromPost ('parentId', 0),
				$this->getFromPost ('isParent', 0),
				$this->getFromPost ('name', null),
				$this->getFromPost ('description', null),
				$this->getFromPost ('visibility', 'private'),
				$this->getFromPost ('category', null),
				$this->getFromPost ('isDeleted', 0),
				$this->getFromPost ('when_created', null),
				$this->getFromPost ('when_modified', null),

				$this->getFromPost ('Symbol', null),
                $this->getFromPost ('Valor', null),
                $this->getFromPost ('Exchange', null),
                $this->getFromPost ('Tracking', 0),
                $this->getFromPost ('isCurrency', 0)
		);
		return $item;
	}



	function resultsetToItems ($result)
	{
        $items = array ();
		while (!$result->EOF)
		{
            $item = new DepotItem
			(
				$result->fields['item_id'],
				trim ($result->fields['owner']),
				$result->fields['parent_id'],
				(isset($result->fields['is_parent'])) ? $result->fields['is_parent'] : 0,
				trim ($result->fields['name']),
				trim ($result->fields['description']),
				trim ($result->fields['visibility']),
				(isset($result->fields['category'])) ? trim ($result->fields['category']) : '',
				(isset($result->fields['is_deleted'])) ? $result->fields['is_deleted'] : 0,
				$result->fields['when_created'],
				(isset($result->fields['when_modified'])) ? $result->fields['when_modified'] : NULL,

				(isset($result->fields['symbol'])) ? trim ($result->fields['symbol']) : '',
				(isset($result->fields['valor'])) ? trim ($result->fields['valor']) : '',
                (isset($result->fields['exchange'])) ? trim ($result->fields['exchange']) : '',
                (isset($result->fields['tracking'])) ? $result->fields['tracking'] : 0,
                (isset($result->fields['is_currency'])) ? $result->fields['is_currency'] : 0
			);
			$items [] = $item;
			$result->MoveNext();

		}

		return $items;

	}


	function requestToItemErrors ()
	{
		$errors = array ();

		if (!isset ($_POST['name']) || ($_POST['name'] == ''))
		{
			$errors [] =  "nameMissing";
		}

		return $errors;
	}
}
?>