<?php
require_once ('framework/model/Item.php');
require_once ('plugins/depot/model/TransactionItem.php');
require_once ('plugins/depot/model/DepotDataItem.php');

/**
 * A depot item
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Moritz Julen - April 2006
 * @package org.brim-project.plugins.depot
 * @subpackage model
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class DepotItem extends Item
{
    var $Symbol;
    var $Valor;
    var $Exchange;
    var $Tracking;
    var $Transaction;
    var $TransactionNumber;
    var $DepotData;
    var $isCurrency;
    var $currencyConversion;


    /**
	 * Full blown constructor with all parameters
	 */
	function DepotItem($theItemId, $theOwner, $theParentId,
		$parent, $theName, $theDescription,
		$theVisibility, $theCategory, $deleted,
        $theCreation, $theModified,

        $theSymbol, $theValor, $theExchange, $tracking, $iscurrency)

	{

		parent :: Item ($theItemId, $theOwner, $theParentId, $parent,
				$theName, $theDescription, $theVisibility,
				$theCategory, $deleted, $theCreation, $theModified);

		$this->type = "DepotItem";
        if (0 == $this->isParent)
        {
            $this->Tracking = 0;
            $this->Symbol = $theSymbol;
            $this->Valor = $theValor;
            $this->Exchange = $theExchange;
            $this->Tracking = ("true" == $tracking || 1 == $tracking);
            $this->isCurrency = $iscurrency;
        }
	}

    function addTransactions($items)
    {
        $this->Transaction = $items;
        $this->TransactionNumber = 0;
        if (NULL != $this->Transaction)
        {
	        foreach($this->Transaction as $trans)
	        {
            	if(! $trans->isDeleted)
            	{
	        		$this->TransactionNumber += $trans->purchaseNumber;
				}
			}
		}
    }

    function addLastTrack($item)
    {
     	if (is_array($item))
     	{
        	$this->DepotData = $item[0];
		}
		else
		{
            $this->DepotData = $item;
		}
    }

    function lastConversionFactor($item)
    {
        if (is_array($item))
     	{
        	$this->currencyConversion = $item[0]->Price;
		}
		else
		{
            $this->currencyConversion = $item->Price;
		}
	}

    function getPerformance()
    {
        $performance = 0;
        if (NULL != $this->Transaction && isset($this->DepotData))
        {
         	$totalamount = 0;
	        foreach($this->Transaction as $item)
	        {
                if(! $item->isDeleted)
            	{
					$totalamount += ($item->purchasePrice * $item->purchaseNumber);
				}
			}
	        if ($totalamount)
	        {
	        	$performance = round(100 / $totalamount * ($this->DepotData->Price * $this->TransactionNumber), 2);
			}
		}
        return $performance.'%';
    }


    function getAmount()
    {
        if (NULL != $this->Transaction && isset($this->DepotData))
        {
     		return round($this->DepotData->Price * $this->TransactionNumber, 2);
		}
		else
		{
		 	return 0;
		}
    }

    function getBaseCurrencyAmount()
    {
        return $this->currencyConversion * $this->getAmount();
	}

    function getNumber()
    {
     	return $this->TransactionNumber;
    }
}
?>