<?php
require_once('plugins/depot/model/DepotItem.php');
require_once('plugins/depot/model/DepotFactory.php');
require_once('framework/model/Services.php');

/**
 * Services for Depot
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Moritz Julen - April 2006
 * @package org.brim-project.plugins.depot
 * @subpackage model
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class DepotServices extends Services
{

	/**
	 * Default constructor
	 */
	function DepotServices()
	{
		parent::Services();
		$this->itemFactory = new DepotFactory();


		include ('plugins/depot/sql/depotQueries.php');
		$this->queries = $queries;
	}

	/**
	 * Adds information for an e-depot account
	 *
	 * @param integer userId the identifier for the user
	 * @param object item the e-depot information to be added
	 *
     * @return integer last know id. This is the id of the depot information
	 * that was newly inserted and for which an id has automatically
	 * been assigned.
	 */
	function addItem($userId, $item)
	{
		// execute the query
		$query = sprintf($this->queries['addItem'],
			$userId,
			$item->parentId,
			$item->isParent,
			addslashes(trim($item->name)),
			addslashes(trim($item->description)),
			addslashes(trim($item->visibility)),
			addslashes(trim($item->category)),
            date("Y-m-d H:i:s"),

            addslashes(trim($item->Symbol)),
            $item->Valor,
            addslashes(trim($item->Exchange)),
            $item->Tracking,
            $item->isCurrency
            );

		$result = $this->db->Execute($query) or
				die ("Could not add DepotItem.".
				$this->db->ErrorMsg () . " " . $query . '<br />');
        $query = $this->queries['lastItemInsertId'];
				$result=$this->db->Execute($query)
					or die ("addDepotItem: " .$this->db->ErrorMsg () . " " . $query);
        return $result->fields[0];
	}

	/**
	 * Modifies information for the e-depot account
	 *
 	 * @param integer userId the identifier for the user who modifies a e-depot account
	 * @param object item the modified e-depot information
	 */
	function modifyItem($userId, $item)
	{
		//die ("DepotService::modifyItem ".bprint_r($item));
		$query = sprintf ($this->queries['modifyItem'],
			date ("Y-m-d H:i:s"),	                                        // when_modified
			addslashes ($item->name),
			addslashes ($item->visibility),
			addslashes ($item->description),
			addslashes ($item->parentId),
			$item->isDeleted,

			addslashes($item->Symbol),
			$item->Valor,
            addslashes($item->Exchange),
			$item->Tracking,

			$item->itemId);

		$this->db->Execute($query)
			or die ("Error modifying itemx: " .
	 		$this->db->ErrorMsg() . " " . $query . '<br />');
	}

	function deleteItem($userId, $itemId)
	{
		$item = $this->getItem($userId, $itemId);

		if (isset($item))
		{
			$query = sprintf($this->queries['deleteItem'], $itemId);

			$result = $this->db->Execute($query) or
				die("DepotServices::DeleteItem: " .
				$this->db->ErrorMsg() . " " . $query. '<br />');
		}
	}

	/**
	 * Delete ALL items for the specified user
	 * @param string userId the name for the user of which all
	 * 	items needs to be deleted
	 */
	function deleteAllItemsForUser($userId)
	{
		// Delete first all secrets and cancellists for the user

		// Delete the basic depot information too
		$query = sprintf($this->queries ['deleteAllForUser'], $userId);
		$this->db->Execute ($query);
	}

    /**
	 * Gets a specific item of the base class
	 */
	function getBaseItem ($userId, $itemId)
	{
     	return parent::getItem($userId, $itemId);
	}
}
?>
