<?php
require_once('framework/ItemController.php');
require_once('plugins/depot/model/TransactionServices.php');

/**
 * The Transaction Controller
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Moritz Julen - April 2006
 * @package org.brim-project.plugins.depot
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class TransactionController extends ItemController
{
	var $depotController;

	/**
	 * Constructor.
	 * Makes sure that the appropriate operations are instantiated.
	 * @param string renderEngineName the render engine that is used
	 * (either Smarty or phpSavant)
	 */
	function TransactionController(&$depotController)
	{
		parent::ItemController();

		$this->operations = new TransactionServices();
		$this->itemFactory = new TransactionFactory();


		$this->pluginName = 'depot';
		$this->title = 'Brim - DepotTracker';
		$this->itemName = 'TransactionItem';
		$this->expandName = 'transactionExpand';

		$this->depotController = $depotController;
	}

    /**
	 * Returns the name of the item that is controller by this
	 * controller
	 *
	 * @return string the name of the item that is controlled by this
	 * controller
	 */
	function getItemName ()
	{
		return "TransactionItem";
	}

	/**
 	 * Returns the actions defined for this item only
 	 *
 	 * @return array an array of item specific actions
	 * (like search, import etc.)
 	 */
	function getActions()
	{
		$dictionary = $this->getDictionary ();
        // Actions
        $actions[0]['name']='actions';
        switch ($this->getAction())
		{
		 	case "modifyTransaction":
				$actions[0]['contents'][]=
							array('href' => 'DepotController.php?action=sell'
									.'&parentId='.$this->getParentId ()
									.'&itemId='.$this->getItemId(),
									'name' => 'sell');
		 		break;
		 	default:
				$actions[0]['contents'][]=
							array('href' => 'DepotController.php?action=buy&parentId='.$this->getParentId (),
								'name' => 'buy');
			break;
		}

		// Sort
		$actions[1]['name']='sort';
		$actions[1]['contents'][]=
					array('href'=>'DepotController.php?action=sortTransaction&order=ASC&field=purchase_date&parentId='.$this->parentId,
						'name'=> 'purchaseDate');
        $actions[1]['contents'][]=
					array('href'=>'DepotController.php?action=sortTransaction&order=ASC&field=purchase_number&parentId='.$this->parentId,
						'name'=> 'purchaseNumber');
        $actions[1]['contents'][]=
					array('href'=>'DepotController.php?action=sortTransaction&order=ASC&field=purchase_price&parentId='.$this->parentId,
						'name'=> 'purchasePrice');

		// help
		$actions[2]['name'] = 'help';
		$actions[2]['contents'][] =
				array ('href' => 'DepotController.php?action=helpTransaction&parentId='.$this->parentId,
					   'name' => 'help');

		return $actions;
	}

	/**
	 * Activate. Basically this means that the appropriate actions
	 * are executed and an optional result is returned
	 * to be processed/displayed
	 */
	function activate()
	{
		$dictionary = $this->getDictionary();
//        echo "Trasaction: ".$this->getAction()." with item: ".$this->itemId." with parent : ".$this->parentId."<br />";
		switch ($this->getAction())
		{
			case "buy":
        		$this->addAction();
                $this->renderEngine->assign ('pageTitle', $dictionary['Transaction'].': '.$dictionary['buy']);
        	    break;
            case "addTransactionPost":
                // buy it
                $this->addItemAction();
                $this->getShowItemsParameters();
                break;
            case "sell":
                $dictionary = $this->getDictionary ();
        		$this->renderer = strtolower ($this->getItemName ());
        		$this->renderEngine->assign ('viewAction', 'sell');
        		$this->renderEngine->assign ('pageTitle', $dictionary['Transaction'].': '.$dictionary['sell']);
        		$this->renderObjects =	$this->operations->
        			getItem ($this->getUserName (),	$this->itemId);
        	    break;
        	case "modifyTransaction":
        		$this->modifyAction();
        		$this->renderEngine->assign ('pageTitle', $dictionary['Transaction'].': '.$dictionary['modify']);
        		break;
            case "modifyTransactionPost":
            	$this->modifyItemAction();
				$this->getShowItemsParameters ();
                break;
            case "deleteTransactionPost":
                $this->operations->deleteItem
					($this->getUserName(), $this->itemId);
				$this->getShowItemsParameters ();
            	break;
            case "sortTransaction":
                $this->sortAllAction ($_GET['field'], $_GET['order']);
            	break;
            case "helpTransaction":
            	$this->helpAction();
            	break;
            case "showTransactions":
            default:
				$this->getShowItemsParameters();
                break;
		}
	}

	function display()
	{
        switch ($this->getAction())
		{
			default:
				$this->renderEngine->assign('depotItem',
						$this->depotController->operations->getItem($this->getUserName(),
													   				$this->parentId));
				parent::display();
		}
	}

    /**
	 * Gets the ancestors for a specific item
	 * and adds them to the controller as parameter
	 */
	function getCurrentAncestors ()
	{
		$currentDepot = $this->depotController->operations->getItem
			($this->getUserName (),$this->parentId);
		$ancestors = $this->depotController->operations->getAncestors ($currentDepot);
		$this->addParameter ("ancestors", array_reverse($ancestors));
	}

    function getDictionary()
	{
     	$dictionary = parent::getDictionary();
        $dictionary['item_quick_help'] = $dictionary['item_quick_help_transaction'];
        return $dictionary;
	}

    /**
	 * The help function is requested. Load the plugins help version
	 * in english, check for the language specific help file afterwards
	 * and load this one afterwards if it exists
	 */
	function helpAction ()
	{
		$this->renderer = 'help';
		$dictionary = $this->getDictionary();
        /*
		include ('plugins/'.$this->pluginName.'/i18n/dictionary_en.php');
		if (file_exists('plugins/'.$this->pluginName.'/i18n/dictionary_'.
			$_SESSION['brimLanguage'].'.php'))
		{
			include ('plugins/'.$this->pluginName.'/i18n/dictionary_'.
				$_SESSION['brimLanguage'].'.php');
		}
		*/
		$this->renderEngine->assign ('pluginHelp', $dictionary['item_help_transaction']);
		$this->renderEngine->assign ('helpaction', 'showTransactions');
	}
}
?>
