<?php

require_once 'framework/Installer.php';

/**
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Moritz Julen - Mai 2006
 * @package org.brim-project.plugins.depot
 * @subpackage model
 * @filesource
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class TransactionItemInstaller extends Installer
{
	function TransactionItemInstaller($engine, $db)
	{
		$this->tableName = 'brim_depot_transaction';

		parent::Installer($engine, $db);
	}

	function getMessage()
	{
     	if (!$this->findTable ($this->tableName))
		{
			return '<h2>Create table <code>' . $this->tableName . '</code></h2>
				<form method="POST"
					action="'.$_SERVER['PHP_SELF'].'">
				<input type="submit" value="Create table"
					name="create_'. $this->tableName .'" />
				</form>';
		}
		else if (!$this->isTableUpToDate())
		{
			echo ('Table not up to date');
			return '<h2>Upgrade <code>' . $this->tableName . '</code></h2>
				<p>
					Some important fields will be added to
					the table
				</p>
				<form method="POST"
						action="'.$_SERVER['PHP_SELF'].'">
					<input type="submit" value="Upgrade table"
						name="upgrade_'. $this->tableName .'" />
				</form>';
		}
	}

	function install()
	{
		if (!$this->findTable ())
		{
			$dbFile = 'plugins/depot/sql/create.';
			$dbFile .= $this->engine;
			$dbFile .= '.'.$this->tableName.'.sql';
			$this->createTable($dbFile);
			$this->createStandardIndex();
		}
		else
		{
			if (!$this->isTableUpToDate ())
			{
				die ('Table '.$this->tableName.' found but does not appear to be up-to-date and no upgrade procedure is found!');
			}
		}
	}

	function isTableUpToDate()
	{
		if (!$this->findTable ())
		{
			return false;
		}
		$columnNames =
			$this->db->MetaColumnNames($this->tableName, true);

		$this->tableUpToDate =
			(count($columnNames) == 17 &&
			$columnNames[ 0] == 'item_id' &&
			$columnNames[ 1] == 'owner' &&
			$columnNames[ 2] == 'parent_id' &&
			$columnNames[ 3] == 'is_parent' &&
			$columnNames[ 4] == 'name' &&
			$columnNames[ 5] == 'description' &&
			$columnNames[ 6] == 'visibility' &&
			$columnNames[ 7] == 'category' &&
			$columnNames[ 8] == 'is_deleted' &&
			$columnNames[ 9] == 'when_created' &&
			$columnNames[10] == 'when_modified' &&

			$columnNames[11] == 'purchase_date' &&
			$columnNames[12] == 'purchase_price' &&
			$columnNames[13] == 'purchase_currency' &&
            $columnNames[14] == 'purchase_number' &&
            $columnNames[15] == 'sold_date' &&
			$columnNames[16] == 'sold_price'
             	);

		return $this->tableUpToDate;
	}

	function upgradeTable()
	{
		// not needed for first version
	}
}
?>