<?php
require_once('plugins/depot/model/TransactionItem.php');
require_once('plugins/depot/model/TransactionFactory.php');
require_once('framework/model/Services.php');

/**
 * Services for Transaction
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Moritz Julen - April 2006
 * @package org.brim-project.plugins.depot
 * @subpackage model
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class TransactionServices extends Services
{

	/**
	 * Default constructor
	 */
	function TransactionServices()
	{
		parent::Services();
		$this->itemFactory = new TransactionFactory();


		include ('plugins/depot/sql/transactionQueries.php');
		$this->queries = $queries;
	}

	/**
	 * Adds information for an e-depot account
	 *
	 * @param integer userId the identifier for the user
	 * @param object item the e-depot information to be added
	 *
     * @return integer last know id. This is the id of the depot information
	 * that was newly inserted and for which an id has automatically
	 * been assigned.
	 */
	function addItem($userId, $item)
	{
		// execute the query
		$query = sprintf($this->queries['addItem'],
			$userId,
			$item->parentId,
			addslashes(trim($item->description)),
			addslashes(trim($item->visibility)),
			addslashes(trim($item->category)),
			date("Y-m-d H:i:s"),

			$item->purchaseDate,
			$item->purchasePrice,
			$item->purchaseCurrency,
			$item->purchaseNumber);

		$result = $this->db->Execute($query) or
				die ("Could not add DepotItem.".
				$this->db->ErrorMsg () . " " . $query . '<br />');

        return $result->fields[0];
	}

	/**
	 * Modifies information for the e-depot account
	 *
 	 * @param integer userId the identifier for the user who modifies a e-depot account
	 * @param object item the modified e-depot information
	 */
	function modifyItem($userId, $item)
	{
		//die ("DepotService::modifyItem ".bprint_r($item));
        if (isset($item->soldPrice))
        {
        	// fill in the data from the purchase
			$baseitem = $this->getItem($userId, $item->itemId);
			if (isset($baseitem))
			{
			 	$item->purchaseDate = $baseitem->purchaseDate;
			 	$item->purchasePrice = $baseitem->purchasePrice;
			 	$item->purchaseCurrency = $baseitem->purchaseCurrency;
			 	$item->purchaseNumber = $baseitem->purchaseNumber;
			 	$item->isDeleted = 1;
			}
		}
		$now = date ("Y-m-d H:i:s");

		$query = sprintf ($this->queries['modifyItem'],
			$now,	// when_modified
            $item->isDeleted,
			$item->purchaseDate,
			$item->purchasePrice,
			$item->purchaseCurrency,
			$item->purchaseNumber,
			$item->soldDate,
			$item->soldPrice,
			$item->itemId);

		$this->db->Execute($query)
			or die ("Error modifying itemtr: " .
	 		$this->db->ErrorMsg() . " " . $query . '<br />');
	}

	function deleteItem($userId, $itemId)
	{
		$item = $this->getItem($userId, $itemId);

		if (isset($item))
		{
			$query = sprintf($this->queries['deleteItem'], $itemId);

			$result = $this->db->Execute($query) or
				die("DepotServices::DeleteItem: " .
				$this->db->ErrorMsg() . " " . $query. '<br />');
		}
	}

    function deleteChildren ($userId, $parentId)
	{
		$children = $this->getChildren ($userId, $parentId);
		for ($i=0; $i<count($children); $i++)
		{
            $this->deleteItem($userId, $children[$i]->itemId);
		}
	}
}
?>
