<?php

require_once('framework/util/StringUtils.php');
require_once('framework/view/TreeDelegate.php');

/**
 * Used in combination with the Tree class
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Moritz Julen - April 2006
 * @package org.brim-project.plugins.depot
 * @subpackage view
 * @filesource
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class CurrencyLineBasedTreeDelegate extends TreeDelegate
{
	/**
	 * Have we already drawn a header?
	 */
	var $headersDrawn;

	function CurrencyLineBasedTreeDelegate ($theConfiguration)
	{
		parent::TreeDelegate ($theConfiguration);
		$this->headersDrawn = false;
	}

	/**
	 * Builds up html code to display the root of the tree
	 * @private
	 *
	 * @param object item the item that is the root of the tree
	 */
	function showRoot($item, $tree)
	{
		if (isset($item))
		{
            $resultString = '<h2>'.$item->name.'</h2>';
			$resultString .= '<a href="'.$this->configuration['callback'];
			$resultString .= '?action=showCurrencies&parentId='.$item->parentId.'">';
			$resultString .= $this->configuration['icons']['up'];
			$resultString .= '</a><br />';
		}
		else
		{
			$resultString = '';
		}
		return $resultString;
	}

	/**
	 * If the specified item is a folder, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean isExpanded whether this folder is expanded (i.e. do the
	 * children of this folder need to be displayed as well?)
	 * @param object tree the tree that uses this class as delegate
	 * @return string the string for this folder
	 */
	function drawFolder($item, $isExpanded, $tree, $indentLevel)
	{
		$resultString = '';
		if ($item->owner == $_SESSION['brimUsername'])
		{
			$resultString .= '<a href="';
			$resultString .= $this->configuration['callback'];
			$resultString .= '?action=modifyCurrency&itemId=';
			$resultString .= $item->itemId . '">';
			$resultString .= $this->configuration['icons']['folder_closed'];
			$resultString .= '</a>';
		}
		else 
		{
			$resultString .= $this->configuration['icons']['folder_closed'];
		}
		$resultString .= '<a href="';
		$resultString .= $this->configuration['callback'];
		$resultString .= '?action=showCurrency&parentId=';
		$resultString .= $item->itemId . '">';
		$resultString .= $item->name;
		$resultString .= '</a>';

		$resultString .= '<br />';
		return $resultString;
	}

	function drawLinesHeader($parentId)
	{
        $resultString = '<td colspan="3"></td></tr><tr>';
		$resultString .= '<td>&nbsp;</td>';

		$resultString .= '<td><b>'.$this->configuration['dictionary']['name'];
		$resultString .= $this->sortArrows ('name', $parentId, 'sortCurrencies');
		$resultString .= '</b></td>';

        $resultString .= '<td><b>'.$this->configuration['dictionary']['Symbol'];
		$resultString .= $this->sortArrows ('Symbol', $parentId, 'sortCurrencies');
		$resultString .= '</b></td>';

		$resultString .= '</tr><tr class="odd">';
		return $resultString;
	}


	/**
	 * If the specified item is a node, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean lastNode whether this node is the last one
	 * @return string the string for this node
	 */
	function drawNode($item, $lastNode, $tree, $indentLevel)
	{
        if ($this->headersDrawn)
		{
			$resultString = '';
		}
		else
		{
			$resultString = $this->drawLinesHeader ($item->parentId);
			$this->headersDrawn = true;
		}
		// edit icon
		$resultString .= '<td width="20" align="right">';
		if ($item->owner == $_SESSION['brimUsername'])
		{
	        $resultString .= '<a href="'.$this->configuration['callback'];
	        $resultString .= '?action=modifyCurrency';
			$resultString .= '&parentId='.$item->parentId;
			$resultString .= '&itemId='.$item->itemId.'" ';
			$resultString .= '>'.$this->configuration['icons']['edit'].'</a>';
		}
		else 
		{
			$resultString .= $this->configuration['icons']['edit'];		
		}
		$resultString .= '</td>';

		$resultString .= '<td>';
		$resultString .= '<a href="'.$this->configuration['callback'];
		$resultString .= '?action=showDepotData';
		$resultString .= '&parentId='.$item->itemId.'" ';
        // overlib popup
        if ($this->configuration['overlib'])
		{
			$popUp = $this->overlibPopup ($item);
			$resultString .= $this->overLib ($item->name, $popUp);
		}
		$resultString .= '>';
		$resultString .= '<b>' . $item->name . '</b></a>';
		$resultString .= '</td>';

        $resultString .= '<td>'.$item->Symbol.'</td>';

   		return $resultString;
	}

	function overlibPopup ($item)
	{
		if ($this->configuration['overlib'])
		{
			$popUp  = '<table cellspacing=2>';
/*
            if ($item->url != null)
			{
				$popUp .= "<tr>";
				$popUp .= "<td><b>".$this->configuration['dictionary']['url'].":</b></td>";
				$popUp .= "<td>".$item->url."</td>";
				$popUp .= "</tr>";
			}
*/
		$popUp .= "</table>";
		}
		return $popUp;
	}
}
?>