<?php

require_once('framework/util/StringUtils.php');
require_once('framework/view/TreeDelegate.php');
require_once('framework/view/globalFunctions.php');

/**
 * Used in combination with the Tree class
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Moritz Julen - April 2006
 * @package org.brim-project.plugins.depot
 * @subpackage view
 * @filesource
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class DepotDataLineBasedTreeDelegate extends TreeDelegate
{
        /**
         * Have we already drawn a header?
         */
        var $headersDrawn;

        function DepotDataLineBasedTreeDelegate ($theConfiguration)
        {
                parent::TreeDelegate ($theConfiguration);
                $this->headersDrawn = false;
        }

        /**
         * Builds up html code to display the root of the tree
         * @private
         *
         * @param object item the item that is the root of the tree
         */
        function showRoot($item, $tree)
        {
                if (isset($item))
                {
                $resultString =  '<h2><a href="'.$this->configuration['callback'];
                        $resultString .= '?action=showData&parentId='.$item->parentId.'">';
            $resultString .= $this->configuration['icons']['node'].'</a>';
                $resultString .= '&nbsp;'.$item->name.'</h2>';
            $resultString .= '<table class="transactiondepotdata">';
            $resultString .=  standardTableRowInput('Symbol',
                                                                                                        $this->configuration['dictionary'],
                                                                                                        'show',
                                                                                                        $item);
            $resultString .=  standardTableRowInput('Valor',
                                                                                                        $this->configuration['dictionary'],
                                                                                                        'show',
                                                                                                        $item);
            $resultString .=  standardTableRowInput('Exchange',
                                                                                                        $this->configuration['dictionary'],
                                                                                                        'show',
                                                                                                        $item);
                        $resultString .= '</table>';
                        $resultString .= '<br />';
                        $resultString .= '<a href="'.$this->configuration['callback'];
                        $resultString .= '?parentId='.$item->parentId;
                        if ($item->isCurrency)
                        {
                     $resultString .= '&action=showCurrencies';
                        }
                        $resultString .= '">';
                        $resultString .= $this->configuration['icons']['up'];
                        $resultString .= '</a><br />';

            // graph image
            if (isset($_SESSION['chartData']))
            {
                    $resultString .= '<img src="'.$this->configuration['callback'].'?action=drawChart" />';
                        }

                        $resultString .= '<h2>'.$this->configuration['dictionary']['TrackInformation'].'</h2>';
                }
                else
                {
                        $resultString = 'empty Item';
                }
                return $resultString;
        }

        /**
         * If the specified item is a folder, draw it
         * @private
         * @param object item the item to draw
         * @param boolean isExpanded whether this folder is expanded (i.e. do the
         * children of this folder need to be displayed as well?)
         * @param object tree the tree that uses this class as delegate
         * @return string the string for this folder
         */
        function drawFolder($item, $isExpanded, $tree, $indentLevel)
        {
                return '';
        }

        function drawLinesHeader($parentId)
        {
        $resultString = '<td colspan="4"></td></tr><tr>';

                $resultString .= '<td>&nbsp;</td>';

        $resultString .= '<td><b>'.$this->configuration['dictionary']['trackDate'];
                $resultString .= $this->sortArrows ('track_date', $parentId, 'sortDepotData');
                $resultString .= '</b></td>';

        $resultString .= '<td><b>'.$this->configuration['dictionary']['Price'];
                $resultString .= $this->sortArrows ('price', $parentId, 'sortDepotData');
                $resultString .= '</b></td>';

                $resultString .= '<td align="right"><b>'.$this->configuration['dictionary']['Volume'];
                $resultString .= $this->sortArrows ('volume', $parentId, 'sortDepotData');
                $resultString .= '</b></td>';

                $resultString .= '</tr><tr class="odd">';
                return $resultString;
        }


        /**
         * If the specified item is a node, draw it
         * @private
         * @param object item the item to draw
         * @param boolean lastNode whether this node is the last one
         * @return string the string for this node
         */
        function drawNode($item, $lastNode, $tree, $indentLevel)
        {
        if ($this->headersDrawn)
                {
                        $resultString = '';
                }
                else
                {
                        $resultString = $this->drawLinesHeader ($item->parentId);
                        $this->headersDrawn = true;
                }
                // edit icon
                $resultString .= '<td width="40" align="right">';
        if ($item->isYearHigh)
        {
                        $resultString .= $this->configuration['icons']['folder_open'].'&nbsp;';
                }
        if ($item->isYearLow)
        {
                        $resultString .= $this->configuration['icons']['folder_closed'].'&nbsp;';
		}
		if ($item->owner == $_SESSION['brimUsername'])
		{
            $resultString .= '<a href="'.$this->configuration['callback'];
        	$resultString .= '?action=modifyDepotData';
        	$resultString .= '&itemId='.$item->itemId;
        	$resultString .= '&parentId='.$item->parentId;
            $resultString .= '" >'.$this->configuration['icons']['edit'].'</a>';
		}
		else 
		{
                $resultString .= $this->configuration['icons']['edit'];
		}
                $resultString .= '</td>';

        $resultString .= '<td>'.date((isset($_SESSION['brimDateFormat'])
                           ? $_SESSION['brimDateFormat'] : 'Y-m-d') , strtotime($item->trackDate)).'</td>';

        $resultString .= '<td>'.number_format($item->Price, 2, '.', "'").'</td>';
        $resultString .= '<td align="right">'.number_format($item->Volume, 0, ".", "'").'</td>';

                return $resultString;
        }

        function overlibPopup ($item)
        {
                if ($this->configuration['overlib'])
                {
                        $popUp  = '<table cellspacing=2>';
/*
            if ($item->url != null)
                        {
                                $popUp .= "<tr>";
                                $popUp .= "<td><b>".$this->configuration['dictionary']['url'].":</b></td>";
                                $popUp .= "<td>".$item->url."</td>";
                                $popUp .= "</tr>";
                        }
*/
                $popUp .= "</table>";
                }
                return $popUp;
        }
}
?>