<?php

require_once('framework/util/StringUtils.php');
require_once('framework/view/TreeDelegate.php');

/**
 * Used in combination with the Tree class
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Moritz Julen - April 2006
 * @package org.brim-project.plugins.depot
 * @subpackage view
 * @filesource
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class DepotLineBasedTreeDelegate extends TreeDelegate
{
        /**
         * Have we already drawn a header?
         */
        var $headersDrawn;
        var $totalAmount;

        function DepotLineBasedTreeDelegate ($theConfiguration)
        {
                parent::TreeDelegate ($theConfiguration);
                $this->headersDrawn = false;

                $this->totalAmount = 0;
        }

        /**
         * Builds up html code to display the root of the tree
         * @private
         *
         * @param object item the item that is the root of the tree
         */
        function showRoot($item, $tree)
        {
                if (isset($item))
                {
            $resultString = '<h2>'.$item->name.'</h2>';
                        $resultString .= '<a href="'.$this->configuration['callback'];
                        $resultString .= '?action=show&parentId='.$item->parentId.'">';
                        $resultString .= $this->configuration['icons']['up'];
                        $resultString .= '</a><br />';
                }
                else
                {
                        $resultString = '';
                }
                return $resultString;
        }

        /**
         * If the specified item is a folder, draw it
         * @private
         * @param object item the item to draw
         * @param boolean isExpanded whether this folder is expanded (i.e. do the
         * children of this folder need to be displayed as well?)
         * @param object tree the tree that uses this class as delegate
         * @return string the string for this folder
         */
        function drawFolder($item, $isExpanded, $tree, $indentLevel)
        {
                $resultString = '';
				if ($item->owner == $_SESSION['brimUsername'])
				{
	                $resultString .= '<a href="';
	                $resultString .= $this->configuration['callback'];
	                $resultString .= '?action=modify&itemId=';
	                $resultString .= $item->itemId . '">';
	                $resultString .= $this->configuration['icons']['folder_closed'];
	                $resultString .= '</a>';
				}
				else 
				{
	                $resultString .= $this->configuration['icons']['folder_closed'];
				}
                $resultString .= '<a href="';
                $resultString .= $this->configuration['callback'];
                $resultString .= '?action=show&parentId=';
                $resultString .= $item->itemId . '">';
                $resultString .= $item->name;
                $resultString .= '</a>';

                $resultString .= '<br />';
                return $resultString;
        }

        function drawLinesHeader($parentId)
        {
        $resultString = '<td colspan="10"></td></tr><tr>';
                $resultString .= '<td>&nbsp;</td>';

        $resultString .= '<td><b>'.$this->configuration['dictionary']['purchaseNumber'];
                $resultString .= '</b></td>';

                $resultString .= '<td><b>'.$this->configuration['dictionary']['name'];
                $resultString .= $this->sortArrows ('name', $parentId);
                $resultString .= '</b></td>';

        $resultString .= '<td><b>'.$this->configuration['dictionary']['Symbol'];
                $resultString .= $this->sortArrows ('Symbol', $parentId);
                $resultString .= '</b></td>';

        $resultString .= '<td><b>'.$this->configuration['dictionary']['Valor'];
                $resultString .= $this->sortArrows ('Valor', $parentId);
                $resultString .= '</b></td>';

        $resultString .= '<td><b>'.$this->configuration['dictionary']['lastQuoationDate'];
        $resultString .= '</b></td>';

        $resultString .= '<td><b>'.$this->configuration['dictionary']['lastQuotation'];
                $resultString .= '</b></td>';

        $resultString .= '<td><b>'.$this->configuration['dictionary']['Performance'];
                $resultString .= '</b></td>';

        $resultString .= '<td align="right"><b>'.$this->configuration['dictionary']['Amount'];
                $resultString .= '</b></td>';

        $resultString .= '<td align="right"><b>'.$this->configuration['depotCurrencyName'];
                $resultString .= '</b></td>';

                $resultString .= '</tr><tr class="odd">';
                return $resultString;
        }


        /**
         * If the specified item is a node, draw it
         * @private
         * @param object item the item to draw
         * @param boolean lastNode whether this node is the last one
         * @return string the string for this node
         */
        function drawNode($item, $lastNode, $tree, $indentLevel)
        {
        if ($this->headersDrawn)
                {
                        $resultString = '';
                }
                else
                {
                        $resultString = $this->drawLinesHeader ($item->parentId);
                        $this->headersDrawn = true;
                }
                // edit icon
                $resultString .= '<td width="40" align="right">';
                $resultString .= '<a href="'.$this->configuration['callback'];
        		$resultString .= '?action=showTransactions';
                $resultString .= '&parentId='.$item->itemId.'" ';
                $resultString .= '>'.$this->configuration['icons']['transactions'].'</a>';
        		$resultString .= '&nbsp;';
        		if ($item->owner == $_SESSION['brimUsername'])
				{
	        		$resultString .= '<a href="'.$this->configuration['callback'];
	        		$resultString .= '?action=modify';
	                $resultString .= '&parentId='.$item->parentId;
	                $resultString .= '&itemId='.$item->itemId.'" ';
	                $resultString .= '>'.$this->configuration['icons']['edit'].'</a>';
				}
				else 
				{
                	$resultString .= $this->configuration['icons']['edit'];
				}
                $resultString .= '</td>';

        		$resultString .= '<td>'.$item->getNumber().'</td>';

                $resultString .= '<td>';
                $resultString .= '<a href="'.$this->configuration['callback'];
                $resultString .= '?action=showDepotData';
                $resultString .= '&parentId='.$item->itemId.'" ';
        		// overlib popup
        		if ($this->configuration['overlib'])
                {
                        $popUp = $this->overlibPopup ($item);
                        $resultString .= $this->overLib ($item->name, $popUp);
                }
                $resultString .= '>';
                $resultString .= '<b>' . $item->name . '</b></a>';
                $resultString .= '</td>';

        $resultString .= '<td>'.$item->Symbol.'</td>';
        $resultString .= '<td>'.$item->Valor.'</td>';

        if (isset($item->DepotData))
        {
                $resultString .= '<td>'.date((isset($_SESSION['brimDateFormat'])
                                   ? $_SESSION['brimDateFormat'] : 'Y-m-d') , strtotime($item->DepotData->trackDate)).'</td>';
                $resultString .= '<td>'.number_format($item->DepotData->Price, 2, '.', "'").'</td>';
                }
                else
                {
            $resultString .= '<td>&nbsp;</td>';
            $resultString .= '<td>&nbsp;</td>';
                }
        $resultString .= '<td>'.$item->getPerformance().'</td>';
        $resultString .= '<td align="right">';
        if (isset($this->configuration['depotConversionCurrencyNames']) &&
                        isset($item->Transaction[0]->purchaseCurrency) &&
                        array_key_exists($item->Transaction[0]->purchaseCurrency, $this->configuration['depotConversionCurrencyNames']) )
            {

                $resultString .= $this->configuration['depotConversionCurrencyNames'][$item->Transaction[0]->purchaseCurrency].' ';
                }
            $resultString .= number_format($item->getAmount(), 2, '.', "'").'</td>';

        $resultString .= '<td align="right">'.number_format($item->getBaseCurrencyAmount(), 2, '.', "'").'</td>';

        $this->totalAmount += $item->getBaseCurrencyAmount();

        if ($lastNode)
        {
            // draw total amount under the last row
                 $resultString .= '</tr><tr><td colspan="9">&nbsp;</td>';
                 $resultString .= '<td class="linebaseTotal" align="right">'.$this->configuration['depotCurrencyName'].' ';
                 $resultString .= number_format($this->totalAmount, 2, '.', "'").'</td>';
                }

                return $resultString;
        }

        function overlibPopup ($item)
        {
                if ($this->configuration['overlib'])
                {
                        $popUp  = '<table cellspacing=2>';
/*
            if ($item->url != null)
                        {
                                $popUp .= "<tr>";
                                $popUp .= "<td><b>".$this->configuration['dictionary']['url'].":</b></td>";
                                $popUp .= "<td>".$item->url."</td>";
                                $popUp .= "</tr>";
                        }
*/
                $popUp .= "</table>";
                }
                return $popUp;
        }
}
?>