<?php

require_once('framework/util/StringUtils.php');
require_once('framework/view/TreeDelegate.php');
require_once('framework/view/globalFunctions.php');

/**
 * Used in combination with the Tree class
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Moritz Julen - April 2006
 * @package org.brim-project.plugins.depot
 * @subpackage view
 * @filesource
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class TransactionLineBasedTreeDelegate extends TreeDelegate
{
        /**
         * Have we already drawn a header?
         */
        var $headersDrawn;
        var $totalpurchaseNumber;
        var $meanpurchasePrice;

        function TransactionLineBasedTreeDelegate ($theConfiguration)
        {
                parent::TreeDelegate ($theConfiguration);
                $this->headersDrawn = false;

                $this->totalpurchaseNumber = 0;
                $this->meanpurchasePrice = 0;
        }

        /**
         * Builds up html code to display the root of the tree
         * @private
         *
         * @param object item the item that is the root of the tree
         */
        function showRoot($item, $tree)
        {
                if (isset($item))
                {
                $resultString =  '<h2><a href="'.$this->configuration['callback'];
                        $resultString .= '?action=showData&parentId='.$item->parentId.'">';
            $resultString .= $this->configuration['icons']['node'].'</a>';
                $resultString .= '&nbsp;'.$item->name.'</h2>';
            $resultString .= '<table class="transactiondepotdata">';
            $resultString .=  standardTableRowInput('Symbol',
                                                                                                        $this->configuration['dictionary'],
                                                                                                        'show',
                                                                                                        $item);
            $resultString .=  standardTableRowInput('Valor',
                                                                                                        $this->configuration['dictionary'],
                                                                                                        'show',
                                                                                                        $item);
            $resultString .=  standardTableRowInput('Exchange',
                                                                                                        $this->configuration['dictionary'],
                                                                                                        'show',
                                                                                                        $item);
                        $resultString .= '</table>';
                        $resultString .= '<br />';
                        $resultString .= '<a href="'.$this->configuration['callback'];
                        $resultString .= '?parentId='.$item->parentId.'">';
                        $resultString .= $this->configuration['icons']['up'];
                        $resultString .= '</a><br />';

                        $resultString .= '<h2>'.$this->configuration['dictionary']['transactions'].'</h2>';
                }
                else
                {
                        $resultString = 'empty Item';
                }
                return $resultString;
        }

        /**
         * If the specified item is a folder, draw it
         * @private
         * @param object item the item to draw
         * @param boolean isExpanded whether this folder is expanded (i.e. do the
         * children of this folder need to be displayed as well?)
         * @param object tree the tree that uses this class as delegate
         * @return string the string for this folder
         */
        function drawFolder($item, $isExpanded, $tree, $indentLevel)
        {
                return '';
        }

        function drawLinesHeader($parentId)
        {
        $resultString = '<td colspan="4"></td></tr><tr>';

                $resultString .= '<td>&nbsp;</td>';

        $resultString .= '<td><b>'.$this->configuration['dictionary']['purchaseDate'];
                $resultString .= $this->sortArrows ('purchase_date', $parentId, 'sortTransaction');
                $resultString .= '</b></td>';

        $resultString .= '<td><b>'.$this->configuration['dictionary']['purchaseNumber'];
                $resultString .= $this->sortArrows ('purchase_number', $parentId, 'sortTransaction');
                $resultString .= '</b></td>';

                $resultString .= '<td align="right"><b>'.$this->configuration['dictionary']['purchasePrice'];
                $resultString .= $this->sortArrows ('purchase_price', $parentId, 'sortTransaction');
                $resultString .= '</b></td>';

                $resultString .= '</tr><tr class="odd">';
                return $resultString;
        }


        /**
         * If the specified item is a node, draw it
         * @private
         * @param object item the item to draw
         * @param boolean lastNode whether this node is the last one
         * @return string the string for this node
         */
        function drawNode($item, $lastNode, $tree, $indentLevel)
        {
        		if ($this->headersDrawn)
                {
                        $resultString = '';
                }
                else
                {
                        $resultString = $this->drawLinesHeader ($item->parentId);
                        $this->headersDrawn = true;
                }
                if(!$item->isDeleted)
                {
                // sell icon
                        $resultString .= '<td width="40">';
                if ($item->owner == $_SESSION['brimUsername'])
                {
                    $resultString .= '<a href="'.$this->configuration['callback'];
                	$resultString .= '?action=sell';
                	$resultString .= '&itemId='.$item->itemId;
                	$resultString .= '&parentId='.$item->parentId;
                    $resultString .= '" >'.$this->configuration['icons']['sell'].'</a>';
                	// edit icon
                	$resultString .= '&nbsp;<a href="'.$this->configuration['callback'];
                	$resultString .= '?action=modifyTransaction';
                	$resultString .= '&itemId='.$item->itemId;
                	$resultString .= '&parentId='.$item->parentId;
                    $resultString .= '" >'.$this->configuration['icons']['edit'].'</a>';
                }
                else 
                {
                    $resultString .= $this->configuration['icons']['sell'];
                    $resultString .= $this->configuration['icons']['edit'];
                }
                $resultString .= '</td>';

                $resultString .= '<td>'.date((isset($_SESSION['brimDateFormat'])
                           ? $_SESSION['brimDateFormat'] : 'Y-m-d') , strtotime($item->purchaseDate)).'</td>';

                $resultString .= '<td>'.$item->purchaseNumber.'</td>';
                $resultString .= '<td align="right">';
                if (isset($this->configuration['depotConversionCurrencyNames']) &&
                        array_key_exists($item->purchaseCurrency, $this->configuration['depotConversionCurrencyNames']) )
                {
                         $resultString .= $this->configuration['depotConversionCurrencyNames'][$item->purchaseCurrency].' ';
                        }
                $resultString .= number_format($item->purchasePrice, 2, '.', "'").'</td>';

                $this->totalpurchaseNumber += $item->purchaseNumber;
                $this->meanpurchasePrice += ($item->purchaseNumber * $item->purchasePrice);

                }
        if ($lastNode)
        {

                 $this->meanpurchasePrice /= $this->totalpurchaseNumber;
                 $resultString .= '</tr><tr><td>&nbsp;</td><td>&nbsp;</td>';
                 $resultString .= '<td class="linebaseTotal">'.$this->totalpurchaseNumber.'</td>';
                 $resultString .= '<td align="right" class="linebaseTotal">';
            $resultString .= $this->configuration['dictionary']['meanPrice'].' ';
                        $resultString .= number_format($this->meanpurchasePrice, 2, '.', "'").'</td>';
                }

                return $resultString;
        }

        function overlibPopup ($item)
        {
                if ($this->configuration['overlib'])
                {
                        $popUp  = '<table cellspacing=2>';
/*
            if ($item->url != null)
                        {
                                $popUp .= "<tr>";
                                $popUp .= "<td><b>".$this->configuration['dictionary']['url'].":</b></td>";
                                $popUp .= "<td>".$item->url."</td>";
                                $popUp .= "</tr>";
                        }
*/
                $popUp .= "</table>";
                }
                return $popUp;
        }
}
?>