<?php

require_once ('framework/Controller.php');
require_once ('plugins/gmail/model/GMailServices.php');
require_once ('framework/util/QuickSort.php');
require_once ('plugins/gmail/util/GMailComparator.php');

/**
 * The GMail Controller
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Barry Nauta - May 2006
 * @package org.brim-project.plugins.gmail
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class GMailController extends Controller
{
	/**
	 * Directory where attachments will be temporary uploaded
	 */
	var $uploadDir;

	/**
	 * Constructor.
	 * Makes sure that the appropriate operations are instantiated.
	 */
	function GMailController ()
	{
		parent::Controller ();
		$this->operations = new GMailServices ();

		$this->pluginName = 'gmail';
		$this->title = 'Brim - GMail';
		$this->itemName = 'GMail';

		$this->expandName = 'gmailExpand';
		if (ini_get ('upload_tmp_dir'))
		{
			$directory = ini_get ('upload_tmp_dir');
		}
		else
		{
			if (@file_exists ('/tmp') &&
				@is_writable ('/tmp') &&
				@is_readable ('/tmp'))
			{
				$directory = '/tmp';
			}
			else if (@file_exists ('c:\temp') &&
				@is_writable ('c:\temp') &&
				@is_readable ('c:\temp'))
			{
				$directory = 'c:\temp';
			}
			else
			{
				$directory = '';
			}
		}
		$_SESSION ['brimUploadDir'] = $directory;
		$this->uploadDir = $_SESSION['brimUploadDir'].'/';
	}


	/**
	 * Returns the name of the item that is controller by this
	 * controller
	 *
	 * @return string the name of the item that is controlled by
	 * this controller
	 */
	function getItemName ()
	{
		return $this->itemName;
	}

	/**
 	 * Returns the actions defined for this item only
 	 *
 	 * @return array an array of item specific actions
	 * (like search, import etc.)
 	 */
	function getActions ()
	{
		$actions=array();

		$actions[0]['name']='actions';
		//
		// Not logged in, show the login option
		//
		if (!isset ($_SESSION['gmailName']))
		{
			$actions[0]['contents'][] =
				array ('href'=>'index.php?plugin=gmail&action=loginGmail',
					'name'=>'login');
		}
		//
		// Logged in, show the invite, logout and compose option
		//
		if (isset ($_SESSION['gmailName']))
		{
			$actions[0]['contents'][] =
				array ('href'=>'index.php?plugin=gmail&action=compose',
					'name'=>'compose');
			$actions[0]['contents'][] =
				array ('href'=>'index.php?plugin=gmail&action=logoutGmail',
					'name'=>'logout');
			$actions[0]['contents'][] =
				array ('href'=>'index.php?plugin=gmail&action=invite',
					'name'=>'invite');
		}
		return $actions;
	}

	/**
	 * Activate. Basically this means that the appropriate actions
	 * are executed and an optional result is returned
	 * to be processed/displayed
	 */
	function activate ()
	{
		$this->checkLogin ();
		$theAction = $this->getAction ();
		if (!isset ($theAction))
		{
			$theAction = 'show';
		}
		$this->renderEngine->assign ('method', $theAction);
		//
		// Now examin the requested action
		//
		switch ($this->getAction ())
		{
			case "help":
				$this->helpAction ();
				break;
			case "loginGmail":
				if (isset ($_SESSION['gmailName']))
				{
					$messages = array ();
					$messages [] = 'alreadyLoggedIn';
				}
				$this->renderer = 'login';
				break;
			case "loginPost":
				$_SESSION['gmailName']=$_POST['gmailName'];
				$_SESSION['gmailPassword']=$_POST['gmailPassword'];
				$this->operations->login ($_SESSION['gmailName'],
					$_SESSION['gmailPassword'], 0);
				$this->show ();
				break;
			case "logoutGmail":
				$this->operations->disconnect ();
				$this->deleteSessionAttachments ();
				unset ($_SESSION['gmailName']);
				unset ($_SESSION['gmailPassword']);
				foreach ($_SESSION as $param=>$value)
				{
					if (stristr ($param, 'brimGmailOffset'))
					{
						unset ($_SESSION[$param]);
					}
				}
				$this->show ();
				break;
			case "showMail":
				$this->showMail ();
				break;
			case "setOffset":
				$_SESSION[$_GET['folder'].'brimGmailOffset']=$_GET['offset'];
				$offset = $_SESSION[$_GET['folder'].'brimGmailOffset'];
				// no break!
			case "showMails":
				$this->show ($_GET['folder']);
				break;
			case "showAttachement":
				$this->operations->getAttachment
					($_GET['messageId'], $_GET['attachmentId'],
						$_GET['attachmentName']);
				break;
			case "compose":
				$this->renderEngine->assign
					('info', $this->operations->getInfo ());
				$this->renderer='composeMessage';
				break;
			case "send":
				$to = $_POST['to'];
				$cc = $_POST['cc'];
				$bcc = $_POST['bcc'];
				$body = $_POST['body'];
				$subject = $_POST['subject'];
				if (isset ($_POST['deleteAttachedFiles']))
				{
					$postParams = $_POST;
					foreach ($postParams as $param=>$value)
					{
						if (strstr($param, 'delete_'))
						{
							unset ($_SESSION['attachments'][$value]);
						}
					}
					//
					// Construct a new message with all parameters
					// filled in. Note that the attachments are
					// not filled in here (null), since they are
					// temporaily placed on the session
					//
					$message = new Message (null, $to, $cc, $bcc,
						null, null, $subject, $body, null);
					$this->renderObjects = $message;
					$this->renderEngine->assign
						('info', $this->operations->getInfo ());
					$this->renderer='composeMessage';
				}
				else if (isset ($_POST['attachFile']))
				{
					//
					// We are not actually sending, but uploading
					// a file.
					//
					if (!move_uploaded_file(
						$_FILES['attachments']['tmp_name'],
						$this->uploadDir.$_FILES['attachments']['name']))
					{
						//
						// In case of an invalid upload,
						// remove the file and show a message
						//
						unset ($_FILES['attachments']);
						$this->renderEngine->assign
							('message','uploadFailure');
					}
					else
					{
						//
						// Upload succeeded, place the parameters
						// on the session
						//
						$_SESSION['attachments'][] =
							$_FILES['attachments'];
					}
					//
					// Construct a new message with all parameters
					// filled in. Note that the attachments are
					// not filled in here (null), since they are
					// temporaily placed on the session
					//
					$message = new Message (null, $to, $cc, $bcc,
						null, null, $subject, $body, null);
					$this->renderObjects = $message;
					$this->renderEngine->assign
						('info', $this->operations->getInfo ());
					$this->renderer='composeMessage';
				}
				else
				{
					//
					// Ok, actually sending the message
					//
					$attach = $_SESSION['attachments'];
					$attachments = array ();
					foreach ($attach as $att)
					{
						if (isset ($att['name']))
						{
							$attachments [] =
								$this->uploadDir.$att['name'];
						}
						else
						{
							$attachments [] =
								$this->uploadDir.$att['filename'];
						}
					}
					$result = $this->operations->send
						($to, $cc, $bcc, $body, $subject, $attachments);
					$message = $result ? 'succes' : 'failure';
					$this->renderEngine->assign ('message', $message);
					if ($result)
					{
						$this->deleteSessionAttachments ();
						$this->show ();
					}
					else
					{
						$message = new Message (null, $to, $cc, $bcc,
							null, null, $subject, $body, null);
						$this->renderObjects = $message;
						$this->renderEngine->assign
							('info', $this->operations->getInfo ());
						$this->renderer='composeMessage';
					}
				}
				break;
			case "toggleStar":
				$this->operations->toggleStar
					(array ($_GET['messageId']), $_GET['star']);
				$this->show ($_GET['folder']);
				break;
			case "star":
				unset ($_POST['action']);
				unset ($_POST['plugin']);
				$messageIds = array_keys($_POST);
				$this->operations->toggleStar ($messageIds, 0);
				$this->show ($_POST['folder']);
				break;
			case "unstar":
				unset ($_POST['action']);
				unset ($_POST['plugin']);
				$messageIds = array_keys($_POST);
				$this->operations->toggleStar ($messageIds, 1);
				$this->show ($_POST['folder']);
				break;
			case "markRead":
				unset ($_POST['action']);
				unset ($_POST['plugin']);
				$messageIds = array_keys($_POST);
				$this->operations->toggleRead ($messageIds, 0);
				$this->show ($_POST['folder']);
				break;
			case "markUnread":
				unset ($_POST['action']);
				unset ($_POST['plugin']);
				$messageIds = array_keys($_POST);
				$this->operations->toggleRead ($messageIds, 1);
				$this->show ($_POST['folder']);
				break;
			case "trash":
				$messageIds = array ();
				$messageIds [] = $_POST['messageId'];
				$this->operations->toggleDelete ($messageIds, 0);
				$this->show ($_POST['folder']);
				break;
			case "delete":
				unset ($_POST['action']);
				unset ($_POST['plugin']);
				$messageTmpIds = array_keys($_POST);
				$messageIds = array ();
				foreach ($messageTmpIds as $messageId)
				{
					// remove the plugin post parameter
					if ($messageId != 'plugin')
					{
						$messageIds [] = $messageId;
					}
				}
				$this->operations->toggleDelete ($messageIds, 0);
				$this->show ($_POST['folder']);
				break;
			case "undelete":
				unset ($_POST['action']);
				unset ($_POST['plugin']);
				$messageIds = array_keys($_POST);
				$this->operations->toggleDelete ($messageIds, 1);
				$this->show ($_POST['folder']);
				break;
			case "deleteForever":
				unset ($_POST['action']);
				unset ($_POST['plugin']);
				$messageTmpIds = array_keys($_POST);
				$messageIds = array ();
				foreach ($messageTmpIds as $messageId)
				{
					// remove the plugin post parameter
					if ($messageId != 'plugin')
					{
						$messageIds [] = $messageId;
					}
				}
				$this->operations->deleteForever ($messageIds);
				$this->show ('Trash');
				break;
			case "reply":
			case "forward":
			case "replyToAll":
				$messageIds = array ();
				$messageIds [] = $_POST['messageId'];
				$conversation =
					$this->operations->getConversationMessage
						($_GET['conversationId'], $messageIds);
				if ($this->getAction () == 'forward')
				{
					$messages = $conversation->messages;
					$attachmentsNonUploaded = array ();
					// TODO 0? Only forward attachments of the 1st msg?
					if (isset ($messages[0]->attachments))
					{
						foreach ($messages[0]->attachments as
							$attachmentNonUploaded)
						{
							$attachmentNonUploaded['name']=
								$attachmentNonUploaded['filename'];
							$attachmentsNonUploaded [] =
								$attachmentNonUploaded;
						}
						//
						// Result array will contain temporary names
						//
						$result = $this->operations->forwardAttachments
							($conversation, $this->uploadDir);
					}
					$attachments = array ();
					if (count($result) !=
						count ($attachmentsNonUploaded))
					{
						die (print_r ('Invalid attachment count'));
					}
					for ($i=0; $i<count($result);$i++)
					{
						$attachmentsNonUploaded[$i]['filename']
							= $result[$i];
					}
					$attachments=
						$attachmentsNonUploaded;
					$_SESSION['attachments'] = $attachments;
				}
				$this->renderObjects = $conversation;
				$this->renderer = 'composeMessage';
				$this->renderEngine->assign
					('info', $this->operations->getInfo ());
				break;
			case "sort":
				$order = $_GET['order'];
				$field = $_GET['field'];
				$label = $_GET['folder'];
				$mail = $this->operations->getAllMail ($label, $offset);
				$this->renderEngine->assign
					('info', $this->operations->getInfo ());
				$quickSort = new QuickSort ();
				$comparator = new GMailComparator ($field);
				$quickSort->sort ($mail, $comparator);
				if ($order == 'DESC')
				{
						$mail = array_reverse($mail);
				}
				$this->renderEngine->assign ('mail', $mail);
				$this->renderEngine->assign
					('currentFolder', $label);
				$this->renderer = 'showMails';
				break;
			case "invite":
				$this->show ();
				$this->renderer = 'invite';
				break;
			case "invitePost":
				if ($this->operations->sendInvitation
					($_POST['inviteName']))
				{
					$this->renderEngine->assign
						('message', 'invitationSent');
				}
				else
				{
					$this->renderEngine->assign
						('message', 'errorSendingInvitation');
				}
				$this->show ();
			default:
				$this->show ();
				break;
			}
	}

	/**
	 * Show a group of conversations, based on the label.
	 *
	 * @param string $label
	 */
	function show ($label='Inbox')
	{
		if ($this->operations->isConnected () ||
			isset ($_SESSION['gmailName']))
		{
			// Some necessary (stupid!) transformations are needed
			$offset = 0;
			if (isset ($_SESSION[$label.'brimGmailOffset']))
			{
				$offset = $_SESSION[$label.'brimGmailOffset'];
			}
			if ($label == 'All')
			{
				$label = $label.'&nbsp;Mail';
			}

			$this->renderEngine->assign
				('mail', $this->operations->getAllMail
					($label, $offset));
			$this->renderEngine->assign
				('info', $this->operations->getInfo ());
			$this->renderEngine->assign
				('currentFolder', $label);
			$this->renderer = 'showMails';
		}
		else
		{
			$this->renderer = 'login';
		}
	}


	function showMail ()
	{
		// not sure why this is needed each time...
		$this->checkLogin ();
		$msgIds = array_merge ($_GET['messageId'],
			explode (",",$_GET['otherMessageIds']));
		if (isset ($_GET['conversationId']))
		{
			$this->renderObjects =
				$this->operations->getConversationMessage
					($_GET['conversationId'], $msgIds);
		}
		else
		{
			$this->renderObjects =
				$this->operations->getConversation($_GET['messageId']);
		}
		$this->renderEngine->assign ('messageId', $_GET['messageId']);
		// Multiple messages (a conversation) are possible
		$this->renderer = 'messages';
	}

	/**
	 * Checks whether the current user is (still) logged in.
	 * There is a login issue with libgmailer, apparently we need to login
	 * for each request?
	 */
	function checkLogin ()
	{
		// Why is this needed each time?
		if (isset ($_SESSION['gmailName'])
			&& isset ($_SESSION['gmailPassword']))
		{
			$this->operations->login ($_SESSION['gmailName'],
				$_SESSION['gmailPassword'], 0);
		}
	}

	/**
	 * After a mail with attachements have been sent, the attachements need
	 * to be removed from the disc as well.
	 */
	function deleteSessionAttachments ()
	{
		if (isset ($_SESSION['attachments']))
		{
			$attachments = $_SESSION['attachments'];
			foreach ($attachments as $attachment)
			{
				if (isset ($attachment['name']))
				{
					unlink ($this->uploadDir.$attachment['name']);
				}
				else
				{
					unlink ($this->uploadDir.$attachment['filename']);
				}
			}
			unset ($_SESSION['attachments']);
		}
	}
}
?>