<?php
/**
 * A converstaion is a group of messages, typically a mailthread.
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Barry Nauta - May 2006
 * @package org.brim-project.plugins.gmail
 * @subpackage model
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */

class Conversation
{
	/**
	 * The title of the conversation
	 *
	 * @var string
	 */
	var $conversationTitle;

	/**
	 * The idenfitier of the conversation
	 *
	 * @var string
	 */
	var $conversationId;

	/**
	 * Is this conversation starred?
	 *
	 * @var boolean
	 */
	var $isStarred;

	/**
	 * The messages encapsulated in this conversation
	 *
	 * @var array
	 */
	var $messages;

	/**
	 * The labels for this conversation
	 *
	 * @var array
	 */
	var $labels;

	/**
	 * Default constructor with title and identifier
	 *
	 * @param string $title the title
	 * @param string $id the identifier
	 */
	function Conversation ($title, $id)
	{
		$this->conversationTitle = $title;
		$this->conversationId = $id;
		$this->messages = array ();
	}

	/**
	 * Adds a message to the conversation
	 *
	 * @param Message $message
	 */
	function addMessage ($message)
	{
		$this->messages[]=$message;
	}

	/**
	 * Returns the title of this conversation
	 *
	 * @return string title
	 */
	function getTitle ()
	{
		return $this->conversationTitle;
	}

	/**
	 * Returns the identifier of this conversation
	 *
	 * @return string identifier
	 */
	function getId ()
	{
		return $this->conversationId;
	}

	/**
	 * Returns all messages in this conversation
	 *
	 * @return array of messages
	 */
	function getMessages ()
	{
		return $this->messages;
	}

	/**
	 * Sets the new value for the starred indication
	 *
	 * @param boolean $newValue
	 */
	function setStarred ($newValue)
	{
		$this->isStarred = $newValue;
	}

	/**
	 * Returns whether this conversation is starred
	 *
	 * @return boolean
	 */
	function isStarred ()
	{
		return $this->isStarred;
	}

	/**
	 * Sets the labels for this conversation
	 *
	 * @param array $labels
	 */
	function setLabels ($labels)
	{
		$this->labels = $labels;
	}


	/**
	 * Returns the labels for this conversation
	 *
	 * @return array
	 */
	function getLabels ()
	{
		return $this->labels;
	}
}
?>