<?php

require 'framework/util/FileUtils.php';
require 'framework/util/MimeTypes.php';
require 'plugins/gmail/util/libgmailer.php';
require 'plugins/gmail/model/MailFactory.php';

/**
 * GMail operations. Wrapper around the GMAIL API
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Barry Nauta - May 2006
 * @package org.brim-project.plugins.gmail
 * @subpackage model
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class GMailServices extends Services
{
	var $factory;
	var $mailer;
	var $fileUtils;
	var $mimeTypes;
	/**
	 * An array of information about the mailbox
	 */
	var $information;


	/**
	 * Default constructor
	 */
	function GMailServices ()
	{
		parent :: Services ();
		$this->mailer = new GMailer ();
		$this->factory = new MailFactory ();
		$this->fileUtils = new FileUtils ();
		$this->mimeTypes = new MimeTypes ();
		$this->information = array ();
	}

	function setLoginInfo ($name, $password, $timeZone)
	{
		$this->mailer->setLoginInfo ($name, $password, $timeZone);
	}

	function connect ()
	{
		return $this->mailer->connect ();
	}

	function login ($name, $password, $timeZone)
	{
		if ($this->isConnected ())
		{
			return true;
		}
		$this->setLoginInfo ($name, $password, $timeZone);
		return $this->connect ();
	}

	function isConnected ()
	{
		return $this->mailer->isConnected();
	}

	function disconnect ()
	{
		return $this->mailer->disconnect();
	}

	function sendInvitation ($address)
	{
		return $this->mailer->invite ($address);
	}

	function getAllMail ($search, $offset)
	{
		if ($this->mailer->fetchBox (GM_LABEL, $search, $offset))
		{
			$snapshot = $this->mailer->getSnapShot (GM_LABEL);
			$this->information ['quotaMb'] = $snapshot->quota_mb;
			$this->information ['quotaPercentage'] = $snapshot->quota_per;
			$this->information ['folders'] = $this->mailer->getStandardBox ();
			$this->information ['foldersNew'] = $snapshot->std_box_new;
			$this->information ['labels'] = $snapshot->label_list;
			$this->information ['labelsNew'] = $snapshot->label_new;
			$this->information ['haveInvitations'] = $snapshot->have_invit;
			$this->information ['offsetMail'] = $snapshot->box_pos;
			$this->information ['totalMail'] = $snapshot->box_total;
			$this->information ['numberOfDisplayedMails'] = count ($snapshot->box);

			return $this->factory->getAllMailFromGMailSnapshot
				($this->mailer->getSnapShot (GM_LABEL));
		}
		return null;
	}


	function getFolders ()
	{
		if (!$this->isConnected ())
		{
			// ??
			//return null;
		}
		return $this->mailer->getStandardBox ();
	}

	/**
	 * Returns general information about your GMail account (like quota, labels
	 * etc)
	 *
	 * @return array general information about your gmail account
	 */
	function getInfo ()
	{
		if (count ($this->information) == 0)
		{
			$snapshot = $this->mailer->getSnapShot (GM_LABEL);
			$this->information ['quotaMb'] = $snapshot->quota_mb;
			$this->information ['quotaPercentage'] = $snapshot->quota_per;
			$this->information ['folders'] = $this->mailer->getStandardBox ();
			$this->information ['foldersNew'] = $snapshot->std_box_new;
			$this->information ['labels'] = $snapshot->label_list;
			$this->information ['labelsNew'] = $snapshot->label_new;
			$this->information ['haveInvitations'] = $snapshot->have_invit;
			$this->information ['offsetMail'] = $snapshot->box_pos;
			$this->information ['totalMail'] = $snapshot->box_total;
			$this->information ['numberOfDisplayedMails'] = count ($snapshot->box);
		}
		return $this->information;
	}

	/**
	 * Retrieves mail based on a mailId
	 *
	 * @param string $messageId the identifier of the message
	 * @return object a mail message based on the messageId,
	 * or <code>null</code> if message retrieval failed
	 */
	/*
	function getMail ($messageId)
	{
		if ($this->mailer->fetchBox (GM_CONVERSATION, $messageId, 0))
		{
			return $this->factory->getMailFromGMailSnapshot
				($this->mailer->getSnapShot (GM_CONVERSATION));
		}
		return null;
	}
	*/

	function getConversationMessage ($conversationId, $messageIds)
	{
		if ($this->mailer->fetchBox (GM_CONVERSATION, array_merge ($conversationId, $messageIds), 0))
		{
			return $this->factory->getConversationFromGMailSnapshot
				($this->mailer->getSnapShot (GM_CONVERSATION));
		}
		return null;
	}

	function getAttachment ($messageId, $attachmentId, $attachmentName)
	{
		$extension = $this->fileUtils->getExtension ($attachmentName);
		$mime = $this->mimeTypes->getMimeForExtension ($extension);
		if (isset ($mime) && $mime->getMainType () == 'image')
		{
			header("Content-Type: ".$mime->getMimeType());
		}
		else
		{
			header("Content-Type: application/octet-stream");
			header('Content-Disposition: attachment; filename="'.$attachmentName.'"');
		}
		echo $this->mailer->getAttachment ($attachmentId, $messageId, 'php://output', false);
		exit();
	}

	function getConversation ($conversationId)
	{
		if ($this->mailer->fetchBox (GM_CONVERSATION, $conversationId, 0))
		{
			//die (print_r ($this->mailer->getSnapShot (GM_CONVERSATION)));
			return $this->factory->getConversationFromGMailSnapshot
				($this->mailer->getSnapShot (GM_CONVERSATION));
		}
		return null;
	}

	function forwardAttachments ($conversation, $path)
	{
		if ($this->mailer->fetchBox
			(GM_CONVERSATION, $conversation->conversationId, 0))
		{
			$snapshot = $this->mailer->getSnapShot (GM_CONVERSATION);
			return $this->mailer->getAttachmentsOf ($snapshot->conv, $path);
		}
		return null;
	}

	function send ($to, $cc, $bcc, $body, $subject, $attachments)
	{
		return $this->mailer->send
			($to, $subject, $body, $cc, $bcc, '', '',
				$attachments, false, 0);
	}

	function toggleStar ($messageIds, $currentValue)
	{
		if ($currentValue)
		{
			$this->mailer->performAction (GM_ACT_UNSTAR, $messageIds, 0);
		}
		else
		{
			$this->mailer->performAction (GM_ACT_STAR, $messageIds, 0);
		}
	}

	function toggleRead ($messageIds, $currentValue)
	{
		if ($currentValue)
		{
			$this->mailer->performAction (GM_ACT_UNREAD, $messageIds, 0);
		}
		else
		{
			$this->mailer->performAction (GM_ACT_READ, $messageIds, 0);
		}
	}

	function toggleDelete ($messageIds, $currentValue)
	{
		if ($currentValue)
		{
			$this->mailer->performAction (GM_ACT_UNTRASH, $messageIds, 0);
		}
		else
		{
			$this->mailer->performAction (GM_ACT_TRASH, $messageIds, 0);
		}
	}

	function deleteForever ($messageIds)
	{
//die (print_r ($messageIds));
		// Doesn't work, probably due to 3rd parameter: label
		$this->mailer->performAction (GM_ACT_DELFOREVER, $messageIds, '');
	}

}
?>