<?php

require_once ('framework/model/ItemFactory.php');
require_once ('plugins/gmail/model/Message.php');
require_once ('plugins/gmail/model/Conversation.php');
require_once ('framework/util/StringUtils.php');

/**
 * MailFactory
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Barry Nauta - May 2006
 * @package org.brim-project.plugins.gmail
 * @subpackage model
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class MailFactory  extends ItemFactory
{
	var $stringUtils;
	/**
	 * Default constructor
	 */
	function MailFactory ()
	{
		parent::ItemFactory ();
		$this->stringUtils = new StringUtils ();
	}
/*
	function getMailFromGMailSnapshot ($gmailSnapshot)
	{
		$messages = array ();
		foreach ($gmailSnapshot->conv as $gmessage)
		{
			$message = $this->getEmptyMessage ();
			$message->messageId = $gmessage['id'];
			$message->sender = $this->stringUtils->utf8_to_unicode_skip_html(
				$gmessage['sender']);
			$message->from = $gmessage['sender_email'];
			$message->subject = $this->stringUtils->utf8_to_unicode_skip_html(
				$gmessage['subj']);
			$message->date = $snapshot['date'];
			if (isset ($gmessage['body']) && trim($gmessage['body'])!='')
			{
				$message->body = $this->stringUtils->
					utf8_to_unicode_skip_html ($gmessage['body']);
			}
			else
			{
				$message->body = $this->stringUtils->
					utf8_to_unicode_skip_html ($gmessage['snippet']);
			}
//			die (print_r ($gmessage));
			if (isset ($gmessage['recv_mail']))
			{
				$message->to = $gmessage['recv_mail'];
			}
			$messages [] = $message;
			// TODO More
		}
		return $messages;
	}
*/
	/**
	 * Fetches one conversation (so a messages with its potential follow-ups/
	 * replies) based on the snapshot (which is the metadata like labels/starred
	 * status etc)
	 *
	 * @param object $gmailSnapshot
	 * @return object conversation
	 */
	function getConversationFromGMailSnapshot ($gmailSnapshot)
	{
		//die (print_r ($gmailSnapshot));
		$conversation = new Conversation
			($gmailSnapshot->conv_title, $gmailSnapshot->conv_id);
		$conversation->setLabels ($gmailSnapshot->labels);
		$conversation->setStarred ($gmailSnapshot->conv_starred);

		//die (print_r ($gmailSnapshot));
		if (isset ($gmailSnapshot->conv) && is_array ($gmailSnapshot->conv))
		{
			foreach ($gmailSnapshot->conv as $gmessage)
			{
				//die (print_r ($gmessage));
				$message = $this->getEmptyMessage ();
				$message->messageId = $gmessage['id'];
				$message->sender = $this->stringUtils->utf8_to_unicode (
					$gmessage['sender']);
				$message->from = $gmessage['sender_email'];
				$message->subject = $this->stringUtils->utf8_to_unicode(
					$gmessage['subj']);
				$message->date = $snapshot['date'];
				if (isset ($gmessage['attachment']))
				{
					foreach ($gmessage['attachment'] as $attachment)
					{
						$message->attachments[]=$attachment;
					}
				}
				if (isset ($gmessage['recv_email']))
				{
					$message->to = $gmessage['recv_email'];
				}
				if (isset ($gmessage['body']) && trim($gmessage['body'])!='')
				{
					$message->body = $this->stringUtils->
						utf8_to_unicode_skip_html ($gmessage['body']);
				}
				else
				{
					$message->body = $this->stringUtils->
						utf8_to_unicode_skip_html ($gmessage['snippet']);
				}
				$conversation->addMessage ($message);
			}
		}
		return $conversation;
	}

	/**
	 * Gets all mails from a snapshot. This function is used to get the overview
	 * list of for example 25 mails.
	 *
	 * @param object $gmailSnapshot
	 * @return array of messages
	 */
	function getAllMailFromGMailSnapshot ($gmailSnapshot)
	{
		//die (print_r ($gmailSnapshot));
		$messages = array();
		$message = null;
		for ($i=0; $i<count($gmailSnapshot->box); $i++)
		{
			$snapshot = $gmailSnapshot->box[$i];
			//die (print_r ($snapshot));
			$message = $this->getEmptyMessage ();
			$message->from = $this->stringUtils->utf8_to_unicode_skip_html(
				$snapshot['sender']);
			$message->isRead = $snapshot['is_read'];
			$message->date = $snapshot['date'];
			$message->subject=$this->stringUtils->utf8_to_unicode_skip_html(
				$snapshot['subj']);
			$message->body = $this->stringUtils->utf8_to_unicode_skip_html(
				$snapshot['snippet']);
			$message->flags[] = $snapshot['flag'];
			$message->attachments = $snapshot['attachment'];
			if (isset ($snapshot['is_starred'])
				&& ($snapshot['is_starred'] == 1))
			{
				$message->flags[] = 'starred';
			}
			$message->messageId = $snapshot['msgid'];
			$messages [] = $message;
		}
		return $messages;
	}

	/**
	 * Returns the type of this specific item
	 *
	 * @return string the type of this specific
	 * item: <code>Message</code>
	 */
	function getType ()
	{
		return "Message";
	}

	/**
	 * Returns an empty message. This message is used for fetching data from
	 * other sources (like the gmailsnapshot) to populate this message
	 *
	 * @access private
	 * @return object an empty message
	 */
	function getEmptyMessage ()
	{
		return new Message (null, null,
			null, null, null, null,
			null, null, null);
	}
}
?>