<?php

require_once 'framework/util/Comparator.php';
require_once 'framework/util/StringUtils.php';

/**
 * The GMail comparator. Checks additionally for &lt;b&gt; tags
 * and removes them for sorting
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Barry Nauta - June 2006
 * @package org.brim-project.plugins.gmail
 * @subpackage util
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class GMailComparator extends Comparator
{

	/**
	 * Constructor with the name of the field which we
	 * would like to use for comparison
	 * @param string theFieldToCompare the name of the
	 * field which we would like to use for comparison
	 */
	function GMailComparator ($theFieldToCompare)
	{
		parent::Comparator ($theFieldToCompare);
	}

	/**
	 * Compare two items
	 * @param object first the first object
	 * @param object second the second object
	 * @return <0 when first < second || first != null && second == null
	 * @return 0  when first == second
	 * @return >0 when first > second || first == null && second != null
	 */
	function compare ($first, $second)
	{
		if (!isset ($first))
		{
			return 1;
		}
		if (!isset ($second))
		{
			return -1;
		}
		$fieldToCompare = $this->fieldToCompare;
		if (is_bool ($first->$fieldToCompare))
		{
			$fst = (string) $fieldToCompare;
		}
		else if (is_array ($first->$fieldToCompare))
		{
			$fst = implode(',', $first->$fieldToCompare);
		}
		else
		{
			$fst = strtolower ($first->$fieldToCompare);
		}
		if (strlen ($fst) == 0)
		{
			$fst = ' ';
		}
		else if ($this->stringUtils->startsWith ($fst, '<b>'))
		{
			$fst = substr ($fst, strlen ('<b>'));
		}
		if (is_bool ($second->$fieldToCompare))
		{
			$snd = (string) $fieldToCompare;
		}
		else if (is_array ($second->$fieldToCompare))
		{
			$snd = implode(',', $second->$fieldToCompare);
		}
		else
		{
			$snd = strtolower ($second->$fieldToCompare);
		}
		if (strlen ($snd) == 0)
		{
			$snd = ' ';
		}
		else if ($this->stringUtils->startsWith ($snd, '<b>'))
		{
			$snd = substr ($snd, strlen ('<b>'));
		}
		return substr_compare ($fst, $snd, 0);
	}
}
?>