<?php

require_once ("framework/util/StringUtils.php");
require_once ("framework/view/TreeDelegate.php");

/**
 * Used in combination with the Tree class
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Barry Nauta - May 2006
 * @package org.brim-project.plugins.gmail
 * @subpackage view
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class GMailLineBasedTreeDelegate extends TreeDelegate
{
	/**
	 * Have we already drawn a header?
	 */
	var $headersDrawn;

	function GMailLineBasedTreeDelegate ($theConfiguration)
	{
		parent::TreeDelegate ($theConfiguration);
		$this->headersDrawn = false;
	}

	/**
	 * Builds up html code to display the root of the tree
	 * @private
	 *
	 * @param object item the item that is the root of the tree
	 */
	function showRoot ($item, $tree)
	{
		$resultString = '';
		if (isset ($item) && ($item != null) && $item->itemId != 0)
		{
			$resultString .= '<h2>'.$item->name.'</h2>';
			$resultString .= '<a href="'.$this->configuration['callback'];
			$resultString .= '&action=show&parentId='.$item->parentId.'">';

			$resultString .= $this->configuration['icons']['up'];
			$resultString .= '</a><br />';
		}
		else
		{
			$resultString = '';
		}
		return $resultString;
	}

	/**
	 * If the specified item is a folder, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean isExpanded whether this folder is expanded (i.e. do the
	 * children of this folder need to be displayed as well?)
	 * @param object tree the tree that uses this class as delegate
	 * @return string the string for this folder
	 */
	function drawFolder ($item, $isExpanded, $tree, $indentLevel)
	{
		$resultString = '';

		$resultString .= '<a href="';
		$resultString .= $this->configuration['callback'];
		$resultString .= '&action=show&parentId=';
		$resultString .= $item->itemId . '">';
		$resultString .= $item->name;
		$resultString .= '</a>';

		$resultString .= '<br />';
		return $resultString;
	}

	function drawLinesHeader ($parentId)
	{
		$resultString = '<td colspan="7"></tr><tr>';
		$resultString .= '<td>&nbsp;</td>';
		$resultString .= '<td>&nbsp;</td>';

		$resultString .= '<td><b>'.$this->configuration['dictionary']['sender'];
		$resultString .= $this->sortArrows ('from', $parentId);
		$resultString .= '</b></td>';

		$resultString .= '<td><b>'.$this->configuration['dictionary']['subject'];
		$resultString .= $this->sortArrows ('subject', $parentId);
		$resultString .= '</b></td>';

		$resultString .= '<td><b>'.$this->configuration['dictionary']['body'];
		$resultString .= $this->sortArrows ('body', $parentId);
		$resultString .= '</b></td>';

		$resultString .= '<td><nobr><img src="plugins/gmail/view/pics/paperclip.gif">';
		$resultString .= $this->sortArrows ('attachments', $parentId);
		$resultString .= '</nobr></td>';

		$resultString .= '<td><b><nobr>'.$this->configuration['dictionary']['date'];
		$resultString .= $this->sortArrows ('date', $parentId);
		$resultString .= '</nobr></b></td>';

		$resultString .= '</tr><tr class="odd">';
		return $resultString;
	}

	/**
	 * If the specified item is a node, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean lastNode whether this node is the last one
	 * @return string the string for this node
	 */
	function drawNode ($item, $lastNode, $tree, $indentLevel)
	{
		/*
//		if ($item->messageId == '1098cdd987c397cf')
		if ($item->messageId == '109553f43e9a8b10')
		{
			$result = array();
//			die (print_r ($item->from));
//$num = 232;
//die (print_r ('&#'.$num.';'));
			for ($i = 0; $i < strlen( $item->from ); $i++)
			{
    			$thisValue = ord( $item->from[ $i ] );
				$result []= $thisValue;
			}
			die (print_r ($result));
			die (print_r ($item));
		}
*/
		if ($this->headersDrawn)
		{
			$resultString = '';
		}
		else
		{
			$resultString = $this->drawLinesHeader ($item->parentId);
			$this->headersDrawn = true;
		}
		// header with two icons and overlib popup
		$resultString .= '<td width="20" align="right">';
		$resultString .= '<input type="checkbox" name="';
		$resultString .= $item->messageId;
		$resultString .= '" />';
		$resultString .= '</td>';

		$resultString .= '<td width="20" align="right">';
		$theFlags = array_flip ($item->flags);

		$resultString .= '<a href="'.$this->configuration['callback'];
		$resultString .= '&action=toggleStar';
		$resultString .= '&folder='.$this->configuration['currentFolder'];
		$resultString .= '&messageId='.$item->messageId;
		if (isset ($theFlags['starred']))
		{
			$resultString .= '&star=1';
			$resultString .= '"><img border="0" src="';
			$resultString .= 'plugins/gmail/view/pics/star_on.gif';
			$resultString .= '"/>';
		}
		else
		{
			$resultString .= '&star=0';
			$resultString .= '"><img border="0" src="';
			$resultString .= 'plugins/gmail/view/pics/star_off.gif';
			$resultString .= '" />';
		}
		$resultString .= '</a>';
		$resultString .= '&nbsp;';
		$resultString .= '</td>';

		$resultString .= '
		<td>';
		$resultString .= '<a href="'.$this->configuration['callback'];
		$resultString .= '&action=showMail&messageId='.$item->messageId;
		$resultString .= '">';
		//$resultString .= $this->stringUtils->utf8_to_unicode_skip_html ($this->stringUtils->truncate ($item->from, 50));
		$resultString .= $this->stringUtils->utf8_to_unicode_skip_html ($item->from);
		$resultString .= '</td>';

		$resultString .= '<td>';
		$resultString .= $this->stringUtils->utf8_to_unicode_skip_html ($this->stringUtils->truncate ($item->subject, 50));
		$resultString .= '</td>';

		$resultString .= '<td>';
		$resultString .= $item->body;
		$resultString .= '</td>';

		$resultString .= '<td>';
		if (isset ($item->attachments) && count ($item->attachments) > 0)
		{
			$resultString .= '<img src="plugins/gmail/view/pics/paperclip.gif">';
		}
		else
		{
			$resultString .= '&nbsp;';
		}
		$resultString .= '</td>';

		$resultString .= '<td>';
		$resultString .= $item->date;
		$resultString .= '</td>';

		return $resultString;
	}


	/**
	 * Renders the sort arrows
	 *
	 * @param string sortField the field on which we would like
	 * to sort
	 * @param integer parentId the current parentId
	 */
	function sortArrows ($sortField, $parentId, $action='sort')
	{
		$resultString = '<nobr>';
		$resultString .= '&nbsp;';
		$resultString .= '<a href="'.$this->configuration['callback'];
		$resultString .= '&action='.$action;
		$resultString .= '&folder='.$this->configuration['currentFolder'];
		$resultString .= '&order=ASC&field='.$sortField.'&parentId='.$parentId;
		$resultString .= '">';
		if (isset ($_GET['order']) && $_GET['order'] == 'ASC'
			&& $_GET['field'] == $sortField)
		{
			$resultString .= $this->configuration['icons']['up_arrow_shaded'];
		}
		else
		{
			$resultString .= $this->configuration['icons']['up_arrow'];
		}
		$resultString .= '</a>';
		$resultString .= '<a href="'.$this->configuration['callback'];
		$resultString .= '&action='.$action;
		$resultString .= '&order=DESC';
		$resultString .= '&field='.$sortField;
		$resultString .= '&parentId='.$parentId;
		$resultString .= '&folder='.$this->configuration['currentFolder'];
		$resultString .= '">';
		if (isset ($_GET['order']) && $_GET['order'] == 'DESC'
			&& $_GET['field'] == $sortField)
		{
			$resultString .= $this->configuration['icons']['down_arrow_shaded'];
		}
		else
		{
			$resultString .= $this->configuration['icons']['down_arrow'];
		}
		$resultString .= '</a>';
		$resultString .= '</nobr>';
		return $resultString;
	}
}
?>