<?php

require_once ('framework/ItemController.php');
require_once ('plugins/news/util/NewsUtils.php');
require_once ('plugins/news/model/NewsServices.php');
require_once ('plugins/news/model/NewsFactory.php');
require_once ('plugins/news/model/NewsPreferences.php');

/**
 * The News Controller
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Barry Nauta
 * @package org.brim-project.plugins.news
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class NewsController extends ItemController
{
	/**
	 * Constructor.
	 * Makes sure that the appropriate operations are instantiated.
	 */
	function NewsController ()
	{
		parent::ItemController ();
		$this->operations = new NewsServices ();
		$this->preferences = new NewsPreferences ();
		$this->itemFactory = new NewsFactory ();

		$this->pluginName = 'news';
		$this->title = 'Brim - News';
		$this->itemName = 'RSS';

		$this->expandName = 'newsExpand';
	}

	/**
 	 * Returns the actions defined for this item only
 	 * Modified by Michael : added navigationMode and rightsmanagement
 	 *
 	 * @return array an array of item specific actions (like search,
	 * import etc.)
 	 */
	function getActions ()
	{
		//
	 	// Actions
		//
		$actions[0]['name'] = 'actions';

			$actions[0]['contents'][] = array(
				'href' => 'index.php?plugin=news&action=add&parentId='.
					$this->getParentId (),
				'name' => 'add'
				);
			$actions[0]['contents'][] = array(
				'href' => 'index.php?plugin=news&action=multipleSelectPre&parentId='.$this->getParentId(),
				'name' => 'multipleSelect'
				);

			$actions[0]['contents'][] = array(
				'href' => 'index.php?plugin=news&action=import',
				'name' => 'import'
				);

			$actions[0]['contents'][] = array(
				'href' => 'index.php?plugin=news&action=export',
				'name' => 'export'
				);

			$actions[0]['contents'][] = array(
				'href' => 'index.php?plugin=news&action=search',
				'name' => 'search'
				);
		//
		// If we are simply 'viewing' an item, add 'modify' as action
		// to the action list
		//
		if ($this->renderEngine->getTokens ('viewAction') == 'show')
		{
			$actions[0]['contents'][]= array (
				'href'=>'index.php?plugin=news&action=modify&itemId='.$this->itemId,
				'name'=>'modify');
		}

		/*
		 * Views
		 */
		$actions[1]['name'] = 'view';
			$actions[1]['contents'][] = array('href' => 'index.php?plugin=news&expand=*',
			'name' => 'expand');
			$actions[1]['contents'][] = array('href' => 'index.php?plugin=news&expand=0',
			'name' => 'collapse');
			$actions[1]['contents'][] = array('href' => 'index.php?plugin=news&action=setYahooTree&parentId='.$this->getParentId (),
			'name' => 'yahooTree');
			$actions[1]['contents'][] = array('href' => 'index.php?plugin=news&action=setExplorerTree&parentId='.$this->getParentId (),
			'name' => 'explorerTree');
			$actions[1]['contents'][] = array('href' => 'index.php?plugin=news&action=setModePublic&parentId='.$this->getParentId (),
			'name' => 'setModePublic');
			$actions[1]['contents'][] = array('href' => 'index.php?plugin=news&action=setModePrivate&parentId='.$this->getParentId (),
			'name' => 'setModePrivate');


		/*
		 * Sort
		 */
		$actions[2]['name'] = 'sort';
			$actions[2]['contents'][] = array('href'=> 'index.php?plugin=news&action=sort&order=DESC&field=when_visited',
			'name' => 'last_visited');
			$actions[2]['contents'][] = array('href'=> 'index.php?plugin=news&action=sort&order=DESC&field=visitCount',
			'name' => 'most_visited');
			$actions[2]['contents'][] = array('href'=> 'index.php?plugin=news&action=sort&order=DESC&field=when_created',
			'name' => 'last_created');
			$actions[2]['contents'][] = array('href'=> 'index.php?plugin=news&action=sort&order=DESC&field=when_modified',
			'name' => 'last_modified');


		/*
		 * Preferences
		 */
			$actions[3]['name'] = 'preferences';
			$actions[3]['contents'][] = array('href'=> 'index.php?plugin=news&action=modifyPreferencesPre',
			'name' => 'modify');

		$actions[4]['name']='help';
			$actions[4]['contents'][]=
				array ('href'=>'index.php?plugin=news&action=help',
					'name'=>'help'
			);
		return $actions;
	}

	/**
	 * Activate. Basically this means that the appropriate actions are executed and an optional result is returned
	 * to be processed/displayed
	 */
	function activate ()
	{
		$dictionary = $this->getDictionary ();
		switch ($this->getAction ())
		{
			case "help":
				$this->helpAction ();
				break;
			case "add":
				$this->addAction ();
				break;
			// this is to show an Item in a special showItem Page
			case "showItem":
				//$this->directAction ($this->getAction (), true);
				//$this->renderEngine->assign ('renderer', 'news');
				$this->showAction ();
				break;
                        case "addAndAddAnother":
                                $this->addItemAction ();
                                unset ($this->renderObjects);
                                $this->addAction ();
                                break;
			case "addItemPost":
				$this->addItemAction ();
				break;
			case "modify":
				$this->modifyAction ();
				 $this->renderEngine->assign ('pageTitle',
				 	$dictionary['modify']);
				break;
			case "modifyItemPost":
				$this->modifyItemAction ();
				$this->getShowItemsParameters ();
				break;
			case "move":
				$this->moveAction ();
				break;
			case "moveItem":
				$this->moveItemAction ();
				$this->getShowItemsParameters ();
				break;
			// Added by Michael. Default navigation mode. If used, change in other plugins.
			case "setModePublic":
				$_SESSION['navigationMode']='public';
				$this->navigationMode ='public';
				$this->getShowItemsParameters ();
				break;
			case "setModePrivate":
				$_SESSION['navigationMode']='private';
				$this->navigationMode ='private';
				$this->getShowItemsParameters ();
				break;
			case "import":
			case "export":
			case "search":
				$this->renderer = $this->getAction ().'News';
				break;
			case "searchItems":
				$this->searchItemAction ();
				break;
			case "multipleSelectPre":
				$_SESSION['newsExpand']= '*';
				$this->multipleSelectAction ();
				break;
			case "multipleSelectPost":
				$itemIds = array_keys ($_POST, "itemId");
				if (isset ($_POST['move']))
				{
					$this->moveMultipleAction ($itemIds);
				}
				else if (isset ($_POST['delete']))
				{
					foreach ($itemIds as $itemId)
					{
						$this->operations->deleteItem ($this->getUserName (), $itemId);
					}
					$this->getShowItemsParameters ();
				}
				break;
                        case "moveMultipleItemsPost":
				$itemIds = explode (",", $_GET['itemIds']);
				$parentId = $_GET['parentId'];
				foreach ($itemIds as $itemId)
				{
					$this->operations->moveItem ($this->getUserName (), $itemId, $parentId);
				}
				$this->getShowItemsParameters ();
				break;
			case "deleteItemPost":
				$this->deleteItemAction ();
				$this->getShowItemsParameters ();
				break;
			case "showItem":
				$this->operations->updateVisiteCount ($this->getUserName(), $this->itemId);
				$bookmark = $this->operations->getItem
					($this->getUserName(), $this->itemId);
				header ("Location: " . $bookmark->locator);
   				exit;
				break;
			case "importNews":
				$newsUtils = new NewsUtils ();
				// first set the execution time to zero: unlimited.
				// Not that this has no effect if safe_mode is on
				set_time_limit (0);

		        $importType=$_POST['importType'];
		        $parentId = $_POST['parentId'];
		   		$importFile = $_FILES['importFile'];
		   		if ($importType == 'Opera')
		        {
		                $newsUtils->importOperaBookmarks
		                	($this->getUserName (), $importFile['tmp_name'], $this, $parentId);
		        }
				else if ($importType == 'Netscape')
				{
		                $newsUtils->importNetscapeBookmarks
		                	($this->getUserName (), $importFile['tmp_name'], $this, $parentId);
				}
		        else
		        {
		                die ($importType . " is not yet supported for importing bookmarks");
		        }
		        $this->getShowItemsParameters ();
				//
		        // We need to force a redirection to this page,
				// otherwise a reload means
		        // resending the POST data and your items will be
				// imported twice
				//
		        header ("Location: NewsController.php");
		        exit ();
				break;
			case "exportBookmarks":
				$newsUtils = new NewsUtils ();
			    $exportType=$_POST['exportType'];
			    $parentId = $_POST['parentId'];
			    if ($exportType == 'Opera')
				{
					Header ("Content-type: text/plain");
					header('Content-Disposition: attachment; filename="brim-opera-news.adr"');
					echo ("Opera Hotlist version 2.0\n\n");

					$newsUtils->exportOperaBookmarks
						($this->getUserName (), $parentId, $this);
					exit ();
				}
				else if ($exportType == 'Netscape')
				{
					Header ("Content-type: text/plain");
					header('Content-Disposition: attachment; filename="brim-mozilla-news.html"');
					$newsUtils->exportNetscapeBookmarks
						($this->getUserName (), $parentId, $this);
					exit ();
				}
				break;
			case "setYahooTree":
				$_SESSION['newsTree']='Yahoo';
				$this->getShowItemsParameters ();
				break;
			case "setExplorerTree":
				$_SESSION['newsTree']='Explorer';
				$this->getShowItemsParameters ();
				break;
			case "modifyPreferencesPre":
				$this->renderObjects =
					$this->preferences->getAllPreferences ($this->getUserName ());
				$this->renderer = 'modifyPreferences';
				break;
			case "modifyPreferencesPost":
				$this->preferences->setPreference ($this->getUserName (), $_POST['name'], $_POST['value']);
				$_SESSION['newsTree']=
					$this->preferences->getPreferenceValue ($this->getUserName (), 'newsTree');
				$_SESSION['newsOverlib']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'newsOverlib');
				$_SESSION['newsYahooTreeColumnCount']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'newsYahooTreeColumnCount');
					$_SESSION['newsNewWindowTarget']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'newsNewWindowTarget');
				//$this->getShowItemsParameters ();
				$this->renderer = 'modifyPreferences';
				$this->renderObjects=$_SESSION;
				break;
			default:
				if (!isset ($_SESSION['newsTree']))
				{
					$_SESSION['newsTree']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'newsTree');
				}
				if (!isset ($_SESSION['newsOverlib']))
				{
					$_SESSION['newsOverlib']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'newsOverlib');
				}
				if (!isset ($_SESSION['newsYahooTreeColumnCount']))
				{
					$_SESSION['newsYahooTreeColumnCount']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'newsYahooTreeColumnCount');
				}
				if (!isset ($_SESSION['newsNewWindowTarget']))
				{
					$_SESSION['newsNewWindowTarget']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'newsNewWindowTarget');
				}
				$this->getShowItemsParameters ();
				break;
		}
	}

}
?>
