<?php

require_once ('framework/model/Item.php');

/**
 * The News item.
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Barry Nauta - March 2003
 * @package org.brim-project.plugins.news
 * @subpackage model
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class News extends Item
{
	/**
	 * When this news item was last visited
	 * @access private
	 * @var string
	 */
	var $when_visited;

	/**
	 * The locator (URI) of this news item
	 * @access private
	 * @var string
	 */
	var $locator;

	/**
	 * The number of times this news item has been visited
	 * @access private
	 * @var int
	 */
	var $visitCount;

	/**
	 * Full-blown Constructor.
	 *
	 * @param integer theItemId the id of the item
	 * @param string theOwner who owns this item?
	 * @param integer theParentId what is the id of the parent of this item?
	 * @param boolean parent is this a parent (true) or child (false)
	 * @param string theName the name of this item
	 * @param string theDescription the description of this item
	 * @param string theVisibility the visibility (private or public)
	 * @param string theCategory what is the category of this item?
	 * @param boolean deleted is this item deleted?
	 * @param string created When was this item created?
	 * @param string modified When was this item modified?
	 * @param string visited When was this item last visited?
  	 * @param string theLocator what is the locator (URL)?
	 * @param integer theVisitCount how many times has this item been vsisted?
	 */
	function News (
		$theItemId, $theOwner, $theParentId, $parent, $theName,
		$theDescription, $theVisibility, $theCategory, $deleted,
		$created, $modified, $visited,
		$theLocator, $theVisitCount)
	{
		parent :: Item ($theItemId, $theOwner, $theParentId, $parent,
				$theName, $theDescription, $theVisibility,
				$theCategory, $deleted, $created, $modified);

		$this->type = "News";
		$this->when_visited = $visited;
		$this->locator = $theLocator;
		$this->visitCount = $theVisitCount;
	}

	/**
	 * Checks whether the constructed item is a valid item (has all the
	 * required fields)
	 *
	 * @return boolean true if the item is valid, false otherwise
	 */
	function isValid ()
	{
		if (!$this->isParent ())
		{
			return parent::isValid () && isset ($this->locator);
		}
		return parent::isValid ();
	}
}
?>