<?php
require_once ("framework/util/StringUtils.php");
require_once ('framework/view/TreeDelegate.php');
require_once ("ext/magpierss/rss_fetch.inc");
require_once ("ext/magpierss/rss_parse.inc");

/**
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Barry Nauta
 * @package org.brim-project.plugins.news
 * @subpackage view
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class NewsExplorerTreeDelegate extends TreeDelegate
{
	/**
	 * Default constructor
	 */
	function NewsExplorerTreeDelegate ($theConfiguration)
	{
		parent::TreeDelegate ($theConfiguration);
	}

	/**
	 * Builds up html code to display the root of the tree
	 * @private
	 *
	 * @param object item the item that is the root of the tree
	 */
	function showRoot ($item, $tree)
	{
		if (isset($item) && $item->itemId != 0)
		{
			$resultString = '<h2>'.$item->name.'</h2>';
			$resultString .= '<a href="'.$this->configuration['callback'];
			$resultString .= '&action=show&parentId='.$item->parentId.'">';
			$resultString .= $this->configuration['icons']['up'];
			$resultString .= '</a>';
		}
		else
        {
			$resultString = $this->configuration['icons']['root'];
		}
		return $resultString;
	}

	/**
	 * If the specified item is a folder, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean isExpanded whether this folder is expanded (i.e. do the
	 * children of this folder need to be displayed as well?)
	 * @param object tree the tree that uses this class as delegate
	 * @return string the string for this folder
	 */
	function drawFolder ($item, $isExpanded, $tree, $indentLevel)
	{
		$resultString = '
								<tr><td>';

		for ($i=0; $i<$indentLevel; $i++)
		{
			$resultString .= $this->configuration['icons']['bar'];
		}

		if ($isExpanded)
		{
			$res = $tree->createExpandedListWithout ($item->itemId);
			$resultString .= '<a href="';
			$resultString .= $this->configuration['callback'];
			$resultString .= '&expand=' . implode (',', $res);
            if (isset($tree->root))
            {
				$resultString .= '&parentId='.$tree->root->itemId;
			}
			$resultString .= '">';
			$resultString .= $this->configuration['icons']['minus'];
			$resultString.= '</a>';

            if ($item->owner == $_SESSION['brimUsername'])
            {
				$resultString.= '<a href="';
				$resultString .= $this->configuration['callback'];
				$resultString .= '&action=modify&itemId='.$item->itemId;
	            if (isset($tree->root))
	            {
					$resultString .= '&parentId='.$tree->root->itemId;
				}
				$resultString .= '">';
				$resultString .= $this->configuration['icons']['folder_open'];
				$resultString .= '</a>';
            }
            else 
            {
				$resultString .= $this->configuration['icons']['folder_open'];        	
            }
		}
		else
		{
			// ???
			$linkExpand = "";
			// ???
			if (!$tree->isExpanded ($item->itemId) && isset ($tree->expanded))
			{
				$linkExpand .= implode(",", $tree->expanded).",".$item->itemId;
			}
			else
			{
				$linkExpand = $item->itemId;
			}
			$resultString .= '<a href="';
			$resultString .= $this->configuration['callback'];
			$resultString .= '&expand=' . $linkExpand;
            if (isset($tree->root))
            {
				$resultString .= '&parentId='.$tree->root->itemId;
			}
			$resultString .= '">';
			$resultString .= $this->configuration['icons'] ['plus'];
			$resultString .= '</a>';
            if ($item->owner == $_SESSION['brimUsername'])
            {
				$resultString .= '<a href="';
				$resultString .= $this->configuration['callback'];
	            $resultString .= '&action=modify&itemId='.$item->itemId;
	            if (isset($tree->root))
	            {
					$resultString .= '&parentId='.$tree->root->itemId;
				}
				$resultString .= '">';
				$resultString .= $this->configuration['icons'] ['folder_closed'];
				$resultString .= '</a>';
            }
            else 
            {
				$resultString .= $this->configuration['icons'] ['folder_closed'];
            }
		}
		$resultString .= '<a href="';
		$resultString .= $this->configuration['callback'];
		$resultString .= '&action=show&parentId=';
		$resultString .= $item->itemId . '">';
		$resultString .= $item->name;
		$resultString .= '</a>';

		$resultString .= '</td></tr>';
		return $resultString;
	}


	/**
	 * If the specified item is a node, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean lastNode whether this node is the last one
	 * @return string the string for this node
	 */
	function drawNode ($item, $lastNode, $tree, $indentLevel)
	{
		$resultString = '
								<tr><td>';
		for ($i=0; $i<$indentLevel; $i++)
		{
			$resultString .= $this->configuration['icons']['bar'];
		}
		if ($lastNode)
		{
			$resultString .= $this->configuration['icons']['corner'];
		}
		else
		{
			$resultString .= $this->configuration['icons']['tee'];
		}
        if ($item->owner == $_SESSION['brimUsername'])
        {
			$resultString .= '<a href="';
			$resultString .= $this->configuration['callback'];
	        $resultString .= '&action=modify&itemId='.$item->itemId;
	        if (isset($tree->root))
	        {
				$resultString .= '&parentId='.$tree->root->itemId;
			}
			$resultString .= '">';
			$resultString .= $this->configuration['icons']['node'];
			$resultString .= '</a>';
        }
        else 
        {
			$resultString .= $this->configuration['icons']['node'];    	
        }
		// testing purposes. Developing on a local machine might imply that
		// you are being blocked by a proxy. Magpie does not provide
		// proxy things, so you can test by loading a file that is something
		// in the form of either file:///c:/temp/myfile.xml or
		// file:///home/barrel/tmp/myfile.xml
		//
		// Local file MUST start with 'file:///'
		if ($this->stringUtils->startsWith ($item->locator, "file:///"))
		{
			$filename = substr($item->locator, strlen("file:///"), strlen ($item->locator));
			$fh = fopen($filename, 'r');
    		$rss_string = fread($fh, filesize($filename) );
    		fclose($fh);
    		$rss = new MagpieRSS ($rss_string);
		}
		else
		{
			$rss = fetch_rss ($item->locator);
		}
		if ($rss)
		{
			$rssFeed  = '<table>';

			// Only show the image if an image URL is provided
			if (isset ($rss->image['url']))
			{
				$rssFeed .= '<tr><td bgcolor=#ffffff>';
				$rssFeed .= '<img src='.$rss->image['url'].' border=0>';
				$rssFeed .= '</td></tr>';
			}

			$rssFeed .= '<tr><td>';
			foreach ($rss->items as $rssitem)
			{
				$rssFeed .= '<table>';
				$rssFeed .= '<tr><td><b>';
				$rssFeed .= $this->stringUtils->urlEncodeQuotes ($rssitem['title']);
				$rssFeed .= '</b></td></tr>';
				$rssFeed .= '<tr><td>';
				if (isset ($rssitem['description']))
				{
					$rssFeed .= $rssitem['description'];
				}
				else
				{
					$rssFeed .= '&nbsp;';
				}
				$rssFeed .= '</td></tr>';
				$rssFeed .= '</table>';

			}
			$rssFeed .= '</td></tr>';
			$rssFeed .= '</table>';

			if (isset ($rss->channel['link']))
			{
				$resultString .= "<a href='".$rss->channel['link']."' ";
				if ($this->configuration['overlib'])
				{
					$resultString .= $this->overLib ($item->name, $item->description);
				}
				if (isset ($this->configuration['newsNewWindowTarget']) &&
					($this->configuration['newsNewWindowTarget'] == '_blank')
				)
				{
					$resultString .= ' target="'.$this->configuration['newsNewWindowTarget'].'" ';
				}

				$resultString .= 'alt="'. $item->name;
				$resultString .= '" >'.$item->name.'</a>';
			}
			else
			{
				$resultString .= $item->name;
			}
		}
		else
		{

			$resultString .= "<b>Error: </b>Could not parse ".$item->name;
		}
		// open in new window option
		/*
		$resultString .= '<a href="';
		$resultString .= $this->configuration['callback'];
		$resultString .= '?action=showItem&itemId=';
		$resultString .= $item->itemId . '">';
		$resultString .= $this->configuration['icons']['open_new_window'] . '</a>';
		*/

		$resultString .= '</td></tr>';
		return $resultString;
	}
}
?>