<?php

require_once ("framework/util/StringUtils.php");
require_once ('framework/view/TreeDelegate.php');
require_once ("ext/magpierss/rss_fetch.inc");
require_once ("ext/magpierss/rss_parse.inc");

/**
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Barry Nauta
 * @package org.brim-project.plugins.news
 * @subpackage view
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class NewsYahooTreeDelegate extends TreeDelegate
{
	/**
	 * Default constructor
	 * @param array theIcons the icons used for display
	 * @param string theCallbackURL
	 */
	function NewsYahooTreeDelegate ($theConfiguration)
	{
		parent::TreeDelegate ($theConfiguration);
	}

	/**
	 * Builds up html code to display the root of the tree
	 * @private
	 *
	 * @param object item the item that is the root of the tree
	 */
	function showRoot ($item, $tree)
	{
		$resultString ='';
		if (isset($item) && $item->itemId != 0)
		{
			$resultString .= '<h2>'.$item->name.'</h2>';
			$resultString .= '<a href="'.$this->configuration['callback'];
			$resultString .= '&action=show&parentId='.$item->parentId.'">';
			$resultString .= $this->configuration['icons']['up'];
			$resultString .= '</a><br />';
		}
		return $resultString;
	}

	/**
	 * If the specified item is a folder, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean isExpanded whether this folder is expanded
	 * (i.e. do the children of this folder need to be displayed as
	 * (well?)
	 * @param object tree the tree that uses this class as delegate
	 * @return string the string for this folder
	 */
	function drawFolder ($item, $isExpanded, $tree, $indentLevel)
	{
		$resultString = '';
	
        if ($item->owner == $_SESSION['brimUsername'])
        {
			$resultString .= '<a href="';
			$resultString .= $this->configuration['callback'];
	        $resultString .= '&action=modify&itemId='.$item->itemId;
	        $resultString .= '&parentId='.$item->parentId. '">';
			$resultString .= $this->configuration['icons'] ['folder_closed'];
			$resultString .= '</a>';
        }
        else 
        {
			$resultString .= $this->configuration['icons'] ['folder_closed'];
        }
		$resultString .= '<a href="';
		$resultString .= $this->configuration['callback'];
		$resultString .= '&action=show&parentId=';
		$resultString .= $item->itemId . '">';
		$resultString .= $item->name;
		$resultString .= '</a>';
		$resultString .= '<br />';
		return $resultString;
	}


	/**
	 * If the specified item is a node, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean lastNode whether this node is the last one
	 * @return string the string for this node
	 */
	function drawNode ($item, $lastNode, $tree, $indentLevel)
	{
		// testing purposes. Developing on a local machine might imply that
		// you are being blocked by a proxy. Magpie does not provide
		// proxy things, so you can test by loading a file that is something
		// in the form of either file:///c:/temp/myfile.xml or
		// file:///home/barrel/tmp/myfile.xml
		//
		// Local file MUST start with 'file:///'
		if ($this->stringUtils->startsWith ($item->locator, "file:///"))
		{
			$filename = substr($item->locator, strlen("file:///"), strlen ($item->locator));
			$fh = fopen($filename, 'r');
    		$rss_string = fread($fh, filesize($filename) );
    		fclose($fh);
    		$rss = new MagpieRSS ($rss_string);
		}
		else
		{
			$rss = fetch_rss ($item->locator);
//die (print_r ($rss));
		}
		if ($rss)
		{
			$resultString = '<table border="0" width="300">';

			// one row with name and icon to modify
			$resultString .= '<tr valign="top">';
			$resultString .= '<td><b>';
        	if ($item->owner == $_SESSION['brimUsername'])
        	{
				$resultString .= '<a href="';
				$resultString .= $this->configuration['callback'];
	            $resultString .= '&action=modify&itemId='.$item->itemId;
	            $resultString .= '&parentId='.$item->parentId. '">';
				$resultString .= $this->configuration['icons']['node'];
				$resultString .= '</a>';
        	}
        	else 
        	{
				$resultString .= $this->configuration['icons']['node'];
        	}
			$resultString .= '<a href="';
			$resultString .= $rss->channel['link'];
			if (
				isset ($this->configuration['newsNewWindowTarget']) &&
				($this->configuration['newsNewWindowTarget'] == '_blank')
				)
			{
				$resultString .= ' target="'.$this->configuration['newsNewWindowTarget'].'" ';
			}
			$resultString .= '">';
			$resultString .= $item->name;
			$resultString .= '</a></b>';
			$resultString .= '</td>';
			$resultString .= '</tr>';

			$resultString .= '<tr>';
			$resultString .= '<td><em>';
			if (isset ($rss->channel['description']))
			{
				$resultString .= $rss->channel['description'];
			}
			else
			{
				$resultString .= '&nbsp;';
			}
			$resultString .= '</em></td>';
			$resultString .= '</tr>';

			// Only show the image if the image URL is provided
			if (isset ($rss->image['url']))
			{
				$resultString .= '<tr>';
				$resultString .= '<td><img src="';
				$resultString .= $rss->image['url'];
				$resultString .= '"></td>';
				$resultString .= '</tr>';
			}
			foreach ($rss->items as $rssitem)
			{
				$resultString .= '<tr>';
				$resultString .= '<td>';
				$resultString .= '<a href="';
				$resultString .= $rssitem['link'];
				$resultString .= '">';
				$resultString .= $this->stringUtils->urlEncodeQuotes ($rssitem['title']);
				$resultString .= '</a>';
				$resultString .= '</td>';
				$resultString .= '</tr>';

				if (isset ($rssitem['description']))
				{
					$resultString .= '<tr>';
					$resultString .= '<td>';
					$resultString .= trim ($rssitem['description']);
					$resultString .= '</td>';
					$resultString .= '</tr>';
				}
			}

			$resultString .= '</table>';
		}
		else
		{
			$resultString = '<table border="0" width="300">';
			$resultString .= '<tr valign="top">';
			$resultString .= '<td><b>';
        	if ($item->owner == $_SESSION['brimUsername'])
        	{
				$resultString .= '<a href="';
				$resultString .= $this->configuration['callback'];
	            $resultString .= '&action=modify&itemId='.$item->itemId;
	            $resultString .= '&parentId='.$item->parentId. '">';
				$resultString .= $this->configuration['icons']['node'];
				$resultString .= '</a>';
        	}
        	else 
        	{
				$resultString .= $this->configuration['icons']['node'];
        	}
			$resultString .= "<b>Error: </b>Could not parse ".$item->name;
			$resultString .= "</td></tr>";
			$resultString .= '</table>';

		}
		return $resultString;
	}
}
?>