<?php
require_once('framework/ItemController.php');
require_once('plugins/recipes/model/RecipeServices.php');
require_once('plugins/recipes/model/RecipePreferences.php');
require_once('plugins/recipes/model/ImageLinkFactory.php');

require_class('RequestCast',
	'framework/util/request/RequestCast.class.php');
/**
 * The Recipe Controller
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Thomas Sterren
 * @package org.brim-project.plugins.recipes
 * @filesource
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */

class RecipeController extends ItemController
{
	var $imageLinkFactory;

	/**
	 * Constructor.
	 * Makes sure that the appropriate operations are instantiated.
	 * @param string renderEngineName the render engine that is used
	 * (either Smarty or phpSavant)
	 */
	function RecipeController()
	{
		parent::ItemController();

		$theFactory = new RecipeFactory();
		$theServices = new RecipeServices();

		$theServices->setFactory($theFactory);
		$theFactory->setServices($theServices);
		$theServices->setFactory($theFactory);	// Do it again (Reference problem?!)

		$this->operations = $theServices;
		$this->itemFactory = $theFactory;
		$this->preferences = new RecipePreferences();

		$this->pluginName = 'recipes';
		$this->title = 'Brim - Recipes';
		$this->itemName = 'Recipe';
		$this->expandName = 'recipeExpand';

		// sterry todo: Create only one ImageLinkFactory
		$this->imageLinkFactory = new ImageLinkFactory();
		$this->imageLinkFactory->setServices($this->operations->imageLinkServices);
	}

	/**
 	 * Returns the actions defined for this item only
 	 *
 	 * @return array an array of item specific actions
	 * (like search, import etc.)
 	 */
	function getActions()
	{
		$actions=array();

		$isAShowItemsAction = ('' == $this->getAction() ||
							  'show' == $this->getAction() ||
							  'addItemPost' == $this->getAction() ||
							  'modifyItemPost' == $this->getAction() ||
							  'deleteItemPost' == $this->getAction() ||
							  'moveItem' == $this->getAction() ||
							  'addFolderPost' == $this->getAction() ||
							  'modifyFolderPost' == $this->getAction() ||
							  'cancel' == $this->getAction() ||
							  'sort' == $this->getAction() ||
							  'setModePublic' == $this->getAction() ||
							  'setModePrivate' == $this->getAction()) ? true : false;


		$isAShowRecipeAction = ('showItem' == $this->getAction() ||
							    'showNextImage' == $this->getAction() ||
							    'showPrevImage' == $this->getAction() ||
							    'cancelImage' == $this->getAction()) ? true : false;

		$controllerFileName = 'index.php';
		$pluginParamString = 'plugin='.$this->pluginName;
		$parentIdParamString = 'parentId='.$this->getParentId();
		$itemIdParamString = 'itemId='.$this->getItemId();

		// Actions
		$actions[0]['name']='actions';


		if ($isAShowRecipeAction)
		{
			// Add link to image
			if ($this->getItemOwner($this->getItemId()) == $this->getUserName())
			{
				$actions[0]['contents'][]=
							array('href' => $controllerFileName.'?'.$pluginParamString.'&action=addImage&'.$parentIdParamString.'&'.$itemIdParamString,
								  'name' => 'add_image');
			}
		}

		if ($isAShowItemsAction)
		{
			$actions[0]['contents'][]=
						array('href' => $controllerFileName.'?'.$pluginParamString.'&action=add&'.$parentIdParamString,
							  'name' => 'add_recipe');
			$actions[0]['contents'][]=
						array('href' => $controllerFileName.'?'.$pluginParamString.'&action=addFolder&'.$parentIdParamString,
							  'name' => 'add_folder');
		}

		$actions[0]['contents'][]=
					array('href' => $controllerFileName.'?'.$pluginParamString.'&action=uploadImage&'.$parentIdParamString,
						  'name' => 'uploadImage');
		$actions[0]['contents'][]=
					array('href' => $controllerFileName.'?'.$pluginParamString.'&action=search&'.$parentIdParamString,
						  'name' => 'search');

		// View
		$actions[1]['name']='view';
		$actions[1]['contents'][] =
					array('href' => $controllerFileName.'?'.$pluginParamString.'&action=setModePublic&'.$parentIdParamString,
						  'name' => 'setModePublic');
		$actions[1]['contents'][] =
					array('href' => $controllerFileName.'?'.$pluginParamString.'&action=setModePrivate&'.$parentIdParamString,
						  'name' => 'setModePrivate');

		if ($isAShowItemsAction)
		{
			// Sort
			$actions[2]['name']='sort';
			$actions[2]['contents'][]=
						array('href'=>$controllerFileName.'?'.$pluginParamString.'&action=sort&order=ASC&field=name&'.$parentIdParamString,
							'name'=> 'name');
			$actions[2]['contents'][]=
						array('href'=>$controllerFileName.'?'.$pluginParamString.'&action=sort&order=ASC&field=duration&'.$parentIdParamString,
							'name'=> 'duration');
			$actions[2]['contents'][]=
						array('href'=>$controllerFileName.'?'.$pluginParamString.'&action=sort&order=ASC&field=costs&'.$parentIdParamString,
							'name'=> 'costs');
			$actions[2]['contents'][]=
						array('href'=>$controllerFileName.'?'.$pluginParamString.'&action=sort&order=ASC&field=is_vegetarian&'.$parentIdParamString,
							'name'=> 'vegetarian');
			$actions[2]['contents'][]=
						array('href'=>$controllerFileName.'?'.$pluginParamString.'&action=sort&order=ASC&field=copyright&'.$parentIdParamString,
							'name'=> 'copyright');
		}

		// Preferences
		$actions[3]['name'] = 'preferences';
		$actions[3]['contents'][] =
			array ('href' => $controllerFileName.'?'.$pluginParamString.'&action=modifyPreferencesPre',
				   'name' => 'modify');

		// help
		$actions[4]['name'] = 'help';
		$actions[4]['contents'][] =
				array ('href' => $controllerFileName.'?'.$pluginParamString.'&action=help',
					   'name' => 'help');

		return $actions;
	}

	/**
	 * Activate. Basically this means that the appropriate actions
	 * are executed and an optional result is returned
	 * to be processed/displayed
	 */
	function activate()
	{
		switch ($this->getAction())
		{
			case "add":
				$this->addAction();
				break;
			case "modify":
				$this->modifyAction();
				break;
			case "modifyItemPost":
				if ($this->modifyItemAction())
				{
					$this->getShowItemsParameters();
				}
				break;
			case "showItem":
			case "cancelImage":
				$this->showAction();
				break;
			case "deleteItemPost":
				$this->deleteItemAction();
				$this->getShowItemsParameters();
				break;
			case "addItemPost":
				$this->addItemAction();
				break;
			case "move":
				$this->moveAction();
				break;
			case "moveItem":
				$this->moveItemAction();
				$this->getShowItemsParameters();
				break;
			case "addFolder":
				$this->addFolderActionPre();
				break;
			case "addFolderPost":
				$this->addFolderActionPost();
				break;
			case "modifyFolder":
				$this->modifyFolderActionPre();
				break;
			case "modifyFolderPost":
				$this->modifyFolderActionPost();
				break;
			case "uploadImage":
				$this->uploadImageAction();
				break;
			case "uploadImagePost":
				$this->uploadImageActionPost();
				break;
			case "addImage":
				$this->addImageActionPre();
				break;
			case "addImagePost":
				$this->addImageActionPost();
				break;
			case "modifyImage":
				$this->modifyImageActionPre();
				break;
			case "modifyImagePost":
				$this->modifyImageActionPost();
				break;
			case "deleteImagePost":
				$this->deleteImageActionPost();
				break;
			case "showNextImage":
			case "showPrevImage":
				$this->showImageAction();
				break;
			case "search":
				$this->renderer = $this->getAction().'Recipe';
				break;
			case "searchTitle":
				$this->searchItemAction('title');
				break;
			case "searchIngredients":
				$this->searchItemAction('ingredients');
				break;
			case "searchTextSections":
				$this->searchItemAction('textsections');
				break;
			case "searchFullText":
				$this->searchItemAction('fulltext');
				break;
			case "help":
				$this->helpAction();
				break;
			case "sort":
				$field = $_GET['field'];
				$order = $_GET['order'];
				$this->addUserFieldNamesToParameters();
				$this->sortAllAction ($field, $order);
				break;
			case "modifyPreferencesPost":
				$this->preferences->setPreference($this->getUserName(),
												  $_POST['name'],
									  			  $_POST['value']);
				// No break here
			case "modifyPreferencesPre":
				$this->renderObjects =
					$this->preferences->getAllPreferences($this->getUserName());
				$this->renderer = 'modifyPreferences';
				break;
			case "setModePublic":
				$_SESSION['navigationMode']='public';
				$this->navigationMode ='public';
				$this->getShowItemsParameters();
				break;
			case "setModePrivate":
				$_SESSION['navigationMode']='private';
				$this->navigationMode ='private';
				$this->getShowItemsParameters();
				break;
			default:
				$this->getShowItemsParameters();
				break;
		}

		$this->addParameter('overlib', $this->preferences->getOverlib());
	}

	function getShowItemsParameters()
	{
		$this->addUserFieldNamesToParameters();
		parent::getShowItemsParameters();
	}

	function getShowPrivateItemsParameters()
	{
		$this->renderer = 'show'.$this->getItemName().'s';
		$rootItems = $this->operations->getChildren
			($this->getUserName(), $this->getParentId());

		$this->renderObjects = $rootItems;
	}

	/**
	 * Search for items
	 */
	function searchItemAction($searchKey = 'title')
	{
		$items = $this->operations->searchExpressionInMultipleFieldsItems($this->getUserName(),
																		  $searchKey,
																		  $_POST['value'],
																		  $this->navigationMode);
		$this->addUserFieldNamesToParameters();

		$this->renderObjects = $items;
		$this->renderer = 'show'.$this->getItemName().'s';
	}

	function addAction()
	{
		$this->addParameter('nbrOfIngrDisp',
							$this->preferences->getNumberOfIngredientsToDisplay());
		$this->addParameter('nbrOfTextSectionsDisp',
							$this->preferences->getNumberOfTextSectionsToDisplay());
		$this->addUserFieldNamesToParameters();

		// Get an empty object
		$this->renderObjects = $this->operations->getItem($this->getUserName(), $this->getParentId());

		parent::addAction();
	}

	/**
	 * Items parameters has been provided, now really add it
	 * Adds only an item if the Refresh button was not pressed
	 *
	 * @protected
	 */
	function addItemAction ()
	{
		$item = $this->itemFactory->requestToItem ();

		if (!isset($_REQUEST['refresh']))
		{
			$errors = $this->itemFactory->requestToItemErrors ();
		}

		if (empty($errors) && !isset($_REQUEST['refresh']))
		{
			$this->operations->addItem ($this->getUserName (),
				$item);
			$this->getShowItemsParameters ();
		}
		else
		{
				//die ('x');
			$this->addParameter("errors", $errors);
			$this->addAction ();
			$this->renderObjects = $item;
		}
	}

	function modifyAction()
	{
		$this->addUserFieldNamesToParameters();
		parent::modifyAction();
	}

	/**
	 * Items parameters has been provided, now really modify it
	 *
	 * @return boolean <code>true</code> if the item was succesfully
	 * added, <code>false</code> in case of failure
	 * @protected
	 */
	function modifyItemAction()
	{
		$retValue = true;

		$baseItem = $this->operations->getItem($this->getUserName(),
											   $this->itemId);
		$item = $this->itemFactory->requestToItem($baseItem);

		if (isset($_REQUEST['refresh']))
		{
			$this->modifyAction();
			$this->renderObjects = $item;

			$retValue = false;
		}
		else
		{
			ItemController::modifyItemAction();
		}

		return $retValue;
	}

	function showAction()
	{
		$this->addUserFieldNamesToParameters();
		parent::showAction();
	}

	function addFolderActionPre()
	{
		$dictionary = $this->getDictionary();

		$this->renderer = 'folder';

		$this->renderEngine->assign('viewAction', 'add');
		$this->renderEngine->assign('pageTitle', $dictionary['add_folder']);

		//$this->renderEngine->assign('parentId', $this->getParentId());
		// Sould be done in prepareFolderForAddPre()

		$this->renderObjects = $this->itemFactory->prepareFolderForAddPre();
	}

	function addFolderActionPost()
	{
		$item = $this->itemFactory->requestToItem();

		$errors = $this->itemFactory->requestToItemErrors();

		if (empty($errors))
		{
			$this->operations->addItem($this->getUserName(), $item);
			$this->itemId = $item->recipeId;
			$this->getShowItemsParameters();
		}
		else
		{
			$this->addParameter("errors", $errors);
			$this->addFolderActionPre();
			$this->renderObjects = $item;
		}
	}

	function modifyFolderActionPre()
	{
		if ($this->getItemOwner($this->getItemId()) != $this->getUserName())
		{
			$this->getShowItemsParameters();
			// Force action
			$this->setAction('');
		}
		else
		{
			$dictionary = $this->getDictionary();

			$this->renderer = 'folder';

			$this->renderEngine->assign('viewAction', 'modify');
			$this->renderEngine->assign('pageTitle', $dictionary['add_folder']);

			$this->renderObjects = $this->operations->getItem($this->getUserName(),
															  $this->itemId);
		}
	}

	function modifyFolderActionPost()
	{
		parent::modifyItemAction();
	}

	function uploadImageAction()
	{
		$dictionary = $this->getDictionary();

		$this->renderer = 'uploadImage';
		$this->renderEngine->assign('viewAction', 'upload');
		$this->renderEngine->assign('pageTitle', $dictionary['uploadImage']);
		$this->renderEngine->assign('recipeServerImagePath', $this->preferences->getServerImagePath());
	}

	function uploadImageActionPost()
	{
		$dictionary = $this->getDictionary();

		$uploadStatus = $this->upload();

		$this->renderer = 'uploadImage';
		$this->renderEngine->assign('viewAction', 'showResult');
		$this->renderEngine->assign('pageTitle', $dictionary['uploadImage']);
		$this->renderEngine->assign('uploadStatus', $uploadStatus);
	}

	function upload()
	{
		$uploadStatus = '';

		$recipeServerImagePath = $this->preferences->getServerImagePath();

		if (!isset($_POST['dirPath']))
		{
			$dirPath = '/';
		}

		if(isset($_FILES['upload']) && is_array($_FILES['upload']))
		{

			if(strrpos($recipeServerImagePath, '/')!= strlen($recipeServerImagePath)-1)
			{
				$recipeServerImagePath.= '/';
			}

			$uploadStatus = $this->doUpload( $_FILES['upload'], $recipeServerImagePath);
		}

		return $uploadStatus;
	}

	function doUpload($file, $serverPath)
	{
		if (file_exists($serverPath.$file['name']))
		{
			return 'fileAlreadyExists';
		}

		if ((strcasecmp(substr($file['name'],-4),".gif")) &&
			(strcasecmp(substr($file['name'],-4),".jpg")) &&
			(strcasecmp(substr($file['name'],-4),".png")) &&
			(strcasecmp(substr($file['name'],-4),".bmp")))
		{
			// Possible file types gif, png, jpg, bmp can be uploaded');
			return 'wrongFileType';
		}

		if (!move_uploaded_file($file['tmp_name'], $serverPath.strtolower($file['name'])))
		{
			return 'uploadFailed';
		}
		else
		{
			chmod($serverPath.strtolower($file['name']), octdec('0666'));
			return 'uploadDone';
		}
	}

	function addImageActionPre()
	{
		$dictionary = $this->getDictionary();

		$this->renderer = 'image';

		$this->renderObjects = $this->imageLinkFactory->prepareItemForAddPre();

		if ($this->getItemOwner($this->renderObjects->recipeId) != $this->getUserName())
		{
			$this->renderEngine->assign("message", $dictionary['modify_not_owner']);

			// Force action to 'showItem'
			$this->setAction('showItem');
			$this->showAction();
		}
		else
		{
			$this->renderEngine->assign('viewAction', 'add');
			$this->renderEngine->assign('pageTitle', $dictionary['add_image']);

			$this->renderEngine->assign('parentId', $this->getParentId());
		}
	}

	function addImageActionPost()
	{
		$item = $this->imageLinkFactory->requestToItem();

		// We are only able to modify an item which we own...
		if ($this->getitemOwner($item->recipeId) != $this->getUserName())
		{
			$this->renderEngine->assign("message", $dictionary['modify_not_owner']);
			$this->itemId = $item->recipeId;
			$this->showAction();
		}
		else
		{
			$errors = $this->imageLinkFactory->requestToItemErrors();
			if (empty($errors))
			{
				$this->operations->addImage($item);
				$this->itemId = $item->recipeId;
				$this->showAction();
			}
			else
			{
				$this->addParameter("errors", $errors);
				$this->addImageActionPre();
				$this->renderObjects = $item;
			}
		}
	}

	function modifyImageActionPre()
	{
		$dictionary = $this->getDictionary();

		$this->renderer = 'image';

		$this->renderObjects =
			$this->operations->getImageLinkItem($_GET['recipeId'], $_GET['imageId']);

		if ($this->getItemOwner($this->renderObjects->recipeId) != $this->getUserName())
		{
			$this->renderEngine->assign("message", $dictionary['modify_not_owner']);

			// Force action to 'showItem'
			$this->setAction('showItem');
			$this->showAction();
		}
		else
		{
			$this->renderEngine->assign ('viewAction', 'modify');
			$this->renderEngine->assign ('pageTitle', $dictionary['modify_image']);
		}
	}

	function modifyImageActionPost()
	{
		$dictionary = $this->getDictionary();

		$baseItem = $this->operations->getImageLinkItem($_POST['recipeId'], $this->getItemId());

		$item = $this->imageLinkFactory->requestToItem($baseItem);

		// We are only able to modify an item which we own...
		if ($this->getitemOwner($item->recipeId) != $this->getUserName())
		{
			$this->renderEngine->assign("message", $dictionary['modify_not_owner']);
			$this->showImageAction($item->arrangement - 1, $item->recipeId);
		}
		else
		{
			//
			// Check for errors
			//
			$errors = $this->imageLinkFactory->requestToItemErrors();
			if ($errors == null)
			{
				$this->operations->modifyImage($item);
				$this->showImageAction($item->arrangement - 1, $item->recipeId);
			}
			else
			{
				$this->addParameter("errors", $errors);
				$this->modifyImageActionPre();
				$this->renderObjects = $item;
			}
		}
	}

	function showImageAction($imageIndex=null, $recipeId=null)
	{
		$imageIndex = (!empty($imageIndex)) ? $imageIndex : $_GET['imageIndex'];
		$recipeId = (!empty($recipeId)) ? $recipeId : $this->getItemId();

		$dictionary = $this->getDictionary();

		$this->renderer = strtolower ($this->getItemName ());
		$this->renderEngine->assign ('viewAction', 'show');
		$this->renderEngine->assign ('pageTitle', $this->getItemName());
		$this->renderEngine->assign ('imageIndex', $imageIndex);

		$this->addUserFieldNamesToParameters();

		$this->renderObjects = $this->operations->getItem($this->getUserName(),	$recipeId);
	}

	function deleteImageActionPost()
	{
		if ($this->getItemOwner($this->getItemId()) != $this->getUserName())
		{
			$this->renderEngine->assign("message", $dictionary['modify_not_owner']);

			// Force action to 'showItem'
			$this->setAction('showItem');
		}
		else
		{
			$this->operations->deleteImage($_GET['imageId']);
		}

		$this->showAction();
	}

	function addUserFieldNamesToParameters()
	{
		for ($userFieldId = 1; $userFieldId <= 5; $userFieldId++)
		{
			$this->addParameter('recipeUserFieldName'.$userFieldId,
								$this->preferences->getUserFieldName($userFieldId));
		}
	}

	function getItemOwner($itemId)
	{
		return $this->operations->getItemOwner($itemId);
	}
}
?>
