<?php

require_once('framework/Installer.php');
require_once('plugins/recipes/model/RecipeBaseInstaller.php');
require_once('plugins/recipes/model/RecipeLinkInstaller.php');
require_once('plugins/recipes/model/IngredientInstaller.php');
require_once('plugins/recipes/model/TextSectionInstaller.php');
require_once('plugins/recipes/model/ImageLinkInstaller.php');

/**
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Thomas Sterren
 * @package org.brim-project.plugins.recipes
 * @subpackage install
 * @filesource
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class RecipeInstaller extends Installer
{
	var $recipeBaseInstaller;
	var $recipeLinkInstaller;
	var $ingredientInstaller;
	var $textSectionInstaller;
	var $imageLinkInstaller;

	var $installSampleData;

	function RecipeInstaller($engine, $db)
	{
		$this->installSampleData = false;

		$this->recipeBaseInstaller = new RecipeBaseInstaller($engine, $db);
		$this->recipeLinkInstaller = new RecipeLinkInstaller($engine, $db);
		$this->ingredientInstaller = new IngredientInstaller($engine, $db);
		$this->textSectionInstaller = new TextSectionInstaller($engine, $db);
		$this->imageLinkInstaller = new ImageLinkInstaller($engine, $db);
	}

	function install()
	{
		$this->recipeBaseInstaller->install();
		$this->recipeLinkInstaller->install();
		$this->ingredientInstaller->install();
		$this->textSectionInstaller->install();
		$this->imageLinkInstaller->install();

		if ($this->installSampleData)
		{
			$this->recipeBaseInstaller->installSampleData();
			$this->recipeLinkInstaller->installSampleData();
			$this->ingredientInstaller->installSampleData();
			$this->textSectionInstaller->installSampleData();
			$this->imageLinkInstaller->installSampleData();
		}
	}

	function findTable()
	{
		if ($this->recipeBaseInstaller->findTable())
		{
			if ($this->recipeLinkInstaller->findTable())
			{
				if ($this->ingredientInstaller->findTable())
				{
					if ($this->textSectionInstaller->findTable())
					{
						return $this->imageLinkInstaller->findTable();
					}
				}
			}
		}
		return false;
	}

	function isTableUpToDate()
	{
		if ($this->recipeBaseInstaller->isTableUpToDate())
		{
			if ($this->recipeLinkInstaller->isTableUpToDate())
			{
				if ($this->ingredientInstaller->isTableUpToDate())
				{
					if ($this->textSectionInstaller->isTableUpToDate())
					{
						return $this->imageLinkInstaller->isTableUpToDate();
					}
				}
			}
		}
		return false;
	}

	function createStandardIndex()
	{
		$this->recipeBaseInstaller->createStandardIndex();
		$this->recipeLinkInstaller->createStandardIndex();
		$this->ingredientInstaller->createStandardIndex();
		$this->textSectionInstaller->createStandardIndex();
		$this->imageLinkInstaller->createStandardIndex();
	}
}
?>