<?php

require_once('framework/model/ItemFactory.php');
require_once('plugins/recipes/model/ImageLink.php');

require_class('ImageLinkRequestCast', 'plugins/recipes/util/request/ImageLinkRequestCast.php');
require_class('ClassHelper', 'framework/util/ClassHelper.class.php');

/**
 * The ImageLinkFactory
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Thomas Sterren
 * @package org.brim-project.plugins.recipes
 * @subpackage model
 * @filesource
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class ImageLinkFactory extends ItemFactory
{
	var $operations;

	/**
	 * Default constructor
	 */
	function ImageLinkFactory()
	{
		parent::ItemFactory();
		$this->requestCast = new ImageLinkRequestCast("ImageLink");

		$this->operations = null;
	}

	function setServices(&$operations)
	{
		$this->operations = $operations;
	}

	/**
	 * Returns the type of this specific item
	 * @return string the type of this specific item:
	 * <code>ImageLink</code>
	 */
	function getType()
	{
		return "ImageLink";
	}

	function requestToItem()
	{
		$itemId 		= $this->getFromPost('itemId', 0);
		$deleted 		= $this->getFromPost('isDeleted', 0);
		$whenCreated 	= $this->getFromPost('when_created', null);
		$whenModified 	= $this->getFromPost('when_modified', null);
		$guid 			= $this->getFromPost('guid', $this->createGUID());
		$parentId 		= $this->getFromPost('parentId', 0);
		$recipeId 		= $this->getFromPost('recipeId', 0);
		$position		= $this->getFromPost('position', 'topRight');
		$arrangement	= $this->getFromPost('arrangement', 0);
		$mainImage		= $this->getFromPost('mainImage', 0);
		$url			= $this->getFromPost('url', null);
		$class			= $this->getFromPost('class', null);
		$style			= $this->getFromPost('style', null);
		$width			= $this->getFromPost('width', null);
		$height			= $this->getFromPost('height', null);
		$border			= $this->getFromPost('border', null);
		$align			= $this->getFromPost('align', null);
		$hSpace			= $this->getFromPost('hSpace', null);
		$vSpase			= $this->getFromPost('vSpase', null);
		$alt			= $this->getFromPost('alt', null);
		$title			= $this->getFromPost('title', null);
		$mediaRef		= $this->getFromPost('mediaRef', null);

		if ($arrangement == 0)
		{
			$arrangement = $this->operations->getImageLinkCount($recipeId) + 1;
		}

		$width = (!empty($width)) ? $width : 'null';
		$height = (!empty($height)) ? $height : 'null';
		$border = (!empty($border)) ? $border : 'null';

		$item = new ImageLink($itemId,
							  $deleted,
							  $whenCreated,
							  $whenModified,
							  $guid,
							  $parentId,
							  $recipeId,
							  $position,
							  $arrangement,
							  $mainImage,
							  $url,
							  $class,
							  $style,
							  $width,
							  $height,
							  $border,
							  $align,
							  $hSpace,
							  $vSpase,
							  $alt,
							  $title,
				  			  $mediaRef);
		return $item;
	}

	function prepareItemForAddPre()
	{
		$item = $this->getEmptyItem();

		$item->recipeId = $this->getFromAnywhere('itemId', 0);
		$item->arrangement = $this->getFromAnywhere('arrangement', 0);

		if ($item->arrangement == 0)
		{
			$item->arrangement = $this->operations->getImageLinkCount($item->recipeId) + 1;
		}

		return $item;
	}

	/**
	 * Factory method: Returns a database result into an item
	 *
	 * @param object result the result retrieved from the database
	 * @return array the items constructed from the database resultset
	 */
	function resultsetToItems($result)
	{
		$items = array();

		while (!$result->EOF)
		{
			$item = new ImageLink(
				$result->fields['item_id'],
				$result->fields['is_deleted'],
				$result->fields['when_created'],
				$result->fields['when_modified'],
				$result->fields['guid'],
				-1,					// parentId. Only necessary during runtime
				$result->fields['recipe_id'],
				trim($this->stringUtils->gpcStripSlashes
					($result->fields['position'])),
				$result->fields['arrangement'],
				$result->fields['is_main_image'],
				trim ($result->fields['url']),
				trim($this->stringUtils->gpcStripSlashes
					($result->fields['class'])),
				trim($this->stringUtils->gpcStripSlashes
					($result->fields['style'])),
				$result->fields['width'],
				$result->fields['height'],
				$result->fields['border'],
				trim ($result->fields['align']),
				$result->fields['hspace'],
				$result->fields['vspace'],
				trim($this->stringUtils->gpcStripSlashes
					($result->fields['alt'])),
				trim($this->stringUtils->gpcStripSlashes
					($result->fields['title'])),
				trim ($result->fields['media_ref']));

			$items[] = $item;

			$result->MoveNext();
		}
		return $items;
	}

	/**
	 * Returns an empty item
	 * @return object an empty item, all values
	 * set to -null-
	 */
	function getEmptyItem()
	{
		$item = new ImageLink(null, null, null, null,
			 				  null, null, null, null,
			 				  null, null, null, null,
			 				  null, null, null, null,
			 				  null, null, null, null,
			 				  null, null);
		return $item;
	}

	/**
	 * Generates a GUID (Global Unique Identifier). Used to identify a
	 * record in a table.
	 */
	function createGUID()
	{
		return md5(uniqid(rand()));
	}

	function getFromAnywhere($value, $default)
	{
		if (isset ($_GET[$value]))
		{
			return $this->stringUtils->gpcStripSlashes ($_GET[$value]);
		}
		else if (isset ($_POST[$value]))
		{
			return $this->stringUtils->gpcStripSlashes ($_POST[$value]);
		}
		else
		{
			return $default;
		}
	}
}
?>