<?php

require_once('framework/model/ItemFactory.php');
require_once('plugins/recipes/model/Ingredient.php');

require_class('IngredientRequestCast', 'plugins/recipes/util/request/IngredientRequestCast.php');
require_class('ClassHelper', 'framework/util/ClassHelper.class.php');

/**
 * The IngredientFactory
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Thomas Sterren
 * @package org.brim-project.plugins.recipes
 * @subpackage model
 * @filesource
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class IngredientFactory extends ItemFactory
{
	/**
	 * Default constructor
	 */
	function IngredientFactory()
	{
		parent::ItemFactory();
		$this->requestCast = new IngredientRequestCast("Ingredient");
	}

	/**
	 * Returns the type of this specific item
	 * @return string the type of this specific item:
	 * <code>Ingredient</code>
	 */
	function getType()
	{
		return "Ingredient";
	}

	function requestToItem()
	{
		$itemId 		= $this->getFromPost('itemId', 0);
		$deleted 		= $this->getFromPost('isDeleted', 0);
		$whenCreated 	= $this->getFromPost('when_created', null);
		$whenModified 	= $this->getFromPost('when_modified', null);
		$guid 			= $this->getFromPost('guid', $this->createGUID());
		$amount 		= $this->getFromPost('amount', null);
		$name			= $this->getFromPost('name', null);
		$description	= $this->getFromPost('description', null);

		$item = new Ingredient($itemId,
							   $deleted,
							   $whenCreated,
							   $whenModified,
							   $guid,
							   $amount,
							   $name,
							   $description);

		return $item;
	}

	/**
	 * Factory method: Returns a database result into an item
	 *
	 * @param object result the result retrieved from the database
	 * @return array the items constructed from the database resultset
	 */
	function resultsetToItems($result)
	{
		$items = array();

		while (!$result->EOF)
		{
			$item = new Ingredient(
				$result->fields['item_id'],
				$result->fields['is_deleted'],
				$result->fields['when_created'],
				$result->fields['when_modified'],
				$result->fields['guid'],
				trim($this->stringUtils->gpcStripSlashes
					($result->fields['amount'])),
				trim($this->stringUtils->gpcStripSlashes
					($result->fields['name'])),
				trim ($this->stringUtils->gpcStripSlashes
					($result->fields['description'])));

			$items[] = $item;

			$result->MoveNext();
		}
		return $items;
	}

	/**
	 * Returns an empty item
	 * @return object an empty item, all values
	 * set to -null-
	 */
	function getEmptyItem()
	{
		$item = new Ingredient(null, null, null, null,
			 				   null, null, null, null);
		return $item;
	}

	/**
	 * Generates a GUID (Global Unique Identifier). Used to identify a
	 * record in a table.
	 */
	function createGUID()
	{
		return md5(uniqid(rand()));
	}

	function requestToIngredients()
	{
		$nbrOfIngredients = $this->getFromPost('nbrOfIngredients', 0);
		$ingredients = array();

		for ($i = 0; $i < $nbrOfIngredients; $i++)
		{
			$itemId			= $this->getFromPost('ingredientItemId'.$i, 0);
			$deleted		= $this->getFromPost('ingredientIsDeleted', 0);
			$whenCreated	= $this->getFromPost('ingredientWhenCreated', null);
			$whenModified	= $this->getFromPost('ingredientWhenModified', null);
			$guid			= $this->getFromPost('ingredientGUID', $this->createGUID());
			$amount			= $this->getFromPost('ingredientAmount'.$i, null);
			$name			= $this->getFromPost('ingredientName'.$i, null);
			$description	= $this->getFromPost('ingredientDescription'.$i, null);

			$item = new Ingredient($itemId,
								   $deleted,
								   $whenCreated,
								   $whenModified,
								   $guid,
								   $amount,
								   $name,
								   $description);

			if ($item->isValid())
			{
				$ingredients[] = $item;
			}
		}
		return $ingredients;
	}
}
?>
