<?php
require_once('plugins/recipes/model/Ingredient.php');
require_once('plugins/recipes/model/IngredientFactory.php');
require_once('framework/model/Services.php');

/**
 * Services for an Ingredient
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Thomas Sterren
 * @package org.brim-project.plugins.recipes
 * @subpackage model
 * @filesource
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class IngredientServices extends Services
{
	var $linkServices;

	/**
	 * Default constructor
	 */
	function IngredientServices()
	{
		parent::Services();
		$this->itemFactory = new IngredientFactory();
		$this->linkServices = null;

		include ('plugins/recipes/sql/ingredientQueries.php');
		$this->queries = $queries;
	}

	function setLinkServices(&$operations)
	{
		$this->linkServices = $operations;
	}

	/**
	 * Adds information for a ingredient
	 *
	 * @param integer userId the identifier for the user
	 * @param object item the ingredient to be added
	 *
     * @return integer last know id. This is the id of the recipe
	 * that was newly inserted and for which an id has automatically
	 * been assigned.
	 */
	function addItem($userId, $item, $linkNewItem = true)
	{
		$now = date("Y-m-d H:i:s");

		if (!isset($item->guid))
		{
			$item->guid = $this->itemFactory->createGUID();
		}

		// execute the query
		$query = sprintf($this->queries['addItem'],
			$now,
			$item->guid,
			addslashes(trim($item->amount)),
			addslashes(trim($item->name)),
			addslashes(trim($item->description)));

		$this->db->Execute($query) or
				die ("Could not add ingredient.".
				$this->db->ErrorMsg () . " " . $query . '<br />');

		// fetch the last known id
		// todo this is generic code and is candidate to move to the base Services class
		$query = $this->queries['lastItemInsertId'];
		$result = $this->db->Execute($query) or
			die ("Could not retrieve last insert id for ingredient. ".
			$this->db->ErrorMsg () . " " . $query . '<br />');

		if ($linkNewItem)
		{
			// Put an entry in the orders table too
			$itemIds = array();

			$itemIds[] = $result->fields[0];

			$this->linkServices->addIngredientIds($userId, $itemIds);
		}

        return $result->fields[0];
	}

	function addItems($recipeId, $items)
	{
		$itemIds = array();

		for ($i = 0; $i < count($items); $i++)
		{
			$itemIds[] = $this->addItem($recipeId, $items[$i], false);
		}

		$this->linkServices->addIngredientIds($recipeId, $itemIds);
	}

	/**
	 * Modifies te recipe
	 *
 	 * @param integer userId the identifier for the user who modifies a recipe
	 * @param object item the modified recipe
	 */
	function modifyItem($userId, $item)
	{
		$now = date ("Y-m-d H:i:s");

		$query = sprintf ($this->queries['modifyItem'],
			$item->isDeleted,
			$now,							// when_modified
			addslashes($item->amount),
			addslashes($item->name),
			addslashes($item->description),
			$item->itemId);

		$this->db->Execute($query)
			or die ("Error modifying item: " .
	 		$this->db->ErrorMsg() . " " . $query . '<br />');
	}

	function modifyItems($recipeId, $items)
	{
		$oldIngredientCount = $this->getIngredientCount($recipeId);

		for ($i = 0; $i < count($items); $i++)
		{
			if ($items[$i]->itemId != 0)
			{
				$this->modifyItem(null, $items[$i]);
			}
			else
			{
				// We have a new ingredients. Add them
				$this->addItem($recipeId, $items[$i], true);
			}
		}

		if ($oldIngredientCount > count($items))
		{
			// Remove messy ingredients
			$this->removeMessyIngredients($recipeId, $oldIngredientCount - count($items));
		}
	}

	function deleteItem($userId, $itemId)
	{
		$item = $this->getItem($userId, $itemId);

		if (isset($item))
		{
			// now delete the specific item
			$query = sprintf($this->queries['deleteItem'], $itemId);

			$result = $this->db->Execute($query) or
				die("RecipeServices::DeleteItem: " .
				$this->db->ErrorMsg() . " " . $query. '<br />');
		}
	}

	/**
	*
	*/
	function getIngredients($recipeId)
	{
		return $this->getItems($recipeId);
	}

	function getIngredientCount($recipeId)
	{
		$query = sprintf($this->queries ['getIngredientCount'],
						 $recipeId);

		$result = $this->db->Execute ($query) or die
				("Operations. getIngredientCount " . $this->db->ErrorMsg () .
					" " . $query);

        return (isset($result->fields[0])) ? $result->fields[0] : 0;
	}

	/**
	* Deletes the last ingredients, which are too much
	*/
	function removeMessyIngredients($recipeId, $messyIngredientCount)
	{
		$this->linkServices->removeMessyIngredients($recipeId, $messyIngredientCount);
	}
}
?>
