<?php
require_once('plugins/recipes/model/Link.php');
require_once('plugins/recipes/model/LinkFactory.php');
require_once('framework/model/Services.php');
require_once('plugins/recipes/model/IngredientServices.php');
require_once('plugins/recipes/model/TextSectionServices.php');

/**
 * Services for an Link
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Thomas Sterren
 * @package org.brim-project.plugins.recipes
 * @subpackage model
 * @filesource
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class LinkServices extends Services
{
	var $ingredientServices;
	var $textSectionServices;

	/**
	 * Default constructor
	 */
	function LinkServices()
	{
		parent::Services();
		$this->itemFactory = new LinkFactory();

		$theIngredientServices = new IngredientServices();
		$theTextSectionServices = new TextSectionServices();

		include ('plugins/recipes/sql/linkQueries.php');
		$this->queries = $queries;

		// Construct an association between ingredient services
		// and link services
		$theIngredientServices->setLinkServices($this);
		// The same for textSection services and link services
		$theTextSectionServices->setLinkServices($this);

		$this->ingredientServices = $theIngredientServices;
		$this->textSectionServices = $theTextSectionServices;

		$this->ingredientServices->setLinkServices($this);
		$this->textSectionServices->setLinkServices($this);
	}

	function setFactory(&$theRecepieFactory)
	{
		// sterry todo: do the same for ingredientServices

		$this->textSectionServices->setTextSectionFactory($theRecepieFactory->textSectionFactory);
	}

	/**
	 * Adds information for a ingredient
	 *
	 * @param integer userId the identifier for the user
	 * @param object item the recipe to be added
	 *
     * @return integer last know id. This is the id of the recipe
	 * that was newly inserted and for which an id has automatically
	 * been assigned.
	 */
	function addItem($item)
	{
		$now = date("Y-m-d H:i:s");

		if (!isset($item->guid))
		{
			$item->guid = $this->itemFactory->createGUID();
		}

		// execute the query
		$query = sprintf($this->queries['addItem'],
			$now,
			$item->guid,
			$item->recipeId,
			$item->arrangement,
			$item->childTableId,
			$item->childItemId);

		$this->db->Execute($query) or
				die ("Could not add link.".
				$this->db->ErrorMsg () . " " . $query . '<br />');

		// fetch the last known id
		// todo this is generic code and is candidate to move to the base Services class
		$query = $this->queries['lastItemInsertId'];
		$result = $this->db->Execute($query) or
			die ("Could not retrieve last insert id for recipe. ".
			$this->db->ErrorMsg () . " " . $query . '<br />');

        return $result->fields[0];
	}

	function addChildIds($recipeId, $tableId, $itemIds, $orderNbr = null)
	{
		if (!isset($orderNbr))
		{
			$orderNbr = $this->getNextFreeOrderNumber($recipeId);
		}

		for ($i = 0; $i < count($itemIds); $i++)
		{
			$link = new Link(0,
							 0,
							 null,
							 null,
							 null,
							 $recipeId,
							 $orderNbr++,
							 $tableId,
							 $itemIds[$i]);

			$this->addItem($link);
		}
	}

	function addIngredientIds($recipeId, $itemIds, $orderNbr = null)
	{
		$this->addChildIds($recipeId, 1, $itemIds, $orderNbr);
	}

	function addTextSectionIds($recipeId, $itemIds, $orderNbr = null)
	{
		$this->addChildIds($recipeId, 2, $itemIds, $orderNbr);
	}

	function getNextFreeOrderNumber($recipeId)
	{
		$query = sprintf($this->queries['getNextFreeOrderNumber'],
						 'arrangement',
						 $recipeId,
						 'arrangement',
						 'DESC');

		$result = $this->db->Execute($query) or
					die ("Could not execute query getNextFreeOrderNumber: ".
					$this->db->ErrorMsg () . " " . $query . '<br />');

		return $result->fields[0] + 1;
	}

	/**
	 * Modifies te recipe
	 *
 	 * @param integer userId the identifier for the user who modifies a recipe
	 * @param object item the modified recipe
	 */
	function modifyItem($userId, $item)
	{
		//die ("LinkService::modifyItem ".bprint_r($item));
		$now = date ("Y-m-d H:i:s");

		$query = sprintf ($this->queries['modifyItem'],
			$now,							// when_modified
			addslashes($item->name),
			$item->isDeleted,
			addslashes($item->login),
			addslashes($item->url),
			addslashes($item->contact_person),
			addslashes($item->contact_phone),
			addslashes($item->description),
			$item->itemId);

		$this->db->Execute($query)
			or die ("Error modifying item: " .
	 		$this->db->ErrorMsg() . " " . $query . '<br />');
	}

	function deleteItem($userId, $itemId)
	{
		$item = $this->getItem($userId, $itemId);

		if (isset($item))
		{
			// Delete first the ingredient or text section entry
			$this->deleteChildItem($item->childTableId, $item->childItemId);

			// now delete the specific item
			$query = sprintf ($this->queries['deleteItem'], $itemId);
			$result = $this->db->Execute($query) or
				die("LinkServices::DeleteItem: " .
				$this->db->ErrorMsg() . " " . $query. '<br />');
		}
	}

	function deleteItems($userId, $recipeId)
	{
		for ($n = 1; $n <= 2; $n++)
		{
			$itemIds = $this->getIds($recipeId, $n);

			for ($i = 0; $i < count($itemIds); $i++)
			{
				$this->deleteItem($userId, $itemIds[$i]);
			}
		}
	}

	/**
	*
	*/
	function getLinks($recipeId)
	{
		return $this->getItems($recipeId);
	}

	function getIds($recipeId, $childTableId, $order='ASC')
	{
		$itemIds = array();

		$query = sprintf($this->queries['getIds'],
						 $childTableId,
						 $recipeId,
						 $order);

		$result = $this->db->Execute ($query) or die
				("Operations. getIds " . $this->db->ErrorMsg() .
			" " . $query);

		while (!$result->EOF)
		{
			$itemIds[] = $result->fields[0];
			$result->MoveNext();
		}

		return $itemIds;
	}

	/**
	* Deletes the last ingredients, which are too much
	*/
	function removeMessyIngredients($recipeId, $messyIngredientCount)
	{
		$itemIds = $this->getIds($recipeId, 1, 'DESC');

		for ($i = 0; $i < $messyIngredientCount; $i++)
		{
			$this->deleteItem(null, $itemIds[$i]);
		}
	}

	/**
	* Deletes the last text sections, which are too much
	*/
	function removeMessyTextSections($recipeId, $messyTextSectionCount)
	{
		$itemIds = $this->getIds($recipeId, 2, 'DESC');

		for ($i = 0; $i < $messyTextSectionCount; $i++)
		{
			$this->deleteItem(null, $itemIds[$i]);
		}
	}

	function deleteChildItem($childTableId, $childItemId)
	{
		if ($childTableId == 1)
		{
			$this->ingredientServices->deleteItem(null, $childItemId);
		}
		else
		{
			$this->textSectionServices->deleteItem(null, $childItemId);
		}
	}

	function getIngredients($recipeId)
	{
		return $this->ingredientServices->getIngredients($recipeId);
	}

	function addIngredients($item)
	{
		$this->ingredientServices->addItems($item->itemId, $item->ingredients);
	}

	function modifyIngredients($item)
	{
		$this->ingredientServices->modifyItems($item->itemId, $item->ingredients);
	}

	/**
	*
	*/
	function getTextSections($recipeId)
	{
		return $this->textSectionServices->getTextSections($recipeId);
	}

	function addTextSections($item)
	{
		$this->textSectionServices->addItems($item->itemId, $item->textSections);
	}

	function modifyTextSections($item)
	{
		$this->textSectionServices->modifyItems($item->itemId, $item->textSections);
	}

	function searchExpressionInMultipleFieldsResult($userId, $searchKey, $value, $navigationMode)
	{
		$fields = array();
		$whereExpression = '';
		$fieldsExpression = '';
		$queryString = '';

		switch($searchKey)
		{
		case 'ingredients':
			$fields[0] = $this->queries['tableIngredients'].'.amount';
			$fields[1] = $this->queries['tableIngredients'].'.name';
			$fields[2] = $this->queries['tableIngredients'].'.description';
			if ($navigationMode != 'public')
			{
				$queryString = $this->queries['getRecipesSearchInIngredientsOfUser'];
			}
			else
			{
				$queryString = $this->queries['getRecipesSearchInIngredientsOfUserOrPublic'];
			}
			break;
		case 'textsections':
			$fields[0] = $this->queries['tableTextSections'].'.name';
			$fields[1] = $this->queries['tableTextSections'].'.description';
			if ($navigationMode != 'public')
			{
				$queryString = $this->queries['getRecipesSearchInTextSectionsOfUser'];
			}
			else
			{
				$queryString = $this->queries['getRecipesSearchInTextSectionsOfUserOrPublic'];
			}
			break;
		}

		// Construct the where expression
		for ($i = 0; $i < count($fields); $i++)
		{
			$whereExpression .= $fields[$i] ." LIKE '%".$value."%'";
			$whereExpression .= ($i < (count($fields) - 1)) ? ' OR ' : '';

			$fieldsExpression .= $fields[$i];
			$fieldsExpression .= ($i < (count($fields) - 1)) ? ', ' : '';
		}

		$query = sprintf($queryString,
						 $whereExpression,
						 $userId);

		$result = $this->db->Execute ($query) or die
				("Operations. Search multiple fields in ingredients/text sections " . $this->db->ErrorMsg() .
			" " . $query);

		return $result;
	}

	function deleteAllItemsForUser($userId, $recipeIds)
	{
		for ($i = 0; $i < count($recipeIds); $i++)
		{
			$this->deleteItems($userId, $recipeIds[$i]);
		}
	}
}
?>
