<?php

require_once('framework/model/ItemFactory.php');
require_once('plugins/recipes/model/IngredientFactory.php');
require_once('plugins/recipes/model/TextSectionFactory.php');
require_once('plugins/recipes/model/Recipe.php');

require_class('RecipeRequestCast', 'plugins/recipes/util/request/RecipeRequestCast.php');
require_class('ClassHelper', 'framework/util/ClassHelper.class.php');

/**
 * The RecipeFactory
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Thomas Sterren
 * @package org.brim-project.plugins.recipes
 * @subpackage model
 * @filesource
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class RecipeFactory extends ItemFactory
{
	var $operations;

	var $linkFactory;
	var $ingredientFactory;
	var $textSectionFactory;

	/**
	 * Default constructor
	 */
	function RecipeFactory()
	{
		parent::ItemFactory();
		$this->requestCast = new RecipeRequestCast("Recipe");
		$this->operations = null;
		$this->setIngredientFactory(new IngredientFactory());
		$this->setTextSectionFactory(new TextSectionFactory());
		$this->setLinkFactory(new LinkFactory());
	}

	function setServices(&$operations)
	{
		$this->operations = $operations;
	}

	function setIngredientFactory(&$theIngredientFactory)
	{
		$this->ingredientFactory = $theIngredientFactory;
	}

	function setTextSectionFactory(&$theTextSectionFactory)
	{
		$this->textSectionFactory = $theTextSectionFactory;
	}

	function setLinkFactory(&$theLinkFactory)
	{
		$this->linkFactory = $theLinkFactory;
	}

	/**
	 * Returns the type of this specific item
	 * @return string the type of this specific item:
	 * <code>Recipe</code>
	 */
	function getType()
	{
		return "Recipe";
	}

	function requestToItem()
	{
		$itemId = $this->getFromPost('itemId', 0);
		$owner = $_SESSION['brimUsername'];
		$parentId = $this->getFromPost('parentId', 0);
		$isParent = $this->getFromPost('isParent', 0);
		$name =
			$this->stringUtils->gpcStripSlashes($_POST['name']);
		$description = $this->getFromPost('description', null);
		$visibility = $this->getFromPost('visibility', 'private');
		$category = $this->getFromPost('category', null);
		$isDeleted = $this->getFromPost('isDeleted', 0);
		$when_created = $this->getFromPost('when_created', null);
		$when_modified = $this->getFromPost('when_modified', null);
		$when_visisted = $this->getFromPost('when_visited', null);
		$guid = $this->createGUID();
		$vegetarian = $this->getFromPost('vegetarian', '');
		$servings = $this->getFromPost('servings', '');
		$complexity = $this->getFromPost('complexity', '');
		$duration = $this->getFromPost('duration', '');
		$costs = $this->getFromPost('costs', '');
		$country = $this->getFromPost('country', '');
		$author = $this->getFromPost('author', '');
		$url = $this->getFromPost('url', '');
		$nutrition = $this->getFromPost('nutrition', '');
		$copyright = $this->getFromPost('copyright', '');
		$userField1 = $this->getFromPost('user_field1', '');
		$userField2 = $this->getFromPost('user_field2', '');
		$userField3 = $this->getFromPost('user_field3', '');
		$userField4 = $this->getFromPost('user_field4', '');
		$userField5 = $this->getFromPost('user_field5', '');

		$item = new Recipe($itemId,
						   $owner,
						   $parentId,
						   $isParent,
						   $name,
						   $description,
						   $visibility,
						   $category,
						   $isDeleted,
						   $when_created,
						   $when_modified,
						   $guid,
						   $vegetarian,
						   $servings,
						   $complexity,
						   $duration,
						   $costs,
						   $country,
						   $author,
						   $url,
						   $nutrition,
						   $copyright,
						   $userField1,
						   $userField2,
						   $userField3,
						   $userField4,
						   $userField5);

		$item->ingredients = $this->requestToIngredients();
		$item->textSections = $this->requestToTextSections();
		$item->links = $this->requestToLinks();

		return $item;
	}

	/**
	 * Factory method: Returns a database result into an item
	 *
	 * @param object result the result retrieved from the database
	 * @return array the items constructed from the database resultset
	 */
	function resultsetToItems($result)
	{
		$items = array();

		while (!$result->EOF)
		{
			$item = new Recipe(
				$result->fields['item_id'],
				trim ($result->fields['owner']),
				$result->fields['parent_id'],
				$result->fields['is_parent'],
				trim($this->stringUtils->gpcStripSlashes
					($result->fields['name'])),
				trim ($this->stringUtils->gpcStripSlashes
					($result->fields['description'])),
				trim ($result->fields['visibility']),
				trim ($result->fields['category']),
				$result->fields['is_deleted'],
				$result->fields['when_created'],
				$result->fields['when_modified'],
				$result->fields['guid'],
				trim($result->fields['is_vegetarian']),
				trim($result->fields['servings']),
				trim($result->fields['complexity']),
				trim($result->fields['duration']),
				trim($result->fields['costs']),
				trim($result->fields['country']),
				trim($result->fields['author']),
				trim($result->fields['url']),
				trim($result->fields['nutrition']),
				trim($result->fields['copyright']),
				trim($result->fields['user_field1']),
				trim($result->fields['user_field2']),
				trim($result->fields['user_field3']),
				trim($result->fields['user_field4']),
				trim($result->fields['user_field5']));

			$this->addIngredients($item);
			$this->addTextSections($item);
			$this->addLinks($item);
			$this->addImageLinks($item);

			$items[] = $item;

			$result->MoveNext();
		}
		return $items;
	}

	/**
	 * Returns an empty item
	 * @return object an empty item, all values
	 * set to -null-
	 */
	function getEmptyItem()
	{
		$item = new Recipe(null, null, null, null,
			 			   null, null, null, null,
			 			   null, null, null, null,
			 			   null, null, null, null,
			 			   null, null, null, null,
			 			   null, null, null, null,
			 			   null, null, null);
		return $item;
	}

	/**
	 * Generates a GUID (Global Unique Identifier). Used to identify a
	 * record in a table.
	 */
	function createGUID()
	{
		return md5(uniqid(rand()));
	}

	/**
	* private function
	*/
	function addIngredients(&$item)
	{
		$item->ingredients = $this->getIngredients($item->getItemId());
	}

	/**
	* private function
	*/
	function addTextSections(&$item)
	{
		$item->textSections = $this->getTextSections($item->getItemId());
	}

	/**
	* private function
	*/
	function addLinks(&$item)
	{
		$item->orders = $this->getLinks($item->getItemId());
	}

	function addImageLinks(&$item)
	{
		$item->imageLinks = $this->getImageLinks($item->getItemId());
	}

	function getIngredients($itemId)
	{
		return $this->operations->getIngredients($itemId);
	}

	function getTextSections($itemId)
	{
		return $this->operations->getTextSections($itemId);
	}

	function getLinks($itemId)
	{
		return $this->operations->getLinks($itemId);
	}

	function getImageLinks($itemId)
	{
		return $this->operations->getImageLinks($itemId);
	}

	function requestToIngredients()
	{
		return $this->ingredientFactory->requestToIngredients();
	}

	function requestToTextSections()
	{
		return $this->textSectionFactory->requestToTextSections();
	}

	function requestToLinks()
	{
		return $this->linkFactory->requestToLinks();
	}

	function getFromAnywhere($value, $default)
	{
		if (isset ($_GET[$value]))
		{
			return $this->stringUtils->gpcStripSlashes ($_GET[$value]);
		}
		else if (isset ($_POST[$value]))
		{
			return $this->stringUtils->gpcStripSlashes ($_POST[$value]);
		}
		else
		{
			return $default;
		}
	}

	function prepareFolderForAddPre()
	{
		$item = $this->getEmptyItem();

		$item->parentId = $this->getFromAnywhere('parentId', 0);
		$item->isParent = 1;

		return $item;
	}
}
?>