<?php
require_once ('framework/model/PreferenceServices.php');

/**
 * The Recipe preferences.
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Thomas Sterren
 * @package org.brim-project.plugins.recipes
 * @subpackage model
 * @filesource
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class RecipePreferences extends PreferenceServices
{
	var $OVERLIB = 'recipeOverlib';
	var $NBROFINGRDISP = 'nbrOfIngrDisp';
	var $NBROFTEXTSECTIONSDISP = 'nbrOfTextSectionsDisp';
	var $USERFIELDNAME = 'recipeUserFieldName';
	var $SERVERIMAGEPATH = 'recipeServerImagePath';

	function RecipePreferences()
	{
		parent::PreferenceServices();
	}

	function getAllPreferences($loginName)
	{
		$result = array();

		$result[$this->OVERLIB] 			  = $this->getOverlib($loginName);
		$result[$this->NBROFINGRDISP]		  = $this->getNumberOfIngredientsToDisplay($loginName);
		$result[$this->NBROFTEXTSECTIONSDISP] = $this->getNumberOfTextSectionsToDisplay($loginName);
		$result[$this->SERVERIMAGEPATH] 	  = $this->getServerImagePath($loginName);

		for ($i = 1; $i <= 5; $i++)
		{
			$result[$this->USERFIELDNAME.$i] = $this->getUserFieldName($i, $loginName);
		}

		return $result;
	}

	function getOverlib($loginName = null)
	{
		if (!isset($loginName))
		{
			$loginName = $this->getUserName();
		}

		$result = $this->getPreferenceValue($loginName, $this->OVERLIB);

		// Set default if not set
		if (!isset($result))
		{
			$result = '1';
		}
		return $result;

	}

	function getNumberOfIngredientsToDisplay($loginName = null)
	{
		if (!isset($loginName))
		{
			$loginName = $this->getUserName();
		}

		$result = $this->getPreferenceValue($loginName, $this->NBROFINGRDISP);

		// Set default if not set
		if (!isset($result) ||
			empty($result))			// Should not be '', '0' nor 0
		{
			$result = '10';
		}
		return $result;

	}

	function getNumberOfTextSectionsToDisplay($loginName = null)
	{
		if (!isset($loginName))
		{
			$loginName = $this->getUserName();
		}

		$result = $this->getPreferenceValue($loginName, $this->NBROFTEXTSECTIONSDISP);

		// Set default if not set
		if (!isset($result)
			|| empty($result))		// Should not be '', '0' nor 0
		{
			$result = '3';
		}
		return $result;

	}

	function getUserFieldName($userFieldId, $loginName = null)
	{
		if (!isset($loginName))
		{
			$loginName = $this->getUserName();
		}

		return $this->getPreferenceValue($loginName, $this->USERFIELDNAME.$userFieldId);
	}

	function getServerImagePath($loginName = null)
	{
		if (!isset($loginName))
		{
			$loginName = $this->getUserName();
		}

		$result = $this->getPreferenceValue($loginName, $this->SERVERIMAGEPATH);

		// Set default if not set
		if (!isset($result))
		{
			$result = './';
		}
		return $result;

	}

	function setPreference ($userId, $name, $value)
	{
		// Check first if there is already an entry
		$prefId = $this->getPreferenceId($userId, $name);

		if (!isset($prefId) || empty($prefId))
		{
			// If not add a new item
			$preference = $this->itemFactory->getPreference
				($userId, $name, $value);
			$this->addItem ($userId, $preference);
		}
		else
		{
			// Modify the existing item
			$pref = $this->getItem ($userId, $prefId);
			$pref->value = $value;
			$this->modifyItem ($userId, $pref);
		}
	}
}
?>