<?php

require_once('framework/model/ItemFactory.php');
require_once('plugins/recipes/model/TextSection.php');

require_class('TextSectionRequestCast', 'plugins/recipes/util/request/TextSectionRequestCast.php');
require_class('ClassHelper', 'framework/util/ClassHelper.class.php');

/**
 * The TextSectionFactory
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Thomas Sterren
 * @package org.brim-project.plugins.recipes
 * @subpackage model
 * @filesource
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class TextSectionFactory extends ItemFactory
{
	/**
	 * Default constructor
	 */
	function TextSectionFactory()
	{
		parent::ItemFactory();
		$this->requestCast = new TextSectionRequestCast("TextSection");
	}

	/**
	 * Returns the type of this specific item
	 * @return string the type of this specific item:
	 * <code>Text section</code>
	 */
	function getType()
	{
		return "TextSection";
	}

	function requestToItem()
	{
		$itemId 		= $this->getFromPost('itemId', 0);
		$deleted 		= $this->getFromPost('isDeleted', 0);
		$whenCreated 	= $this->getFromPost('when_created', null);
		$whenModified 	= $this->getFromPost('when_modified', null);
		$guid 			= $this->getFromPost('guid', $this->createGUID());
		$name			= $this->getFromPost('name', null);
		$description	= $this->getFromPost('description', null);

		$item = new TextSection($itemId,
								$deleted,
								$whenCreated,
								$whenModified,
								$guid,
								$name,
								$description);

		return $item;
	}

	/**
	 * Factory method: Returns a database result into an item
	 *
	 * @param object result the result retrieved from the database
	 * @return array the items constructed from the database resultset
	 */
	function resultsetToItems($result)
	{
		$items = array();

		while (!$result->EOF)
		{
			$item = new TextSection(
				$result->fields['item_id'],
				$result->fields['is_deleted'],
				$result->fields['when_created'],
				$result->fields['when_modified'],
				$result->fields['guid'],
				trim($this->stringUtils->gpcStripSlashes
					($result->fields['name'])),
				trim ($this->stringUtils->gpcStripSlashes
					($result->fields['description'])));

			$items[] = $item;

			$result->MoveNext();
		}
		return $items;
	}

	/**
	 * Returns an empty item
	 * @return object an empty item, all values
	 * set to -null-
	 */
	function getEmptyItem()
	{
		$item = new TextSection(null, null, null, null,
			 					null, null, null);
		return $item;
	}

	/**
	 * Generates a GUID (Global Unique Identifier). Used to identify a
	 * record in a table.
	 */
	function createGUID()
	{
		return md5(uniqid(rand()));
	}

	function requestToTextSections()
	{
		$nbrOfTextSections = $this->getFromPost('nbrOfTextSections', 0);
		$textSections = array();

		for ($i = 0; $i < $nbrOfTextSections; $i++)
		{
			$itemId			= $this->getFromPost('textSectionItemId'.$i, 0);
			$deleted		= $this->getFromPost('textSectionIsDeleted', 0);
			$whenCreated	= $this->getFromPost('textSectionWhenCreated', null);
			$whenModified	= $this->getFromPost('textSectionWhenModified', null);
			$guid			= $this->getFromPost('textSectionGUID', $this->createGUID());
			$name			= $this->getFromPost('textSectionName'.$i, null);
			$description	= $this->getFromPost('textSectionDescription'.$i, null);

			$item = new TextSection($itemId,
									$deleted,
									$whenCreated,
									$whenModified,
									$guid,
									$name,
									$description);

			if ($item->isValid())
			{
				$textSections[] = $item;
			}
		}
		return $textSections;
	}
}
?>