<?php

require_once 'framework/Installer.php';

/**
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Thomas Sterren
 * @package org.brim-project.plugins.recipes
 * @subpackage model
 * @filesource
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class TextSectionInstaller extends Installer
{
	function TextSectionInstaller($engine, $db)
	{
		$this->tableName = 'brim_recipes_textsections';
		parent::Installer($engine, $db);
	}

	function install()
	{
		if (!$this->findTable())
		{
			$dbFile = 'plugins/recipes/sql/create.';
			$dbFile .= $this->engine;
			$dbFile .= '.'.$this->tableName.'.sql';
			$this->createTable($dbFile);
			$this->createStandardIndex();
		}
		else
		{
			if (!$this->isTableUpToDate())
			{
				die('Table '.$this->tableName.' found but does not appear to be up-to-date and no upgrade procedure is found!');
			}
		}
	}

	function isTableUpToDate()
	{
		if (!$this->findTable())
		{
			return false;
		}

		$columnNames =
			$this->db->MetaColumnNames($this->tableName, true);

		$this->tableUpToDate =
			(count($columnNames) == 7 &&
			$columnNames[0] == 'item_id' &&
			$columnNames[1] == 'is_deleted' &&
			$columnNames[2] == 'when_created' &&
			$columnNames[3] == 'when_modified' &&
			$columnNames[4] == 'guid' &&
			$columnNames[5] == 'name' &&
			$columnNames[6] == 'description');

		return $this->tableUpToDate;
	}

	function getColumnsCount($tableName)
	{
		$columnNames =
			$this->db->MetaColumnNames($this->tableName, true);

		return count($columnNames);
	}

	function getRecordCount()
	{
		$count = 0;

		$query = 'SELECT * FROM '.$this->tableName;

		$result = $this->db->Execute($query) or
			die("::getRecordCount: " .
		$this->db->ErrorMsg() . " " . $query. '<br />');

		$count = $result->RecordCount();

		return $count;
	}

	function createStandardIndex()
	{
		$indexName = $this->tableName . '_index';

		$primaryKeys = $this->db->MetaIndexes($this->tableName);

		if (!array_key_exists($indexName, $primaryKeys))
		{
			include 'framework/configuration/databaseConfiguration.php';
			$query = 'CREATE INDEX '.$this->tableName.'_index ';
			$query .= 'ON '.$this->tableName.' ';
			if ($engine == 'postgres')
			{
				$query .= '(name)';
			}
			else
			{
				$query .= '(`name`(32))';
			}

			$this->db->Execute($query) or die($this->db->ErrorMsg());
		}
	}

	function installSampleData()
	{
		// Only add sample data if the table is empty
		if ($this->findTable() && 0 == $this->getRecordCount())
		{
			$sampleDataFile = 'plugins/recipes/sql/sampledata.';
			$sampleDataFile .= $this->engine;
			$sampleDataFile .= '.'.$this->tableName.'.sql';
			$this->addSampleData($sampleDataFile);
		}
	}

	/**
	 * Adds sample data based on the definitions as found
	 * in the specified filename
	 *
	 * @param string queryFileName the filename of the
	 * file that contains the data definitions
	 */
	function addSampleData($queryFileName)
	{
		$file = file($queryFileName);

		$query = "";
		foreach($file as $sql_line)
		{
			if(trim($sql_line) != "" && strpos($sql_line, "--") === false)
			{
				$query .= $sql_line;
				if(preg_match("/;\s*$/", $sql_line))
				{
					$this->db->Execute($query) or
						die($this->db->ErrorMsg());

					$query = "";
				}
			}
  		}
	}
}
?>