<?php
require_once('plugins/recipes/model/TextSection.php');
require_once('plugins/recipes/model/TextSectionFactory.php');
require_once('framework/model/Services.php');

/**
 * Services for a text section
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Thomas Sterren
 * @package org.brim-project.plugins.recipes
 * @subpackage model
 * @filesource
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class TextSectionServices extends Services
{
	var $linkServices;

	/**
	 * Default constructor
	 */
	function TextSectionServices()
	{
		parent::Services();
		$this->itemFactory = null;
		$this->linkServices = null;

		include ('plugins/recipes/sql/textSectionQueries.php');
		$this->queries = $queries;
	}

	function setLinkServices(&$operations)
	{
		$this->linkServices = $operations;
	}

	function setTextSectionFactory(&$theTextSectionFactory)
	{
		$this->itemFactory = $theTextSectionFactory;
	}

	/**
	 * Adds information for a text section
	 *
	 * @param integer userId the identifier for the user
	 * @param object item the text section to be added
	 *
     * @return integer last know id. This is the id of the recipe
	 * that was newly inserted and for which an id has automatically
	 * been assigned.
	 */
	function addItem($userId, $item, $linkNewItem = true)
	{
		$now = date("Y-m-d H:i:s");

		if (!isset($item->guid))
		{
			$item->guid = $this->itemFactory->createGUID();
		}

		// execute the query
		$query = sprintf($this->queries['addItem'],
			$now,
			$item->guid,
			addslashes(trim($item->name)),
			addslashes(trim($item->description)));

		$this->db->Execute($query) or
				die ("Could not add text section.".
				$this->db->ErrorMsg () . " " . $query . '<br />');

		// fetch the last known id
		// todo this is generic code and is candidate to move to the base Services class
		$query = $this->queries['lastItemInsertId'];
		$result = $this->db->Execute($query) or
			die ("Could not retrieve last insert id for text section. ".
			$this->db->ErrorMsg () . " " . $query . '<br />');

		if ($linkNewItem)
		{
			// Put an entry in the orders table too
			$itemIds = array();

			$itemIds[] = $result->fields[0];

			$this->linkServices->addTextSectionIds($userId, $itemIds);
		}

        return $result->fields[0];
	}

	function addItems($recipeId, $items)
	{
		$itemIds = array();

		for ($i = 0; $i < count($items); $i++)
		{
			$itemIds[] = $this->addItem(null, $items[$i], false);
		}

		$this->linkServices->addTextSectionIds($recipeId, $itemIds);
	}

	/**
	 * Modifies te recipe
	 *
 	 * @param integer userId the identifier for the user who modifies a recipe
	 * @param object item the modified recipe
	 */
	function modifyItem($userId, $item)
	{
		//die ("RecipeService::modifyItem ".bprint_r($item));
		$now = date ("Y-m-d H:i:s");

		$query = sprintf ($this->queries['modifyItem'],
			$item->isDeleted,
			$now,							// when_modified
			addslashes($item->name),
			addslashes($item->description),
			$item->itemId);

		$this->db->Execute($query)
			or die ("Error modifying item: " .
	 		$this->db->ErrorMsg() . " " . $query . '<br />');
	}

	function modifyItems($recipeId, $items)
	{
		$oldTextSectionCount = $this->getTextSectionCount($recipeId);

		for ($i = 0; $i < count($items); $i++)
		{
			if ($items[$i]->itemId != 0)
			{
				$this->modifyItem(null, $items[$i]);
			}
			else
			{
				// We have a new text section. Add them
				$this->addItem($recipeId, $items[$i], true);
			}
		}

		if ($oldTextSectionCount > count($items))
		{
			// Remove messy text sections
			$this->removeMessyTextSections($recipeId, $oldTextSectionCount - count($items));
		}
	}

	function deleteItem($userId, $itemId)
	{
		$item = $this->getItem($userId, $itemId);

		if (isset($item))
		{
			// now delete the specific item
			$query = sprintf($this->queries['deleteItem'], $itemId);

			$result = $this->db->Execute($query) or
				die("RecipeServices::DeleteItem: " .
				$this->db->ErrorMsg() . " " . $query. '<br />');
		}
	}

	/**
	*
	*/
	function getTextSections($recipeId)
	{
		return $this->getItems($recipeId);
	}

	function getTextSectionCount($recipeId)
	{
		$query = sprintf($this->queries ['getTextSectionCount'],
						 $recipeId);

		$result = $this->db->Execute ($query) or die
				("Operations. getTextSectionCount " . $this->db->ErrorMsg () .
					" " . $query);

        return (isset($result->fields[0])) ? $result->fields[0] : 0;
	}

	/**
	* Deletes the last text section, which are too much
	*/
	function removeMessyTextSections($recipeId, $messyTextSectionCount)
	{
		$this->linkServices->removeMessyTextSections($recipeId, $messyTextSectionCount);
	}
}
?>
