<?php
/*
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Thomas Sterren
 * @package org.brim-project.plugins.recipes
 * @subpackage util.request
 * @filesource
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */

require_once('framework/util/request/RequestCastConfiguration.class.php');

/**
 * The Request cast configuration class knows about the inner details
 * of a class that needs to be casted.
 */
class IngredientRequestCastConfiguration extends RequestCastConfiguration
{
	/**
  	 * Default constructor.
 	 */
	function IngredientRequestCastConfiguration()
	{

	}

	/**
	 * Returns the configuration mapping between a POST and an Object.
	 * (may be refactored as to use an XML config file).
	 *
	 *
	 * @return array
	 * This array is composed like this :
	 * - key : numeric
	 * - values :
	 * - name of the field
	 * - minimal required (1 means mandatory, more than 1 is for arrays)
	 * - maximal required (more than 1 is for arrays)
	 * - type, can be string (everything), alpha, digit, mail.
	 * - error message if no match on min/max/type
	 * - default value
	 */
	function getFieldMapping($className)
	{
		switch(strtolower($className))
		{
			case strtolower("Ingredient"):
				$config[] = array(
					"name" => "itemId",
					"field" => "itemId",
					"min" => 0,
					"max" => 1,
					"type" => "digit",
					"message" => "",
					"default" => 0);

				$config[] = array(
					"name" => "type",
					"field" => "type",
					"min" => 0,
					"max" => 1,
					"type" => "string",
					"message" => "",
					"default" => 'Ingredient');

				$config[] = array(
					"name" => "when_created",
					"field" => "when_created",
					"min" => 0,
					"max" => 1,
					"type" => "string",
					"message" => "",
					"default" => null);

				$config[] = array(
					"name" => "when_modified",
					"field" => "when_modified",
					"min" => 0,
					"max" => 1,
					"type" => "string",
					"message" => "",
					"default" => null);

				$config[] = array(
					"name" => "guid",
					"field" => "guid",
					"min" => 0,
					"max" => 1,
					"type" => "string",
					"message" => "",
					"default" => null);

				$config[] = array(
					"name" => "amount",
					"field" => "amount",
					"min" => 0,
					"max" => 1,
					"type" => "string",
					"message" => "",
					"default" => null);

				$config[] = array(
					"name" => "name",
					"field" => "name",
					"min" => 1,
					"max" => 1,
					"type" => "string",
					"message" => 'ingredientNameMissing',
					"default" => null);

				$config[] = array(
					"name" => "description",
					"field" => "description",
					"min" => 0,
					"max" => 1,
					"type" => "string",
					"message" => "",
					"default" => null);

				return $config;
				break;
		}
	}
}
?>