<?php

require_once('framework/util/StringUtils.php');
require_once('framework/view/TreeDelegate.php');

/**
 * Used in combination with the Tree class
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Thomas Sterren
 * @package org.brim-project.plugins.recipes
 * @subpackage view
 * @filesource
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class RecipeLineBasedTreeDelegate extends TreeDelegate
{
	/**
	 * Have we already drawn a header?
	 */
	var $headersDrawn;

	function RecipeLineBasedTreeDelegate($theConfiguration)
	{
		parent::TreeDelegate($theConfiguration);
		$this->headersDrawn = false;
	}

	/**
	 * Builds up html code to display the root of the tree
	 * @private
	 *
	 * @param object item the item that is the root of the tree
	 */
	function showRoot($item, $tree)
	{

		if (isset($item) && $item->itemId != 0)
		{
			$resultString = '<h2>'.$item->name.'</h2>';
			$resultString .= '<a href="'.$this->configuration['callback'];
			$resultString .= '?plugin='.$this->configuration['pluginName'];
			$resultString .= '&action=show';
			$resultString .= '&parentId='.$item->parentId;
			$resultString .= '">';
			$resultString .= $this->configuration['icons']['up'];
			$resultString .= '</a><br />';
		}
		else
		{
			$resultString = '';
		}
		return $resultString;
	}

	/**
	 * If the specified item is a folder, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean isExpanded whether this folder is expanded (i.e. do the
	 * children of this folder need to be displayed as well?)
	 * @param object tree the tree that uses this class as delegate
	 * @return string the string for this folder
	 */
	function drawFolder($item, $isExpanded, $tree, $indentLevel)
	{
		$resultString = '';
		if ($item->owner == $_SESSION['brimUsername'])
       	{
			$resultString .= '<a href="';
			$resultString .= $this->configuration['callback'];
			$resultString .= '?plugin='.$this->configuration['pluginName'];
	        $resultString .= '&action=modifyFolder';
	        $resultString .= '&itemId='.$item->itemId;
	        $resultString .= '&parentId='.$tree->root->itemId;
	        $resultString .= '">';
			$resultString .= $this->configuration['icons']['folder_closed'];
			$resultString .= '</a>';
       	}
       	else 
       	{
			$resultString .= $this->configuration['icons']['folder_closed'];
       	}
		$resultString .= '<a href="';
		$resultString .= $this->configuration['callback'];
		$resultString .= '?plugin='.$this->configuration['pluginName'];
		$resultString .= '&action=show';
		$resultString .= '&parentId='.$item->itemId;
		$resultString .=  '">';
		$resultString .= $item->name;
		$resultString .= '</a>';

		$resultString .= '<br />';
		return $resultString;
	}

	function drawLinesHeader($parentId)
	{
		$resultString = '<td colspan="8"></td></tr><tr>';
		$resultString .= '<td>&nbsp;</td>';
		$resultString .= '<td>&nbsp;</td>';

		$resultString .= '<td><div style="white-space:nowrap;"><b>'.$this->configuration['dictionary']['name'];
		$resultString .= $this->sortArrows ('name', $parentId);
		$resultString .= '</b></div></td>';

		$resultString .= '<td><div style="white-space:nowrap;"><b>'.$this->configuration['dictionary']['duration'];
		$resultString .= $this->sortArrows ('duration', $parentId);
		$resultString .= '</b></div></td>';

		$resultString .= '<td><div style="white-space:nowrap;"><b>'.$this->configuration['dictionary']['costs'];
		$resultString .= $this->sortArrows ('costs', $parentId);
		$resultString .= '</b></div></td>';

		$resultString .= '<td><div style="white-space:nowrap;"><b>'.$this->configuration['dictionary']['vegetarian'];
		$resultString .= $this->sortArrows ('is_vegetarian', $parentId);
		$resultString .= '</b></div></td>';

		$resultString .= '<td><div style="white-space:nowrap;"><b>'.$this->configuration['dictionary']['copyright'];
		$resultString .= $this->sortArrows ('copyright', $parentId);
		$resultString .= '</b></div></td>';

		$resultString .= '</tr><tr class="odd">';
		return $resultString;
	}
	/**
	 * If the specified item is a node, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean lastNode whether this node is the last one
	 * @return string the string for this node
	 */
	function drawNode($item, $lastNode, $tree, $indentLevel)
	{
		$pluginName = 'recipes';

		if ($this->headersDrawn)
		{
			$resultString = '';
		}
		else
		{
			$resultString = $this->drawLinesHeader ($item->parentId);
			$this->headersDrawn = true;
		}
		// header with two icons and overlib popup
		$resultString .= '<td width="20" align="right">';
		if ($item->owner == $_SESSION['brimUsername'])
       	{
			$resultString .= '<a href="'.$this->configuration['callback'];
	        $resultString .= '?plugin='.$this->configuration['pluginName'];
	        $resultString .= '&action=modify&itemId='.$item->itemId;
	        $resultString .= '&parentId='.$item->parentId.'">';
			$resultString .= $this->configuration['icons']['edit'].'</a>';
       	}
       	else 
       	{
			$resultString .= $this->configuration['icons']['edit'];	
       	}
		$resultString .= '</td>';

		$resultString .= '<td width="20" align="right">';
		if ($item->owner == $_SESSION['brimUsername'])
       	{
			$resultString .= '<a href="'.$this->configuration['callback'];
			$resultString .= '?plugin='.$this->configuration['pluginName'];
			$resultString .= '&action=deleteItemPost';
			$resultString .= '&itemId='.$item->itemId.'" ';
			// delete confirmation
			$resultString .= 'onclick="javascript:return confirm (\'';
			$resultString .= $this->configuration['dictionary']['confirm_delete'];
			$resultString .= '\');" ';
			$resultString .= '>'.$this->configuration['icons']['delete'].'</a>';
       	}
       	else 
       	{
			$resultString .= $this->configuration['icons']['delete'];
       	}
		$resultString .= '</td>';

		$resultString .= '<td>';
		$resultString .= '<a href="'.$this->configuration['callback'];
		$resultString .= '?plugin='.$this->configuration['pluginName'];
		$resultString .= '&action=showItem';
		$resultString .= '&itemId='.$item->itemId;
		$resultString .= '&parentId='.$item->parentId;
		$resultString .= '" ';
		if ($this->configuration['overlib'])
		{
			$popUp = $this->overlibPopup ($item);
			$resultString .= $this->overLib ($item->name, $popUp);
		}
		$resultString .= '>';
		$resultString .= '<b>' . $item->name . '</b></a>';
		$resultString .= '</td>';

		$resultString .= '<td>';
		if ($item->duration != null)
		{
			$resultString .= $item->duration;
		}
		else
		{
			$resultString .= '&nbsp;';
		}
		$resultString .= '</td>';

		$resultString .= '<td>';
		if ($item->costs != null)
		{
			$resultString .= $item->costs;
		}
		else
		{
			$resultString .= '&nbsp;';
		}
		$resultString .= '</td>';

		$resultString .= '<td>';
		if ($item->vegetarian == 1)
		{
			$resultString .= $this->configuration['dictionary']['yes'];
		}
		else
		{
			$resultString .= $this->configuration['dictionary']['no'];
		}
		$resultString .= '</td>';

		$resultString .= '<td>';
		if ($item->copyright != null)
		{
			$resultString .= $item->copyright;
		}
		else
		{
			$resultString .= '&nbsp;';
		}
		$resultString .= '</td>';

		return $resultString;
	}

	function overlibPopup ($item)
	{
		if ($this->configuration['overlib'])
		{
			$popUp  = '<table cellspacing=2>';
			if ($item->vegetarian != null)
			{
				$popUp .= "<tr>";
				$popUp .= "<td><b>".$this->configuration['dictionary']['vegetarian'].":</b></td>";
				$popUp .= "<td>";
				if ($item->vegetarian == 1)
				{
					$popUp .= $this->configuration['dictionary']['yes'];
				}
				else
				{
					$popUp .= $this->configuration['dictionary']['no'];
				}
				$popUp .= "</td>";
				$popUp .= "</tr>";
			}
			if ($item->servings != null)
			{
				$popUp .= "<tr>";
				$popUp .= "<td><b>".$this->configuration['dictionary']['servings'].":</b></td>";
				$popUp .= "<td>".$item->servings."</td>";
				$popUp .= "</tr>";
			}
			if ($item->complexity != null)
			{
				$popUp .= "<tr>";
				$popUp .= "<td><b>".$this->configuration['dictionary']['complexity'].":</b></td>";
				$popUp .= "<td>".$item->complexity."</td>";
				$popUp .= "</tr>";
			}
			if ($item->duration != null)
			{
				$popUp .= "<tr>";
				$popUp .= "<td><b>".$this->configuration['dictionary']['duration'].":</b></td>";
				$popUp .= "<td>".$item->duration."</td>";
				$popUp .= "</tr>";
			}
			if ($item->costs != null)
			{
				$popUp .= "<tr>";
				$popUp .= "<td><b>".$this->configuration['dictionary']['costs'].":</b></td>";
				$popUp .= "<td>".$item->costs."</td>";
				$popUp .= "</tr>";
			}
			if ($item->country != null)
			{
				$popUp .= "<tr>";
				$popUp .= "<td><b>".$this->configuration['dictionary']['country'].":</b></td>";
				$popUp .= "<td>".$item->country."</td>";
				$popUp .= "</tr>";
			}
			if ($item->author != null)
			{
				$popUp .= "<tr>";
				$popUp .= "<td><b>".$this->configuration['dictionary']['author'].":</b></td>";
				$popUp .= "<td>".$item->author."</td>";
				$popUp .= "</tr>";
			}
			if ($item->url != null)
			{
				$popUp .= "<tr>";
				$popUp .= "<td><b>".$this->configuration['dictionary']['url'].":</b></td>";
				$popUp .= "<td>".$item->url."</td>";
				$popUp .= "</tr>";
			}
			if ($item->nutrition != null)
			{
				$popUp .= "<tr>";
				$popUp .= "<td><b>".$this->configuration['dictionary']['nutrition'].":</b></td>";
				$popUp .= "<td>".$item->nutrition."</td>";
				$popUp .= "</tr>";
			}
			if ($item->copyright != null)
			{
				$popUp .= "<tr>";
				$popUp .= "<td><b>".$this->configuration['dictionary']['copyright'].":</b></td>";
				$popUp .= "<td>".$item->copyright."</td>";
				$popUp .= "</tr>";
			}
			for ($userFieldId = 1; $userFieldId <= 5; $userFieldId++)
			{
				$userField = '';
				$attributeName = 'user_field'.$userFieldId;

				if (isset($this->configuration['recipeUserFieldName'.$userFieldId]))
				{
					$userField = $this->configuration['recipeUserFieldName'.$userFieldId];
				}

				if (!empty($userField) &&
					!empty($item->$attributeName))
				{
					$popUp .= "<tr>";
					$popUp .= "<td><b>".$userField.":</b></td>";
					$popUp .= "<td>".$item->$attributeName."</td>";
					$popUp .= "</tr>";
				}
			}
			if ($item->description != null)
			{
				$popUp .= "<tr>";
				$popUp .= '<td colspan="2">'.$item->description."</td>";
				$popUp .= "</tr>";
			}
			$popUp .= "</table>";
		}
		return $popUp;
	}

	/**
	 * Returns the overlib javascript
	 * @param string title the title of the popup
	 * @param string text the text of the popup
	 */
	function overLib($title, $text)
	{
		$string = addslashes ($text);
		$string = $this->stringUtils->urlEncodeQuotes ($string);
		$string = $this->stringUtils->newlinesToHtml ($string);

		$resultString  = 'onmouseover="return overlib(\'';
		$resultString .= $string;
		$resultString .= "', WIDTH, '";
		$resultString .= $this->stringUtils->urlEncodeQuotes(addslashes (300));
		$resultString .= "', CAPTION, '";
		$resultString .= $this->stringUtils->urlEncodeQuotes(addslashes ($title)) . '\');" ';
		$resultString .= 'onmouseout="return nd();" ';
		return $resultString;
	}

	/**
	 * Renders the sort arrows
	 *
	 * @param string sortField the field on which we would like
	 * to sort
	 * @param integer parentId the current parentId
	 */
	function sortArrows($sortField, $parentId)
	{
		$resultString = '&nbsp;';
		$resultString .= '<a href="'.$this->configuration['callback'];
		$resultString .= '?plugin='.$this->configuration['pluginName'];
		$resultString .= '&action=sort&order=ASC&field='.$sortField;
		$resultString .= '&parentId='.$parentId;
		if (isset ($_GET['order']) && $_GET['order'] == 'ASC' && $_GET['field'] == $sortField)
		{
			$resultString .= '">'.$this->configuration['icons']['up_arrow_shaded'].'</a>';
		}
		else
		{
			$resultString .= '">'.$this->configuration['icons']['up_arrow'].'</a>';
		}
		$resultString .= '<a align href="'.$this->configuration['callback'];
		$resultString .= '?plugin='.$this->configuration['pluginName'];
		$resultString .= '&action=sort&order=DESC&field='.$sortField;
		$resultString .= '&parentId='.$parentId;
		if (isset ($_GET['order']) && $_GET['order'] == 'DESC' && $_GET['field'] == $sortField)
		{
			$resultString .= '">'.$this->configuration['icons']['down_arrow_shaded'].'</a>';
		}
		else
		{
			$resultString .= '">'.$this->configuration['icons']['down_arrow'].'</a>';
		}
		return $resultString;
	}
}
?>
