<?php

require_once ('framework/ItemController.php');
require_once ('plugins/weather/model/WeatherServices.php');
require_once ('plugins/weather/model/WeatherPreferences.php');
require_once ('plugins/weather/model/WeatherFactory.php');
require_once ('plugins/weather/util/MetarTafParser.php');
/**
 * The Weather Controller
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Barry Nauta - April 2006
 * @package org.brim-project.plugins.weather
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class WeatherController extends ItemController
{
	var $weather;
	/**
	 * Constructor.
	 * Makes sure that the appropriate operations are instantiated.
	 */
	function WeatherController ()
	{
		parent::ItemController ();
		$this->operations = new WeatherServices ();
		$this->preferences = new WeatherPreferences ();
		$this->itemFactory = new WeatherFactory ();

		$this->pluginName = 'weather';
		$this->title = 'Brim - Weather';
		$this->itemName = 'MetarTaf';

		$this->expandName = 'weatherExpand';
		$this->weather = new MetarTafParser ();
	}

	/**
 	 * Returns the actions defined for this item only
 	 *
 	 * @return array an array of item specific actions (like search, import etc.)
 	 */
	function getActions ()
	{
		$actions=array();

		// Actions
		$actions[0]['name']= 'actions';
		$actions[0]['contents'][]=
			array('href' => 'index.php?plugin=weather&action=add&parentId='.$this->getParentId (),
			'name' => 'add');
		$actions[0]['contents'][]=
			array ('href'=>'index.php?plugin=weather&action=multipleSelectPre&parentId='.$this->getParentId(),
			'name'=>'multipleSelect');
		$actions[0]['contents'][]=
			array('href' => 'index.php?plugin=weather&action=search',
			'name' => 'search');

		//
		// If we are simply 'viewing' an item, add 'modify' as action
		// to the action list
		//
		if ($this->renderEngine->getTokens ('viewAction') == 'show')
		{
			$actions[0]['contents'][]= array (
			'href'=>'index.php?plugin=weather&action=modify&itemId='.$this->itemId,
			'name'=>'modify');
		}

		// View
		$actions[1]['name']= 'view';
		$actions[1]['contents'][]=
			array('href' => 'index.php?plugin=weather&expand=*',
			'name' => 'expand');
		$actions[1]['contents'][]=
			array('href' => 'index.php?plugin=weather&expand=0',
			'name' => 'collapse');
		$actions[1]['contents'][] =
			array('href' => 'index.php?plugin=weather&action=setModePublic&parentId='.$this->getParentId (),
			'name' => 'setModePublic');
		$actions[1]['contents'][] =
			array('href' => 'index.php?plugin=weather&action=setModePrivate&parentId='.$this->getParentId (),
			'name' => 'setModePrivate');

		// Preferences
		$actions[2]['name']= 'preferences';
		$actions[2]['contents'][]=
			array ('href'=>'index.php?plugin=weather&action=modifyPreferencesPre',
			'name'=>'modify');

		$actions[3]['name']='help';
		$actions[3]['contents'][]=
				array ('href'=>'index.php?plugin=weather&action=help',
						'name'=>'help'
													               );
		return $actions;
	}

	/**
	 * Activate. Basically this means that the appropriate actions
	 * are executed and an optional result is returned
	 * to be processed/displayed
	 */
	function activate ()
	{
		switch ($this->getAction ())
		{
			case "help":
				$this->helpAction ();
				break;
			case "add":
				$this->addAction ();
				break;
			case "modify":
				$this->modifyAction ();
				break;
			case "showItem":
				$this->showAction ();
				break;
			case "deleteItemPost":
				$this->deleteItemAction ();
				$this->getShowItemsParameters ();
				break;
			case "move":
				$this->moveAction ();
				break;
			case "moveItem":
				$this->moveItemAction ();
				$this->getShowItemsParameters ();
				break;
			// Added by Michael. Default navigation mode.
			case "setModePublic":
				$_SESSION['navigationMode']='public';
				$this->navigationMode ='public';
				$this->getShowItemsParameters ();
				break;
			case "setModePrivate":
				$_SESSION['navigationMode']='private';
				$this->navigationMode ='private';
				$this->getShowItemsParameters ();
				break;
			case "multipleSelectPre":
				$_SESSION['weatherExpand']='*';
				$this->multipleSelectAction ();
				break;
			case "multipleSelectPost":
				$itemIds = array_keys ($_POST, "itemId");
				if (isset ($_POST['move']))
				{
					$this->moveMultipleAction ($itemIds);
				}
				else if (isset ($_POST['delete']))
				{
					foreach ($itemIds as $itemId)
					{
						$this->operations->deleteItem ($this->getUserName (), $itemId);
					}
					$this->getShowItemsParameters ();
				}
				break;
			case "moveMultipleItemsPost":
				$itemIds = explode (",", $_GET['itemIds']);
				$parentId = $_GET['parentId'];
				foreach ($itemIds as $itemId)
				{
					$this->operations->moveItem ($this->getUserName (), $itemId, $parentId);
				}
				$this->getShowItemsParameters ();
				break;
			case "searchWeather":
				$this->searchItemAction();
				break;
			case "search":
				$this->renderer = $this->getAction().'Weather';
				break;
                        case "addAndAddAnother":
                                $this->addItemAction ();
                                unset ($this->renderObjects);
                                $this->addAction ();
                                break;
			case "addItemPost":
				$this->addItemAction();
				break;
			case "refresh":
				//
				// Basically, a refresh is a modify
				//
				$item = $this->operations->getItem ($userId, $this->itemId);
				$this->operations->modifyItem ($this->getUserName(), $item);
				$this->getShowItemsParameters ();
				break;
			case "modifyItemPost":
				$this->modifyItemAction();
				$this->getShowItemsParameters ();
				break;
			case "modifyPreferencesPre":
				$this->renderObjects =
					$this->preferences->getAllPreferences ($this->getUserName ());
				$this->renderer = 'modifyPreferences';
				break;
			case "modifyPreferencesPost":
				$this->preferences->setPreference ($this->getUserName (), $_POST['name'], $_POST['value']);
				$_SESSION['weatherOverlib']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'weatherOverlib');
				$_SESSION['weatherYahooTreeColumnCount']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'weatherYahooTreeColumnCount');
				$_SESSION['brimWeatherTemperatureUnits']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'brimWeatherTemperatureUnits');
				$_SESSION['brimWeatherSpeedUnits']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'brimWeatherSpeedUnits');
				$this->renderer = 'modifyPreferences';
				$this->renderObjects=$_SESSION;
				break;
			default:
				if (!isset ($_SESSION['weatherOverlib']))
				{
					$_SESSION['weatherOverlib']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'weatherOverlib');
				}
				if (!isset ($_SESSION['weatherYahooTreeColumnCount']))
				{
					$_SESSION['weatherYahooTreeColumnCount']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'weatherYahooTreeColumnCount');
				}
				if (!isset ($_SESSION['brimWeatherTemperatureUnits']))
				{
					$_SESSION['brimWeatherTemperatureUnits']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'brimWeatherTemperatureUnits');
				}
				if (!isset ($_SESSION['brimWeatherSpeedUnits']))
				{
					$_SESSION['brimWeatherSpeedUnits']=
						$this->preferences->getPreferenceValue ($this->getUserName (), 'brimWeatherSpeedUnits');
				}
				$this->getShowItemsParameters ();
				break;
			}
	}

	/**
	 * Gets the items that need to be shown at this moment
	 * (based on parentId etc) and additionally checks whether
	 * the information retrieved from the database needs an update
	 */
	function getShowItemsParameters ()
	{
		parent::getShowItemsParameters ();
		$items = $this->renderObjects;
		for ($i=0; $i<count ($items); $i++)
		{
			$item = $items[$i];
			$item = $this->updateItemIfNecessary ($userId, $item);			
			$items[$i]=$item;
		}
		$this->renderObjects = $this->addWeatherInformation ($items);
	}

	/**
	 * Adds weather information (i.e. parsing of the metar information)
	 * to the objects and returns these objects with the added weather
	 * information
	 *
	 * @param array  $objects
	 * @return array
	 */
	function addWeatherInformation ($objects)
	{
		//
		// Loop over all objects
		//
		for ($i=0; $i<count ($objects); $i++)
		{
			$object = $objects [$i];
			if ($object->isParent)
			{
				//
				// Recurse if parent
				//
				$children = $this->operations->getChildren
					($this->getUsername(), $object->itemId);
				for ($j=0; $j<count ($children); $j++)
				{
					$child = $children [$j];
					$this->addWeatherInformation (array ($child));
				}
			}
			else
			{
				// 
				// Item: parse metar
				//
				$object->metarInfo = 
					$this->weather->parse ($object->metar, 'metar');
				$object->tafInfo = 
					$this->weather->parse ($object->metar, 'taf');
				$objects [$i] = $object;
			}
		}
		return $objects;
	}
	
	/**
	 * Checks when an item was last observed and updates the item
	 * if its last checked information is older than one hour
	 *
	 * @param string $userId
	 * @param object $item
	 * @return object
	 * 
	 * @todo BIG QUESTION: should this functionality be here or in the
	 * Services.... 
	 */
	function updateItemIfNecessary ($userId, $item)
	{
		//
		// Upon item retrieval, check for the last observed
		// time and if this is more than one hour ago, 
		// update (the modifyItem takes care of this)
		//
		$time = time ();
		// Time in Z??? date ('Z', $time)?
		$oneHourAgo = strtotime (date ('Y-m-d H:i:s', $time)) - (1*60*60);
		if (!isset ($item->whenUpdated) || !isset ($item->metar) || 
			!isset ($item->taf) || strtotime ($item->whenUpdated) < $oneHourAgo) 
		{
			$item->whenUpdated = date ('Y-m-d H:i:s', $time);
			$this->operations->modifyItem ($userId, $item);
		}
		return $this->operations->getItem ($userId, $item->itemId);
	}
}
?>
