<?php

require_once ('framework/util/StringUtils.php');
require_once ('framework/model/Item.php');

/**
 * A Metar item
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Barry Nauta - April 2006
 * @package org.brim-project.plugins.weather
 * @subpackage model
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class MetarTaf extends Item
{

	/**
	 * This Metar/Taf's station (ICAO code)
	 *
	 * @var string
	 */
	var $station;
	
	/**
	 * The Metar as retrieved from the web. This string needs to be 
	 * parsed 
	 * 
	 * @var string
	 */
	var $metar;
	
	/**
	 * When was this item last observed?
	 */
	var $metarObserved;
	
	/**
	 * When was this item last updated (i.e. metar data stored in db)?
	 */
	var $metarUpdated;
	
	/**
	 * The Taf as retrieved from the web. This string needs to be 
	 * parsed 
	 * 
	 * @var string
	 */
	var $taf;
	
	/**
	 * When was this item last observed?
	 */
	var $tafObserved;
	
	/**
	 * When was this item last updated (i.e. taf data stored in db)?
	 */
	var $tafUpdated;
	
	/**
	 * Info, parsed from the Metar string
	 */
	var $metarInfo;
	
	/**
	 * Info, parsed from the Taf string
	 */
	var $tafInfo;
	
	/**
 	 * Full blown constructor
	 *
	 * @param integer theItemId the itemId
	 * @param string theOwner the owner
	 * @param integer theParentId the identifier of the parent
	 * @param boolean parent is this a parent yes or no?
	 * @param string theName the name of this item
	 * @param string theDescription the decription
	 * @param string theVisibility private or public
	 * @param string theCategory the category
	 * @param boolean deleted is this item marked as deleted?
	 * @param string theCreation when was this item created?
	 * @param string theModified when was this item last modified?
	 * @param string theStation the station (ICAO code)
	 * @param string theMetar the metar code
	 * @param date theMetarObserved when was this metar last observed?
	 * @param date theMetarUpdated when was this metar last updated?
	 * @param string theTafthe taf code
	 * @param date theTafObserved when was this taf last observed?
	 * @param date theTafUpdated when was this taf last updated?
	 */
	function MetarTaf ($theItemId, $theOwner, $theParentId, $parent,
		$theName, $theDescription,
		$theVisibility, $theCategory, $deleted,
		$theCreation, $theModified, 
		$theStation, $theMetar, $theMetarObserved, $theMetarUpdated,
		$theTaf, $theTafObserved, $theTafUpdated)
	{
		parent :: Item ($theItemId, $theOwner, $theParentId, $parent,
				$theName, $theDescription, $theVisibility,
				$theCategory, $deleted, $theCreation, $theModified);
				
		$this->station = $theStation;
		$this->metar = $theMetar;
		$this->metarObserved = $theMetarObserved;
		$this->metarUpdated = $theMetarUpdated;
		$this->taf = $theTaf;
		$this->tafObserved = $theTafObserved;
		$this->tafUpdated = $theTafUpdated;
		$this->type = "MetarTaf";
	}
	
	/**
	 * Checks whether the constructed item is a valid item (has all the
	 * required fields)
	 *
	 * @return boolean <code>true</code> if the item is valid,
	 * <code>false</code> otherwise
	 */
	function isValid ()
	{
		if (!$this->isParent)
		{
			return $this->name != null && $this->station != null;
		}
		else 
		{
			return $this->name != null;
		}
	}
}
?>