<?php

require_once ('framework/model/Services.php');
require_once ('plugins/weather/model/MetarTaf.php');
require_once ('plugins/weather/model/WeatherFactory.php');
require_once ('plugins/weather/util/MetarTafParser.php');

/**
 * Operations on Metar's/Taf's
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Barry Nauta - April 2006
 * @package org.brim-project.plugins.weather
 * @subpackage model
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class WeatherServices extends Services
{
	/**
	 * The actual parser
	 *
	 * @var object
	 */
	var $metarTafParser;
	
	/**
 	 * Default constructor
	 */
	function WeatherServices ()
	{
		parent::Services();
		$this->itemFactory = new WeatherFactory ();

		$queries = array ();
		include ('plugins/weather/sql/weatherQueries.php');
		$this->queries = $queries;
		
		$this->metarTafParser = new MetarTafParser ();
	}

	/**
	 * Adds weather information for a user
	 *
	 * @param integer userId the identifier for the user
	 * @param object item the item to be added
	 *
     * @return integer last know id. This is the id of the item
	 * that was newly inserted and for which an id has automatically
	 * been assigned.
	 */
	function addItem ($userId, $item)
	{
		$now = date ("Y-m-d H:i:s");
		$metar = $this->metarTafParser->getMetarTafFromWeb ($item->station, 'metar');
		$taf = $this->metarTafParser->getMetarTafFromWeb ($item->station, 'taf');
		//die (print_r ($metar));

		// Brussels. Clear visibility. No rain, Broken clouds
		// $metar ['metar'] = 'EBBR 071050Z 26008KT 230V300 9999 BKN022 09/03 Q1016 NOSIG';
		// Overcast and light rain
		// $metar ['metar'] = 'EGKK 111150Z 24018KT 8000 -RA SCT012 OVC015 12/10 Q0984 RETS';
		
		//$metar ['metar'] = 'EBBR 141120Z 28010KT 260V320 9999 FEW025 BKN040 13/04 Q1013 NOSIG';
		//$metar ['observed'] = '2006 18 04 12:00';
		//$result = $this->metarTafParser->parse ($metar['metar'], 'metar');
		$query  = sprintf ($this->queries['addItem'],
			$userId,
			addslashes ($item->parentId),
			addslashes ($item->isParent),
			addslashes ($item->name),
			addslashes ($item->description),
			addslashes ($item->visibility),
			addslashes ($item->category),
			$now,
			addslashes ($item->station),
			$metar['metar'],
			$metar['metarObserved'],
			$now,
			$taf['taf'],
			$taf['tafObserved'],
			$now);
		$result = $this->db->Execute($query)
			or die("AddWeather: " . $this->db->ErrorMsg() . " " . $query);
		$item->info = $result;
	}

	/**
	 * Modifies a metar.
	 *
 	 * @param integer userId the identifier for the user who modifies a metar
	 * @param object item the modified metar
	 */
	function modifyItem ($userId, $item)
	{

		$now = date ("Y-m-d H:i:s");
		$metar = $this->metarTafParser->getMetarTafFromWeb ($item->station, 'metar');
		if (!isset ($metar))
		{
			//
			// No information could be retrieved. Keep the existing
			//
			$metar = array ();
			$metar ['metar'] = $item->metar;
			$metar ['metarObserved'] = $item->metarObserved;
		}
		$taf = $this->metarTafParser->getMetarTafFromWeb ($item->station, 'taf');
		if (!isset ($taf))
		{
			//
			// No information could be retrieved. Keep the existing
			//
			$taf = array ();
			$taf ['taf'] = $item->taf;
			$taf ['tafObserved'] = $item->tafObserved;
		}
		$query  = sprintf ($this->queries['modifyItem'],
			$now,
			addslashes ($item->name),
			addslashes ($item->visibility),
			addslashes ($item->description),
			addslashes ($item->parentId),
			$item->isDeleted,
			addslashes ($item->station),
			$metar ['metar'],
			$metar ['metarObserved'],
			addslashes ($item->metarUpdated),
			$taf ['taf'],
			$taf ['tafObserved'],
			addslashes ($item->tafUpdated),
			$item->itemId) ;
		$result = $this->db->Execute($query)
			or die("ModifyWeather: " . $this->db->ErrorMsg() . " " . $query);
	}
}
?>
