<?php

/**
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Barry Nauta - April 2006
 * @package org.brim-project.plugins.notes
 * @subpackage sql
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */

class ICAOUtils
{
	/**
	 * Default constructur
	 *
	 * @return ICAOUtils
	 */
	function ICAOUtils ()
	{
	}
	
	/**
	 * Returns an array of countries in the form of
	 * 
	 * <pre>
	 * $countries ['nl'] = 'Netherlands';
	 * </pre>
	 * 
	 * @return array
	 */
	function getCountryList ()
	{
		include 'plugins/weather/util/include/countries.php';
		return $countries;
	}
	
	/**
	 * Returns the country for a countryCode.
	 * 
	 * Example:
	 * countryCode 'nl' will return 'Netherlands'
	 *
	 * @param string $countryCode
	 * @return string
	 */
	function getCountryForCountryCode ($countryCode)
	{
		$countries = $this->getCountryList ();
		return $countries [$countryCode];
	}
	
	/**
	 * Returns an array of stations for the specified country code
	 * 
	 * As an exmaple: for countryCode 'nl', the following subset is 
	 * returned:
	 * 
	 * <pre>
	 * $icao ['nl'] ['EHAM'] = 'Schiphol, Amsterdam';
	 * $icao ['nl'] ['EHBD'] = 'Budel, Weert';
	 * etc...
	 * </pre>
	 * 
	 * @param string $country
	 * @return array
	 */
	function getStationsForCountryCode ($countryCode)
	{
		include 'plugins/weather/util/include/icao_'.$countryCode.'.php';
		return $icao;
	}
	
	/**
	 * Returns the country code for the specified icao code
	 * or 'null' if not found
	 * 
	 * Example:
	 * 'EBBR' (Brussels National Airport) will return 'be'
	 * (Belgium)
	 *
	 * @param string $stationCode
	 * @return string
	 */
	function getCountryCodeForICAOCode ($stationICAOCode)
	{
		$result = array ();
		$countries = $this->getCountryList ();
		
		foreach ($countries as $countryKey => $countryValue)
		{
			unset ($icao);
			include 'plugins/weather/util/include/icao_'.$countryKey.'.php';
			foreach ($icao [$countryKey] as $countryCode => $icaoCode)
			{
				$result [$countryCode] = $countryKey;
			}
		}
		if (!isset ($result[$stationICAOCode]))
		{
			return null;
		}
		return $result [$stationICAOCode];
	}
	
	/**
	 * Gets the station name for the specified ICAO code
	 * or 'null' if not found
	 * 
	 * Example:
	 * 'EBBR' (Brussels National Airport) will 
	 * returm 'Brussels Intl.'
	 *
	 * @param unknown_type $stationCode
	 * @return unknown
	 */
	function getStationForICAOCode ($stationCode)
	{
		$country = $this->getCountryCodeForICAOCode ($stationCode);
		if (isset ($country))
		{
			include 'plugins/weather/util/include/icao_'.$country.'.php';
			return $icao [$country][$stationCode];
		}
		return null;
	}
	
	/**
	 * Returns the country name for the specified icao code
	 * or 'null' if not found
	 * 
	 * Example:
	 * 'EBBR' (Brussels National Airport) will return Belgium
	 *
	 * @param string $stationCode
	 * @return string
	 * @see getCountryCodeForICAOCode
	 */
	function getCountryForICAOCode ($stationCode)
	{
		$country = $this->getCountryCodeForICAOCode ($stationCode);
		if (isset ($country))
		{
			return $this->getCountryForCountryCode($country);
		}
		return null;
	}
}
?>