<?php

require_once ("framework/util/StringUtils.php");
require_once ('framework/view/TreeDelegate.php');
require_once ('plugins/weather/util/MetarTafHelper.php');
require_once ('plugins/weather/util/ICAOUtils.php');
/**
 * Used in combination with the Tree class
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Barry Nauta - April 2006
 * @package org.brim-project.plugins.weather
 * @subpackage view
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class WeatherYahooTreeDelegate extends TreeDelegate
{
	var $helper;
	var $icao;
	/**
	 * Default constructor
	 */
	function WeatherYahooTreeDelegate ($theConfiguration)
	{
		parent::TreeDelegate ($theConfiguration);
		$this->helper = new MetarTafHelper ();
		$this->icao = new ICAOUtils ();
	}

	/**
	 * Builds up html code to display the root of the tree
	 * @private
	 *
	 * @param object item the item that is the root of the tree
	 */
	function showRoot ($item, $tree)
	{
		if (isset($item) && isset ($item->itemId) && $item->itemId != 0)
		{
			$resultString = '<h2>'.$item->name.'</h2>';
			$resultString .= '<a href="'.$this->configuration['callback'];
			$resultString .= '&action=show&parentId='.$item->parentId.'">';
			$resultString .= $this->configuration['icons']['up'];
			$resultString .= '</a><br />';
		}
		else
		{
			$resultString = '';
		}
		return $resultString;
	}

	/**
	 * If the specified item is a folder, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean isExpanded whether this folder is expanded (i.e. do the
	 * children of this folder need to be displayed as well?)
	 * @param object tree the tree that uses this class as delegate
	 * @return string the string for this folder
	 */
	function drawFolder ($item, $isExpanded, $tree, $indentLevel)
	{
		$resultString = '<a href="';
		$resultString .= $this->configuration['callback'];
        $resultString .= '&action=modify&itemId='.$item->itemId;
        $resultString .= '&parentId='.$item->parentId.'">';
		$resultString .= $this->configuration['icons'] ['folder_closed'];
		$resultString .= '</a>';

		$resultString .= '<a href="';
		$resultString .= $this->configuration['callback'];
		$resultString .= '&action=show&parentId=';
		$resultString .= $item->itemId . '">';
		$resultString .= $item->name;
		$resultString .= '</a>';

		$resultString .= '<br />';
		return $resultString;
	}


	/**
	 * If the specified item is a node, draw it
	 * @private
	 * @param object item the item to draw
	 * @param boolean lastNode whether this node is the last one
	 * @return string the string for this node
	 */
	function drawNode ($item, $lastNode, $tree, $indentLevel)
	{
		$resultString = '';
		$resultString .= '
						 <table border="0" valign="top" width="200" cellpadding="0" cellspacing="0" ';
		$resultString .= 'bgcolor="#ffffff">
';
		//
		// First row with name and delete, update and modify icons
		//
		$resultString .= '<tr class="menu"><td colspan="3" class="menu">
';
		//
		// Name with optional overlib
		// Column 0, 1 & 2
		//
		$resultString .= '<a href="" ';
		if ($this->configuration['overlib'])
		{
			$resultString .= $this->overLib ($item);
		}
		$resultString .= '>';
		$resultString .= '<b>'.$this->stringUtils->truncate ($item->name, 30). '</b></a>';
		$resultString .= '</td>
';
		//
		// Refresh
		// Column 3
		//
		$resultString .= '<td width="20" align="right" class="menu">';
		$resultString .= '<a href="'.$this->configuration['callback'];
        $resultString .= '&action=refresh&itemId='.$item->itemId;
        $resultString .= '">';
		$resultString .= $this->configuration['icons']['refresh'].'</a>';
		$resultString .= '</td>
';
		//
		// Edit
		// Column 4
		//
		$resultString .= '<td width="20" align="right" class="menu">';
		$resultString .= '<a href="'.$this->configuration['callback'];
        $resultString .= '&action=modify&itemId='.$item->itemId;
        $resultString .= '&parentId='.$item->parentId.'">';
		$resultString .= $this->configuration['icons']['edit'].'</a>';
		$resultString .= '</td>
';
		//
		// Delete
		// Column 5
		//
		$resultString .= '<td width="20" align="right" class="menu">';
		$resultString .= '<a href="'.$this->configuration['callback'];
		$resultString .= '&itemId='.$item->itemId;
		$resultString .= '&parentId='.$item->parentId;
		$resultString .= '&action=deleteItemPost" ';
		//
		// delete confirmation
		//
		$resultString .= 'onclick="javascript:return confirm (\'';
		$resultString .= $this->configuration['dictionary']['confirm_delete'];
		$resultString .= '\');" ';

		$resultString .= '>'.$this->configuration['icons']['delete'].'</a>';
		$resultString .= '</td></tr>
';
		//
		// New row with observation date
		//
		$resultString .= '<tr><td colspan="6">';
		if (isset ($item->metarObserved) && ($item->metarObserved != '0000-00-00 00:00:00'))
		{
			$resultString .= '('.date ('d/m H:i', strtotime ($item->metarObserved)).')';
		}
		$resultString .= '</td></tr>
';
		//
		// Third row with weather icons
		//
		$resultString .= '<tr>';
		//
		// Weather icon
		//
		$resultString .= '<td>';
		$resultString .= '<img src="plugins/weather/view/pics/';
		$resultString .= $this->helper->transformWeatherInformationToWeatherIcon ($item->metarInfo).'">';
		$resultString .= '</td>
';
		// 
		// Temperature icon
		//
		$resultString .= '<td>';
		$resultString .= '<img src="plugins/weather/view/pics/';
		$resultString .= $this->helper->transformWeatherInformationToTemperatureIcon ($item->metarInfo).'">';
		$resultString .= '</td>
';
		//
		// Wind icon
		//
		$resultString .= '<td>';
		$resultString .= '<img src="plugins/weather/view/pics/';
		$resultString .= $this->helper->transformWeatherInformationToWindIcon ($item->metarInfo).'">';
		$resultString .= '</td>
';
		$resultString .= '<td colspan="3">';
		//
		// Text
		//
		$resultString .= $this->configuration ['dictionary']['tempOneCharAbbreviation'].':&nbsp;';
		if ($_SESSION['brimWeatherTemperatureUnits']=='celsius')
		{
			$resultString .= '<b>';
			if (isset ($item->metarInfo['temperature']['temperature']))
			{
				$resultString .= $item->metarInfo['temperature']['temperature'];
			}
			else 
			{
				$resultString .= '?';
			}
			$resultString .= '&#0186;C</b>';
		}
		else 
		{
			$resultString .= '<b>';
			if (isset ($item->metarInfo['temperature']['temperature']))
			{
				$resultString .= (1.8 * ($item->metarInfo['temperature']['temperature']))+32;
			}
			else 
			{
				$resultString .= '?';
			}
			$resultString .= '&#0186;F</b>';

		}
		$resultString .= '<br />
';
		$resultString .= $this->configuration ['dictionary']['windOneCharAbbreviation'].':&nbsp;';
		$resultString .= $item->metarInfo['wind']['speed'].'&nbsp;'.$item->metarInfo['wind']['units'];
		if (isset ($item->metarInfo['variableWind']) || isset ($item->metarInfo['wind']['direction']))
		{
			$resultString .= '<br />
';
			$resultString .= $this->configuration ['dictionary']['directionOneCharAbbreviation'].':&nbsp;';
			if ($item->metarInfo ['wind']['direction'] == 'VRB')
			{
				$resultString .= $this->configuration ['dictionary']['variable'];
			}
			else 
			{
				$resultString .= $item->metarInfo ['wind']['direction'].'&nbsp;';
				$resultString .= '('.$item->metarInfo['wind']['directionCompass'].')';
			}
			if (isset ($item->metarInfo['variableWind']))
			{	
				$resultString .= '<br /><font size="-2">&nbsp;&nbsp;&nbsp;';
				// Variable wind direction is optinal
				$resultString .= $item->metarInfo['variableWind']['from'].'&nbsp;';
				$resultString .= '('.$item->metarInfo['variableWind']['fromCompass'].')';
				$resultString .= '&nbsp;=&gt;&nbsp;';
				$resultString .= $item->metarInfo['variableWind']['to'].'&nbsp;';
				$resultString .= '('.$item->metarInfo['variableWind']['toCompass'].')';
				$resultString .= '</font>';				
			}
		}
		
		$resultString .= '</td>';
		$resultString .= '</tr>';
		//
		// New row with station information
		//
		$resultString .= '<tr>';
		$resultString .= '<td colspan="3">';
		$station = str_replace(', ','<br />',
			$this->icao->getStationForICAOCode ($item->station));
		$resultString .= $station;
		$resultString .= '<br />';
		$resultString .= '<a href="http://en.wikipedia.org/wiki/ISO_3166-1:';
		$resultString .= strtoupper($this->icao->getCountryCodeForICAOCode ($item->station));
		$resultString .= '">'.$this->icao->getCountryForICAOCode ($item->station).'</a>';
		$resultString .= '</td>';
		$resultString .= '<td colspan="3">';
		$resultString .= '<br/><a href="http://weather.noaa.gov/pub/data/observations/metar/stations/'.$item->station.'.TXT"';
		$resultString .= '><b>'.$item->station.'</b></a>';
		$resultString .= '<br /><a href="ftp://weather.noaa.gov/data/observations/metar/decoded/'.$item->station.'.TXT"';
		$resultString .= '>('.$this->configuration ['dictionary']['decoded'].')</a>';
		$resultString .= '</td>';
		$resultString .= '</tr>';
/*		$resultString .= '<tr>';
		$resultString .= '<td colspan="6">';
		$resultString .= var_export ($item, true);
		$resultString .= '</td>';
		$resultString .= '</tr>';
*/		$resultString .= '</table>';

		return $resultString;
	}
	
	function overLib ($item)
	{
		$text = $this->helper->getInfoAsHtml 
			($item->metarInfo, $this->configuration['dictionary']);
		return parent::overLib ($item->name, $text);
	}
}
?>
