<?php

require_once ('framework/Controller.php');
require_once ('framework/util/StringUtils.php');

/**
 * The Webtools Controller
 *
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Barry Nauta - March 2004
 * @package org.brim-project.plugins.webtools
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
class WebtoolsController extends Controller
{
	/**
	 * String manipulation utilities
	 *
	 * @var object stringUtils
	 */
	var $stringUtils;

	/**
	 * Constructor.
	 * Makes sure that the appropriate operations are instantiated.
	 */
	function WebtoolsController ()
	{
		parent::Controller ();
		$this->pluginName = 'webtools';
		$this->title = 'Brim - Webtools';
		$this->itemName = 'Webtools';
		$this->stringUtils = new StringUtils ();
	}


	/**
 	 * Returns the actions defined for this item only
 	 *
 	 * @return array an array of item specific actions
 	 */
	function getActions ()
	{
		/*
		 * Views
		 */
		$actions[0]['name'] = 'actions';
			$actions[0]['contents'][] = array
				(
					'href'=>'index.php?plugin=webtools&action=rot13',
					'name'=>'rot13'
				);
			$actions[0]['contents'][] = array
				(
					'href'=>'index.php?plugin=webtools&action=units',
					'name'=>'units'
				);
			$actions[0]['contents'][] = array
				(
					'href'=>'index.php?plugin=webtools&action=calculator',
					'name'=>'calculator'
				);
		$actions[1]['name'] = 'web';
			$actions[1]['contents'][] = array
				(
					'href'=>'index.php?plugin=webtools&action=urlCode',
					'name'=>'urlCode'
				);
			$actions[1]['contents'][] = array
				(
					'href'=>'index.php?plugin=webtools&action=htmlEscapeCodes',
					'name'=>'htmlEscapeCodes'
				);
			$actions[1]['contents'][] = array
				(
					'href'=>'index.php?plugin=webtools&action=characterEntities',
					'name'=>'characterEntities'
				);
			$actions[1]['contents'][] = array
				(
					'href'=>'index.php?plugin=webtools&action=subnetCalculator',
					'name'=>'subnetCalculator'
				);
		//}

		//
		// Colors
		//
		$actions[2]['name'] = 'colors';
			$actions[2]['contents'][] = array
				(
					'href'=>'index.php?plugin=webtools&action=colorCodes',
					'name'=>'colorCodes'
				);
/*
			$actions[2]['contents'][] = array
				(
					'href'=>'index.php?plugin=webtools&action=colorWheel',
					'name'=>'colorWheel'
				);
*/
			$actions[2]['contents'][] = array
				(
					'href'=>'index.php?plugin=webtools&action=namedColors',
					'name'=>'namedColors'
				);
			$actions[2]['contents'][] = array
				(
					'href'=>'index.php?plugin=webtools&action=colorMatch',
					'name'=>'colorMatch'
				);
		$actions[3]['name']='system';
			$actions[3]['contents'][] = array
				(
					'href'=>'index.php?plugin=webtools&action=asciiTable',
					'name'=>'ascii_table'
				);
			$actions[3]['contents'][] = array
				(
					'href'=>'index.php?plugin=webtools&action=md5',
					'name'=>'md5'
				);
			$actions[3]['contents'][] = array
				(
					'href'=>'index.php?plugin=webtools&action=base64',
					'name'=>'base64'
				);
			$actions[3]['contents'][] = array
				(
					'href'=>'index.php?plugin=webtools&action=hexdec',
					'name'=>'hexdec'
				);
			$actions[3]['contents'][] = array
				(
					'href'=>'index.php?plugin=webtools&action=chmod',
					'name'=>'chmod'
				);
			$actions[3]['contents'][] = array
				(
					'href'=>'index.php?plugin=webtools&action=byteConversion',
					'name'=>'byteConversion'
				);
		$actions[4]['name']='help';
		$actions[4]['contents'][]=
				array ('href'=>'index.php?plugin=webtools&action=help',
						'name'=>'help'
		);
		return $actions;
	}

	/**
	 * Activate. Basically this means that the appropriate actions
	 * are executed and an optional result is returned
	 * to be processed/displayed
	 */
	function activate ()
	{
		switch ($this->getAction ())
		{
			// Modified by Michael. I wonder if this "directAction" I added is not nonsens...
			case "rot13":
				$this->renderer = 'rot13';
				if (isset ($_POST['inputString']))
				{
					$theString =
						$this->stringUtils->gpcStripSlashes ($_POST['inputString']);
					$this->renderEngine->assign (
						'inputString', $theString);
					$this->renderEngine->assign (
						'rotatedInput',
						$this->rotate13($theString));
				}
				break;
			case "help":
				$this->helpAction();
				break;
			case "chmod":
			case "base64":
			case "md5":
			case "hexdec":
			case "byteConversion":
			case "namedColors":
			case "colorWheel":
			case "characterEntities":
			case "htmlEscapeCodes":
			case "asciiTable":
			case "extendedAsciiTable":
			case "colorCodes":
			case "units":
			case "calculator":
				$this->renderer = $this->getAction ();
				break;
			case "colorMatch":
				if (isset ($_POST['requestedColor']))
				{
					$this->renderObjects = $_POST['requestedColor'];
				}
				$this->renderer = 'colorMatch';
				break;
			case "subnetCalculator":
				include ('plugins/webtools/model/SubnetCalculator.php');
				$calculator = new SubnetCalculator ();
				if (isset ($_POST['address']))
				{
					$this->renderObjects =
						$calculator->calculate ($_POST['address']);
				}
				$this->renderer = 'subnetCalculator';
				break;
			case "setModePublic":
				$_SESSION['navigationMode']='public';
				$this->navigationMode ='public';
				break;
			case "setModePrivate":
				$_SESSION['navigationMode']='private';
				$this->navigationMode ='private';
				break;
			case "modifyPreferencesPre":
				$this->renderObjects =
					$this->preferences->getAllPreferences ($this->getUserName ());
				$this->renderer = 'modifyPreferences';
				break;
			case "modifyPreferencesPost":
				$this->preferences->setPreference ($this->getUserName (), $_POST['name'], $_POST['value']);
				break;
			case "urlCode":
				$this->renderer = 'urlCode';
				if (isset ($_POST['whichWay']))
				{
					$inputString = $_POST['inputString'];
					if ($_POST['whichWay'] == 'decode')
					{
						$resultString = urldecode ($inputString);
					}
					else
					{
						$resultString = urlencode ($inputString);
					}
					$this->renderEngine->assign ('inputString', $inputString);
					$this->renderEngine->assign ('resultString', $resultString);
				}
				//die ('encode');
				break;
			default:
				$this->renderer = 'blank';
				break;
		}
	}

	/**
	 * Display which basically means that the template will be invoked
	 */
	function displayObsolete ()
	{
		global $menuItems, $menu;

		$this->renderEngine->assign('title', $this->getTitle ());
		$this->renderEngine->assign('menuItems', $menuItems);
		$this->renderEngine->assign('menu', $menu);
		$this->renderEngine->assign('dictionary', $this->getDictionary ());

		$this->renderEngine->assign('parameters',
			$this->getParameters ());
		$this->renderEngine->assign('action',
			$this->getAction ());
		$this->renderEngine->assign('renderActions',
			$this->getActions ());

		$this->renderEngine->assign ('pluginName', $this->pluginName);
		$this->renderEngine->assign ('renderer', $this->getTemplateFile ());
		if (isset ($_GET['debug']))
		{
			error_reporting(E_ALL);
			$this->renderEngine->display('templates/'.$this->getTemplate().'/template.tpl.php');
			// todo add more
		}
		else
		{
			error_reporting(E_ERROR);
			@$this->renderEngine->display('templates/'.$this->getTemplate().'/template.tpl.php');
		}
	}


	function rotate13 ($input)
	{
		if (!function_exists('str_rot13'))
		{
			$from = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
			$to  = 'nopqrstuvwxyzabcdefghijklmNOPQRSTUVWXYZABCDEFGHIJKLM';
			return strtr($input, $from, $to);
		}
		else
		{
			return str_rot13 ($input);
		}
	}

}
?>
