<?php
header("Content-Type: text/html; charset=utf-8");

/**
 * This file is part of the Brim project.
 * The brim-project is located at the following
 * location: {@link http://www.brim-project.org/ http://www.brim-project.org/}
 *
 * <pre> Enjoy :-) </pre>
 *
 * @author Barry Nauta
 * @package org.brim-project.templates
 * @subpackage text-only
 *
 * @copyright [brim-project.org] - Copyright (c) 2003 - 2006 Barry Nauta
 *
 * @license http://opensource.org/licenses/gpl-license.php
 * The GNU Public License
 */
 ?>
<html>
<head>
	<title><?php echo $dictionary['item_title'] ?></title>
	<!--
		The template stylesheet
	-->
	<style type="text/css" media="screen"
		>@import "templates/text-only/template.css";</style>
	<!--
		The plugins DEFAULT stylesheet (plugin specific styles end up 
		here so we can keep the main stylesheet generic
	-->
	<style type="text/css" media="screen"
		>@import "plugins/<?php echo ($pluginName); ?>/view/template.css";</style>
	<!--
		A plugin can also provide a specific stylesheet for a template.
		If this stylesheets exists, load it as well
	-->
<?php
	$style = 'templates/text-only/plugins/'.$pluginName.'/template.css';
	if (file_exists ($style))
	{
		echo ('<style type="text/css" media="screen"
		>@import "'.$style.'";</style>');
	}
?>

	<meta http-equiv="Content-Type" content="text/html;charset=UTF-8">
<!--
		content="text/html; charset=<?php echo $dictionary['charset'] ?>">		
-->

</head>
<body>
<!--
	Overlib, JavaScript popups
-->
<div id="overDiv" 
	style="position:absolute; visibility:hidden; z-index:1000;"></div>

<script language="JavaScript" src="ext/overlib/overlib.js"><!-- overLIB (c) Erik Bosrup --></script>
<script language="JavaScript" src="ext/overlib/overlib_fade.js"></script>
<script language="JavaScript" src="ext/overlib/overlib_bubble.js"></script>


<!--
	Generic Javascript functions
-->
<?php include 'templates/text-only/javascript.inc' ?>


<!--
	The plugin menu contains links to the activated plugins
	like bookmarks, contacts, etc...
-->
<div id="pluginMenu">
<?php
	foreach ($menuItems as $link)
	{
		echo ('<div class="pluginMenuLink">');
		echo ('<a href="'.$link['href'].'">'.$link['name'].'</a>');
		echo ('</div>');
	}
?>
</div>


<!--
	The application menu. Contains items like: preferences, logout,
	plugins (the menu to enable/disable them), about etc
-->
<div id="applicationMenu">
<?php
	$i=0;
	foreach ($menu as $link)
	{
		echo ('<span class="applicationMenuLink">');
		echo ('<a href="'.$link['href'].'">'.$link['name'].'</a>');
		echo ('</span>');
		
		//
		// I wonder... Can't this be done with a stylesheet param?
		//
		$i++;
		if ($i != count($menu))
		{
			echo ('&middot;');
		}
	}
?>
</div>

<!--
	The actual pane. The plugin provides information that
	will be displayed on this pane
-->
<div id="actionMenu">
<!--
	Show the logo
-->
<p class="applicationTitle"><a href="index.php">Brim</a></p>

<!--
	The title of the plugin we're currently using
-->
<p class="pluginTitle"><?php echo $dictionary['item_title']; ?></p>

<?php
	if (isset ($renderActions))
	{
		//
		// Render actions are labeled under a header 
		// like 'actions', 'view' etc
		//
		echo ('<div id="actions">');

		// 
		// Loop over each group
		//
		foreach ($renderActions as $actionGroup)
		{
			echo ('<p class="actionGroupTitle">');
			echo ($actionGroup['name']);
			echo ('</p>');

			// 
			// Loop over each item in the group
			//
			foreach ($actionGroup['contents'] as $action)
			{
					echo ('<div class="action">');
					echo ('<a href="'.$action['href']);
					echo ('">'.$action['name'].'</a>');
					echo ('</div>');
			}
		}
		echo ('<p class="copyright">');
		echo ('<a href="http://opensource.org/licenses/gpl-license.php">GPL</a> - ');
		echo ('Copyright (c) 2004 by<br />');
		echo ('<a href="mailto:barry@nauta.be">Barry Nauta</a>&nbsp;');
		echo ('<br /><a href="http://www.brim-project.org/"
			>Brim Homepage</a>');
		echo ('</p>');
		echo ('</div>');
	}
?>
</div>

<!--
	Now display the content provided by the plugin
-->
<div id="content">
	<?php include $renderer ?>
</div>


</body>
</html>
